<?php
/**
 * EAuthUserIdentity class file.
 *
 * @author Maxim Zemskov <nodge@yandex.ru>
 * @link http://github.com/Nodge/yii-eauth/
 * @license http://www.opensource.org/licenses/bsd-license.php
 */

/**
 * EAuthUserIdentity is a base User Identity class to authenticate with EAuth.
 *
 * @package application.extensions.eauth
 */
class BUserIdentity extends CBaseUserIdentity {

	const ERROR_NOT_AUTHENTICATED = 3;

    protected $isBlocked = false;
    protected $blockDate = '';

	/**
	 * @var EAuthServiceBase the authorization service instance.
	 */
	protected $service;

	/**
	 * @var string the unique identifier for the identity.
	 */
	protected $id;

	/**
	 * @var string the display name for the identity.
	 */
	protected $name;

	/**
	 * Constructor.
	 *
	 * @param EAuthServiceBase $service the authorization service instance.
	 */
	public function __construct($service) {
		$this->service = $service;
	}

	/**
	 * Authenticates a user based on {@link service}.
	 * This method is required by {@link IUserIdentity}.
	 *
	 * @return boolean whether authentication succeeds.
	 */
	public function authenticate() {
		if ($this->service->isAuthenticated) {
			$id = $this->service->getAttribute('id');
			$first_name = $this->service->getAttribute('firstname');
			$surname = $this->service->getAttribute('surname');
			$email = $this->service->getAttribute('email');
			$account_id = $this->service->getAttribute('account_id');

			$connection = Yii::app()->db;

			$user = $connection->createCommand('SELECT u.uid, i.status FROM {{users}} u INNER JOIN {{usersinfo}} i ON i.uid = u.uid WHERE u.mail = :email')
				->bindParam(":email", $email)
				->queryRow();
			if(!empty($user)){
                //Проверка блокировки
                $user_block = $connection->createCommand("SELECT uid, days, FROM_UNIXTIME(date_end, '%d.%m.%Y %h:%i') AS date_end FROM {{users_block}} WHERE uid = :uid AND date_end > :dt")->bindParam(":uid", $user['uid'])->bindValue(":dt", time())->queryRow();
                if(!empty($user_block)){
                    $this->isBlocked = true;
                    $this->blockDate = $user_block['date_end'];
                    $this->errorCode = self::ERROR_NOT_AUTHENTICATED;
                    return !$this->errorCode;
                }
				
				if($user['status'] == 0){
					$this->errorCode = self::ERROR_NOT_AUTHENTICATED;
					return !$this->errorCode;
				}
				
				$connection->createCommand("UPDATE {{usersinfo}} SET name = :name, fio = :fio WHERE uid = :uid")->bindParam(":uid", $user['uid'])->bindParam(":name", $first_name)->bindParam(":fio", $surname)->query();

				$this->id = $user['uid'];
				$this->name = $email;

				$this->setState('id', $this->id);
				$this->setState('name', $this->name);
				$this->setState('service', $this->service->serviceName);
                Yii::app()->session->setUserId($user['uid']);

				$this->errorCode = self::ERROR_NONE;
			}else{
                $transaction = $connection->beginTransaction();
                try {
                    //Регистрируем пользователя
                    $connection = Yii::app()->db;
                    $connection->createCommand()->insert('{{users}}', array('mail' => $email, 'created' => time()));
                    $uid = Yii::app()->db->getLastInsertID();

                    $connection->createCommand()->insert('{{usersinfo}}', array('uid' => $uid, 'refx' => 1, 'owner' => $uid, 'email' => $email, 'name' => $first_name, 'fio' => $surname, 'tel' => '', 'alias' => 'id'.$uid, 'type' => 1));
                    $connection->createCommand()->insert('{{alias}}', array('uid' => $uid, 'name' => 'id'.$uid, 'type' => 1));

                    //Настройки
                    $connection->createCommand()->insert('{{users_settings}}', array('uid' => $uid, 'find_place' => 1, 'mail_send' => 1 ));

                    //Создаем кошельки
                    $hash1 = $uid . "." . 1;
                    $connection->createCommand()->insert('{{users_wallet}}', array('uid' => $uid, 'puid' => 0, 'fuid' => 0, 'date' => time(), 'cash_now' => 0, 'cash_out' => 0, 'cash_all' => 0, 'cash_percent' => 0, 'quotas' => 0, 'quotas_once' => 0, 'type' => 1, 'status' => 1, 'cerrency' => 'BP', 'hash' => $hash1));

                    $hash2 = $uid . "." . 2;
                    $connection->createCommand()->insert('{{users_wallet}}', array('uid' => $uid, 'puid' => 0, 'fuid' => 0, 'date' => time(), 'cash_now' => 0, 'cash_out' => 0, 'cash_all' => 0, 'cash_percent' => 0, 'quotas' => 0, 'quotas_once' => 0, 'type' => 2, 'status' => 1, 'cerrency' => 'BP', 'hash' => $hash2));

                    $hash3 = $uid . "." . 3;
                    $connection->createCommand()->insert('{{users_wallet}}', array('uid' => $uid, 'puid' => 0, 'fuid' => 0, 'date' => time(), 'cash_now' => 0, 'cash_out' => 0, 'cash_all' => 0, 'cash_percent' => 0, 'quotas' => 0, 'quotas_once' => 0, 'type' => 3, 'status' => 1, 'cerrency' => 'BP', 'hash' => $hash3));

                    $hash4 = $uid . "." . 4;
                    $connection->createCommand()->insert('{{users_wallet}}', array('uid' => $uid, 'puid' => 0, 'fuid' => 0, 'date' => time(), 'cash_now' => 0, 'cash_out' => 0, 'cash_all' => 0, 'cash_percent' => 0, 'quotas' => 0, 'quotas_once' => 0, 'type' => 4, 'status' => 0, 'cerrency' => 'BP', 'hash' => $hash4));

                    $hash5 = $uid . "." . 5;
                    $connection->createCommand()->insert('{{users_wallet}}', array('uid' => $uid, 'puid' => 0, 'fuid' => 0, 'date' => time(), 'cash_now' => 0, 'cash_out' => 0, 'cash_all' => 0, 'cash_percent' => 0, 'quotas' => 0, 'quotas_once' => 0, 'type' => 5, 'status' => 1, 'cerrency' => 'BP', 'hash' => $hash5));

                    $this->id = $uid;
                    $this->name = $email;

                    $this->setState('id', $this->id);
                    $this->setState('name', $this->name);
                    $this->setState('service', $this->service->serviceName);
                    Yii::app()->session->setUserId($uid);

                    $transaction->commit();
                    $this->errorCode = self::ERROR_NONE;
                } catch (Exception $e) {
                    $transaction->rollback();
                    //var_dump($e); exit;
                    $this->errorCode = self::ERROR_NOT_AUTHENTICATED;
                }
			}
		}
		else {
			$this->errorCode = self::ERROR_NOT_AUTHENTICATED;
		}
		return !$this->errorCode;
	}

	/**
	 * Returns the unique identifier for the identity.
	 * This method is required by {@link IUserIdentity}.
	 *
	 * @return string the unique identifier for the identity.
	 */
	public function getId() {
		return $this->id;
	}

	/**
	 * Returns the display name for the identity.
	 * This method is required by {@link IUserIdentity}.
	 *
	 * @return string the display name for the identity.
	 */
	public function getName() {
		return $this->name;
	}

    public function isBlocked() {
        return $this->isBlocked;
    }

    public function getBlockDate() {
        return $this->blockDate;
    }
}