<?php

/**
 * UserIdentity represents the data needed to identity a user.
 * It contains the authentication method that checks if the provided
 * data can identity the user.
 */
class UserIdentity extends CUserIdentity
{
	private $_id;
	public $mail;

	const ERROR_EMAIL_INVALID = 3;
	const ERROR_STATUS_BLOCKED = 4;
	const ERROR_FLOOD = 5;

	/**
	 * Authenticates a user.
	 * The example implementation makes sure if the name and pass
	 * are both 'demo'.
	 * In practical applications, this should be changed to authenticate
	 * against some persistent user identity storage (e.g. database).
	 * @return boolean whether authentication succeeds.
	 */
	public function authenticate()
	{
		if (!empty($this->username) && !empty($this->password)) {

			if (UserModule::floodIsAllowed("failed_login_attempt")) {
				$user = User::model()->notsafe()->findByAttributes(array('mail' => $this->username));

				if ($user === null) { // USER NOT FOUND
					$this->errorCode = self::ERROR_EMAIL_INVALID;
					UserModule::floodRegisterEvent("failed_login_attempt");
				// USER FOUND
				} else if (UserModule::encrypting($this->password, $user->pass) !== $user->pass) { // CHECK PASSWORD
					if (UserModule::floodIsAllowed("failed_pass_attempt", $user->uid)) {
						$this->errorCode = self::ERROR_PASSWORD_INVALID;
					} else {
						$this->errorCode = self::ERROR_FLOOD;
					}
					UserModule::floodRegisterEvent("failed_pass_attempt", $user->uid);
				} else if (!UserModule::floodIsAllowed("failed_pass_attempt", $user->uid)) {
					$this->errorCode = self::ERROR_FLOOD;
				} else {
					$this->_id = $user->uid;
					Yii::app()->session->setUserId($this->_id);

					$connection = Yii::app()->db;
					$user_info = $connection->createCommand("SELECT alias FROM {{usersinfo}} WHERE uid = :uid")->bindParam(":uid", $user->uid)->queryRow();

					$this->setState('alias', $user_info['alias']);
					UserModule::floodEmpty("failed_pass_attempt", $user->uid);
					$this->errorCode = self::ERROR_NONE;
				}

			} else {
				$this->errorCode = self::ERROR_FLOOD;
			}

		} else {
			return false;
		}

		return !$this->errorCode;
	}

	/**
	 * @return integer the ID of the user record
	 */
	public function getId()
	{
		return $this->_id;
	}

}