<?php

class UserModule extends CComponent
{

	/**
	 * @var string
	 * @desc hash method (md5,sha1 or algo hash function http://www.php.net/manual/en/function.hash.php)
	 */
	public $hash = 'md5';


	/**
	 * @var boolean
	 * @desc login after registration (need loginNotActiv or activeAfterRegister = true)
	 */
	public $autoLogin = true;
	public $registrationUrl = array("/user/registration");
	public $recoveryUrl = array("/user/recovery/recovery");
	public $loginUrl = array("/user/login");
	public $logoutUrl = array("/user/logout");
	public $profileUrl = array("/user/profile");
	public $returnUrl = array("/user/profile");
	public $returnLogoutUrl = array("/user/login");

	/**
	 * @var int
	 * @desc Remember Me Time (seconds), defalt = 2592000 (30 days)
	 */
	public $rememberMeTime = 2592000; // 30 days
	public $fieldsMessage = '';

	/**
	 * @var array
	 * @desc User model relation from other models
	 * @see http://www.yiiframework.com/doc/guide/database.arr
	 */
	public $relations = array();

	/**
	 * @var array
	 * @desc Profile model relation from other models
	 */
	public $profileRelations = array();

	/**
	 * @var boolean
	 */
	public $captcha = array('registration' => true);

	/**
	 * @var boolean
	 */
	//public $cacheEnable = false;

	public $tableUsers = '{{users}}';

	static private $_users = array();
	static private $_userByName = array();
	static private $_admin;
	static private $_admins;

	/**
	 * @var array
	 * @desc Behaviors for models
	 */
	public $componentBehaviors = array();

	public function init()
	{
		// this method is called when the module is being created
		// you may place code here to customize the module or the application
		// import the module-level models and components
		$this->setImport(array(
			'user.models.*',
			'user.components.*',
		));
	}

	public function getBehaviorsFor($componentName)
	{
		if (isset($this->componentBehaviors[$componentName])) {
			return $this->componentBehaviors[$componentName];
		} else {
			return array();
		}
	}

	public function beforeControllerAction($controller, $action)
	{
		if (parent::beforeControllerAction($controller, $action)) {
			// this method is called before any module controller action is performed
			// you may place customized code here
			return true;
		} else
			return false;
	}

	/**
	 * @param $input
	 * @param $count
	 * @internal param $password
	 * @return string
	 */
	function _password_base64_encode($input, $count)
	{
		$output = '';
		$i = 0;
		$itoa64 = self::_password_itoa64();
		do {
			$value = ord($input[$i++]);
			$output .= $itoa64[$value & 0x3f];
			if ($i < $count) {
				$value |= ord($input[$i]) << 8;
			}
			$output .= $itoa64[($value >> 6) & 0x3f];
			if ($i++ >= $count) {
				break;
			}
			if ($i < $count) {
				$value |= ord($input[$i]) << 16;
			}
			$output .= $itoa64[($value >> 12) & 0x3f];
			if ($i++ >= $count) {
				break;
			}
			$output .= $itoa64[($value >> 18) & 0x3f];
		} while ($i < $count);

		return $output;
	}

	/**
	 * Returns a string for mapping an int to the corresponding base 64 character.
	 */
	function _password_itoa64()
	{
		return './0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz';
	}

	/**
	 * Parse the log2 iteration count from a stored hash or setting string.
	 * @param $setting
	 * @return int
	 */
	function _password_get_count_log2($setting)
	{
		$itoa64 = self::_password_itoa64();
		return strpos($itoa64, $setting[3]);
	}

	/**
	 * @param $algo
	 * @param $password
	 * @param $setting
	 * @return bool|string
	 */
	function _password_crypt($algo, $password, $setting)
	{
		// Prevent DoS attacks by refusing to hash large passwords.
		if (strlen($password) > 512) {
			return FALSE;
		}
		// The first 12 characters of an existing hash are its setting string.
		$setting = substr($setting, 0, 12);

		if ($setting[0] != '$' || $setting[2] != '$') {
			return FALSE;
		}
		$count_log2 = self::_password_get_count_log2($setting);
		// Hashes may be imported from elsewhere, so we allow != DRUPAL_HASH_COUNT
		if ($count_log2 < Yii::app()->params['min_hash_count'] || $count_log2 > Yii::app()->params['max_hash_count']) {
			return FALSE;
		}
		$salt = substr($setting, 4, 8);
		// Hashes must have an 8 character salt.
		if (strlen($salt) != 8) {
			return FALSE;
		}

		// Convert the base 2 logarithm into an integer.
		$count = 1 << $count_log2;

		// We rely on the hash() function being available in PHP 5.2+.
		$hash = hash($algo, $salt . $password, TRUE);
		do {
			$hash = hash($algo, $hash . $password, TRUE);
		} while (--$count);

		$len = strlen($hash);
		$output = $setting . self::_password_base64_encode($hash, $len);
		// _password_base64_encode() of a 16 byte MD5 will always be 22 characters.
		// _password_base64_encode() of a 64 byte sha512 will always be 86 characters.
		$expected = 12 + ceil((8 * $len) / 6);
		return (strlen($output) == $expected) ? substr($output, 0, Yii::app()->params['hash_length']) : FALSE;
	}

	/**
	 * Hash a password using a secure hash.
	 *
	 * @param $password
	 *   A plain-text password.
	 * @param int $count_log2
	 *   Optional integer to specify the iteration count. Generally used only during
	 *   mass operations where a value less than the default is needed for speed.
	 *
	 * @return bool|string A string containing the hashed password (and a salt), or FALSE on failure.
	 */
	public static function user_hash_password($password, $count_log2 = 0) {
		if (empty($count_log2)) {
			// Use the standard iteration count.
			$count_log2 = Yii::app()->params['hash_count'];
		}
		return self::_password_crypt('sha512', $password, self::_password_generate_salt($count_log2));
	}

	public static function session_hash_string( $user_ip, $unique_string )
	{
		return md5($user_ip.$unique_string);
	}

	/**
	 * Generates a random base 64-encoded salt prefixed with settings for the hash.
	 *
	 * Proper use of salts may defeat a number of attacks, including:
	 *  - The ability to try candidate passwords against multiple hashes at once.
	 *  - The ability to use pre-hashed lists of candidate passwords.
	 *  - The ability to determine whether two users have the same (or different)
	 *    password without actually having to guess one of the passwords.
	 *
	 * @param $count_log2
	 *   Integer that determines the number of iterations used in the hashing
	 *   process. A larger value is more secure, but takes more time to complete.
	 *
	 * @return string A 12 character string containing the iteration count and a random salt.
	 */
	function _password_generate_salt($count_log2) {
		$output = '$S$';
		// Ensure that $count_log2 is within set bounds.
		$count_log2 = self::_password_enforce_log2_boundaries($count_log2);
		// We encode the final log2 iteration count in base 64.
		$itoa64 = self::_password_itoa64();
		$output .= $itoa64[$count_log2];
		// 6 bytes is the standard salt for a portable phpass hash.
		$output .= self::_password_base64_encode(self::_random_bytes(6), 6);
		return $output;
	}

	/**
	 * Returns a string of highly randomized bytes (over the full 8-bit range).
	 *
	 * This function is better than simply calling mt_rand() or any other built-in
	 * PHP function because it can return a long string of bytes (compared to < 4
	 * bytes normally from mt_rand()) and uses the best available pseudo-random
	 * source.
	 *
	 * @param $count
	 *   The number of characters (bytes) to return in the string.
	 * @return string
	 */
	function _random_bytes($count)  {
		// $random_state does not use drupal_static as it stores random bytes.
		static $random_state, $bytes, $has_openssl;

		$missing_bytes = $count - strlen($bytes);

		if ($missing_bytes > 0) {
			// PHP versions prior 5.3.4 experienced openssl_random_pseudo_bytes()
			// locking on Windows and rendered it unusable.
			if (!isset($has_openssl)) {
				$has_openssl = version_compare(PHP_VERSION, '5.3.4', '>=') && function_exists('openssl_random_pseudo_bytes');
			}

			// openssl_random_pseudo_bytes() will find entropy in a system-dependent
			// way.
			if ($has_openssl) {
				$bytes .= openssl_random_pseudo_bytes($missing_bytes);
			}

			// Else, read directly from /dev/urandom, which is available on many *nix
			// systems and is considered cryptographically secure.
			elseif ($fh = @fopen('/dev/urandom', 'rb')) {
				// PHP only performs buffered reads, so in reality it will always read
				// at least 4096 bytes. Thus, it costs nothing extra to read and store
				// that much so as to speed any additional invocations.
				$bytes .= fread($fh, max(4096, $missing_bytes));
				fclose($fh);
			}

			// If we couldn't get enough entropy, this simple hash-based PRNG will
			// generate a good set of pseudo-random bytes on any system.
			// Note that it may be important that our $random_state is passed
			// through hash() prior to being rolled into $output, that the two hash()
			// invocations are different, and that the extra input into the first one -
			// the microtime() - is prepended rather than appended. This is to avoid
			// directly leaking $random_state via the $output stream, which could
			// allow for trivial prediction of further "random" numbers.
			if (strlen($bytes) < $count) {
				// Initialize on the first call. The contents of $_SERVER includes a mix of
				// user-specific and system information that varies a little with each page.
				if (!isset($random_state)) {
					$random_state = print_r($_SERVER, TRUE);
					if (function_exists('getmypid')) {
						// Further initialize with the somewhat random PHP process ID.
						$random_state .= getmypid();
					}
					$bytes = '';
				}

				do {
					$random_state = hash('sha256', microtime() . mt_rand() . $random_state);
					$bytes .= hash('sha256', mt_rand() . $random_state, TRUE);
				}
				while (strlen($bytes) < $count);
			}
		}
		$output = substr($bytes, 0, $count);
		$bytes = substr($bytes, $count);
		return $output;
	}

	/**
	 * Ensures that $count_log2 is within set bounds.
	 *
	 * @param $count_log2
	 *   Integer that determines the number of iterations used in the hashing
	 *   process. A larger value is more secure, but takes more time to complete.
	 *
	 * @return int Integer within set bounds that is closest to $count_log2.
	 */
	function _password_enforce_log2_boundaries($count_log2) {
		if ($count_log2 < Yii::app()->params['min_hash_count']) {
			return Yii::app()->params['min_hash_count'];
		}
		elseif ($count_log2 > Yii::app()->params['max_hash_count']) {
			return Yii::app()->params['max_hash_count'];
		}

		return (int) $count_log2;
	}

	/**
	 * @param $password
	 * @param $user_pass
	 * @return string hash.
	 */
	public static function encrypting($password, $user_pass)
	{
		if (substr($user_pass, 0, 2) == 'U$') {
			// This may be an updated password from user_update_7000(). Such hashes
			// have 'U' added as the first character and need an extra md5().
			$stored_hash = substr($user_pass, 1);
			$password = md5($password);
		} else {
			$stored_hash = $user_pass;
		}

		$type = substr($stored_hash, 0, 3);
		switch ($type) {
			case '$S$':
				// A normal Drupal 7 password using sha512.
				$hash = self::_password_crypt('sha512', $password, $stored_hash);
				break;
			case '$H$':
				// phpBB3 uses "$H$" for the same thing as "$P$".
			case '$P$':
				// A phpass password generated using md5.  This is an
				// imported password or from an earlier Drupal version.
				$hash = self::_password_crypt('md5', $password, $stored_hash);
				break;
			default:
				$hash = hash("md5", $password);
		}
		return $hash;
	}

	/**
	 * @param $event
	 * @param int $floodLimit
	 * @param int $window
	 * @param null $identifier
	 * @internal param int $floodLimit
	 * @internal param $threshold
	 * @return bool
	 */
	public static function floodIsAllowed($event, $identifier = NULL, $floodLimit = 0, $window = 7200)
	{
		if(empty($floodLimit)){
			$floodLimit = Yii::app()->params['flood_limit'];
		}
		if (!isset($identifier)) {
			$identifier = Yii::app()->request->getUserHostAddress();
		}
		$criteria = new CDbCriteria();
		$criteria->condition = 'event = :event AND identifier = :identifier AND (timestamp > :today_midnight AND timestamp < :time_now)';
		$criteria->params = array(
			':event' => $event,
			':identifier' => $identifier,
			':today_midnight' => Helpers::dayNowMidnight(),
			':time_now' => Helpers::requestTime()
		);

		return (Flood::model()->count($criteria) < $floodLimit);
	}

	/**
	 * @param $event
	 * @param null $identifier
	 * @internal param int $floodLimit
	 * @internal param int $window
	 * @internal param $name
	 * @internal param $event
	 * @internal param int $floodLimit
	 * @internal param int $floodLimit
	 * @internal param $threshold
	 * @return bool
	 */
	public static function floodRegisterEvent($event, $identifier = NULL) {
		if (!isset($identifier)) {
			$identifier = Yii::app()->request->getUserHostAddress();
		}

		$flood = new Flood();
		$flood->event = $event;
		$flood->identifier = $identifier;
		$flood->timestamp = Helpers::requestTime();
		$flood->expiration = Helpers::dayNextMidnight();

		return $flood->save();

	}

	public static function floodEmpty($event, $identifier = NULL) {
		if (!empty($identifier)) {
			try {
				$connection=Yii::app()->db;
				$connection->createCommand("DELETE FROM {{flood}} WHERE event = :event AND identifier = :identifier AND (timestamp > :today_midnight AND timestamp < :time_now)")
					->bindParam(":event", $event)
					->bindParam(":identifier", $identifier)
					->bindParam(":today_midnight", Helpers::dayNowMidnight())
					->bindParam(":time_now", Helpers::requestTime())
					->query();

				return true;
			} catch (Exception $e) {
				return false;
			}
		}
		return false;
	}

	/**
	 * Генерация случайной ссылки
	 * @param $length
	 * @return string
	 */
	public static function genRef($length)
	{
		$chars = 'abcdefghiklmnopqrstuvwxyzABCDEFGHIKLMNOPQRSTUVXYZ0123456789';
		$numChars = strlen($chars);
		$string = '';
		for ($i = 0; $i < $length; $i++) {
			$string .= substr($chars, rand(1, $numChars) - 1, 1);
		}
		return $string;
	}

	/**
	 * @param $place
	 * @return boolean
	 */
	public static function doCaptcha($place = '')
	{
		if (!extension_loaded('gd'))
			return false;
		if (is_array($place)) {
			if ($place !== '' and in_array($place, Yii::app()->getModule('user')->captcha))
				return Yii::app()->getModule('user')->captcha[$place];
		}
		return false;
	}

	/**
	 * Return admin status.
	 * @return boolean
	 */
	public static function isAdmin()
	{
		if (Yii::app()->user->isGuest)
			return false;
		else {
			if (!isset(self::$_admin)) {
				if (self::user()->superuser)
					self::$_admin = true;
				else
					self::$_admin = false;
			}
			return self::$_admin;
		}
	}

	/**
	 * Return admins.
	 * @return array syperusers names
	 */
	public static function getAdmins()
	{
		if (!self::$_admins) {
			$admins = User::model()->active()->superuser()->findAll();
			$return_name = array();
			foreach ($admins as $admin) array_push($return_name, $admin->username);
			self::$_admins = ($return_name) ? $return_name : array('');
		}
		return self::$_admins;
	}

	/**
	 * Send mail method
	 */
	public static function sendMail($email, $subject, $message)
	{

		$message = wordwrap($message, 70);
		$message = str_replace("\n.", "\n..", $message);
		$yiiMailMessage = new YiiMailMessage;
		$yiiMailMessage->setBody($message, 'text/html');
		$yiiMailMessage->subject = $subject;
		$yiiMailMessage->addTo($email);
		$yiiMailMessage->from = Yii::app()->params['adminEmail'];
		return Yii::app()->mail->send($yiiMailMessage);
//    	$adminEmail = Yii::app()->params['adminEmail'];
//	    $headers = "MIME-Version: 1.0\r\nFrom: $adminEmail\r\nReply-To: $adminEmail\r\nContent-Type: text/html; charset=utf-8";
//	    $message = wordwrap($message, 70);
//	    $message = str_replace("\n.", "\n..", $message);
//	    return mail($email,'=?UTF-8?B?'.base64_encode($subject).'?=',$message,$headers);
	}

	/**
	 * Return safe user data.
	 * @param int $id
	 * @param bool $clearCache
	 * @internal param id $user not required
	 * @return user object or false
	 */
	public static function user($id = 0, $clearCache = false)
	{
		if (!$id && !Yii::app()->user->isGuest) {
			$id = Yii::app()->user->id;
		}
		if ($id) {
			if (!isset(self::$_users[$id]) || $clearCache) {
				self::$_users[$id] = User::model()->findbyPk($id);
			}
			return self::$_users[$id];
		} else
			return false;
	}

	/**
	 * Return safe user data.
	 * @param user name
	 * @return user object or false
	 */
	public static function getUserByName($username)
	{
		if (!isset(self::$_userByName[$username])) {
			$_userByName[$username] = User::model()->findByAttributes(array('username' => $username));
		}
		return $_userByName[$username];
	}

	/**
	 * Return safe user data.
	 * @param user id not required
	 * @return user object or false
	 */
	public function users()
	{
		return User;
	}

}
