<?php

class AjaxController extends Controller
{

	public function filters()
	{
		return array(
			'accessControl', // perform access control for CRUD operations
		);
	}

	public function accessRules()
	{
		return array(
			array('allow',
				'actions'=>array('postgetcomments', 'pagegetgroups', 'pagegetsubscribers'),
				'users'=>array('?'),
			),
			array('deny',
				'users'=>array('?'),
			),
		);
	}

	public function actionContactDelete()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			Functions::access_control(1);
			$connection = Yii::app()->db;
			$res = array();

			//Входящие данные
			$uid = intval($_POST["uid"]);
			$group_id = intval($_POST["group_id"]);

			$transaction = $connection->beginTransaction();
			try {
				$group = $connection->createCommand("SELECT * FROM {{usersinfo}} WHERE uid = :group_id AND owner = :uid AND type = 2")
					->bindParam(":group_id", $group_id)
					->bindParam(":uid", Yii::app()->user->id)
					->queryRow();
				if (!empty($group)) {
					$contact = $connection->createCommand("SELECT * FROM {{contact}} WHERE uid = :group_id AND contact_uid = :uid AND type = 2")
						->bindParam(":group_id", $group_id)
						->bindParam(":uid", $uid)
						->queryRow();
					if(!empty($contact)){
						Yii::app()->db->createCommand('DELETE FROM {{contact}} WHERE id = :id')
						->bindParam(":id", $contact['id'])
						->query();
						$transaction->commit();
						$res["status"] = 200;
					}else{
						$res["status"] = 500;
						$res["message"] = "<p>3Сервер временно недоступен.</p>";
					}
				} else {
					$res["status"] = 500;
					$res["message"] = "<p>Сервер временно недоступен.</p>";
				}
			} catch(Exception $e) {
				$transaction->rollback();
				$res["status"] = 500;
				$res["message"] = "<p>Сервер временно недоступен.</p>";
			}
			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionGetUserCategories()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$connection = Yii::app()->db;
			$res = array();

			$uid = intval($_POST['uid']);
			$user_info = $connection->createCommand("SELECT * FROM {{usersinfo}} WHERE uid = :uid")
				->bindParam(":uid", $uid)
				->queryRow();

			if (!empty($user_info)) {
				$categories = $connection->createCommand("SELECT c.* FROM {{categories}} c INNER JOIN {{good_category}} gc LEFT JOIN {{goods}} g ON gc.category_id = c.id AND g.uid = :uid AND c.parent = 0 AND g.gid = gc.good_id WHERE NOT ISNULL(g.gid)")
					->bindParam(":uid", $uid)
					->queryAll();

				$res["categories"] = $categories;
				$res["status"] = 200;
			} else {
				$res["status"] = 500;
				$res["message"] = '<p>Доступ запрещен.</p>';
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionGetCategories()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$connection = Yii::app()->db;
			$res = array();

			$categories = $connection->createCommand("SELECT id, name, parent  FROM {{categories}}")
				->queryAll();
			$res["categories"] = $categories;
			$res["status"] = 200;

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionPageGetGroupsAll()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$connection = Yii::app()->db;
			$res = array();
			$uid = intval($_POST["uid"]);
			$group_info = $connection->createCommand("SELECT * FROM {{usersinfo}} WHERE uid = :uid")
				->bindParam(":uid", $uid)
				->queryRow();
			if (!empty($group_info)) {
				$groups = $connection->createCommand("SELECT u.uid, u.name as 'fio', u.photo, u.alias, u.about FROM {{usersinfo}} u INNER JOIN {{friends}} f ON f.uid = :uid AND f.fuid = u.uid WHERE (u.type = 2 AND f.uid = :uid)")
					->bindParam(":uid", $group_info['uid'])
					->queryAll();
				$res["groups"] = $groups;
				$res["status"] = 200;
			} else {
				$res["status"] = 500;
			}
			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionPageGetGroups()
	{
		if (Yii::app()->request->isAjaxRequest) {
			$connection = Yii::app()->db;
			$res = array();

			$uid = intval($_POST["uid"]);
			$limit = 4;

			$group_info = $connection->createCommand("SELECT * FROM {{usersinfo}} WHERE uid = :uid")
				->bindParam(":uid", $uid)
				->queryRow();
			if (!empty($group_info)) {
				$groups = $connection->createCommand("SELECT u.uid, u.name as 'fio', u.photo, u.alias, u.about FROM {{usersinfo}} u INNER JOIN {{friends}} f ON f.uid = :uid AND f.fuid = u.uid INNER JOIN {{groups}} g ON g.cid = u.uid WHERE (u.type = 2 AND f.uid = :uid) ORDER BY g.count_user DESC")
					->bindParam(":uid", $group_info['uid'])
					->bindValue(":limit", 3)
					->queryAll();
				$totalRecords = count($groups);

				if($totalRecords > $limit){
					$rand = rand(1, $totalRecords-$limit);
					$groups = array_slice($groups, $rand, $limit);
				}

				$res["groups"] = $groups;
				$res["total"] = $totalRecords;
				$res["status"] = 200;
			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionPostGetReposts()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$connection = Yii::app()->db;
			$res = array();

			$post_id = intval($_POST["post_id"]);
			$part = intval($_POST["part"]);

			$post = $connection->createCommand("SELECT id FROM {{posts}} WHERE id = :post_id")->bindParam(":post_id", $post_id)->queryRow();

			if(!empty($post)){
				if($part){
					$reposts = $connection->createCommand("SELECT SQL_CALC_FOUND_ROWS DISTINCT u.uid, CONCAT(u.name, ' ', u.fio) as 'fio', u.name, u.photo as photo, u.alias FROM {{usersinfo}} u INNER JOIN {{posts}} p ON p.repost <> 0 AND p.repost = :pid AND p.puid = u.uid ORDER BY date DESC LIMIT 6")->bindParam(":pid", $post_id)->queryAll();
				}else{
					$reposts = $connection->createCommand("SELECT SQL_CALC_FOUND_ROWS DISTINCT u.uid, CONCAT(u.name, ' ', u.fio) as 'fio', u.name, u.photo as photo, u.alias FROM {{usersinfo}} u INNER JOIN {{posts}} p ON p.repost <> 0 AND p.repost = :pid AND p.puid = u.uid ORDER BY date DESC")->bindParam(":pid", $post_id)->queryAll();
				}
				$count = $connection->createCommand('SELECT FOUND_ROWS()')->queryScalar();

				$res["reposts"] = $reposts;
				$res["count"] = $count;
				$res["status"] = 200;
			}else{
				$res["status"] = 500;
			}
			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionPostGetLikes()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$connection = Yii::app()->db;
			$res = array();

			$post_id = intval($_POST["post_id"]);
			$part = intval($_POST["part"]);

			$post = $connection->createCommand("SELECT id FROM {{posts}} WHERE id = :post_id")->bindParam(":post_id", $post_id)->queryRow();

			if(!empty($post)){
				if($part){
					$likes = $connection->createCommand("SELECT SQL_CALC_FOUND_ROWS CONCAT(u.name, ' ', u.fio) as 'fio', u.name, u.photo as photo, u.alias FROM {{posts_like}} l INNER JOIN {{usersinfo}} u ON l.pid = :pid AND l.uid = u.uid LIMIT 6")->bindParam(":pid", $post_id)->queryAll();
				}else{
					$likes = $connection->createCommand("SELECT SQL_CALC_FOUND_ROWS CONCAT(u.name, ' ', u.fio) as 'fio', u.name, u.photo as photo, u.alias FROM {{posts_like}} l INNER JOIN {{usersinfo}} u ON l.pid = :pid AND l.uid = u.uid")->bindParam(":pid", $post_id)->queryAll();
				}
				$count = $connection->createCommand('SELECT FOUND_ROWS()')->queryScalar();

				$res["likes"] = $likes;
				$res["count"] = $count;
				$res["status"] = 200;
			}else{
				$res["status"] = 500;
			}
			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionImHistory(){
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$connection = Yii::app()->db;
//			$msg_db = Yii::app()->msg_db;
			$res = array();
			$sel = intval($_POST['sel']);
			$page = intval($_POST["page"]);
			$ts = intval($_POST["ts"]);
			$ts = !empty($ts) ? $ts : time();

			if (!empty($page)) {
				$messages = $connection->createCommand('SELECT id , fuid, tuid, message, date, is_readed FROM {{messages}} WHERE ((tuid = :sel AND fuid = :uid) OR (fuid = :sel AND tuid = :uid)) AND date < :ts ORDER BY date DESC LIMIT :limit OFFSET :offset')
					->bindValue(":uid", Yii::app()->user->id)
					->bindValue(":sel", $sel)
					->bindValue(":limit", 10, PDO::PARAM_INT)
					->bindValue(":offset", ($page - 1) * 10, PDO::PARAM_INT)
					->bindValue(":ts", $ts)
					->queryAll();

				$res["messages"] = $messages;
				$res["status"] = 200;
			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionAnswersGetNext()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$connection = Yii::app()->db;
			$res = array();

			$page = intval($_POST["page"]);

			if (!empty($page)) {
				$answers = $connection->createCommand("SELECT e.id, e.uid, e.fuid, e.date, e.type, e.data1 AS post_id, e.data3 AS comment_id, CONCAT(u.name, ' ', u.fio) as 'fio', u.name, u.alias, u.photo, u.sex, c.text as text, a.text AS answer FROM {{events}} e INNER JOIN {{usersinfo}} u ON u.uid = e.fuid AND e.uid = :uid LEFT JOIN {{comments}} c ON c.id = e.data2 LEFT JOIN {{comments}} a ON a.id = e.data3 WHERE e.type = 4 OR e.type = 5 OR e.type = 6 OR e.type = 7 ORDER BY date DESC LIMIT :limit OFFSET :offset")
					->bindValue(":uid", Yii::app()->user->id)
					->bindValue(":limit", 10, PDO::PARAM_INT)
					->bindValue(":offset", ($page - 1) * 10, PDO::PARAM_INT)
					->queryAll();

				$connection->createCommand("UPDATE {{events}} SET status = 1 WHERE uid = :uid AND (type = 4 OR type = 5 OR type = 6 OR type = 7)")
					->bindParam(":uid", Yii::app()->user->id)
					->query();

				$res["answers"] = $answers;
				$res["status"] = 200;
			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionNotificationGetNext()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$connection = Yii::app()->db;
			$res = array();

			$page = intval($_POST["page"]);

			if (!empty($page)) {

                // type = 8 (friends)
				$notifications = $connection->createCommand("SELECT f.id, f.uid, f.fuid, f.date, 8 as type, 0 as post_id, 0 as comment_id, CONCAT(u.name, ' ', u.fio) as fio, u.alias, u.photo, u.sex FROM {{friends}} f INNER JOIN {{usersinfo}} u ON u.uid = f.uid WHERE f.fuid = :uid AND f.status = 0 UNION SELECT e.id, e.uid, e.fuid, e.date, e.type, e.data1 AS post_id, e.data2 AS comment_id, CONCAT(u.name, ' ', u.fio) as 'fio', u.alias, u.photo, u.sex FROM {{events}} e INNER JOIN {{usersinfo}} u ON u.uid = e.fuid AND e.uid = :uid WHERE e.type = 2 OR e.type = 3 ORDER BY type = 8 DESC, date DESC LIMIT :limit OFFSET :offset")
					->bindValue(":uid", Yii::app()->user->id)
					->bindValue(":limit", 10, PDO::PARAM_INT)
					->bindValue(":offset", ($page - 1) * 10, PDO::PARAM_INT)
					->queryAll();

				$res["notifications"] = $notifications;
				$res["status"] = 200;
			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionComment()
	{
		if (!Yii::app()->user->isGuest && Yii::app()->request->isAjaxRequest) {
			Functions::access_control(1);
			$connection = Yii::app()->db;
			$res = array();

			$text = mysql_escape_string(strip_tags($_POST["text"]));
			$post_id = intval($_POST["post_id"]);
			$answer_id = intval($_POST["answer_id"]);

			$post = $connection->createCommand("SELECT id, comment, puid FROM {{posts}} WHERE id = :post_id AND status = 1")
				->bindParam(":post_id", $post_id)
				->queryRow();
            $banned = $connection->createCommand("SELECT * FROM {{users_ban}} WHERE uid = :uid AND fuid = :fuid")
                ->bindParam(":uid", $post['puid'])
                ->bindParam(":fuid", Yii::app()->user->id)
                ->queryRow();

			if (!empty($text) && !empty($post) && empty($banned) && strlen($text) < 500) {
				$transaction = $connection->beginTransaction();
				try {
					if ($post['comment'] == 0) {
						$connection->createCommand("UPDATE {{posts}} SET comment = 1 WHERE id = :id")
							->bindParam(":id", $post["id"])
							->query();
					}
					$connection->createCommand()->insert('{{comments}}', array('date' => time(), 'uid' => Yii::app()->user->id, 'pid' => $post['id'], 'text' => $text, 'type' => 1));
					$comment_id = Yii::app()->db->getLastInsertID();
					$comment = $connection->createCommand("SELECT c.*, CONCAT(u.name, ' ', u.fio) as 'fio', u.photo as photo, u.alias FROM {{comments}} c INNER JOIN {{usersinfo}} u ON c.id = :id AND c.uid = :uid AND u.uid = :uid AND c.type = 1")
						->bindParam(":id", $comment_id)
						->bindParam(":uid", Yii::app()->user->id)
						->queryRow();

					if (!empty($comment)) {

						//оставил комментарий к Вашей записи
						$post_owner = $connection->createCommand("SELECT * FROM {{usersinfo}} WHERE uid = :uid AND type = 1")
							->bindParam(":uid", $post['puid'])
							->queryRow();
						if (!empty($post_owner) && Yii::app()->user->id != $post['puid']) {
							$connection->createCommand()->insert('{{events}}', array(
								'uid' => $post['puid'],
								'fuid' => Yii::app()->user->id,
								'date' => time(),
								'type' => 4,
								'status' => 0,
								'data1' => $post_id,
								'data2' => $comment['id']
							));
						}

						//в ответ на Ваш комментарий
						$comment_event = $connection->createCommand("SELECT * FROM {{comments}} WHERE id = :id")
							->bindParam(":id", $answer_id)
							->queryRow();
						if (!empty($comment_event)) {
							$connection->createCommand()->insert('{{events}}', array(
								'uid' => $comment_event['uid'],
								'fuid' => Yii::app()->user->id,
								'date' => time(),
								'type' => 5,
								'status' => 0,
								'data1' => $post['id'],
								'data2' => $comment_event['id'],
								'data3' => $comment['id']
							));
						}

						$transaction->commit();
						$res["comment"] = $comment;
						$res["status"] = 200;
					} else {
						$transaction->rollback();
						$res["status"] = 500;
					}
				} catch (Exception $e) {
					$transaction->rollback();
					$res["status"] = 500;
					$res["message"] = "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
				}
			} else {
				$res["status"] = 500;
                $res["message"] = "Вы не можете написать комментарий на странице данного пользователя.";
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}

	}

	public function actionGroupUploadPhoto()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest && !empty($_FILES['attach_photo'])) {
			Functions::access_control(1);
			$connection = Yii::app()->db;
			$res = array();
			$err = array();


			//Блокировка файлом ===================
			$lock = $connection->createCommand("SELECT uid, `lock` FROM {{users}} WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->queryRow();
			if ($lock['lock'] == 0) {
				$connection->createCommand("UPDATE {{users}} SET `lock` = 1 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
			} else {
				$res["status"] = 500;
				$res["message"] = "Идет обработка Вашего запроса. Обновите страницу через несколько минут и повторите попытку снова.";
				echo CJSON::encode($res);
				Yii::app()->end();
			}//Блокировка файлом ===================



			//Получаем информацию о файле
			$type = mysql_escape_string(htmlspecialchars(strip_tags($_FILES['attach_photo']["type"])));
			$tmp_name = mysql_escape_string(htmlspecialchars(strip_tags($_FILES['attach_photo']["tmp_name"])));
			$name = mysql_escape_string(htmlspecialchars(strip_tags($_FILES['attach_photo']["name"])));

			if (($type == "application/octet-stream") && (($type != "image/jpeg") || ($type != "image/png") || ($type != "image/gif"))) {
				$err .= "Тип файла не поддерживается.";
			}

			//Если файл поддерживается
			if (empty($err)) {
				$server = f_getUploadServer();
				$user_info = $connection->createCommand('SELECT * FROM {{usersinfo}} WHERE uid = :uid')
					->bindParam(":uid", Yii::app()->user->id)
					->queryRow();

				if(!empty($server) && !empty($user_info)){
					$data = array(
						'server_id' => $server['id'],
						'type' => 3,
						'uid' => Yii::app()->user->id,
						'photo' => '@'.$tmp_name.';filename='.$name.';type='.$type,
						'signature' => sha1(md5($server['id'].'3'.Yii::app()->user->id.Yii::app()->params['api_pass']))
					);

					$ch = curl_init();
					curl_setopt($ch, CURLOPT_URL, "http://".$server['address']."/file/uploadPhoto");
					curl_setopt($ch, CURLOPT_POST, 1);
					curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
					curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
					curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
					curl_setopt($ch, CURLOPT_REFERER, "http://".$server['address']."/file/uploadPhoto");

					$result = curl_exec($ch);
					curl_close($ch);

					$results = json_decode($result, true);

					if ($results['status'] == 200 && !empty($results['photo'])){
						$connection->createCommand("UPDATE {{servers}} set images = images + 1 WHERE id = :id")
							->bindParam(":id", $server['id'])
							->query();
						if(!empty($user_info['photo'])){
							$fs_db = Yii::app()->fs_db;
							$fs_db->createCommand("UPDATE {{images}} SET status = 2 WHERE path = :path")
									->bindParam(":path", $user_info['photo'])
									->query();
						}

						$res['status'] = 200;
						$res['photo'] = $results['photo'];
					}else{
						$res['status'] = 500;
						$res['message'] = $results['error'];
					}
				}else{
					$res['status'] = 500;
					$res['message'] = 'Сервер временно недоступен.';
				}
			}else{
				$res['status'] = 500;
				$res['message'] = $err;
			}

			$connection->createCommand("UPDATE {{users}} SET `lock` = 0 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionPostUploadPhoto()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest && !empty($_FILES['attach_photo'])) {
			Functions::access_control(1);
			$connection = Yii::app()->db;
			$res = array();
			$err = array();

			//Блокировка файлом ===================
			$lock = $connection->createCommand("SELECT uid, `lock` FROM {{users}} WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->queryRow();
			if ($lock['lock'] == 0) {
				$connection->createCommand("UPDATE {{users}} SET `lock` = 1 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
			} else {
				$res["status"] = 500;
				$res["message"] = "Идет обработка Вашего запроса. Обновите страницу через несколько минут и повторите попытку снова.";
				echo CJSON::encode($res);
				Yii::app()->end();
			}//Блокировка файлом ===================

			//Получаем информацию о файле
			$type = mysql_escape_string(htmlspecialchars(strip_tags($_FILES['attach_photo']["type"])));
			$tmp_name = mysql_escape_string(htmlspecialchars(strip_tags($_FILES['attach_photo']["tmp_name"])));
			$name = mysql_escape_string(htmlspecialchars(strip_tags($_FILES['attach_photo']["name"])));

			if (($type == "application/octet-stream") && (($type != "image/jpeg") || ($type != "image/png") || ($type != "image/gif"))) {
				$err .= "Тип файла не поддерживается.";
			}

			//Если файл поддерживается
			if (empty($err)) {
				$server = f_getUploadServer();
				$user_info = $connection->createCommand('SELECT * FROM {{usersinfo}} WHERE uid = :uid')
					->bindParam(":uid", Yii::app()->user->id)
					->queryRow();

				if(!empty($server) && !empty($user_info)){
					$data = array(
						'server_id' => $server['id'],
						'type' => 2,
						'uid' => Yii::app()->user->id,
						'photo' => '@'.$tmp_name.';filename='.$name.';type='.$type,
						'signature' => sha1(md5($server['id'].'2'.Yii::app()->user->id.Yii::app()->params['api_pass']))
					);

					$ch = curl_init();
					curl_setopt($ch, CURLOPT_URL, "http://".$server['address']."/file/uploadPhoto");
					curl_setopt($ch, CURLOPT_POST, 1);
					curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
					curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
					curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
					curl_setopt($ch, CURLOPT_REFERER, "http://".$server['address']."/file/uploadPhoto");

					$result = curl_exec($ch);
					curl_close($ch);

					$results = json_decode($result, true);

					if ($results['status'] == 200 && !empty($results['photo'])){
						$connection->createCommand("UPDATE {{servers}} set images = images + 1 WHERE id = :id")
							->bindParam(":id", $server['id'])
							->query();

						$res['status'] = 200;
						$res['photo'] = $results['photo'];
					}else{
						$res['status'] = 500;
						$res['message'] = $results['message'];
					}
				}else{
					$res['status'] = 500;
					$res['message'] = 'Сервер временно недоступен.';
				}
			}else{
				$res['status'] = 500;
				$res['message'] = $err;
			}

			$connection->createCommand("UPDATE {{users}} SET `lock` = 0 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionUserUploadPhoto()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest && !empty($_FILES['page_avatar'])) {
			$connection = Yii::app()->db;
			$res = array();
			$err = array();

			//Входящие данные
			$uid = intval($_POST["uid"]);
			$x1 = intval($_POST["x1"]);
			$y1 = intval($_POST["y1"]);
			$x2 = intval($_POST["x2"]);
			$y2 = intval($_POST["y2"]);

			//Получаем информацию о файле
			$type = mysql_escape_string(htmlspecialchars(strip_tags($_FILES['page_avatar']["type"])));
			$tmp_name = mysql_escape_string(htmlspecialchars(strip_tags($_FILES['page_avatar']["tmp_name"])));
			$name = mysql_escape_string(htmlspecialchars(strip_tags($_FILES['page_avatar']["name"])));

			if (($type == "application/octet-stream") && (($type != "image/jpeg") || ($type != "image/png") || ($type != "image/gif"))) {
				$err .= "Тип файла не поддерживается.";
			}

			//Если файл поддерживается
			if (empty($err)) {
				$server = f_getUploadServer();
				$user_info = $connection->createCommand('SELECT * FROM {{usersinfo}} WHERE uid = :uid')
					->bindParam(":uid", Yii::app()->user->id)
					->queryRow();

				if(!empty($server) && !empty($user_info)){
					$data = array(
						'photo' => '@'.$tmp_name.';filename='.$name.';type='.$type,
						'x1' => $x1,
						'y1' => $y1,
						'x2' => $x2,
						'y2' => $y2,
						'uid' => Yii::app()->user->id,
						'server_id' => $server['id'],
						'signature' => sha1(md5($x1.$y1.$x2.$y2. Yii::app()->user->id.$server['id'].Yii::app()->params['api_pass']))
					);

					$ch = curl_init();
					curl_setopt($ch, CURLOPT_URL, "http://".$server['address']."/file/useruploadphoto");
					curl_setopt($ch, CURLOPT_POST, 1);
					curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
					curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
					curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
					curl_setopt($ch, CURLOPT_REFERER, "http://".$server['address']."/file/useruploadphoto");

					$result = curl_exec($ch);
					curl_close($ch);

					$results = json_decode($result, true);
//					$res["test"] = $result;

					if ($results['status'] == 200 && !empty($results['photo'])) {
						$connection->createCommand("UPDATE {{usersinfo}} set photo = :photo WHERE uid = :uid")
							->bindParam(":uid", $uid)
							->bindParam(":photo", $results['photo'])
							->query();

						$connection->createCommand("UPDATE {{servers}} set images = images + 1 WHERE id = :id")
							->bindParam(":id", $server['id'])
							->query();

						if(!empty($user_info['photo'])){
							$fs_db = Yii::app()->fs_db;
							$fs_db->createCommand("UPDATE {{images}} SET status = 2 WHERE path = :path")
									->bindParam(":path", $user_info['photo'])
									->query();
						}

						$res["status"] = 200;
						$res["file"] = $results['photo'];
					}else{
						$res["status"] = 500;
						$res["message"] = $results["message"];
					}
				}else{
					$res["status"] = 500;
					$res["message"] = 'Сервер временно недоступен.';
				}
			}else{
				$res["status"] = 500;
				$res["message"] = $err;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionPageSetStatus()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			Functions::access_control(1);
			$connection = Yii::app()->db;
			$res = array();

			$status = mysql_escape_string(htmlspecialchars(strip_tags($_POST["status"])));

			$page_info = $connection->createCommand("SELECT * FROM {{usersinfo}} WHERE uid = :uid")
				->bindParam(":uid", Yii::app()->user->id)
				->queryRow();

			if (!empty($page_info)) {
				$connection->createCommand("UPDATE {{usersinfo}} SET status = :status WHERE uid = :uid")
					->bindParam(":uid", $page_info['uid'])
					->bindParam(":status", $status)
					->query();

				$res["status"] = 200;
			}else{
				$res["status"] = 500;
				$res["message"] = 'Доступ запрещен';
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionPageGetSubscribers()
	{
		if (Yii::app()->request->isAjaxRequest) {
			$connection = Yii::app()->db;
			$res = array();

			$uid = intval($_POST["uid"]);
			$limit = 6;

			$page_info = $connection->createCommand("SELECT * FROM {{usersinfo}} WHERE uid = :uid")
					->bindParam(":uid", $uid)
					->queryRow();
			if (!empty($page_info)) {
                if($page_info['type'] == 1){
                    $users = $connection->createCommand("SELECT u.uid, u.name as 'fio', u.photo, u.alias FROM {{usersinfo}} u INNER JOIN {{friends}} f ON f.uid = u.uid AND f.fuid = :uid AND u.type = 1 AND f.status = 2")
                        ->bindParam(":uid", $page_info['uid'])
                        ->queryAll();
                    $totalRecords = $connection->createCommand('SELECT FOUND_ROWS()')->queryScalar();
                }else{
                    $users = $connection->createCommand("SELECT u.uid, u.name as 'fio', u.photo, u.alias FROM {{usersinfo}} u INNER JOIN {{friends}} f ON f.uid = u.uid AND f.fuid = :uid AND u.type = 1")
                        ->bindParam(":uid", $page_info['uid'])
                        ->queryAll();
                    $totalRecords = count($users);
                    if($totalRecords > $limit){
                        $rand = rand(1, $totalRecords-$limit);
                        $users = array_slice($users, $rand, $limit);
                    }
                }

				$res["total"] = $totalRecords;
				$res["status"] = 200;
				$res["subscribers"] = $users;
			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionPageGetVideo()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$connection = Yii::app()->db;
			$res = array();

			$uid = intval($_POST["uid"]);
			$limit = intval($_POST["limit"]);

			if (!empty($uid)) {
				$video = $connection->createCommand("SELECT SQL_CALC_FOUND_ROWS media_vid, `date` FROM {{posts}} WHERE repost = 0 AND puid = :uid AND media_vid <> '' ORDER BY date DESC LIMIT :limit")
					->bindParam(":uid", $uid)
					->bindParam(":limit", $limit)
					->queryAll();
				$totalRecords = $connection->createCommand('SELECT FOUND_ROWS()')->queryScalar();

				$res["video"] = $video;
				$res["total"] = $totalRecords;
				$res["status"] = 200;
			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionGroupsMy()
	{

		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();

			$connection = Yii::app()->db;
			$limit = Yii::app()->params['users-per-page'];

			$friends = intval($_POST['friends']);
			$page = intval($_POST['page']);
			$search_query = mysql_escape_string(htmlspecialchars(strip_tags($_POST["search_query"])));
			$pieces = explode(" ", $search_query);

			$query = array();

			$query['not_me'] = ' u.uid <> :uid ';
			if (!empty($country) && $country > 0) {
				$query['country'] = ' u.country = :country ';
			}
			if (!empty($search_query) && strlen($search_query) >= 3) {
				if (count($pieces) == 1) {
					$query['search_query'] = ' (u.name LIKE :text1 || u.fio LIKE :text1) ';
				} elseif (count($pieces) == 2) {
					$query['search_query'] = ' (u.name LIKE :text1 || u.fio LIKE :text1 || u.name LIKE :text2 || u.fio LIKE :text2) ';
				}
			}

			$query = !empty($query) ? " WHERE " . implode(" AND ", $query) : '';
			$friends_query_1 = !empty($friends) ? "  INNER JOIN {{friends}} f ON f.uid = :uid AND f.fuid = u.uid  " : ' LEFT JOIN {{friends}} f ON f.uid = :uid AND f.fuid = u.uid ';
			$friends_query_2 = !empty($friends) ? "" : '  AND f.id IS NULL  ';

			$sql = "SELECT SQL_CALC_FOUND_ROWS u.uid, u.name, u.fio, u.tel, u.photo, u.country, a.name AS alias, (f.id IS NOT NULL) AS friend FROM {{usersinfo}} u ".$friends_query_1." LEFT JOIN {{alias}} a ON a.uid = u.uid " . $query . $friends_query_2 . " ORDER BY uid LIMIT :limit OFFSET :offset";
			$command = $connection->createCommand($sql);
			$command->bindParam(":uid", Yii::app()->user->id, PDO::PARAM_INT);
			$command->bindValue(":limit", $limit, PDO::PARAM_INT);
			$command->bindValue(":offset", ($page - 1) * $limit, PDO::PARAM_INT);

			if (!empty($search_query) && strlen($search_query) >= 3) {
				if (count($pieces) == 1) {
					$command->bindValue(":text1", '%' . $pieces[0] . '%');
				} elseif (count($pieces) == 2) {
					$command->bindValue(":text1", '%' . $pieces[0] . '%');
					$command->bindValue(":text2", '%' . $pieces[2] . '%');
				}
			}

			$users = $command->queryAll();
			$totalRecords = $connection->createCommand('SELECT FOUND_ROWS()')->queryScalar();

			if (!empty($users)) {
				$res["users"] = $users;
				$res["total"] = $totalRecords;
				$res["status"] = 200;
			} else {
				$res["status"] = 500;
				$res["total"] = 0;
			}
			$res["test"] = $friends;

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionGroupList()
	{

		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();

			$connection = Yii::app()->db;
			$limit = Yii::app()->params['users-per-page'];
			$page = intval($_POST['page']);

			$groups = $connection->createCommand("SELECT SQL_CALC_FOUND_ROWS u.uid, u.name, u.photo, u.alias, u.about, (f.uid IS NOT NULL) AS subscribed FROM {{usersinfo}} u LEFT JOIN {{friends}} f ON f.uid = :uid AND f.fuid = u.uid WHERE (u.type = 2) ORDER BY uid LIMIT :limit OFFSET :offset")
				->bindParam(":uid", Yii::app()->user->id)
				->bindValue(":limit", $limit)
				->bindValue(":offset", ($page - 1) * $limit)
				->queryAll();

			$totalRecords = $connection->createCommand('SELECT FOUND_ROWS()')->queryScalar();

			if (!empty($groups)) {
				$res["groups"] = $groups;
				$res["total"] = $totalRecords;
				$res["status"] = 200;
			} else {
				$res["status"] = 500;
				$res["total"] = 0;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionGsearch()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			$limit = Yii::app()->params['users-per-page'];

			$uid = isset($_POST['uid']) ? intval($_POST['uid']) : Yii::app()->user->id;
			$act = intval($_POST['act']);
			$page = intval($_POST['page']);
			$search_query = mysql_escape_string(htmlspecialchars(strip_tags($_POST["search_query"])));
			$pieces = explode(" ", $search_query);

			$query = array();
			try {
				$query['group'] = ' u.type = 2 AND u.status = 1 ';

				if (!empty($search_query) && strlen($search_query) >= 3) {
					if (count($pieces) == 1) {
						$query['search_query'] = ' (u.name LIKE :text1) ';
					} elseif (count($pieces) == 2) {
						$query['search_query'] = ' (u.name LIKE :text1 || u.name LIKE :text2) ';
					}
				}

				$query = !empty($query) ? " WHERE " . implode(" AND ", $query) : '';

				if($act == 1){
					$sql = "SELECT g.count_user, u.uid, u.name, u.fio, u.photo, u.alias, u.about, (f.uid IS NOT NULL) AS subscribed FROM {{usersinfo}} u INNER JOIN {{friends}} f ON f.uid = :uid AND f.fuid = u.uid INNER JOIN {{groups}} g ON g.cid = u.uid  ".$query." ORDER BY g.count_user DESC LIMIT :limit OFFSET :offset";
				}elseif($act == 2){
					$sql = "SELECT g.count_user, u.uid, u.name, u.fio, u.photo, u.alias, u.about, (f.uid IS NOT NULL) AS subscribed FROM {{usersinfo}} u LEFT JOIN {{friends}} f ON f.uid = :uid AND f.fuid = u.uid AND u.owner = :uid INNER JOIN {{groups}} g ON g.cid = u.uid  ".$query." ORDER BY g.count_user DESC LIMIT :limit OFFSET :offset";
				}else{
					$sql = "SELECT g.count_user, u.uid, u.name, u.fio, u.photo, u.alias, u.about, (f.uid IS NOT NULL) AS subscribed FROM {{usersinfo}} u LEFT JOIN {{friends}} f ON f.uid = :uid AND f.fuid = u.uid INNER JOIN {{groups}} g ON g.cid = u.uid  ".$query." ORDER BY g.count_user DESC LIMIT :limit OFFSET :offset";
				}

				$command = $connection->createCommand($sql);
				$command->bindParam(":uid", $uid, PDO::PARAM_INT);
				$command->bindValue(":limit", $limit, PDO::PARAM_INT);
				$command->bindValue(":offset", ($page - 1) * $limit, PDO::PARAM_INT);

				if (!empty($search_query) && strlen($search_query) >= 3) {
					if (count($pieces) == 1) {
						$command->bindValue(":text1", '%' . $pieces[0] . '%');
					} elseif (count($pieces) == 2) {
						$command->bindValue(":text1", '%' . $pieces[0] . '%');
						$command->bindValue(":text2", '%' . $pieces[2] . '%');
					}
				}

				$groups = $command->queryAll();
				$totalRecords = $connection->createCommand('SELECT FOUND_ROWS()')->queryScalar();

				if (!empty($groups)) {
					$res["status"] = 200;
					$res["groups"] = $groups;
					$res["total"] = $totalRecords;
				} else {
					$res["status"] = 500;
					$res['test'] = $command;
					$res["total"] = 0;
				}
			} catch (Exception $e) {
				$res["status"] = 500;
				$res["message"] = "Сервер временно недоступен.";
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionPostLike()
	{
		if (Yii::app()->request->isAjaxRequest) {
			$res = array();
			$connection = Yii::app()->db;

			$post_id = intval($_POST["post"]);
			$post = $connection->createCommand("SELECT * FROM {{posts}} WHERE id = :post_id")->bindParam(":post_id", $post_id)->queryRow();

			$transaction = $connection->beginTransaction();
			try {
				if (!empty($post)) {

					$like = $connection->createCommand("SELECT * FROM {{posts_like}} WHERE uid = :uid AND pid = :pid")
							->bindParam(":pid", $post_id)
							->bindParam(":uid", Yii::app()->user->id)
							->queryRow();

					if (empty($like)) {
						$connection->createCommand("UPDATE {{posts}} SET like_count = like_count + 1  WHERE id = :id")
								->bindParam(":id", $post["id"])
								->query();
						$connection->createCommand()->insert('{{posts_like}}', array(
								'uid' => Yii::app()->user->id,
								'pid' => $post["id"],
								'hash' => Yii::app()->user->id.'.'.$post["id"]
						));

						$likes = $post["like_count"] + 1;
					} else {
						$connection->createCommand("UPDATE {{posts}} SET like_count = :likes  WHERE id = :id")
								->bindParam(":id", $post["id"])
								->bindValue(":likes", ($post["like_count"] - 1) < 0 ? 0 : $post["like_count"] - 1)
								->query();
						$connection->createCommand("DELETE FROM {{posts_like}} WHERE uid = :uid AND pid = :pid")
								->bindParam(":pid", $post_id)
								->bindParam(":uid", Yii::app()->user->id)
								->query();

						$likes = $post["like_count"] - 1;
					}

					$transaction->commit();
					$res['like_count'] = $likes;
					$res["status"] = 200;

				} else {
					$transaction->rollback();
					$res["status"] = 500;
				}
			} catch (Exception $e) {
				$transaction->rollback();
				$res["status"] = 500;
			}
			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionPostGetComments()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$connection = Yii::app()->db;
			$res = array();

			$post_id = intval($_POST["post_id"]);
			$part = intval($_POST["part"]);

			if($part){
				$comments = $connection->createCommand("SELECT SQL_CALC_FOUND_ROWS c.*, CONCAT(u.name, ' ', u.fio) as 'fio', u.name, u.photo as photo, a.name as alias FROM {{comments}} c LEFT JOIN {{alias}} a ON a.uid = c.uid INNER JOIN {{usersinfo}} u ON c.pid = :pid AND c.uid = u.uid AND c.type = 1 ORDER BY date DESC LIMIT 3")->bindParam(":pid", $post_id)->queryAll();
			}else{
				$comments = $connection->createCommand("SELECT SQL_CALC_FOUND_ROWS c.*, CONCAT(u.name, ' ', u.fio) as 'fio', u.name, u.photo as photo, a.name as alias FROM {{comments}} c LEFT JOIN {{alias}} a ON a.uid = c.uid INNER JOIN {{usersinfo}} u ON c.pid = :pid AND c.uid = u.uid AND c.type = 1 ORDER BY date ASC")->bindParam(":pid", $post_id)->queryAll();
			}
			$count = $connection->createCommand('SELECT FOUND_ROWS()')->queryScalar();

			$res["comments"] = $comments;
			$res["count"] = $count;
			$res["status"] = 200;

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionCommentDelete()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$connection = Yii::app()->db;

			//Входящие данные
			$id = intval($_POST["id"]);
			$user_ban = intval($_POST["user_ban"]);

			$transaction = $connection->beginTransaction();
			try {
				$comment = $connection->createCommand("SELECT * FROM {{comments}} WHERE id = :id AND type = 1")
					->bindParam(":id", $id)
					->queryRow();

				if (!empty($comment) && in_array($user_ban, array(0,1,2))) {
					//проверяем владелца поста
					$user_info = $connection->createCommand("SELECT u.* FROM {{usersinfo}} u INNER JOIN {{posts}} p ON p.id = :post_id AND u.uid = p.puid")
						->bindParam(":post_id", $comment['pid'])
						->queryRow();

					//Правила удаления комментариев
					if(
						!empty($user_info) &&
						($comment['uid'] == Yii::app()->user->id) || // Автор коммента может удалить свой коммент
						($user_info['owner'] == Yii::app()->user->id)  //Владелец поста может удаить все комменты
					){
						//удаляем комменарий
						Yii::app()->db->createCommand('DELETE FROM {{comments}} WHERE id = :id AND type = 1')
							->bindParam(":id", $id)
							->query();

						//удаляем уведомления
						Yii::app()->db->createCommand('DELETE FROM {{events}} WHERE (type = 5 AND data3 = :id) OR (type = 4 AND data2 = :id)')
							->bindParam(":id", $id)
							->query();

						if(
							$user_ban == 1 && // Если выбрано заблокировать пользователя
							$user_info['owner'] == Yii::app()->user->id && // Если я владелец поста
							$user_info['owner'] != $comment['uid'] // Если коммент не владельца поста
						){
							$banned = $connection->createCommand("SELECT * FROM {{users_ban}} WHERE uid = :post_owner_uid AND fuid = :fuid")
								->bindParam(":post_owner_uid", $user_info['uid'])
								->bindParam(":fuid", $comment['uid'])
								->queryRow();
							if(empty($banned)){
								$connection->createCommand()->insert('{{users_ban}}', array(
									'uid' => $user_info['uid'],
									'fuid' => $comment['uid'],
									'date' => time(),
									'hash' => $user_info['uid'].'.'.$comment['uid']
								));
							}
						}

						if(
							$user_ban == 2 && // Если выбрано удалить все комментарии за неделю
							$user_info['owner'] == Yii::app()->user->id && // Если я владелец поста
							$user_info['owner'] != $comment['uid'] // Если коммент не владельца поста
						){
							//удаляем комменарии за последнюю неделю
							Yii::app()->db->createCommand('DELETE c FROM {{comments}} c INNER JOIN {{posts}} p ON c.uid = :comment_uid AND c.pid = p.id AND p.puid = :page_uid AND c.date > :ban_date AND c.type = 1')
								->bindParam(":comment_uid", $comment['uid'])
								->bindParam(":page_uid", $user_info['uid'])
								->bindParam(":ban_date", strtotime('-1 week', time()))
								->query();
						}

						$transaction->commit();
						$res["status"] = 200;
					}else{
						$res["status"] = 500;
						$res["message"] = "Доступ запрещен.";
					}
				} else {
					$res["status"] = 500;
					$res["message"] = "При удалении комментария возникла ошибка.";
				}
			} catch(Exception $e) {
				$transaction->rollback();
				$res["status"] = 500;
				$res["message"] = "При удалении комментария возникла ошибка.";
			}
			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionFriendsList()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;

			$res["friends"] = $connection->createCommand("SELECT b.id, u.uid, CONCAT(u.name, ' ', u.fio) as fio, u.photo, u.alias FROM {{usersinfo}} u INNER JOIN {{friends}} f ON f.uid = :uid AND f.fuid = u.uid LEFT JOIN {{users_ban}} b on b.uid = u.uid AND b.fuid = :uid WHERE u.type = 1 AND b.id IS NULL")->bindParam(":uid", Yii::app()->user->id)->queryAll();
			$res["status"] = 200;

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionUnsubscribe()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;

			$uid = intval($_POST["uid"]);

			$info = $connection->createCommand("SELECT uid, type, owner FROM {{usersinfo}} WHERE uid = :uid")->bindParam(":uid", $uid)->queryRow();

			if (!empty($info)) {
				$transaction = $connection->beginTransaction();
				try {
					$connection->createCommand("DELETE FROM {{friends}} WHERE uid = :uid AND fuid = :fuid")->bindParam(":uid", Yii::app()->user->id)->bindParam(":fuid", $uid)->query();
                    $friend_my = $connection->createCommand("SELECT * FROM {{friends}} WHERE uid = :uid AND fuid = :fuid")->bindParam(":uid", $uid)->bindParam(":fuid", Yii::app()->user->id)->queryRow();
                    if(!empty($friend_my) && $friend_my['status'] == 2){
                        $connection->createCommand("UPDATE {{friends}} SET status = 1 WHERE uid = :uid AND fuid = :fuid")->bindParam(":uid", $uid)->bindParam(":fuid", Yii::app()->user->id)->query();
                    }

					$subscribe_repost = $connection->createCommand("SELECT * FROM {{events}} WHERE uid = :uid AND fuid = :fuid AND type = 3")
						->bindParam(":uid", $uid)
						->bindParam(":fuid", Yii::app()->user->id)
						->queryRow();
					if (!empty($subscribe_repost)) {
						$connection->createCommand("DELETE FROM {{events}} WHERE uid = :uid AND fuid = :fuid AND type = 3")
							->bindParam(":uid", $uid)
							->bindParam(":fuid", Yii::app()->user->id)
							->query();
					}

					if($info['type'] == 2){
						$connection->createCommand("UPDATE {{groups}} SET count_user = count_user - 1 WHERE cid = :cid")
							->bindParam(":cid", $info["uid"])
							->query();
					}

					$transaction->commit();
					$res["status"] = 200;
				} catch (Exception $e) {
					$transaction->rollback();
					$res["status"] = 500;
					$res["message"] = "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
				}
			} else {
				$res["status"] = 500;
				$res["message"] = "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionSubscribe()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			$err = '';

			$uid = intval($_POST["uid"]);

			$friend = $connection->createCommand("SELECT uid, type, owner FROM {{usersinfo}} WHERE uid = :uid")->bindParam(":uid", $uid)->queryRow();
			$is_friend = $connection->createCommand("SELECT * FROM {{friends}} WHERE uid = :uid AND fuid = :fuid")->bindParam(":uid", Yii::app()->user->id)->bindParam(":fuid", $uid)->queryRow();

			$today = strtotime('today midnight');

			$friends_today = intval($connection->createCommand("SELECT COUNT(id) as friends FROM {{friends}} WHERE uid = :uid AND date > :today")
				->bindParam(":uid", Yii::app()->user->id)
				->bindParam(":today", $today)
				->queryScalar());

			$friends_total = intval($connection->createCommand("SELECT COUNT(id) as friends FROM {{friends}} WHERE uid = :uid LIMIT 2000")
				->bindParam(":uid", Yii::app()->user->id)
				->queryScalar());

			if ($friends_today > 500) {
				$err .= "<p>У Вас превышен лимит подписок на день.</p>";
			}
			if ($friends_total > 20000) {
				$err .= "<p>У Вас превышен лимит подписок.</p>";
			}

			if (!empty($friend) && empty($is_friend) && $err == '') {
				$transaction = $connection->beginTransaction();
				try {
                    $is_subscribed = $connection->createCommand("SELECT * FROM {{friends}} WHERE fuid = :uid AND uid = :fuid AND status IN(0, 1)")->bindParam(":uid", Yii::app()->user->id)->bindParam(":fuid", $uid)->queryRow();

                    if(!empty($is_subscribed)){
                        $connection->createCommand()->insert('{{friends}}', array('uid' => Yii::app()->user->id, 'fuid' => $uid, 'date' => time(), 'status' => 2));
                        $connection->createCommand("UPDATE {{friends}} SET status = 2 WHERE uid = :uid AND fuid = :fuid")
                            ->bindParam(":uid", $uid)
                            ->bindParam(":fuid", Yii::app()->user->id)
                            ->query();
                    }else{
                        $connection->createCommand()->insert('{{friends}}', array('uid' => Yii::app()->user->id, 'fuid' => $uid, 'date' => time(), 'status' => 0));
                    }

					$subscribe_repost = $connection->createCommand("SELECT * FROM {{events}} WHERE uid = :uid AND fuid = :fuid AND type = 3")
						->bindParam(":uid", $uid)
						->bindParam(":fuid", Yii::app()->user->id)
						->queryRow();
					if (empty($subscribe_repost)) {
						$connection->createCommand()->insert('{{events}}', array(
							'uid' => $uid,
							'fuid' => Yii::app()->user->id,
							'date' => time(),
							'type' => 3,
							'status' => 0
						));
					}

					if($friend['type'] == 2){
						$connection->createCommand("UPDATE {{groups}} SET count_user = count_user + 1 WHERE cid = :cid")
							->bindParam(":cid", $friend["uid"])
							->query();
					}

					$transaction->commit();
					$res["status"] = 200;
				} catch (Exception $e) {
					$transaction->rollback();
					$res["status"] = 500;
					$res["message"] = "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
				}
			} else {
				$res["status"] = 500;
				$res["message"] = "Возникла ошибка. ".$err;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionUsearch()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			$limit = Yii::app()->params['users-per-page'];

			$uid = isset($_POST['uid']) ? intval($_POST['uid']) : Yii::app()->user->id;
			$act = intval($_POST['act']);
			$page = intval($_POST['page']);
			$country = intval($_POST['country']);
			$city = intval($_POST['city']);
			$sex = intval($_POST['sex']);
			$marital_status = intval($_POST['marital_status']);
			$age_from = intval($_POST['age_from']);
			$age_to = intval($_POST['age_to']);
			$search_query = mysql_escape_string(htmlspecialchars(strip_tags($_POST["search_query"])));
			$pieces = explode(" ", $search_query);

			$query = array();
			try {
				$query['user'] = ' u.type = 1 AND u.status = 1 ';
				$query['not_me'] = ' u.uid <> :uid ';
				if (!empty($country) && $country > 0) {
					$query['country'] = ' u.country = :country ';
				}
				if (!empty($city) && $city > 0) {
					$query['city'] = ' u.city = :city ';
				}
				if (!empty($sex) && in_array($sex, array(1, 2))) {
					$query['sex'] = ' u.sex = :sex ';
				}
				if (!empty($marital_status) && $marital_status > 0 && $marital_status <= 7) {
					$query['marital_status'] = ' u.marital_status = :marital_status ';
				}
				if (!empty($age_from) && $age_from >= 14) {
					$query['age_from'] = ' FLOOR(DATEDIFF(CURDATE(), u.birth)/365)>=:age_from ';
				}
				if (!empty($age_to) && $age_to <= 80) {
					$query['age_to'] = ' FLOOR(DATEDIFF(CURDATE(), u.birth)/365)<=:age_to ';
				}
				if (!empty($search_query) && strlen($search_query) >= 3) {
					if (count($pieces) == 1) {
						$query['search_query'] = ' (u.name LIKE :text1 || u.fio LIKE :text1) ';
					} elseif (count($pieces) == 2) {
						$query['search_query'] = ' (u.name LIKE :text1 || u.fio LIKE :text1 || u.name LIKE :text2 || u.fio LIKE :text2) ';
					}
				}

				$query = !empty($query) ? " WHERE " . implode(" AND ", $query) : '';

				if($act == 1){ // изходящие заявки
					$sql = "SELECT SQL_CALC_FOUND_ROWS u.uid, u.name, u.fio, u.alias, u.status, u.photo, u.country, u.online, u.sex FROM {{usersinfo}} u INNER JOIN {{friends}} f ON f.uid = :uid AND f.fuid = u.uid AND f.status IN (0, 1) " . $query . " ORDER BY uid DESC LIMIT :limit OFFSET :offset";
				}elseif($act == 2){ // входящие заявки
					$sql = "SELECT SQL_CALC_FOUND_ROWS u.uid, u.name, u.fio, u.alias, u.status, u.photo, u.country, u.online, u.sex, f.status as friend FROM {{usersinfo}} u INNER JOIN {{friends}} f ON f.fuid = :uid AND f.uid = u.uid AND f.status IN (0, 1) " . $query . " ORDER BY f.status ASC, uid DESC LIMIT :limit OFFSET :offset";
                }elseif($act == 3){ //blacklist
                    $sql = "SELECT SQL_CALC_FOUND_ROWS u.uid, u.name, u.fio, u.alias, u.status, u.photo, u.country, u.online, u.sex FROM {{usersinfo}} u INNER JOIN {{users_ban}} b ON b.uid = :uid AND b.fuid = u.uid " . $query . " ORDER BY uid DESC LIMIT :limit OFFSET :offset";
                }else{ // all users
					$sql = "SELECT SQL_CALC_FOUND_ROWS u.uid, u.name, u.fio, u.alias, u.status, u.photo, u.country, u.online, u.sex, (f.id IS NOT NULL) AS friend FROM {{usersinfo}} u LEFT JOIN {{friends}} f ON f.uid = :uid AND f.fuid = u.uid " . $query . " ORDER BY uid DESC LIMIT :limit OFFSET :offset";
				}

				$command = $connection->createCommand($sql);
				$command->bindParam(":uid", $uid, PDO::PARAM_INT);
				$command->bindValue(":limit", $limit, PDO::PARAM_INT);
				$command->bindValue(":offset", ($page - 1) * $limit, PDO::PARAM_INT);

				if (!empty($country) && $country > 0) {
					$command->bindParam(":country", $country);
				}
				if (!empty($city) && $city > 0) {
					$command->bindParam(":city", $city);
				}
				if (!empty($sex) && in_array($sex, array(1, 2))) {
					$command->bindParam(":sex", $sex);
				}
				if (!empty($marital_status)) {
					$command->bindParam(":marital_status", $marital_status);
				}
				if (!empty($age_from) && $age_from >= 14) {
					$command->bindParam(":age_from", $age_from);
				}
				if (!empty($age_to) && $age_to <= 80) {
					$command->bindParam(":age_to", $age_to);
				}
				if (!empty($search_query) && strlen($search_query) >= 3) {
					if (count($pieces) == 1) {
						$command->bindValue(":text1", '%' . $pieces[0] . '%');
					} elseif (count($pieces) == 2) {
						$command->bindValue(":text1", '%' . $pieces[0] . '%');
						$command->bindValue(":text2", '%' . $pieces[2] . '%');
					}
				}

				$users = $command->queryAll();
				$totalRecords = $connection->createCommand('SELECT FOUND_ROWS()')->queryScalar();

				if (!empty($users)) {
					$res["status"] = 200;
					$res["users"] = $users;
					$res["total"] = $totalRecords;
				} else {
					$res["status"] = 500;
					$res["total"] = 0;
				}
			} catch (Exception $e) {
				$res["status"] = 500;
				$res["message"] = "Сервер временно недоступен.";
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionEditBasicInfo()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;

			$sex = intval($_POST["sex"]);
			$marital_status = intval($_POST["marital_status"]);
			$bday = intval($_POST["bday"]);
			$bmonth = intval($_POST["bmonth"]);
			$byear = intval($_POST["byear"]);

			$birth = strtotime($byear . '-' . $bmonth . '-' . $bday);

			if (in_array($sex, array(0, 1, 2)) && in_array($sex, array(0,1,2,3,4,5,6,7)) && !empty($birth)) {
				if($sex == 0){
					$marital_status = 0;
				}
				$connection->createCommand("UPDATE {{usersinfo}} SET sex = :sex, marital_status = :marital_status, birth = :birth WHERE uid = :uid")
					->bindParam(":uid", Yii::app()->user->id)
					->bindParam(":sex", $sex)
					->bindParam(":marital_status", $marital_status)
					->bindParam(":birth", date('Y-m-d', $birth))
					->query();
				$res["status"] = 200;
			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionEditPersonalInfo()
	{
		$res["message"] = "Функция временно недоступна.";
		$res["status"] = 500;
		echo CJSON::encode($res);
		Yii::app()->end();

		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$err = '';
			$connection = Yii::app()->db;

			$interests = mysql_escape_string(htmlspecialchars(strip_tags($_POST["interests"])));
			$activities = mysql_escape_string(htmlspecialchars(strip_tags($_POST["activities"])));
			$about = mysql_escape_string(htmlspecialchars(strip_tags($_POST["about"])));

			if(!empty($alias) && $alias != $group_info['alias'] &&  !f_alias_allowed($alias)){
				$err .= '<li>Вы ввели недопустимое название адреса страницы или указаный адрес уже занят.</li>';
			}

			if (empty($err)) {
				$connection->createCommand("UPDATE {{usersinfo}} SET interests = :interests, activities = :activities, about = :about WHERE uid = :uid")
					->bindParam(":uid", Yii::app()->user->id)
					->bindParam(":interests", $interests)
					->bindParam(":activities", $activities)
					->bindParam(":about", $about)
					->query();
				$res["status"] = 200;
			}else{
				$res["status"] = 500;
				$res["message"] = $err;
			}


			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionEditContactInfo()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;

			$country = intval($_POST['country']);
			$city = intval($_POST['city']);
			$tel = mysql_escape_string(htmlspecialchars(strip_tags($_POST["tel"])));
			$skype = mysql_escape_string(htmlspecialchars(strip_tags($_POST["skype"])));

			$data = [
				'city_ids' => $city,
				'v' => '5.40',
			];
			$ch = curl_init();
			curl_setopt($ch, CURLOPT_URL, "https://api.vk.com/method/database.getCitiesById");
			curl_setopt($ch, CURLOPT_HTTPHEADER, ['Accept-Language: ru']);
			curl_setopt($ch, CURLOPT_POST, 1);
			curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
			curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
			curl_setopt($ch, CURLOPT_REFERER, "https://api.vk.com/method/database.getCitiesById");

			$result = curl_exec($ch);
			curl_close($ch);

			$results = json_decode($result, true);
			$city = !empty($results['response']) ? $city : 0;

			$connection->createCommand("UPDATE {{usersinfo}} SET country = :country, city = :city, tel = :tel, skype = :skype WHERE uid = :uid")
				->bindParam(":uid", Yii::app()->user->id)
				->bindParam(":country", $country)
				->bindParam(":city", $city)
				->bindParam(":tel", $tel)
				->bindParam(":skype", $skype)
				->query();
			$res["status"] = 200;

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionCountries()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$query = mysql_escape_string(htmlspecialchars(strip_tags($_POST["q"])));

			if (strlen($query) >= 2) {
				$data = [
						'need_all' => 1,
						'count' => 1000,
						'offset' => 0,
						'v' => '5.40'
				];
				$ch = curl_init();
				curl_setopt($ch, CURLOPT_URL, "https://api.vk.com/method/database.getCountries");
				curl_setopt($ch, CURLOPT_HTTPHEADER, ['Accept-Language: ru']);
				curl_setopt($ch, CURLOPT_POST, 1);
				curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
				curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
				curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
				curl_setopt($ch, CURLOPT_REFERER, "https://api.vk.com/method/database.getCountries");

				$result = curl_exec($ch);
				curl_close($ch);

				$results = json_decode($result, true);

				$res["countries"] = $results['response']['items'];
				$res["status"] = 200;
			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionCities()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();

			$country_id = intval($_POST['id']);
			$query = mysql_escape_string(htmlspecialchars(strip_tags($_POST["q"])));

			if ($country_id > 0 && strlen($query) >= 2) {
				$data = [
					'need_all' => 1,
					'count' => 10,
					'offset' => 0,
					'v' => '5.40',
					'q' => $query,
					'country_id' => $country_id,
				];
				$ch = curl_init();
				curl_setopt($ch, CURLOPT_URL, "https://api.vk.com/method/database.getCities");
				curl_setopt($ch, CURLOPT_HTTPHEADER, ['Accept-Language: ru']);
				curl_setopt($ch, CURLOPT_POST, 1);
				curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
				curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
				curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
				curl_setopt($ch, CURLOPT_REFERER, "https://api.vk.com/method/database.getCities");

				$result = curl_exec($ch);
				curl_close($ch);

				$results = json_decode($result, true);

				$res["cities"] = $results['response']['items'];
				$res["status"] = 200;
			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionError()
	{
		if ($error = Yii::app()->errorHandler->error) {
			if (Yii::app()->request->isAjaxRequest)
				echo $error['message'];
			else
				$this->render('error', $error);
		}
	}
}