<?php

class ControlController extends Controller
{
	public $layout='//layouts/control';

	public function filters()
	{
		return array(
			'accessControl',
		);
	}

	public function accessRules()
	{
		return array(
			array('allow',
				'users' => array('@'),
			),
			array('deny',
				'users' => array('*'),
			)
		);
	}
	
	
	private function accessUid() {
		
		if(in_array(Yii::app()->user->id, array(3, 100014, 100019, 217228))) {
			$access = true;	
		} else {
			$access = false;
		}
		
		$access = true;
		
		return $access;
		
	}
	
	
	

	public function actionIndex()
	{
		
		if(!$this->accessUid()) Yii::app()->end();
		$this->render('index');
	}

	public function actionPaymentSolution()
	{
		if(!$this->accessUid()) Yii::app()->end();
		$this->render('paymentsolution');
	}

	public function actionPosts()
	{
		if(!$this->accessUid()) Yii::app()->end();
		$this->render('posts');
	}

	public function actionPostDelete()
	{
		if(!$this->accessUid()) Yii::app()->end();
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			$fs_db = Yii::app()->fs_db;

			//Входящие данные
			$id = intval($_POST["id"]);

			$info = $connection->createCommand("SELECT uid, alias, package FROM {{usersinfo}} WHERE uid = :uid AND status = 1 AND package > 0")
				->bindParam(":uid", Yii::app()->user->id)
				->queryRow();

			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->bindValue(":action", 'posts')
				->queryRow();

			$post = $connection->createCommand("SELECT * FROM {{posts}} WHERE id = :id AND status = 1")
				->bindParam(":id", $id)
				->queryRow();

			if (!empty($info) && !empty($is_access) && !empty($post)) {

				$transaction = $connection->beginTransaction();
				try {

					// Удалаем запись
					$connection->createCommand("UPDATE {{posts}} SET status = 0 WHERE id = :id AND status = 1")
						->bindParam(":id", $id)
						->query();

					// Удаляем все репосты
					$connection->createCommand("UPDATE {{posts}} SET status = 0 WHERE repost = :id AND status = 1")
						->bindParam(":id", $id)
						->query();


					// если это репост
					if($post['repost'] > 0){
						$original_post = $connection->createCommand("SELECT * FROM {{posts}} WHERE id = :id AND status = 1")
							->bindParam(":id", $post['repost'])
							->queryRow();

						// Удалаем оригинал
						$connection->createCommand("UPDATE {{posts}} SET status = 0 WHERE id = :id AND status = 1")
							->bindParam(":id", $original_post['id'])
							->query();

						// Удаляем все репосты
						$connection->createCommand("UPDATE {{posts}} SET status = 0 WHERE repost = :id AND status = 1")
							->bindParam(":id", $original_post['id'])
							->query();
					}

					// Удаляем изображения
					if(!empty($post['media_img'])){
						$photos_count = $connection->createCommand("SELECT COUNT(*) FROM {{posts}} WHERE media_img = :photo AND status = 1")
							->bindParam(":photo", $post['media_img'])
							->queryScalar();
						if($photos_count == 0){
							//Удаляем изображение
							$fs_db->createCommand("UPDATE {{images}} SET status = 2 WHERE path = :path")
								->bindParam(":path", $post['media_img'])
								->query();
						}
					}

				} catch (Exception $e) {
					$transaction->rollback();
					$res["status"] = 500;
					$res["message"] = "При удалении записи возникла ошибка.";
				}

				$transaction->commit();
				$res["status"] = 200;
			} else {
				$res["status"] = 500;
				$res["message"] = "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionPostFilter()
	{
		if(!$this->accessUid()) Yii::app()->end();
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			$limit = Yii::app()->params['users-per-page'];
			$page = intval($_POST["page"]);

			$info = $connection->createCommand("SELECT uid, alias, package FROM {{usersinfo}} WHERE uid = :uid AND status = 1 AND package > 0")
				->bindParam(":uid", Yii::app()->user->id)
				->queryRow();

			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->bindValue(":action", 'posts')
				->queryRow();

			if (!empty($page) && !empty($info) && !empty($is_access)) {

				$res["posts"]= $connection->createCommand("SELECT p.id, p.uid, p.puid, p.type, p.category_name, p.text, p.desc, p.title, p.repost, p.date, p.like_count, p.repost_count, p.dislike_count, p.media_img, p.media_vid, u.photo, CONCAT(u.name, ' ', u.fio) as 'fio', u.alias, u2.photo as repost_photo, CONCAT(u2.name, ' ', u2.fio) as 'repost_fio', u2.alias as repost_alias FROM {{posts}} p INNER JOIN {{usersinfo}} u ON u.uid = p.uid LEFT JOIN {{usersinfo}} u2 ON u2.uid = p.puid WHERE p.status = 1 AND p.dislike_count > 0 LIMIT :limit OFFSET :offset")
					->bindValue(":limit", $limit, PDO::PARAM_INT)
					->bindValue(":offset", ($page - 1) * $limit, PDO::PARAM_INT)
					->queryAll();

				$res["status"] = 200;
			} else {
				$res["status"] = 500;
				$res["message"] = "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionGetPaymentSolutions(){

		if(!$this->accessUid()) Yii::app()->end();
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;

			if (Yii::app()->user->id > 0) {

				$res["solutions"]= $connection->createCommand("SELECT s.*, CONCAT(u.name, ' ', u.fio) as fio FROM {{users_payment_solution}} s INNER JOIN {{usersinfo}} u ON u.uid = s.uid WHERE s.status IN (0,1) ORDER BY status ASC, date DESC LIMIT 20")
					->queryAll();

				$res["status"] = 200;

			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionPaymentSolutionActivate(){

		if(!$this->accessUid()) Yii::app()->end();
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			$err = '';

			$id = intval($_POST["id"]);
			$transaction_code = mysql_escape_string(htmlspecialchars(strip_tags($_POST["code"])));
			$uid = explode("-", $transaction_code);
			$uid = intval($uid[0]);

			$solution = $connection->createCommand("SELECT * FROM {{users_payment_solution}} WHERE id = :id AND status = 0")
				->bindParam(":id", $id)
				->queryRow();

			$info = $connection->createCommand("SELECT uid, alias, package FROM {{usersinfo}} WHERE uid = :uid AND status = 1 AND package > 0")
				->bindParam(":uid", Yii::app()->user->id)
				->queryRow();

			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->bindValue(":action", 'paymentsolution')
				->queryRow();

			$trans = $connection->createCommand("SELECT * FROM {{users_payment_package}} WHERE uid = :uid AND code = :code AND status = 1 AND type IN (1,2)")
				->bindParam(":uid", $solution['uid'])
				->bindParam(":code", $transaction_code)
				->queryRow();

			$wallet = $connection->createCommand("SELECT id, uid, money_my FROM {{users_payment_wallet}} WHERE id = :id")
				->bindParam(":id", $trans["psid"])
				->queryRow();

			$userinfo = $connection->createCommand("SELECT package, level, refx FROM {{usersinfo}} WHERE uid = :uid")
				->bindParam(":uid", $trans["uid"])
				->queryRow();

			if(empty($transaction_code) || empty($trans) || $uid != $solution['uid']){
				$err = '<li>Код активации веден неверно.</li>';
			}
			if(empty($solution)){
				$err = '<li>Заявка не найдена.</li>';
			}
			if(empty($info) || empty($is_access)){
				$err = '<li>Доступ запрещен.</li>';
			}
			
			if(empty($trans)){
				$err = '<li>Транзакция payment_package не найдена.</li>';
			}
			
			if(empty($wallet)){
				$err = '<li>Кошелек не найден.</li>';
			}
			
			if($err == "" && $trans["type"] == 1) {
				if($userinfo['package'] >= $trans['package']){
					$err .= "<li>Вы не можете активировать данный пакет, так как подписка пользователя более актуальна.</li>";
				}
			}

			if (!empty($info) && !empty($is_access) && !empty($trans) && !empty($wallet) && !empty($userinfo) && $err == '') {
				
				
				
				$transaction = $connection->beginTransaction();
				try {
					
					if($trans["type"] == 1) {
					
					//++++++++++++++++++++++++++++++++++++
					$amount = $trans["amount"];
					//++++++++++++++++++++++++++++++++++++

					$connection->createCommand()->insert('{{users_payment_transactions}}', array('uid' => $trans["uid"], 'date' => time(), 'code' => $trans["code"], 'amount' => $amount, 'package' => $trans["package"] , 'payment_amount' => $amount, 'payment_currency' => 'USD', 'payment_transaction' => $trans["code"], 'payment_date' => time(), 'payment_from' => '', 'payment_to' => '', 'status' => 1));
					$utransactions_id = $connection->getLastInsertID();


					$connection->createCommand()->insert('{{users_payment_hendactivation}}', array('uid' => Yii::app()->user->id, 'date' => time(), 'code' => $trans["code"], 'status' => 1));
					$utransactions_id = $connection->getLastInsertID();


					$connection->createCommand("UPDATE {{users_payment_package}} SET status = 2 WHERE uid = :uid AND code = :code AND status = 1")
						->bindParam(":uid", $trans["uid"])
						->bindParam(":code", $trans["code"])
						->query();

					$connection->createCommand("UPDATE {{usersinfo}} SET package = :package WHERE uid = :uid; UPDATE {{users_invite_user}} SET status = 1, package = :package WHERE uid = :uid; ")
						->bindParam(":uid", $trans["uid"])
						->bindParam(":package", $trans["package"])
						->query();

					$connection->createCommand()->insert('{{users_pkg}}', array('uid' => $trans["uid"], 'date' => time(),  'deposit' => $amount, 'pid' => $utransactions_id, 'type' => $trans["package"], 'status' => 1, 'hash' => doubleval($trans["uid"] . "." . $trans["package"]) ));
					$kpg_id = Yii::app()->db->getLastInsertID();




					//Обновляем сумму в кошельке у хранителя
					$connection->createCommand("UPDATE {{users_payment_wallet}} SET money_my = money_my + :money WHERE id = :id")
						->bindParam(":id", $trans["psid"])
						->bindParam(":money", $amount)
						->query();

					//Вставляем транзакцию
					$connection->createCommand()->insert('{{utransactions}}', array(
						'did' => $kpg_id, 'psid' => $wallet["id"], 'uid' => $wallet['uid'], 'ruid' => $trans["uid"], 'amount' => $amount, 'amount_now' => $wallet['money_my'] + $amount, 'date' => time(), 'type' => 1, 'status' => 1, 'transaction' => $trans["code"], 'action' => 1
					));
					$utransactions = $connection->getLastInsertID();

					//Вставляем бонус + увеличиваем потенциал =============

					//Вставляем потенциал

					$percent = 0.003;
					$days = 333;
					$amount = $trans["amount"];

					$percent_promo = 0; //0.2 20%
					$amount_all = $amount + $percent_promo;


					$connection->createCommand()->insert('{{users_potential}}', array('uid' => $trans["uid"], 'cuid' => $trans["uid"], 'puid' => 0, 'fuid' => 0, 'date' => time(), 'dt' => 0, 'dte' => $days, 'deposit' => $amount, 'percent' => $percent, 'cash_now' => 0, 'cash_out' => 0, 'cash_all' => 0, 'type' => 1, 'status' => 1));
					$pid_id = Yii::app()->db->getLastInsertID();
					
					//Вставляем привязку из архива
					$amount_archive = doubleval($amount/2);
					$connection->createCommand()->insert('{{users_potential_archive}}', array(
						'uid' => $trans["uid"], 
						'pid' => $pid_id, 
						'gid' => 0,
						'date' => time(), 
						'amount' => $amount_archive, 
						'status' => 0
					));


					//Вставляем акционное приумножение

					$promo = 0.7; //В 2 раза
					$invite_count = 10;
					switch($trans["package"]) {
						case 1:
							$promo = 0.7;
							$invite_count = 10;
							break;
						case 2:
							$promo = 0.8;
							$invite_count = 10;
							break;
						case 3:
							$promo = 0.9;
							$invite_count = 10;
							break;
						case 4:
							$promo = 1;
							$invite_count = 10;
							break;
						case 5:
							$promo = 1.1;
							$invite_count = 10;
							break;
						case 6:
							$promo = 1.2;
							$invite_count = 10;
							break;
						case 7:
							$promo = 1.25;
							$invite_count = 10;
							break;
						case 8:
							$promo = 1;
							$invite_count = 10;
							break;
						case 9:
							$promo = 0.75;
							$invite_count = 10;
							break;
						case 10:
							$promo = 0.5;
							$invite_count = 10;
							break;

					}

					$hash_promo = $trans["uid"] . "." . time();
					$date_activate = time() + rand(36000, 108000);
					$amount_promo = $amount * $promo;

					$connection->createCommand()->insert('{{users_potential}}', array('uid' => $trans["uid"], 'cuid' => $trans["uid"], 'puid' => 0, 'fuid' => 0, 'date' => time(), 'dt' => 0, 'dte' => $days, 'deposit' => $amount_promo, 'percent' => $percent, 'cash_now' => 0, 'cash_out' => 0, 'cash_all' => 0, 'type' => 3, 'status' => 1));
					$pid_promo_id = Yii::app()->db->getLastInsertID();

					$connection->createCommand()->insert('{{users_potential_promo}}', array('uid' => $trans["uid"], 'pid' => $pid_id, 'amount' => $amount, 'promo' => $promo, 'date' => time(), 'date_activate' => $date_activate, 'status' => 1, 'hash' => $hash_promo));


					//Вставляем бонус + увеличиваем потенциал =============

					//Раздаем инвайты
					if($userinfo["package"] == 0) {

						$connection->createCommand()->insert('{{users_invite_new}}', array('uid' => $trans["uid"], 'amount' => $invite_count, 'date' => time(), 'type' => 1, 'status' => 0, 'hash' => doubleval($trans["uid"] . "." . time()) ));

					}
					
					
					if($userinfo["level"] == -1 && $userinfo["package"] == 0) {
						$connection->createCommand("UPDATE {{usersinfo}} SET level = 0 WHERE uid = :uid; UPDATE {{usersinfo}} SET count_users = count_users + 1 WHERE uid = :refx;")
						->bindParam(":uid", $trans["uid"])
						->bindParam(":refx", $userinfo["refx"])
						->query();
					}


					//Начисляем призовые. Если нет - отлаживаем их начисление;
					if(Functions::access_level(1, $trans["uid"])) {
						Money2::update_money_x($amount, $trans["uid"], 1); //type 1 = pkg
					} else {

						//Откладываем начисление до дольнейших разбирательств в чем проблема
						$connection->createCommand()->insert('{{usersdeposit_rx2_cancel}}', array('uid' => $trans["uid"], 'amount' => $amount, 'date' =>  time(), 'type' => 1, 'status' => 0));

					}

					$connection->createCommand("UPDATE {{users_payment_solution}} SET status = 1, code = :code WHERE id = :id")
						->bindParam(":id", $id)
						->bindParam(":code", $transaction_code)
						->query();

					$res["status"] = 200;
					$res["message"] = "Активация подписки прошла успешно. Ваш потенциал пополнен на $amount бонусных единиц (Bonus Point). " . $transaction_code;
					
					}
					
					
					// =================================================================================================
					// ТИП 2 - пополнение потенциала
					// =================================================================================================
					
					if($trans["type"] == 2) {
						
						
						//++++++++++++++++++++++++++++++++++++
						$amount = $trans["amount"];
						//++++++++++++++++++++++++++++++++++++
				
						$connection->createCommand()->insert('{{users_payment_transactions}}', array('uid' => $trans["uid"], 'date' => time(), 'code' => $trans["code"], 'amount' => $amount, 'package' => $trans["package"] , 'payment_amount' => $amount, 'payment_currency' => "USD", 'payment_transaction' => $trans["code"], 'payment_date' => time(), 'payment_from' => '', 'payment_to' => '', 'status' => 1));							
						$utransactions_id = $connection->getLastInsertID();
						
						$connection->createCommand("UPDATE {{users_payment_package}} SET status = 2 WHERE uid = :uid AND code = :code AND status = 1")
							->bindParam(":uid", $trans["uid"])
							->bindParam(":code", $trans["code"])
							->query();

						//Обновляем сумму в кошельке у хранителя
						$connection->createCommand("UPDATE {{users_payment_wallet}} SET money_my = money_my + :money WHERE id = :id")
							->bindParam(":id", $trans["psid"])
							->bindParam(":money", $amount)
							->query();
						
						//Вставляем транзакцию
						$connection->createCommand()->insert('{{utransactions}}', array(
							'did' => $trans["id"], 'psid' => $wallet["id"], 'uid' => $wallet['uid'], 'ruid' => $trans["uid"], 'amount' => $amount, 'amount_now' => $wallet['money_my'] + $amount, 'date' => time(), 'type' => 1, 'status' => 1, 'transaction' => $trans["code"], 'action' => 3
						));
						$utransactions = $connection->getLastInsertID();
						
					
					
					
						//Вставляем бонус + увеличиваем потенциал =============
						
						//Вставляем потенциал
						
						$percent = 0.003;
						$days = 333;
						$amount = $trans["amount"];
						
						$percent_promo = 0; //0.2 20%
						$amount_all = $amount + $percent_promo;
						

						$connection->createCommand()->insert('{{users_potential}}', array('uid' => $trans["uid"], 'cuid' => $trans["uid"], 'puid' => 0, 'fuid' => 0, 'date' => time(), 'dt' => 0, 'dte' => $days, 'deposit' => $amount, 'percent' => $percent, 'cash_now' => 0, 'cash_out' => 0, 'cash_all' => 0, 'type' => 4, 'status' => 1));			
						$pid_id = Yii::app()->db->getLastInsertID();

						
						//Вставляем акционное приумножение
						
						$promo = 0.7; //В 2 раза
						$invite_count = 10;
						switch($trans["package"]) {
							case 1:
								$promo = 0.7;
								$invite_count = 10;
								break;
							case 2:
								$promo = 0.8;
								$invite_count = 10;
								break;
							case 3:
								$promo = 0.9;
								$invite_count = 10;
								break;
							case 4:
								$promo = 1;
								$invite_count = 10;
								break;
							case 5:
								$promo = 1.1;
								$invite_count = 10;
								break;
							case 6:
								$promo = 1.2;
								$invite_count = 10;
								break;
							case 7:
								$promo = 1.25;
								$invite_count = 10;
								break;
							case 8:
								$promo = 1;
								$invite_count = 10;
								break;
							case 9:
								$promo = 0.75;
								$invite_count = 10;
								break;
							case 10:
								$promo = 0.5;
								$invite_count = 10;
								break;
							
						}
						
						$hash_promo = $trans["uid"] . "." . time();
						$date_activate = time() + rand(36000, 108000);
						$amount_promo = intval($amount * $promo * 100) / 100;
						
						$connection->createCommand()->insert('{{users_potential}}', array('uid' => $trans["uid"], 'cuid' => $trans["uid"], 'puid' => 0, 'fuid' => 0, 'date' => time(), 'dt' => 0, 'dte' => $days, 'deposit' => $amount_promo, 'percent' => $percent, 'cash_now' => 0, 'cash_out' => 0, 'cash_all' => 0, 'type' => 3, 'status' => 1));			
						$pid_promo_id = Yii::app()->db->getLastInsertID();
						
						$connection->createCommand()->insert('{{users_potential_promo}}', array('uid' => $trans["uid"], 'pid' => $pid_id, 'amount' => $amount, 'promo' => $promo, 'date' => time(), 'date_activate' => $date_activate, 'status' => 1, 'hash' => $hash_promo));
						
						
						
						if($userinfo["level"] == -1 && $userinfo["package"] == 0) {
							$connection->createCommand("UPDATE {{usersinfo}} SET level = 0 WHERE uid = :uid; UPDATE {{usersinfo}} SET count_users = count_users + 1 WHERE uid = :refx;")
							->bindParam(":uid", $trans["uid"])
							->bindParam(":refx", $userinfo["refx"])
							->query();
						}
						
	
						//Начисляем призовые. Если нет - отлаживаем их начисление;
						if(Functions::access_level(1, $trans["uid"])) {
							Money2::update_money_x($amount, $trans["uid"], 2); //type 1 = pkg
						} else {
							
							//Откладываем начисление до дольнейших разбирательств в чем проблема
							$connection->createCommand()->insert('{{usersdeposit_rx2_cancel}}', array('uid' => $trans["uid"], 'amount' => $amount, 'date' =>  time(), 'type' => 1, 'status' => 0));
							
						}
						
						$res["status"] = 200;
						$res["message"] = " Потенциал пользователя пополнен на $amount и $amount_promo Bonus Points." . $transaction_code;
						 
					}
					
					
					
					
					$transaction->commit();

				} catch (Exception $e) {
					$transaction->rollback();
					$res["status"] = 500;
					$res["message"] = $e . "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
				}
			} else {
				$res["status"] = 500;
				$res["message"] = "Возникла ошибка. ".$err;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	
	public function actionUserVerify()
	{
		$this->render('userverify');
	}
	
	public function actionGetUserVerify()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->bindValue(":action", 'userverify')
				->queryRow();

			if (Yii::app()->user->id > 0 && !empty($is_access)) {
				
				$date = time();
				
				$res["verify"]= $connection->createCommand("SELECT u.*, v.percent, v.discount, v.multi, v.type, FLOOR(($date - v.date) / 86400) as 'days' FROM {{usersinfo}} u INNER JOIN {{users_verify}} v ON u.uid = v.uid WHERE u.verify = 1 AND u.type = 1")
					->queryAll();

				$res["status"] = 200;

			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	public function actionSetUserVerifyOk()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$email = mysql_escape_string(htmlspecialchars(strip_tags($_POST["email"])));
			$percent = intval($_POST["percent"]);
            $discount = intval($_POST["discount"]);
            $multi = intval($_POST["multi"]);
            $type = intval($_POST["type"]);
			
			$err = "";
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->bindValue(":action", 'userverify')
				->queryRow();
				
			$userinfo = $connection->createCommand("SELECT * FROM {{usersinfo}} WHERE email = :email AND type = 1")
				->bindParam(":email", $email)
				->queryRow();
			
			if(empty($is_access))
				Yii::app()->end();
				
			if(!empty($userinfo))
				$uid = $userinfo["uid"];
				
				
			$is_verify = $connection->createCommand("SELECT * FROM {{users_verify}} WHERE uid = :uid")
				->bindParam(":uid", $uid)
				->queryRow();
				
			if(!empty($is_verify))
				$err .= "<li>Пользователь находится в списке верифицированных.</li>";
				
			if($userinfo["verify"] == 1)
				$err .= "<li>Пользователь верифицирован.</li>";
			
			if($userinfo["package"] <= 0)
				$err .= "<li>Недостаточная подписка.</li>";
				
			if($percent < 10 || $percent > 100)
				$err .= "<li>Минимальный процент 10, максимальный 100.</li>";

            if($discount < 0 || $discount > $percent){
                $err .= "<li>Минимальная скидка 0, максимальная не должна превышать процент.</li>";
            }
            
	        if($multi < 0 || $multi > 100)
	            $err .= "<li>Минимальный множитель 0, максимальный 100.</li>";
	            
	        if(!in_array($type, array(0,1)))
	            $err .= "<li>Неверно указан тип верификации.</li>";

			
			if (Yii::app()->user->id > 0 && $err == "") {

				$connection->createCommand()->insert('{{users_verify}}', array('uid' => $uid, 'cuid' => Yii::app()->user->id, 'date' => time(), 'percent' => $percent, 'discount' => $discount, 'multi' => $multi, 'status' => 1, 'type' => $type ));
				
				$connection->createCommand("UPDATE {{usersinfo}} SET verify = 1, package = 3 WHERE uid = :uid AND type = 1 AND verify = 0")
					->bindParam(":uid", $uid)
					->query();
					
				$data = "$email, $percent";
				Log::setlog(Yii::app()->user->id, $uid, 'control', 'setuserverifyok', 1, $data);

				$res["status"] = 200;
				$res["userinfo"] = $userinfo;
				$res["message"] = "Пользователь успешно добавлен в список верифицированных.";

			} else {
				$res["status"] = 500;
				$res["message"] = "Возникла ошибка. " . $err;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	public function actionSetUserVerifyCancel()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$uid = intval($_POST["uid"]);
			
			$err = "";
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->bindValue(":action", 'userverify')
				->queryRow();
				
			$is_verify = $connection->createCommand("SELECT * FROM {{users_verify}} WHERE uid = :uid")
				->bindParam(":uid", $uid)
				->queryRow();
				
			$userinfo = $connection->createCommand("SELECT * FROM {{usersinfo}} WHERE uid = :uid AND type = 1")
				->bindParam(":uid", $uid)
				->queryRow();
				
			if(empty($is_access))
				Yii::app()->end();
				
			/*if(empty($is_verify))
				$err .= "<li>Пользователь не находится в списке верифицированных.</li>";*/
				
			if($userinfo["verify"] == 0)
				$err .= "<li>Пользователь не верифицирован.</li>";
			
			if($userinfo["package"] <= 0)
				$err .= "<li>Недостаточная подписка.</li>";

			if (Yii::app()->user->id > 0 && !empty($is_access) && $err == "") {

				$connection->createCommand("DELETE FROM {{users_verify}} WHERE uid = :uid")
					->bindParam(":uid",$uid)
					->query();
					
				$connection->createCommand("UPDATE {{usersinfo}} SET verify=0 WHERE uid = :uid")
					->bindParam(":uid", $uid)
					->query();
					
				$connection->createCommand("UPDATE {{goods}} SET status=0 WHERE uid = :uid")
					->bindParam(":uid", $uid)
					->query();
				
				$data = "$uid";
				Log::setlog(Yii::app()->user->id, $uid, 'control', 'setuserverifycancel', 1, $data);
				
				$res["status"] = 200;
				$res["message"] = "Пользователь удален из списка верифицированных.";

			} else {
				$res["status"] = 500;
				$res["message"] = "Возникла ошибка. " . $err;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	public function actionSetUserVerifyEdit()
    {
        if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
            $res = array();
            $connection = Yii::app()->db;

            $uid = mysql_escape_string(htmlspecialchars(strip_tags($_POST["uid"])));
            $percent = intval($_POST["percent"]);
            $discount = intval($_POST["discount"]);
            $multi = intval($_POST["multi"]);
            $type = intval($_POST["type"]);

            $err = "";

            $is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
                ->bindParam(":uid", Yii::app()->user->id)
                ->bindValue(":action", 'userverify')
                ->queryRow();

            $userinfo = $connection->createCommand("SELECT * FROM {{usersinfo}} WHERE uid = :uid AND type = 1")
                ->bindParam(":uid", $uid)
                ->queryRow();

            if(empty($is_access))
                Yii::app()->end();

            if(!empty($userinfo))
                $uid = $userinfo["uid"];

            $is_verify = $connection->createCommand("SELECT * FROM {{users_verify}} WHERE uid = :uid")
                ->bindParam(":uid", $uid)
                ->queryRow();

            if(empty($is_verify))
                $err .= "<li>Пользователь не найден.</li>";

            if($userinfo["verify"] != 1)
                $err .= "<li>Пользователь не верифицирован.</li>";

            if($userinfo["package"] <= 0)
                $err .= "<li>Недостаточная подписка.</li>";

            if($percent < 10 || $percent > 100)
                $err .= "<li>Минимальный процент 10, максимальный 100.</li>";

            if($multi < 0 || $multi > 100)
                $err .= "<li>Минимальный множитель 0, максимальный 100.</li>";

            if($discount < 0 || $discount > $percent){
                $err .= "<li>Минимальная скидка 0, максимальная не должна превышать процент.</li>";
            }
            
            if(!in_array($type, array(0,1)))
	            $err .= "<li>Неверно указан тип верификации.</li>";

            if (Yii::app()->user->id > 0 && $err == "") {

                $connection->createCommand("UPDATE {{users_verify}} SET percent = :percent, discount = :discount, multi = :multi, type = :type WHERE uid = :uid AND status = 1")
                    ->bindParam(":uid", $uid)
                    ->bindParam(":percent", $percent)
                    ->bindParam(":discount", $discount)
                    ->bindParam(":multi", $multi)
                    ->bindParam(":type", $type)
                    ->query();

                $data = $userinfo['email'].', '. $percent.', '.$discount.', '.$multi . ', ' . $type;
                Log::setlog(Yii::app()->user->id, $uid, 'control', 'setuserverifyedit', 1, $data);

                $res["status"] = 200;
                $res["message"] = "Изменения успешно сохранены!";

            } else {
                $res["status"] = 500;
                $res["message"] = "Возникла ошибка. " . $err;
            }

            echo CJSON::encode($res);
            Yii::app()->end();
        }
    }
	
	
	public function actionGetUserVerifyOrders()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;

			$uid = intval($_POST["uid"]);

			$user_info = $connection->createCommand("SELECT uid, alias, package FROM {{usersinfo}} WHERE uid = :uid AND status = 1 AND package > 0")
				->bindParam(":uid", $uid)
				->queryRow();
			$my_info = $connection->createCommand("SELECT uid, alias, package FROM {{usersinfo}} WHERE uid = :uid AND status = 1 AND package > 0")
				->bindParam(":uid", Yii::app()->user->id)
				->queryRow();
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->bindValue(":action", 'userverify')
				->queryRow();

			if (!empty($user_info) && !empty($is_access) && !empty($my_info)) {
				$orders = $connection->createCommand("SELECT g.title as 'price_title', o.id, o.gid, o.uid, FROM_UNIXTIME(o.date, '%d.%m.%Y') AS date, g.title, o.amount as price FROM {{orders}} o INNER JOIN {{goods}} g ON o.gid = g.gid WHERE g.uid = :uid AND o.status = 4 ORDER BY o.date DESC")
					->bindParam(":uid", $uid)
					->queryAll();

				$res["orders"] = $orders;
				$res["status"] = 200;
			}else{
				$res["status"] = 500;
				$res["message"] = "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	public function actionStatistic()
	{
		$connection = Yii::app()->db;
		
		$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
			->bindParam(":uid", Yii::app()->user->id)
			->bindValue(":action", 'statistic')
			->queryRow();
			
		if(empty($is_access))
			Yii::app()->end();
		
		$this->render('statistic');
	}
	
	
	public function actionStatisticMarket()
	{
		$connection = Yii::app()->db;

		$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
			->bindParam(":uid", Yii::app()->user->id)
			->bindValue(":action", 'statisticmarket')
			->queryRow();

		if(empty($is_access))
			Yii::app()->end();

		$this->render('statisticmarket');
	}
	
	
	public function actionGetStatMarketWeek()
	{

		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			
			$res = array();
			$connection = Yii::app()->db;
			$datestart = intval($_POST["datestart"]);
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
			->bindParam(":uid", Yii::app()->user->id)
			->bindValue(":action", 'statisticmarket')
			->queryRow();
			
		if(empty($is_access))
			Yii::app()->end();

			if (Yii::app()->user->id > 0) {
				$stats = [];
				$date_start = $datestart; //2 января 2017
				$date_end = time();
				$week = 604800;

				while($date_end + $week > $date_start){
					$stat = $connection->createCommand("SELECT FLOOR(SUM(amount)) as amount FROM {{utransactions2}} WHERE type = 0 AND action = 21 AND date >= :d1 AND date < :d2")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();
					$stat['date_start'] = date("d.m.Y", $date_start);

					$stats[] = $stat;

					$date_start += $week;
				}
				$res['stats'] = $stats;
				$res["status"] = 200;

			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	public function actionGetStatUsersWeek()
	{

		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			
			$res = array();
			$connection = Yii::app()->db;
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
			->bindParam(":uid", Yii::app()->user->id)
			->bindValue(":action", 'statistic')
			->queryRow();
			
		if(empty($is_access))
			Yii::app()->end();

			if (Yii::app()->user->id > 0) {
				$stats = [];
				$date_start = 1452470400;
				$date_end = time();
				$week = 604800;

				while($date_end + $week > $date_start){
					$stat = $connection->createCommand("SELECT COUNT(*) as users FROM {{users}} WHERE created >= :d1 AND created < :d2")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();
					
					$stat2 = $connection->createCommand("SELECT COUNT(*) as users FROM {{users}} u INNER JOIN {{usersinfo}} i ON u.uid = i.uid WHERE u.created >= :d1 AND u.created < :d2 AND i.package > 0")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();
						
					$stat3 = $connection->createCommand("SELECT COUNT(*) as users FROM {{users}} u INNER JOIN {{usersinfo}} i ON u.uid = i.uid WHERE u.created >= :d1 AND u.created < :d2 AND i.package = 0")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();
						
						
					$stat['date_start'] = date("d.m.Y", $date_start);

					$stats[] = $stat;
					$stats_package[] = $stat2;
					$stats_nopackage[] = $stat3;

					$date_start += $week;
				}
				$res['stats'] = $stats;
				$res['stats_package'] = $stats_package;
				$res['stats_nopackage'] = $stats_nopackage;
				$res["status"] = 200;

			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	public function actionGetStatUsersAll()
	{

		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			
			$res = array();
			$connection = Yii::app()->db;
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
			->bindParam(":uid", Yii::app()->user->id)
			->bindValue(":action", 'statistic')
			->queryRow();
			
		if(empty($is_access))
			Yii::app()->end();

			if (Yii::app()->user->id > 0) {
				$stats = [];
				$date_start = 1452470400;
				$date_end =   time();
				$week = 604800;

				while($date_end + $week > $date_start){
					$stat = $connection->createCommand("SELECT COUNT(*) as users FROM {{users}} u INNER JOIN {{usersinfo}} i ON u.uid = i.uid WHERE u.created <= :d1")
						->bindParam(":d1", intval($date_start + $week))
						->queryRow();
						
					$stat2 = $connection->createCommand("SELECT COUNT(*) as users FROM {{users}} u INNER JOIN {{usersinfo}} i ON u.uid = i.uid WHERE u.created <= :d1 AND i.package > 0")
						->bindParam(":d1", intval($date_start + $week))
						->queryRow();
						
					$stat3 = $connection->createCommand("SELECT COUNT(*) as users FROM {{users}} u INNER JOIN {{usersinfo}} i ON u.uid = i.uid WHERE u.created <= :d1 AND i.package = 0")
						->bindParam(":d1", intval($date_start + $week))
						->queryRow();
						
						
					$stat['date_start'] = date("d.m.Y", $date_start);

					$stats[] = $stat;
					$stats_package[] = $stat2;
					$stats_nopackage[] = $stat3;

					$date_start += $week;
				}
				$res['stats'] = $stats;
				$res['stats_package'] = $stats_package;
				$res['stats_nopackage'] = $stats_nopackage;
				$res["status"] = 200;

			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	public function actionGetStatUsersTransactionsDays()
	{

		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
			->bindParam(":uid", Yii::app()->user->id)
			->bindValue(":action", 'statistic')
			->queryRow();
			
		if(empty($is_access))
			Yii::app()->end();
			
			if (Yii::app()->user->id > 0) {
				$stats = [];
				$date_start = 1488326400;
				$date_end =   time();
				$week = 86400;

				while($date_end + $week > $date_start){
					$stat = $connection->createCommand("SELECT SUM(amount) as transactions FROM {{utransactions}} WHERE type = 1 AND date >= :d1 AND date < :d2")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();
					
					//Перфект	
					/*$stat2 = $connection->createCommand("SELECT SUM(t.amount) as transactions FROM {{utransactions}} t INNER JOIN {{users_payment_package}} p ON t.did = p.id WHERE t.type = 1 AND t.date >= :d1 AND t.date < :d2 AND t.psid IN (1,3,6,10,15,20)")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();*/
					$stat2 = $connection->createCommand("SELECT SUM(amount) as transactions FROM {{utransactions}} WHERE type = 1 AND date >= :d1 AND date < :d2 AND psid IN (1,3,6,10,15,20)")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();

					
					//Ваучеры	
					$stat3 = $connection->createCommand("SELECT SUM(amount) as transactions FROM {{utransactions}} WHERE type = 1 AND date >= :d1 AND date < :d2 AND psid NOT IN (1,3,6,10,15,20,23,30)")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();
						
						
					//Караты
					$stat4 = $connection->createCommand("SELECT SUM(t.amount) as transactions FROM {{utransactions}} t INNER JOIN {{users_payment_package}} p ON t.did = p.id WHERE t.type = 1 AND t.date >= :d1 AND t.date < :d2 AND t.psid = 23")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();
						
						
					//MS
					$stat5 = $connection->createCommand("SELECT SUM(t.amount) as transactions FROM {{utransactions}} t INNER JOIN {{users_payment_package}} p ON t.did = p.id WHERE t.type = 1 AND t.date >= :d1 AND t.date < :d2 AND t.psid = 30")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();
						
					
					$stat['date_start'] = date("d.m.Y", $date_start);
					$stats[] = $stat;
					$stats_perfect[] = $stat2;
					$stats_voucher[] = $stat3;
					$stats_crt[] = $stat4;
					$stats_ms[] = $stat5;
					
					$date_start += $week;
				}
				$res['stats'] = $stats;
				$res['stats_perfect'] = $stats_perfect;
				$res['stats_voucher'] = $stats_voucher;
				$res['stats_crt'] = $stats_crt;
				$res['stats_ms'] = $stats_ms;
				$res["status"] = 200;

			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	
	public function actionGetStatUsersTransactionsWeek()
	{

		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
			->bindParam(":uid", Yii::app()->user->id)
			->bindValue(":action", 'statistic')
			->queryRow();
			
		if(empty($is_access))
			Yii::app()->end();
			
			if (Yii::app()->user->id > 0) {
				$stats = [];
				$date_start = 1452470400;
				$date_end =   time();
				$week = 604800;

				while($date_end + $week > $date_start){
					$stat = $connection->createCommand("SELECT SUM(amount) as transactions FROM {{utransactions}} WHERE type = 1 AND date >= :d1 AND date < :d2")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();
					
					//Перфект	
					/*$stat2 = $connection->createCommand("SELECT SUM(t.amount) as transactions FROM {{utransactions}} t INNER JOIN {{users_payment_package}} p ON t.did = p.id WHERE t.type = 1 AND t.date >= :d1 AND t.date < :d2 AND t.psid IN (1,3,6,10,15,20)")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();*/
					$stat2 = $connection->createCommand("SELECT SUM(amount) as transactions FROM {{utransactions}} WHERE type = 1 AND date >= :d1 AND date < :d2 AND psid IN (1,3,6,10,15,20)")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();

					
					//Ваучеры	
					$stat3 = $connection->createCommand("SELECT SUM(amount) as transactions FROM {{utransactions}} WHERE type = 1 AND date >= :d1 AND date < :d2 AND psid NOT IN (1,3,6,10,15,20,23)")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();
						
						
					//Караты
					$stat4 = $connection->createCommand("SELECT SUM(t.amount) as transactions FROM {{utransactions}} t INNER JOIN {{users_payment_package}} p ON t.did = p.id WHERE t.type = 1 AND t.date >= :d1 AND t.date < :d2 AND t.psid = 23")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();
						
					
					$stat['date_start'] = date("d.m.Y", $date_start);
					$stats[] = $stat;
					$stats_perfect[] = $stat2;
					$stats_voucher[] = $stat3;
					$stats_crt[] = $stat4;
					
					$date_start += $week;
				}
				$res['stats'] = $stats;
				$res['stats_perfect'] = $stats_perfect;
				$res['stats_voucher'] = $stats_voucher;
				$res['stats_crt'] = $stats_crt;
				$res["status"] = 200;

			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	
	public function actionGetStatUsersTransactionsAll()
	{

		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
			->bindParam(":uid", Yii::app()->user->id)
			->bindValue(":action", 'statistic')
			->queryRow();
			
		if(empty($is_access))
			Yii::app()->end();
			
			if (Yii::app()->user->id > 0) {
				$stats = [];
				$date_start = 1452470400;
				$date_end =   time();
				$week = 604800;

				while($date_end + $week > $date_start){
					$stat = $connection->createCommand("SELECT SUM(amount) as transactions FROM {{utransactions}} WHERE type = 1 AND date <= :d1")
						->bindParam(":d1", intval($date_start + $week))
						->queryRow();
					$stat2 = $connection->createCommand("SELECT SUM(amount) as transactions FROM {{utransactions}} WHERE type = 1 AND date <= :d1 AND psid IN (1,3,6,10,15,20)")
						->bindParam(":d1", $date_start)
						->queryRow();
						
					/*$stat2 = $connection->createCommand("SELECT SUM(t.amount) as transactions FROM {{utransactions}} t INNER JOIN {{usersinfo}} u ON u.uid = t.ruid WHERE u.country = 1 AND t.type = 1 AND t.date <= :d1 AND t.psid IN (1,3,6,10,15,20)")
						->bindParam(":d1", $date_start)
						->queryRow();*/

					
					//Ваучеры	
					$stat3 = $connection->createCommand("SELECT SUM(amount) as transactions FROM {{utransactions}} WHERE type = 1 AND date <= :d1 AND psid NOT IN (1,3,6,10,15,20,23,30)")
						->bindParam(":d1", $date_start)
						->queryRow();
						
						
					//Караты
					$stat4 = $connection->createCommand("SELECT SUM(t.amount) as transactions FROM {{utransactions}} t INNER JOIN {{users_payment_package}} p ON t.did = p.id WHERE t.type = 1 AND t.date <= :d1 AND t.psid = 23")
						->bindParam(":d1", $date_start)
						->queryRow();
						
					//MS
					$stat5 = $connection->createCommand("SELECT SUM(t.amount) as transactions FROM {{utransactions}} t INNER JOIN {{users_payment_package}} p ON t.did = p.id WHERE t.type = 1 AND t.date <= :d1 AND t.psid = 30")
						->bindParam(":d1", $date_start)
						->queryRow();
						
					/*$stat5 = $connection->createCommand("SELECT SUM(t.amount) as transactions FROM {{utransactions}} t INNER JOIN {{users_payment_package}} p INNER JOIN {{usersinfo}} u ON t.did = p.id AND u.uid = t.ruid WHERE u.country = 1 AND t.type = 1 AND t.date <= :d1 AND t.psid = 30")
						->bindParam(":d1", $date_start)
						->queryRow();*/
						
					
					$stat['date_start'] = date("d.m.Y", $date_start);
					$stats[] = $stat;
					$stats_perfect[] = $stat2;
					$stats_voucher[] = $stat3;
					$stats_crt[] = $stat4;
					$stats_ms[] = $stat5;
					
					$date_start += $week;
				}
				$res['stats'] = $stats;
				$res['stats_perfect'] = $stats_perfect;
				$res['stats_voucher'] = $stats_voucher;
				$res['stats_crt'] = $stats_crt;
				$res['stats_ms'] = $stats_ms;
				$res["status"] = 200;

			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	
	
	public function actionGetStatUsersTopayWeek()
	{

		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
			->bindParam(":uid", Yii::app()->user->id)
			->bindValue(":action", 'statistic')
			->queryRow();
			
		if(empty($is_access))
			Yii::app()->end();
			
			if (Yii::app()->user->id > 0) {
				$stats = [];
				$date_start = 1452470400;
				$date_end =   time();
				$week = 604800;

				while($date_end + $week > $date_start){
					$stat = $connection->createCommand("SELECT SUM(amount) as transactions FROM {{utransactions2}} WHERE type = 0 AND ruid = 106652 AND action = 41 AND date >= :d1 AND date < :d2")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();
						
					$stat2 = $connection->createCommand("SELECT SUM(t.amount) as transactions FROM {{utransactions2}} t INNER JOIN {{usersinfo}} u ON t.uid = u.uid WHERE t.type = 0 AND t.ruid = 106652 AND t.action = 41 AND t.date >= :d1 AND t.date < :d2 AND u.verify = 1")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();
						
					$stat3 = $connection->createCommand("SELECT SUM(t.amount) as transactions FROM {{utransactions2}} t INNER JOIN {{usersinfo}} u ON t.uid = u.uid WHERE t.type = 0 AND t.ruid = 106652 AND t.action = 41 AND t.date >= :d1 AND t.date < :d2 AND u.verify = 0")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();	
					
					$stat['date_start'] = date("d.m.Y", $date_start);
					$stats[] = $stat;
					$stats_verify[] = $stat2;
					$stats_noverify[] = $stat3;
					$date_start += $week;
				}
				$res['stats'] = $stats;
				$res['stats_verify'] = $stats_verify;
				$res['stats_noverify'] = $stats_noverify;
				$res["status"] = 200;

			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	
	public function actionGetStatUsersTopayAll()
	{

		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
			->bindParam(":uid", Yii::app()->user->id)
			->bindValue(":action", 'statistic')
			->queryRow();
			
		if(empty($is_access))
			Yii::app()->end();
			
			if (Yii::app()->user->id > 0) {
				$stats = [];
				$date_start = 1452470400;
				$date_end =   time();
				$week = 604800;

				while($date_end + $week > $date_start){
					$stat = $connection->createCommand("SELECT SUM(amount) as transactions FROM {{utransactions2}} WHERE type = 0 AND ruid = 106652 AND action = 41 AND date <= :d1")
						->bindParam(":d1", intval($date_start + $week))
						->queryRow();
						
					$stat2 = $connection->createCommand("SELECT SUM(t.amount) as transactions FROM {{utransactions2}} t INNER JOIN {{usersinfo}} u ON t.uid = u.uid WHERE t.type = 0 AND t.ruid = 106652 AND t.action = 41 AND t.date <= :d1 AND u.verify = 1")
						->bindParam(":d1", intval($date_start + $week))
						->queryRow();
						
					$stat3 = $connection->createCommand("SELECT SUM(t.amount) as transactions FROM {{utransactions2}} t INNER JOIN {{usersinfo}} u ON t.uid = u.uid WHERE t.type = 0 AND t.ruid = 106652 AND t.action = 41 AND t.date <= :d1 AND u.verify = 0")
						->bindParam(":d1", intval($date_start + $week))
						->queryRow();
						
						
					$stat['date_start'] = date("d.m.Y", $date_start);
					$stats[] = $stat;
					$stats_verify[] = $stat2;
					$stats_noverify[] = $stat3;
					$date_start += $week;
				}
				$res['stats'] = $stats;
				$res['stats_verify'] = $stats_verify;
				$res['stats_noverify'] = $stats_noverify;
				$res["status"] = 200;

			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	
	public function actionUserFuelBonus()
	{
		$connection = Yii::app()->db;
		
		$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
			->bindParam(":uid", Yii::app()->user->id)
			->bindValue(":action", 'userfuelbonus')
			->queryRow();
			
		if(empty($is_access))
			Yii::app()->end();
		
		$this->render('userfuelbonus');
	}
	
	
	
	public function actionGetUserFuelBonus()
	{
		$connection = Yii::app()->db;
		
		$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
			->bindParam(":uid", Yii::app()->user->id)
			->bindValue(":action", 'userfuelbonus')
			->queryRow();
			
		if(empty($is_access))
			Yii::app()->end();
			
		if(Yii::app()->user->id > 0) {
			
			$res["users"] = $connection->createCommand("SELECT u.*, p.deposit,  FROM_UNIXTIME(p.date, '%d-%m-%Y %H:%i') as 'date' FROM {{usersinfo}} u INNER JOIN {{users_potential}} p ON u.uid = p.uid WHERE p.deposit >= 5000 AND p.type = 1 AND p.date < 1456790400")
					->queryAll();
					
			$res["status"] = 200;
			
		}
		
		echo CJSON::encode($res);
		Yii::app()->end();
	}
	
	
	
	
	public function actionPaymentVerify()
	{
		$this->render('paymentverify');
	}
	
	
	public function actionGetPaymentVerify(){

		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->bindValue(":action", 'paymentverify')
				->queryRow();
				
			if(empty($is_access))
				Yii::app()->end();
			
			if (Yii::app()->user->id > 0) {

				$res["payments"]= $connection->createCommand("SELECT p.id, FROM_UNIXTIME(p.date, '%d-%m-%Y') AS date, p.code, p.status, CONCAT(u.name, ' ', u.fio) as fio  FROM {{control_paymentverify}} p INNER JOIN {{usersinfo}} u ON p.uid = u.uid WHERE p.uid = :uid ORDER BY p.date DESC")
					->bindParam(":uid", Yii::app()->user->id)
					->queryAll();

				$res["status"] = 200;

			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}

	}

	public function actionSetPaymentVerify()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;

			$code = mysql_escape_string(htmlspecialchars(strip_tags($_POST['code'])));
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
			->bindParam(":uid", Yii::app()->user->id)
			->bindValue(":action", 'paymentverify')
			->queryRow();
			
		if(empty($is_access))
			Yii::app()->end();

			$payment = $connection->createCommand("SELECT * FROM {{users_payment_package}} WHERE code = :code AND verify = 0 AND status = 2")
				->bindParam(":code", $code)
				->queryRow();

			$potential = $connection->createCommand("SELECT p.* FROM {{users_potential}} p INNER JOIN {{utransactions}} t WHERE t.transaction = :code AND t.ruid = p.uid AND t.amount = p.deposit AND t.date = p.date AND p.type IN (1,4)")
				->bindParam(":code", $code)
				->queryRow();

			$potential2 = $connection->createCommand("SELECT * FROM {{users_potential}} WHERE uid = :uid AND date = :date AND type = 3 AND id > :id")
				->bindParam(":uid", $potential["uid"])
				->bindParam(":date", $potential["date"])
				->bindParam(":id", $potential['id'])
				->queryRow();

			$verify = $connection->createCommand("SELECT *  FROM {{control_paymentverify}} WHERE code = :code")
				->bindParam(":code", $code)
				->queryRow();

			$hash1 = $connection->createCommand("SELECT id FROM {{users_potential_hash}} WHERE uid = :uid AND pid = :pid")
				->bindParam(":uid", $potential['uid'])
				->bindParam(":pid", $potential['id'])
				->queryRow();

			$hash2 = $connection->createCommand("SELECT id FROM {{users_potential_hash}} WHERE uid = :uid AND pid = :pid")
				->bindParam(":uid", $potential['uid'])
				->bindParam(":pid", $potential2['id'])
				->queryRow();

			$err = "";

			if (empty($payment)){
				$err .= "<li>Данного кода не существует.</li>";
			}
			if (!empty($verify)){
				$err .= "<li>Данный код уже активирован.</li>";
			}
			/*if (!empty($hash1)){
				$err .= "<li>Данный потенциал уже активирован.</li>";
			}
			if (!empty($hash2)){
				$err .= "<li>Данный потенциал уже активирован.</li>";
			}*/
			if (empty($potential)){
				$err .= "<li>Потенциал не найден.</li>";
			}
			if (empty($potential2)){
				$err .= "<li>Бонусный потенциал не найден.</li>";
			}

			if (Yii::app()->user->id > 0 && $err == "") {
				$transaction = $connection->beginTransaction();
				try {
					$connection->createCommand()->insert('{{control_paymentverify}}', array(
						'uid' => Yii::app()->user->id,
						'tuid' => $payment['uid'],
						'date' => time(),
						'code' => $payment['code'],
						'status' => 1,
						'hash' => md5($payment['uid'] . $payment['code'] . Yii::app()->params['api_verify'])
					));

					
					if(empty($hash1)) {
					$connection->createCommand()->insert('{{users_potential_hash}}', array(
						'uid' => $potential['uid'],
						'pid' => $potential['id'],
						'amount' => $potential['deposit'],
						'hash' => md5($potential['uid'].$potential['deposit'].$potential['id'].Yii::app()->params['potential_hash'])
					));
					}

					if(empty($hash2)) {
					$connection->createCommand()->insert('{{users_potential_hash}}', array(
						'uid' => $potential2['uid'],
						'pid' => $potential2['id'],
						'amount' => $potential2['deposit'],
						'hash' => md5($potential2['uid'].$potential2['deposit'].$potential2['id'].Yii::app()->params['potential_hash'])
					));
					}

					$connection->createCommand("UPDATE {{users_potential}} SET pid = :pid WHERE id = :id AND uid = :uid")
						->bindParam(":id", $potential2['id'])
						->bindParam(":pid", $potential['id'])
						->bindParam(":uid", $potential2['uid'])
						->query();

					$connection->createCommand("UPDATE {{users_payment_package}} SET verify = 1 WHERE id = :id AND verify = 0")
						->bindParam(":id", $payment["id"])
						->query();

					$transaction->commit();
					$res["status"] = 200;
					$res["message"] = "Код успешно активирован.";
				} catch (Exception $e) {
					$transaction->rollback();
					$res["status"] = 500;
					$res["message"] = $e . "Сервер временно недоступен.";
					$res['test'] = $potential;
				}

			} else {
				$res["status"] = 500;
				$res["message"] = "Возникла ошибка. ".$err;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	
	public function actionVerifyPotential()
	{
		$this->render('verifypotential');
	}

	//Потенциалы
	public function actionGetPotentialVerify(){

		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$connection = Yii::app()->db;

			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")->bindParam(":uid", Yii::app()->user->id)
				->bindValue(":action", 'verifypotential')->queryRow();
			if(empty($is_access))
				Yii::app()->end();

			$res = array();
			$err = "";

			//Входящие данные
			$email = mysql_escape_string(htmlspecialchars(strip_tags($_POST["email"])));

			$info = $connection->createCommand("SELECT CONCAT(fio, ' ', name) as fio, tel, email, uid, alias, package FROM {{usersinfo}} WHERE email = :email AND type = 1 AND uid > 100020")
				->bindParam(":email", $email)
				->queryRow();

			if(empty($info)){
				$err .= "<li>Пользователь не найден.</li>";
			}

			if (Yii::app()->user->id > 0 && $err == "") {

				$potentials = $connection->createCommand("SELECT uid, id, FROM_UNIXTIME(date, '%d/%m/%Y  %H:%i') AS date, deposit as amount FROM {{users_potential}} WHERE uid = :uid AND type = 1 ORDER BY date DESC")
					->bindParam(":uid", $info['uid'])
					->queryAll();
				$res["potentials"] = [];
				foreach($potentials as $potential){
					$potential_hash = $connection->createCommand("SELECT * FROM {{users_potential_hash}} WHERE pid = :pid")
						->bindParam(":pid", $potential['id'])
						->queryRow();

					if(empty($potential_hash)){
						$potential['verify_status'] = 0;
					}elseif(!empty($potential_hash) && $potential_hash['hash'] == md5($potential['uid'].$potential['amount'].$potential['id'].Yii::app()->params['potential_hash'])){
						$potential['verify_status'] = 1;
					}else{
						$potential['verify_status'] = 2;
					}
					$res["potentials"][] = $potential;
				}


				$package_potentials = $connection->createCommand("SELECT p.uid, p.id, FROM_UNIXTIME(p.date, '%d/%m/%Y  %H:%i') AS date, p.amount, w.pay_wallet, w.pay_name, p.code FROM {{users_payment_package}} p INNER JOIN {{users_payment_wallet}} w ON p.psid = w.id AND p.status = 2 WHERE p.uid = :uid AND p.type = 1 ORDER BY date DESC")
					->bindParam(":uid", $info['uid'])
					->queryAll();
				$res["package_potentials"] = [];
				foreach($package_potentials as $payment){
					$payment_verify = $connection->createCommand("SELECT * FROM {{control_paymentverify}} WHERE code = :code AND tuid = :tuid")
						->bindParam(":code", $payment['code'])
						->bindParam(":tuid", $payment['uid'])
						->queryRow();

					if(empty($payment_verify)){
						$payment['verify_status'] = 0;
					}elseif(!empty($payment_verify) && $payment_verify['hash'] == md5($payment['uid'].$payment['code'].Yii::app()->params['api_verify'])){
						$payment['verify_status'] = 1;
					}else{
						$payment['verify_status'] = 2;
					}
					$res["package_potentials"][] = $payment;
				}


				$pay_potentials = $connection->createCommand("SELECT p.uid, p.id, FROM_UNIXTIME(p.date, '%d/%m/%Y  %H:%i') AS date, p.amount, w.pay_wallet, w.pay_name, p.code FROM {{users_payment_package}} p INNER JOIN {{users_payment_wallet}} w ON p.psid = w.id AND p.status = 2 WHERE p.uid = :uid AND p.type = 2 ORDER BY date DESC")
					->bindParam(":uid", $info['uid'])
					->queryAll();
				$res["pay_potentials"] = [];
				foreach($pay_potentials as $payment){
					$payment_verify = $connection->createCommand("SELECT * FROM {{control_paymentverify}} WHERE code = :code AND tuid = :tuid")
						->bindParam(":code", $payment['code'])
						->bindParam(":tuid", $payment['uid'])
						->queryRow();

					if(empty($payment_verify)){
						$payment['verify_status'] = 0;
					}elseif(!empty($payment_verify) && $payment_verify['hash'] == md5($payment['uid'].$payment['code'].Yii::app()->params['api_verify'])){
						$payment['verify_status'] = 1;
					}else{
						$payment['verify_status'] = 2;
					}
					$res["pay_potentials"][] = $payment;
				}


				$res["voucher_potentials"] = $connection->createCommand("SELECT v.id, FROM_UNIXTIME(vu.date_start, '%d/%m/%Y  %H:%i') AS date, v.amount, CONCAT(u.name,' ', u.fio) as fio, u.alias FROM {{users_voucher_code}} v INNER JOIN {{users_voucher_user}} vu ON vu.uid = v.uid_activate AND vu.voucher = v.voucher INNER JOIN {{usersinfo}} u ON u.uid = v.uid WHERE v.uid_activate = :uid AND v.status = 1 ORDER BY date DESC")
					->bindParam(":uid", $info['uid'])
					->queryAll();

				$res["status"] = 200;
				$res["user_info"] = $info['fio'].', '.$info['email'].', тел: <b>'.$info['tel'].'</b>, пакет: <b>'.$info['package'].'</b>, uid: <b>'.$info['uid'].'</b>, <a target="_blank" href="/'.$info['alias'].'">перейти на страницу</a>';
			} else {
				$res["status"] = 500;
				$res["message"] = "Возникла ошибка. ".$err;
			}
			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	public function actionUserBlock()
	{
		$this->render('userblock');
	}
	
	
	// Блокировка
    public function actionGetUserBlock()
    {
        if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
            $res = array();
            $connection = Yii::app()->db;

            $is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
                ->bindParam(":uid", Yii::app()->user->id)
                ->bindValue(":action", 'userblock')
                ->queryRow();

            if (Yii::app()->user->id > 0 && !empty($is_access)) {
                $res["block"]= $connection->createCommand("SELECT u.uid, u.name, u.fio, email, alias, comment, FLOOR((b.date_end - :dt) / 86400) as 'days_end', FROM_UNIXTIME(b.date, '%d/%m/%Y') AS date, b.days FROM {{usersinfo}} u INNER JOIN {{users_block}} b ON u.uid = b.uid WHERE b.date_end > :dt ORDER BY b.id DESC")
                    ->bindParam(":dt", time())
                    ->queryAll();

                $res["status"] = 200;
            } else {
                $res["status"] = 500;
            }

            echo CJSON::encode($res);
            Yii::app()->end();
        }
    }

    public function actionSetUserBlockOk()
    {
        if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
            $res = array();
            $connection = Yii::app()->db;

            $alias = mysql_escape_string(htmlspecialchars(strip_tags($_POST["alias"])));
            $comment = mysql_escape_string(htmlspecialchars(strip_tags($_POST["comment"])));
            $days = intval($_POST["days"]);

            $err = '';

            $is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
                ->bindParam(":uid", Yii::app()->user->id)
                ->bindValue(":action", 'userblock')
                ->queryRow();

            $user_info = $connection->createCommand("SELECT * FROM {{usersinfo}} WHERE alias = :alias AND type = 1")->bindParam(":alias", $alias)->queryRow();

            if(empty($is_access)){
                Yii::app()->end();
            }
            if(empty($user_info)){
                $err .= 'Пользователь не найден.';
            }
            if($days < 0){
                $err .= "<li>Укажите количество дней.</li>";
            }
            if($days > 500){
                $err .= "<li>Максимальный термин блокировки 180 дней.</li>";
            }
            if($comment == ''){
                $err .= "<li>Укажите комментарий.</li>";
            }
            if(strlen($comment) > 200){
                $err .= "<li>Длина комментария не должна превышать 200 символов.</li>";
            }

            if (Yii::app()->user->id > 0 && $err == "") {
                $dt = time();
                $dt_end = strtotime('+'.$days.' days', $dt);

                $is_blocked = $connection->createCommand("SELECT * FROM {{users_block}} WHERE uid = :uid")
                    ->bindParam(":uid", $user_info['uid'])
                    ->queryRow();
                if(!empty($is_blocked)){
                    $connection->createCommand("UPDATE {{users_block}} SET `date` = :dt, date_end = :dt_end, days = :days, comment = :comment WHERE uid = :uid")
                        ->bindParam(":uid", $user_info['uid'])
                        ->bindParam(":days", $days)
                        ->bindParam(":comment", $comment)
                        ->bindParam(":dt", $dt)
                        ->bindParam(":dt_end", $dt_end)
                        ->query();
                }else{
                    $connection->createCommand()->insert('{{users_block}}', array('uid' => $user_info['uid'], 'cuid' => Yii::app()->user->id, 'date' => $dt, 'date_end' => $dt_end, 'days' => $days, 'comment' => $comment));
                }

                $connection->createCommand("DELETE FROM {{sessions}} WHERE uid = :uid")->bindParam(":uid", $user_info['uid'])->query();

                $data = $alias.", ".$days;
                Log::setlog(Yii::app()->user->id, $user_info['uid'], 'control', 'setuserblockok', 1, $data);

                $res["status"] = 200;
                $res["userinfo"] = $user_info;
                $res["message"] = "Пользователь успешно заблокирован.";

            } else {
                $res["status"] = 500;
                $res["message"] = "Возникла ошибка. " . $err;
            }

            echo CJSON::encode($res);
            Yii::app()->end();
        }
    }
    
    
    
    public function actionSetUserBlockDeletePosts()
    {
        if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
            $res = array();
            $connection = Yii::app()->db;

            $uid = mysql_escape_string(htmlspecialchars(strip_tags($_POST["uid"])));

            $err = '';

            $is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
                ->bindParam(":uid", Yii::app()->user->id)
                ->bindValue(":action", 'userblock')
                ->queryRow();

            $user_info = $connection->createCommand("SELECT * FROM {{usersinfo}} WHERE uid = :uid AND type = 1")->bindParam(":uid", $uid)->queryRow();

            if(empty($is_access)){
                Yii::app()->end();
            }
            if(empty($user_info)){
                $err .= 'Пользователь не найден.';
            }
            if (Yii::app()->user->id > 0 && $err == "") {

                $connection->createCommand("UPDATE {{posts}} SET status = 0 WHERE uid = :uid OR puid = :uid")
                ->bindParam(":uid", $user_info['uid'])
                ->query();
                
                $connection->createCommand("DELETE FROM {{comments}} WHERE uid = :uid")
                ->bindParam(":uid", $user_info['uid'])
                ->query();


                //Log::setlog(Yii::app()->user->id, $user_info['uid'], 'control', 'setuserblockok', 1, $data);

                $res["status"] = 200;
                $res["userinfo"] = $user_info;
                $res["message"] = "Все записи и комментарии пользователя удалены.";

            } else {
                $res["status"] = 500;
                $res["message"] = "Возникла ошибка. " . $err;
            }

            echo CJSON::encode($res);
            Yii::app()->end();
        }
    }
    
    
    

    public function actionSetUserBlockCancel()
    {
        if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
            $res = array();
            $connection = Yii::app()->db;

            $uid = intval($_POST["uid"]);
            $err = "";

            $is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
                ->bindParam(":uid", Yii::app()->user->id)
                ->bindValue(":action", 'userblock')
                ->queryRow();

            $is_blocked = $connection->createCommand("SELECT * FROM {{users_block}} WHERE uid = :uid")
                ->bindParam(":uid", $uid)
                ->queryRow();

            $user_info = $connection->createCommand("SELECT * FROM {{usersinfo}} WHERE uid = :uid AND type = 1")
                ->bindParam(":uid", $uid)
                ->queryRow();

            if(empty($is_access)){
                Yii::app()->end();
            }
            if(empty($is_blocked)){
                $err .= "<li>Пользователь не находится в списке заблокированных.</li>";
            }
            if(empty($user_info)){
                $err .= "<li>Пользователь не найден.</li>";
            }

            if (Yii::app()->user->id > 0 && !empty($is_access) && $err == "") {
                $connection->createCommand("DELETE FROM {{users_block}} WHERE uid = :uid")
                    ->bindParam(":uid",$uid)
                    ->query();

                $data = "$uid";
                Log::setlog(Yii::app()->user->id, $uid, 'control', 'setuserblockcancel', 1, $data);

                $res["status"] = 200;
                $res["message"] = "Пользователь удален из списка заблокированных.";

            } else {
                $res["status"] = 500;
                $res["message"] = "Возникла ошибка. " . $err;
            }

            echo CJSON::encode($res);
            Yii::app()->end();
        }
    }
    
    
    public function actionSendMessage()
	{
		$this->render('sendmessage');
	}
	
	
	public function actionGetSendMessages()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;

			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->bindValue(":action", 'sendmessage')
				->queryRow();

			if (Yii::app()->user->id > 0 && !empty($is_access)) {
				$res["messages"]= $connection->createCommand("SELECT m.id, u.name, u.fio, u.alias, m.text, m.count, FROM_UNIXTIME(m.date, '%d/%m/%Y') AS date FROM {{control_sendmessage}} m INNER JOIN {{usersinfo}} u ON u.uid = m.uid ORDER BY m.date DESC")->queryAll();
				$res["status"] = 200;
			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionSetSendMessage()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;

			$text = mysql_escape_string(htmlspecialchars(strip_tags($_POST["text"])));

			$err = '';

			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->bindValue(":action", 'sendmessage')
				->queryRow();

			if(empty($is_access)){
				Yii::app()->end();
			}
			if($text == ''){
				$err .= "<li>Укажите текст сообщения.</li>";
			}

			if (Yii::app()->user->id > 0 && $err == "") {
				$transaction = $connection->beginTransaction();
				try {

					$dt = time();
					$connection->createCommand("INSERT INTO {{messages}} (fuid, tuid, date, message, is_readed) SELECT SQL_CALC_FOUND_ROWS 100037, uid, :dt, :message, 0 FROM {{usersinfo}} WHERE verify = 1")->bindParam(":dt", $dt)->bindParam(":message", $text)->query();
					$totalRecords = $connection->createCommand('SELECT FOUND_ROWS()')->queryScalar();
					
					$connection->createCommand()->insert('{{control_sendmessage}}', array('uid' => Yii::app()->user->id, 'date' => time(), 'count' => $totalRecords, 'text' => $text, 'status' => 1));

					Log::setlog(Yii::app()->user->id, Yii::app()->user->id, 'control', 'sendmessage', 1, $text);

					$transaction->commit();
					$res["status"] = 200;
					$res["message"] = "Сообщение успешно отправлено.";
				} catch (Exception $e) {
					$transaction->rollback();
					$res["status"] = 500;
					$res["message"] = "Сервер временно недоступен.";
				}
			} else {
				$res["status"] = 500;
				$res["message"] = "Возникла ошибка. " . $err;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	
	public function actionStatisticUsers()
	{
		$connection = Yii::app()->db;
		
		$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
			->bindParam(":uid", Yii::app()->user->id)
			->bindValue(":action", 'statistic')
			->queryRow();
			
		if(empty($is_access))
			Yii::app()->end();
		
		$this->render('statisticusers');
	}
	
	
	
	
	public function actionGetStatUsersRefxWeek()
	{

		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
			->bindParam(":uid", Yii::app()->user->id)
			->bindValue(":action", 'statistic')
			->queryRow();
			
		if(empty($is_access))
			Yii::app()->end();
			
			if (Yii::app()->user->id > 0) {
				$stats = [];
				$date_start = 1452470400;
				$date_end =   time();
				$week = 604800;

				while($date_end + $week > $date_start){
					
					//Руденко
					$stat = $connection->createCommand("SELECT FLOOR(SUM(deposit)) as transactions FROM {{usersdeposit_rx2}} WHERE type = 1 AND date >= :d1 AND date < :d2 AND uid = 100006")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();

					//Михлик
					$stat2 = $connection->createCommand("SELECT FLOOR(SUM(deposit)) as transactions FROM {{usersdeposit_rx2}} WHERE type = 1 AND date >= :d1 AND date < :d2 AND uid = 100008")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();

					
					//Куруч	
					$stat3 = $connection->createCommand("SELECT FLOOR(SUM(deposit)) as transactions FROM {{usersdeposit_rx2}} WHERE type = 1 AND date >= :d1 AND date < :d2 AND uid = 100067")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();
						
						
					//Нерушаев
					$stat4 = $connection->createCommand("SELECT FLOOR(SUM(deposit)) as transactions FROM {{usersdeposit_rx2}} WHERE type = 1 AND date >= :d1 AND date < :d2 AND uid = 100016")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();
						
					//Андреева
					$stat5 = $connection->createCommand("SELECT FLOOR(SUM(deposit)) as transactions FROM {{usersdeposit_rx2}} WHERE type = 1 AND date >= :d1 AND date < :d2 AND uid = 100011")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();
					
					//Левченко
					$stat6 = $connection->createCommand("SELECT FLOOR(SUM(deposit)) as transactions FROM {{usersdeposit_rx2}} WHERE type = 1 AND date >= :d1 AND date < :d2 AND uid = 100213")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();
						
					//Артур
					$stat7 = $connection->createCommand("SELECT FLOOR(SUM(deposit)) as transactions FROM {{usersdeposit_rx2}} WHERE type = 1 AND date >= :d1 AND date < :d2 AND uid = 100002")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();
						
						
					//Довгалюк
					$stat8 = $connection->createCommand("SELECT FLOOR(SUM(deposit)) as transactions FROM {{usersdeposit_rx2}} WHERE type = 1 AND date >= :d1 AND date < :d2 AND uid = 100009")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();
						
						
						
						
					
					$stat['date_start'] = date("d.m.Y", $date_start);
					$stats[] = $stat;
					$stats_100008[] = $stat2;
					$stats_100067[] = $stat3;
					$stats_100016[] = $stat4;
					$stats_100011[] = $stat5;
					$stats_100213[] = $stat6;
					$stats_100002[] = $stat7;
					$stats_100009[] = $stat8;
					
					$date_start += $week;
				}
				$res['stats'] = $stats;
				$res['stats_100008'] = $stats_100008;
				$res['stats_100067'] = $stats_100067;
				$res['stats_100016'] = $stats_100016;
				$res['stats_100011'] = $stats_100011;
				$res['stats_100213'] = $stats_100213;
				$res['stats_100002'] = $stats_100002;
				$res['stats_100009'] = $stats_100009;
				$res["status"] = 200;

			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	
	public function actionGetStatUsersRefxAll()
	{

		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
			->bindParam(":uid", Yii::app()->user->id)
			->bindValue(":action", 'statistic')
			->queryRow();
			
		if(empty($is_access))
			Yii::app()->end();
			
			if (Yii::app()->user->id > 0) {
				$stats = [];
				$date_start = 1452470400;
				$date_end =   time();
				$week = 604800;

				while($date_end + $week > $date_start){
					
					//Руденко
					$stat = $connection->createCommand("SELECT FLOOR(SUM(deposit)) as transactions FROM {{usersdeposit_rx2}} WHERE type = 1 AND date <= :d1 AND uid = 100006")
						->bindParam(":d1", $date_start)
						->queryRow();

					//Михлик
					$stat2 = $connection->createCommand("SELECT FLOOR(SUM(deposit)) as transactions FROM {{usersdeposit_rx2}} WHERE type = 1 AND date <= :d1 AND uid = 100008")
						->bindParam(":d1", $date_start)
						->queryRow();

					
					//Куруч	
					$stat3 = $connection->createCommand("SELECT FLOOR(SUM(deposit)) as transactions FROM {{usersdeposit_rx2}} WHERE type = 1 AND date <= :d1 AND uid = 100067")
						->bindParam(":d1", $date_start)
						->queryRow();
						
						
					//Нерушаев
					$stat4 = $connection->createCommand("SELECT FLOOR(SUM(deposit)) as transactions FROM {{usersdeposit_rx2}} WHERE type = 1 AND date <= :d1 AND uid = 100016")
						->bindParam(":d1", $date_start)
						->queryRow();
						
					//Андреева
					$stat5 = $connection->createCommand("SELECT FLOOR(SUM(deposit)) as transactions FROM {{usersdeposit_rx2}} WHERE type = 1 AND date <= :d1 AND uid = 100011")
						->bindParam(":d1", $date_start)
						->queryRow();
						
					//Левченко
					$stat6 = $connection->createCommand("SELECT FLOOR(SUM(deposit)) as transactions FROM {{usersdeposit_rx2}} WHERE type = 1 AND date <= :d1 AND uid = 100213")
						->bindParam(":d1", $date_start)
						->queryRow();
						
					//Артур
					$stat7 = $connection->createCommand("SELECT FLOOR(SUM(deposit)) as transactions FROM {{usersdeposit_rx2}} WHERE type = 1 AND date <= :d1 AND uid = 100002")
						->bindParam(":d1", $date_start)
						->queryRow();
						
					//Довгалюк
					$stat8 = $connection->createCommand("SELECT FLOOR(SUM(deposit)) as transactions FROM {{usersdeposit_rx2}} WHERE type = 1 AND date <= :d1 AND uid = 100009")
						->bindParam(":d1", $date_start)
						->queryRow();
						
					
					$stat['date_start'] = date("d.m.Y", $date_start);
					$stats[] = $stat;
					$stats_100008[] = $stat2;
					$stats_100067[] = $stat3;
					$stats_100016[] = $stat4;
					$stats_100011[] = $stat5;
					$stats_100213[] = $stat6;
					$stats_100002[] = $stat7;
					$stats_100009[] = $stat8;
					
					$date_start += $week;
				}
				$res['stats'] = $stats;
				$res['stats_100008'] = $stats_100008;
				$res['stats_100067'] = $stats_100067;
				$res['stats_100016'] = $stats_100016;
				$res['stats_100011'] = $stats_100011;
				$res['stats_100213'] = $stats_100213;
				$res['stats_100002'] = $stats_100002;
				$res['stats_100009'] = $stats_100009;
				$res["status"] = 200;
				$res["status"] = 200;

			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	
	public function actionGetStatisticUsersTopayWeek()
	{

		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
			->bindParam(":uid", Yii::app()->user->id)
			->bindValue(":action", 'statistic')
			->queryRow();
			
		if(empty($is_access))
			Yii::app()->end();
			
			if (Yii::app()->user->id > 0) {
				$stats = [];
				$date_start = 1452470400;
				$date_end =   time();
				$week = 604800;

				while($date_end + $week > $date_start){
					
					$stat = $connection->createCommand("SELECT FLOOR(SUM(amount)) as transactions FROM {{utransactions2}} WHERE type = 0 AND uid = 100006 AND date >= :d1 AND date < :d2")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();
						
					$stat2 = $connection->createCommand("SELECT FLOOR(SUM(amount)) as transactions FROM {{utransactions2}} WHERE type = 0 AND uid = 100008 AND date >= :d1 AND date < :d2")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();
						
					$stat3 = $connection->createCommand("SELECT FLOOR(SUM(amount)) as transactions FROM {{utransactions2}} WHERE type = 0 AND uid = 100067 AND date >= :d1 AND date < :d2")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();	
						
					$stat4 = $connection->createCommand("SELECT FLOOR(SUM(amount)) as transactions FROM {{utransactions2}} WHERE type = 0 AND uid = 100016 AND date >= :d1 AND date < :d2")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();	
						
					$stat5 = $connection->createCommand("SELECT FLOOR(SUM(amount)) as transactions FROM {{utransactions2}} WHERE type = 0 AND uid = 100011 AND date >= :d1 AND date < :d2")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();	
						
					$stat6 = $connection->createCommand("SELECT FLOOR(SUM(amount)) as transactions FROM {{utransactions2}} WHERE type = 0 AND uid = 100213 AND date >= :d1 AND date < :d2")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();
						
					$stat7 = $connection->createCommand("SELECT FLOOR(SUM(amount)) as transactions FROM {{utransactions2}} WHERE type = 0 AND uid = 100002 AND date >= :d1 AND date < :d2")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();
						
					$stat8 = $connection->createCommand("SELECT FLOOR(SUM(amount)) as transactions FROM {{utransactions2}} WHERE type = 0 AND uid = 100009 AND date >= :d1 AND date < :d2")
						->bindParam(":d1", $date_start)
						->bindParam(":d2", intval($date_start + $week))
						->queryRow();
					
					$stat['date_start'] = date("d.m.Y", $date_start);
					$stats[] = $stat;
					$stats_100008[] = $stat2;
					$stats_100067[] = $stat3;
					$stats_100016[] = $stat4;
					$stats_100011[] = $stat5;
					$stats_100213[] = $stat6;
					$stats_100002[] = $stat7;
					$stats_100009[] = $stat8;
					
					$date_start += $week;
				}
				$res['stats'] = $stats;
				$res['stats_100008'] = $stats_100008;
				$res['stats_100067'] = $stats_100067;
				$res['stats_100016'] = $stats_100016;
				$res['stats_100011'] = $stats_100011;
				$res['stats_100213'] = $stats_100213;
				$res['stats_100002'] = $stats_100002;
				$res['stats_100009'] = $stats_100009;
				$res["status"] = 200;

			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	
	public function actionGetStatisticUsersTopayAll()
	{

		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
			->bindParam(":uid", Yii::app()->user->id)
			->bindValue(":action", 'statistic')
			->queryRow();
			
		if(empty($is_access))
			Yii::app()->end();
			
			if (Yii::app()->user->id > 0) {
				$stats = [];
				$date_start = 1452470400;
				$date_end =   time();
				$week = 604800;

				while($date_end + $week > $date_start){
					
					$stat = $connection->createCommand("SELECT FLOOR(SUM(amount)) as transactions FROM {{utransactions2}} WHERE type = 0 AND uid = 100006 AND date <= :d1")
						->bindParam(":d1", $date_start)
						->queryRow();
						
					$stat2 = $connection->createCommand("SELECT FLOOR(SUM(amount)) as transactions FROM {{utransactions2}} WHERE type = 0 AND uid = 100008 AND date <= :d1")
						->bindParam(":d1", $date_start)
						->queryRow();
						
					$stat3 = $connection->createCommand("SELECT FLOOR(SUM(amount)) as transactions FROM {{utransactions2}} WHERE type = 0 AND uid = 100067 AND date <= :d1")
						->bindParam(":d1", $date_start)
						->queryRow();	
						
					$stat4 = $connection->createCommand("SELECT FLOOR(SUM(amount)) as transactions FROM {{utransactions2}} WHERE type = 0 AND uid = 100016 AND date <= :d1")
						->bindParam(":d1", $date_start)
						->queryRow();	
						
					$stat5 = $connection->createCommand("SELECT FLOOR(SUM(amount)) as transactions FROM {{utransactions2}} WHERE type = 0 AND uid = 100011 AND date <= :d1")
						->bindParam(":d1", $date_start)
						->queryRow();
						
					$stat6 = $connection->createCommand("SELECT FLOOR(SUM(amount)) as transactions FROM {{utransactions2}} WHERE type = 0 AND uid = 100213 AND date <= :d1")
						->bindParam(":d1", $date_start)
						->queryRow();	
						
					$stat7 = $connection->createCommand("SELECT FLOOR(SUM(amount)) as transactions FROM {{utransactions2}} WHERE type = 0 AND uid = 100002 AND date <= :d1")
						->bindParam(":d1", $date_start)
						->queryRow();
						
					$stat8 = $connection->createCommand("SELECT FLOOR(SUM(amount)) as transactions FROM {{utransactions2}} WHERE type = 0 AND uid = 100009 AND date <= :d1")
						->bindParam(":d1", $date_start)
						->queryRow();
					
					$stat['date_start'] = date("d.m.Y", $date_start);
					$stats[] = $stat;
					$stats_100008[] = $stat2;
					$stats_100067[] = $stat3;
					$stats_100016[] = $stat4;
					$stats_100011[] = $stat5;
					$stats_100213[] = $stat6;
					$stats_100002[] = $stat7;
					$stats_100009[] = $stat8;
					
					$date_start += $week;
				}
				$res['stats'] = $stats;
				$res['stats_100008'] = $stats_100008;
				$res['stats_100067'] = $stats_100067;
				$res['stats_100016'] = $stats_100016;
				$res['stats_100011'] = $stats_100011;
				$res['stats_100213'] = $stats_100213;
				$res['stats_100002'] = $stats_100002;
				$res['stats_100009'] = $stats_100009;
				$res["status"] = 200;

			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	
	public function actionGetStatisticUsersBuyAll()
	{

		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
			->bindParam(":uid", Yii::app()->user->id)
			->bindValue(":action", 'statistic')
			->queryRow();
			
		if(empty($is_access))
			Yii::app()->end();
			
			if (Yii::app()->user->id > 0) {
				$stats = [];
				$date_start = 1452470400;
				$date_end =   time();
				$week = 604800;

				while($date_end + $week > $date_start){
					
					$stat = $connection->createCommand("SELECT FLOOR(SUM(amount)) as transactions FROM {{utransactions2}} WHERE type = 0 AND uid = 100006 AND date <= :d1")
						->bindParam(":d1", $date_start)
						->queryRow();
						
					$stat2 = $connection->createCommand("SELECT FLOOR(SUM(amount)) as transactions FROM {{utransactions2}} WHERE type = 0 AND uid = 100008 AND date <= :d1")
						->bindParam(":d1", $date_start)
						->queryRow();
						
					$stat3 = $connection->createCommand("SELECT FLOOR(SUM(amount)) as transactions FROM {{utransactions2}} WHERE type = 0 AND uid = 100067 AND date <= :d1")
						->bindParam(":d1", $date_start)
						->queryRow();	
						
					$stat4 = $connection->createCommand("SELECT FLOOR(SUM(amount)) as transactions FROM {{utransactions2}} WHERE type = 0 AND uid = 100016 AND date <= :d1")
						->bindParam(":d1", $date_start)
						->queryRow();	
						
					$stat5 = $connection->createCommand("SELECT FLOOR(SUM(amount)) as transactions FROM {{utransactions2}} WHERE type = 0 AND uid = 100011 AND date <= :d1")
						->bindParam(":d1", $date_start)
						->queryRow();
						
					$stat6 = $connection->createCommand("SELECT FLOOR(SUM(amount)) as transactions FROM {{utransactions2}} WHERE type = 0 AND uid = 100213 AND date <= :d1")
						->bindParam(":d1", $date_start)
						->queryRow();
						
					$stat7 = $connection->createCommand("SELECT FLOOR(SUM(amount)) as transactions FROM {{utransactions2}} WHERE type = 0 AND uid = 100002 AND date <= :d1")
						->bindParam(":d1", $date_start)
						->queryRow();
						
					$stat8 = $connection->createCommand("SELECT FLOOR(SUM(amount)) as transactions FROM {{utransactions2}} WHERE type = 0 AND uid = 100009 AND date <= :d1")
						->bindParam(":d1", $date_start)
						->queryRow();	
					
					$stat['date_start'] = date("d.m.Y", $date_start);
					$stats[] = $stat;
					$stats_100008[] = $stat2;
					$stats_100067[] = $stat3;
					$stats_100016[] = $stat4;
					$stats_100011[] = $stat5;
					$stats_100213[] = $stat6;
					$stats_100002[] = $stat7;
					$stats_100009[] = $stat8;
					
					$date_start += $week;
				}
				$res['stats'] = $stats;
				$res['stats_100008'] = $stats_100008;
				$res['stats_100067'] = $stats_100067;
				$res['stats_100016'] = $stats_100016;
				$res['stats_100011'] = $stats_100011;
				$res['stats_100213'] = $stats_100213;
				$res['stats_100002'] = $stats_100002;
				$res['stats_100009'] = $stats_100009;
				$res["status"] = 200;

			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	
	
	
	
	
	
	
	public function actionUrlBlackList()
	{
		$this->render('urlblacklist');
	}
	
	public function actionGetUrlBlackList()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->bindValue(":action", 'urlblacklist')
				->queryRow();

			if (Yii::app()->user->id > 0 && !empty($is_access)) {
				
				$date = time();
				
				$res["verify"]= $connection->createCommand("SELECT u.id, u.url, u.count_delete, count_show, FROM_UNIXTIME(u.date, '%d.%m.%Y') AS date, CONCAT(i.name, ' ', i.fio) as 'fio' FROM {{control_urlblacklist}} u INNER JOIN {{usersinfo}} i ON u.cuid = i.uid WHERE u.status = 1 ORDER BY u.id DESC")
					->queryAll();

				$res["status"] = 200;

			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	public function actionSetUrlBlackListOk()
	{
		
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$url = mysql_escape_string(htmlspecialchars(strip_tags($_POST["url"])));
			$url = str_replace(array("https://", "http://", "www.", " "), array("", "", ""), $url);
			
			$err = "";
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->bindValue(":action", 'urlblacklist')
				->queryRow();
				
			$userinfo = $connection->createCommand("SELECT * FROM {{usersinfo}} WHERE email = :email AND type = 1")
				->bindParam(":email", $email)
				->queryRow();
			
			if(empty($is_access))
				Yii::app()->end();
				
			if(!empty($userinfo))
				$uid = $userinfo["uid"];
				
				
			$url_blacklist = $connection->createCommand("SELECT * FROM {{control_urlblacklist}} WHERE url=:url")
			    ->bindParam(":url", $url)
			    ->queryRow();	
			    
			    			
			if(!empty($url_blacklist))
				$err .= "<li>Данная ссылка уже находится в черном списке.</li>";
				
			if(strlen($url) < 7)
				$err .= "<li>Длинна ссылки слишком маленькая.</li>";
							
			if (Yii::app()->user->id > 0 && $err == "") {

				$connection->createCommand()->insert('{{control_urlblacklist}}', array('cuid' => Yii::app()->user->id, 'url' => $url, 'date' => time(), 'count_delete' => 0, 'count_show' => 0, 'status' => 1 ));


				$res["status"] = 200;
				$res["userinfo"] = $userinfo;
				$res["message"] = "Сайт успешно добавлен в черный список.";

			} else {
				$res["status"] = 500;
				$res["message"] = "Возникла ошибка. " . $err;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	public function actionSetUrlBlackListCancel()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$uid = intval($_POST["uid"]);
			
			$err = "";
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->bindValue(":action", 'urlblacklist')
				->queryRow();
				
			$is_verify = $connection->createCommand("SELECT * FROM {{users_verify}} WHERE uid = :uid")
				->bindParam(":uid", $uid)
				->queryRow();
				
			$userinfo = $connection->createCommand("SELECT * FROM {{usersinfo}} WHERE uid = :uid AND type = 1")
				->bindParam(":uid", $uid)
				->queryRow();
				
			if(empty($is_access))
				Yii::app()->end();
				
			/*if(empty($is_verify))
				$err .= "<li>Пользователь не находится в списке верифицированных.</li>";*/
				
			if($userinfo["verify"] == 0)
				$err .= "<li>Пользователь не верифицирован.</li>";
			
			if($userinfo["package"] <= 0)
				$err .= "<li>Недостаточная подписка.</li>";

			if (Yii::app()->user->id > 0 && !empty($is_access) && $err == "") {

				$connection->createCommand("DELETE FROM {{users_verify}} WHERE uid = :uid")
					->bindParam(":uid",$uid)
					->query();
					
				$connection->createCommand("UPDATE {{usersinfo}} SET verify=0 WHERE uid = :uid")
					->bindParam(":uid", $uid)
					->query();
					
				$connection->createCommand("UPDATE {{goods}} SET status=0 WHERE uid = :uid")
					->bindParam(":uid", $uid)
					->query();
				
				$data = "$uid";
				Log::setlog(Yii::app()->user->id, $uid, 'control', 'setuserverifycancel', 1, $data);
				
				$res["status"] = 200;
				$res["message"] = "Пользователь удален из списка верифицированных.";

			} else {
				$res["status"] = 500;
				$res["message"] = "Возникла ошибка. " . $err;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	public function actionSetUrlBlackListEdit()
    {
        if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
            $res = array();
            $connection = Yii::app()->db;

            $uid = mysql_escape_string(htmlspecialchars(strip_tags($_POST["uid"])));
            $percent = intval($_POST["percent"]);
            $discount = intval($_POST["discount"]);
            $multi = intval($_POST["multi"]);

            $err = "";

            $is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
                ->bindParam(":uid", Yii::app()->user->id)
                ->bindValue(":action", 'urlblacklist')
                ->queryRow();

            $userinfo = $connection->createCommand("SELECT * FROM {{usersinfo}} WHERE uid = :uid AND type = 1")
                ->bindParam(":uid", $uid)
                ->queryRow();

            if(empty($is_access))
                Yii::app()->end();

            if(!empty($userinfo))
                $uid = $userinfo["uid"];

            $is_verify = $connection->createCommand("SELECT * FROM {{users_verify}} WHERE uid = :uid")
                ->bindParam(":uid", $uid)
                ->queryRow();

            if(empty($is_verify))
                $err .= "<li>Пользователь не найден.</li>";

            if($userinfo["verify"] != 1)
                $err .= "<li>Пользователь не верифицирован.</li>";

            if($userinfo["package"] <= 0)
                $err .= "<li>Недостаточная подписка.</li>";

            if($percent < 10 || $percent > 100)
                $err .= "<li>Минимальный процент 10, максимальный 100.</li>";

            if($multi < 0 || $multi > 100)
                $err .= "<li>Минимальный множитель 0, максимальный 100.</li>";

            if($discount < 0 || $discount > $percent){
                $err .= "<li>Минимальная скидка 0, максимальная не должна превышать процент.</li>";
            }

            if (Yii::app()->user->id > 0 && $err == "") {

                $connection->createCommand("UPDATE {{users_verify}} SET percent = :percent, discount = :discount, multi = :multi WHERE uid = :uid AND status = 1")
                    ->bindParam(":uid", $uid)
                    ->bindParam(":percent", $percent)
                    ->bindParam(":discount", $discount)
                    ->bindParam(":multi", $multi)
                    ->query();

                $data = $userinfo['email'].', '. $percent.', '.$discount.', '.$multi;
                Log::setlog(Yii::app()->user->id, $uid, 'control', 'setuserverifyedit', 1, $data);

                $res["status"] = 200;
                $res["message"] = "Изминения успешно сохранены!";

            } else {
                $res["status"] = 500;
                $res["message"] = "Возникла ошибка. " . $err;
            }

            echo CJSON::encode($res);
            Yii::app()->end();
        }
    }
	
	
	
	public function actionMarketPay()
	{
		$this->render('marketpay');
	}
	
	public function actionGetMarketPay()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->bindValue(":action", 'marketpay')
				->queryRow();
			if(empty($is_access))
                Yii::app()->end();
                
			$orders = $connection->createCommand("SELECT m.id, m.uid, m.amount, FROM_UNIXTIME(m.date, '%d.%m.%Y %H:%i') as date, m.wallet, m.status, m.confirm_status, m.confirm_amount, FROM_UNIXTIME(m.confirm_date, '%d.%m.%Y %H:%i') as confirm_date, CONCAT(u.name, ' ', u.fio) as fio, u.email, u.alias FROM {{control_marketpay}} m INNER JOIN {{usersinfo}} u ON u.uid = m.uid WHERE m.status IN(-2,0,1,2,3,4) ORDER BY m.id DESC")
				->queryAll();
			
			if (!empty($orders)) {
				$res["orders"] = $orders;
				$res["status"] = 200;
			} else {
				$res["status"] = 500;
				$res["message"] = "Список заявок пуст.";
			}

			echo CJSON::encode($res);
			Yii::app()->end();
			
		}
	}
	
	
	public function actionSetMarketPayCancel()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->bindValue(":action", 'marketpay')
				->queryRow();
			if(empty($is_access))
                Yii::app()->end();
                
            $id = intval($_POST["id"]);
            	
			$orders = $connection->createCommand("SELECT * FROM {{control_marketpay}} WHERE id = :id AND status IN (0,1)")
				->bindParam(":id", $id)
				->queryRow();
			
			$err = "";
			
			if(empty($orders)) {
				$err .= "Данная заявка не найдена.";
			}
 			
			if ($err == "") {
				
				$transaction = $connection->beginTransaction();
				try {
						
						$connection->createCommand("UPDATE {{control_marketpay}} SET status = -2 WHERE id = :id")
						->bindParam(":id", $id)
						->query();

					$transaction->commit();
					$res["status"] = 200;
					$res["message"] = "Заявка отклонена.";
					
				} catch (Exception $e) {
					$transaction->rollback();
					$res["status"] = 500;
					$res["message"] = "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
				}
				
				
			} else {
				$res["status"] = 500;
				$res["message"] = "Возникла ошибка." . $err;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
			
		}
	}

	
	public function actionSetMarketPayConfirm()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->bindValue(":action", 'marketpay')
				->queryRow();
			if(empty($is_access))
                Yii::app()->end();
                
            $id = intval($_POST["id"]);
            $amount = intval($_POST["amount"]);
            	
			$orders = $connection->createCommand("SELECT * FROM {{control_marketpay}} WHERE id = :id AND status IN (0)")
				->bindParam(":id", $id)
				->queryRow();
			
			$err = "";
				
			if($amount > $orders["amount"]) {
				$err .= "<li>Сумма не может превышать сумме поданой заявки.</li>";
			}
			
			if($amount <= 0) {
				$err .= "<li>Сумма указана неверно.</li>";
			}
			
			if(empty($orders)) {
				$err .= "<li>Данная заявка не найдена.</li>";
			}
 			
			if ($err == "") {
				
				$transaction = $connection->beginTransaction();
				try {
						
						$connection->createCommand("UPDATE {{control_marketpay}} SET status = 1, confirm_amount = :confirm_amount, confirm_status = 1, confirm_date = :confirm_date, confirm_uid = :confirm_uid  WHERE id = :id")
						->bindParam(":confirm_amount", $amount)
						->bindParam(":confirm_date", time())
						->bindParam(":confirm_uid", Yii::app()->user->id)
						->bindParam(":id", $id)
						->query();

					$transaction->commit();
					$res["status"] = 200;
					$res["message"] = "Заявка успешно подтверждена и передана на обработку.";
					
				} catch (Exception $e) {
					$transaction->rollback();
					$res["status"] = 500;
					$res["message"] = "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
				}
				
				
			} else {
				$res["status"] = 500;
				$res["message"] = "Возникла ошибка." . $err;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
			
		}
	}
	
	
	
	
	public function actionSetMarketPayMs()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->bindValue(":action", 'marketpay')
				->queryRow();
			if(empty($is_access))
                Yii::app()->end();
                
            $id = intval($_POST["id"]);
            	
			$orders = $connection->createCommand("SELECT * FROM {{control_marketpay}} WHERE id = :id AND status IN (1)")
				->bindParam(":id", $id)
				->queryRow();
			$orders_uid = $orders["uid"];
			$orders_confirm_amount = $orders["confirm_amount"];
			
			$receiver = $connection->createCommand("SELECT email FROM {{usersinfo}} WHERE uid = :uid")
					->bindParam(":uid", $orders_uid)
					->queryScalar(); //кому перечислять деньги
			
			$err = "";
			
			if(empty($orders)) {
				$err .= "<li>Данная заявка не найдена.</li>";
			}
			
			if(empty($receiver)) {
				$err .= "<li>Пользователь не найден.</li>";
			}
			
			
			//Наш кошелек
			$wallet = $connection->createCommand("SELECT * FROM {{users_wallet}} WHERE uid = :uid AND type = 1 AND status = 1")->bindParam(":uid", $orders_uid)->queryRow();
			$my = $connection->createCommand("SELECT uid, CONCAT(name, ' ', fio) as 'fio' FROM {{usersinfo}} WHERE uid = :uid")->bindParam(":uid", $orders_uid)->queryRow();

			//Информация получателя
			$user_to_uid = 201378;
			
			$user_to = $connection->createCommand("SELECT uid, CONCAT(name, ' ', fio) as 'fio' FROM {{usersinfo}} WHERE uid = :uid AND status = 1")->bindParam(":uid", $user_to_uid)->queryRow();
			$wallet_to = $connection->createCommand("SELECT * FROM {{users_wallet}} WHERE uid = :uid AND type = 1 AND status = 1")->bindParam(":uid", $user_to_uid)->queryRow();

			if ((empty($user_to)) || (empty($wallet_to))) {
				$err .= "<li>Данного пользователя не существует.</li>";
			}
			if (($wallet['cash_now'] < $orders_confirm_amount) && ($orders_confirm_amount <= 0)) {
				$err .= "<li>У пользователя недостаточно средств на кошельке.</li>";
			}
			if ((empty($wallet)) || ($orders_uid == 0)) {
				$err .= "<li>Вы не можете провести оплату. Обновите страницу и повторите попытку снова.</li>";
			}
			
			
			//Данные платежа
			$timestamp = 1480520331;//time();
			$amount = $orders["confirm_amount"];
			$remote = 'bokobok';
			$note = 'Покупка USD за BP.';
			
			$currency = 'PM-USD';
			$originator = 'bokobok.ec@gmail.com';
			
			
			//Номер транзакции	
			$pass = "GccABqkHCfQ2x5zSE832ePrcpXFDle00";
			$order_code = $orders["id"] . "-" . md5($orders["id"] . $orders["uid"] . $timestamp . $pass);
			$transfer_id = $order_code;
			
			
			$sign = '';
			if($err == '') {
				$data = implode("|", [$timestamp, $transfer_id, $originator, $amount, $currency, $receiver]);		
				$private_key = Yii::app()->params['rsa_private_key'];
				$pk  = openssl_get_privatekey(Yii::app()->params['rsa_private_key']);
				openssl_sign($data, $sign_ssl, $pk);
				$sign = base64_encode($sign_ssl);
			}
			
			if($sign == '') {
				$err .= "<li>Сигнатура не совпадает</li>";
			}
			
 			
			if ($err == "") {
				
				$transaction = $connection->beginTransaction();
				try {
										
					$connection->createCommand()->insert('{{control_marketpay_start}}', array(
						'uid' => Yii::app()->user->id, 
						'oid' => $orders["id"],
						'timestamp' => $timestamp,
			            'amount' => $amount,
			            'currency' => $currency,
			            'transfer_id' => $transfer_id,
			            'remote' => $remote,
			            'originator' => $originator,
			            'receiver' => $receiver,
			            'note' => $note,
			            'sign' => $sign,
			            'status' => 0
					));
					$ms_start_id = $connection->getLastInsertID();
					
					$connection->createCommand("UPDATE {{control_marketpay}} SET status = 2 WHERE id = :id")
						->bindParam(":id", $id)
						->query();
						
						
						
					//Совершаем перевод на кошелек пользователя
					
					//Вставляем транзакцию мне
					$connection->createCommand()->insert('{{utransactions2}}', array('did' => 0, 'uid' => $orders_uid, 'ruid' => $user_to_uid, 'amount' => $amount, 'amount_now' => $wallet["cash_now"] - $amount, 'date' => time(), 'type' => 0, 'status' => 1, 'invoice' => $ms_start_id, 'action' => 42));
					$utransactions1 = $connection->getLastInsertID();

					//Вставляем транзакцию адрессату
					$connection->createCommand()->insert('{{utransactions2}}', array('did' => 0, 'uid' => $user_to_uid, 'ruid' => $orders_uid, 'amount' => $amount, 'amount_now' => $wallet_to["cash_now"] + $amount, 'date' => time(), 'type' => 1, 'status' => 1, 'invoice' => $ms_start_id, 'action' => 42));
					$utransactions2 = $connection->getLastInsertID();

					$connection->createCommand("UPDATE {{users_wallet}} SET cash_now = cash_now - :amount WHERE uid = :uid AND type = 1 AND status = 1; UPDATE {{users_wallet}} SET cash_now = cash_now + :amount WHERE uid = :touid AND type = 1 AND status = 1")
						->bindParam(":amount", $amount)
						->bindParam(":uid", $orders_uid)
						->bindParam(":touid", $user_to_uid)
						->query();
                    
					
					$transaction->commit();
					//Позитивный результат
					$res["status"] = 200;
					$res["message"] = "Оплата прошла успешно.";
				} catch (Exception $e) {
					$transaction->rollback();
					$res["status"] = 500;
					$res["message"] = $e . "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
				}
				
				
			} else {
				$res["status"] = 500;
				$res["message"] = "Возникла ошибка." . $err;
			}
			
			
			if($res["status"] = 200) {
				
				$money_receive = Api::money_receive($timestamp, $amount, $currency, $transfer_id, $remote, $originator, $receiver, $note, $sign);
				$money_receive_results = json_decode($money_receive, true);
				$connection->createCommand("UPDATE {{control_marketpay_start}} SET status_start = :status WHERE id = :id")->bindParam(":status", $money_receive_results)->bindParam(":id", $ms_start_id)->query();
				
			}
			
			

			echo CJSON::encode($res);
			Yii::app()->end();
			
		}
	}
	
	
	
	
	public function actionMarketPayMs()
	{
		$this->render('marketpayms');
	}
	
	public function actionGetMarketPayMs()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->bindValue(":action", 'marketpayms')
				->queryRow();
			if(empty($is_access))
                Yii::app()->end();
                
			$orders = $connection->createCommand("SELECT m.id, m.uid, m.amount, FROM_UNIXTIME(m.date, '%d.%m.%Y %H:%i') as date, m.wallet, m.status, m.confirm_status, m.confirm_amount, FROM_UNIXTIME(m.confirm_date, '%d.%m.%Y %H:%i') as confirm_date, CONCAT(u.name, ' ', u.fio) as fio, u.email, u.alias FROM {{control_marketpay}} m INNER JOIN {{usersinfo}} u ON u.uid = m.uid WHERE m.status IN(1,2,3,4) ORDER BY m.id DESC")
				->queryAll();
			
			if (!empty($orders)) {
				$res["orders"] = $orders;
				$res["status"] = 200;
			} else {
				$res["status"] = 500;
				$res["message"] = "Список заявок пуст.";
			}

			echo CJSON::encode($res);
			Yii::app()->end();
			
		}
	}
	
	
	public function actionSetMarketPayMsCancel()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->bindValue(":action", 'marketpayms')
				->queryRow();
			if(empty($is_access))
                Yii::app()->end();
                
            $id = intval($_POST["id"]);
            	
			$orders = $connection->createCommand("SELECT * FROM {{control_marketpay}} WHERE id = :id AND status IN (0,1)")
				->bindParam(":id", $id)
				->queryRow();
			
			$err = "";
			
			if(empty($orders)) {
				$err .= "Данная заявка не найдена.";
			}
 			
			if ($err == "") {
				
				$transaction = $connection->beginTransaction();
				try {
						
						$connection->createCommand("UPDATE {{control_marketpay}} SET status = -2 WHERE id = :id")
						->bindParam(":id", $id)
						->query();

					$transaction->commit();
					$res["status"] = 200;
					$res["message"] = "Заявка отклонена.";
					
				} catch (Exception $e) {
					$transaction->rollback();
					$res["status"] = 500;
					$res["message"] = "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
				}
				
				
			} else {
				$res["status"] = 500;
				$res["message"] = "Возникла ошибка." . $err;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
			
		}
	}
	
	
	
	public function actionSetMarketPayMsMs()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->bindValue(":action", 'marketpayms')
				->queryRow();
			if(empty($is_access))
                Yii::app()->end();
                
            $id = intval($_POST["id"]);
            	
			$orders = $connection->createCommand("SELECT * FROM {{control_marketpay}} WHERE id = :id AND status IN (1)")
				->bindParam(":id", $id)
				->queryRow();
			$orders_uid = $orders["uid"];
			$orders_confirm_amount = $orders["confirm_amount"];
			
			$receiver = $connection->createCommand("SELECT email FROM {{usersinfo}} WHERE uid = :uid")
					->bindParam(":uid", $orders_uid)
					->queryScalar(); //кому перечислять деньги
			
			$err = "";
			
			if(empty($orders)) {
				$err .= "<li>Данная заявка не найдена.</li>";
			}
			
			if(empty($receiver)) {
				$err .= "<li>Пользователь не найден.</li>";
			}
			
			
			//Наш кошелек
			$wallet = $connection->createCommand("SELECT * FROM {{users_wallet}} WHERE uid = :uid AND type = 1 AND status = 1")->bindParam(":uid", $orders_uid)->queryRow();
			$my = $connection->createCommand("SELECT uid, CONCAT(name, ' ', fio) as 'fio' FROM {{usersinfo}} WHERE uid = :uid")->bindParam(":uid", $orders_uid)->queryRow();

			//Информация получателя
			$user_to_uid = 201378;
			
			$user_to = $connection->createCommand("SELECT uid, CONCAT(name, ' ', fio) as 'fio' FROM {{usersinfo}} WHERE uid = :uid AND status = 1")->bindParam(":uid", $user_to_uid)->queryRow();
			$wallet_to = $connection->createCommand("SELECT * FROM {{users_wallet}} WHERE uid = :uid AND type = 1 AND status = 1")->bindParam(":uid", $user_to_uid)->queryRow();

			if ((empty($user_to)) || (empty($wallet_to))) {
				$err .= "<li>Данного пользователя не существует.</li>";
			}
			if (($wallet['cash_now'] < $orders_confirm_amount) && ($orders_confirm_amount <= 0)) {
				$err .= "<li>У пользователя недостаточно средств на кошельке.</li>";
			}
			if ((empty($wallet)) || ($orders_uid == 0)) {
				$err .= "<li>Вы не можете провести оплату. Обновите страницу и повторите попытку снова.</li>";
			}
			
			
			//Данные платежа
			$timestamp = 1480520331;//time();
			$amount = $orders["confirm_amount"];
			$remote = 'bokobok';
			$note = 'Покупка USD за BP.';
			
			$currency = 'PM-USD';
			$originator = 'bokobok.ec@gmail.com';
			
			
			//Номер транзакции	
			$pass = "GccABqkHCfQ2x5zSE832ePrcpXFDle00";
			$order_code = $orders["id"] . "-" . md5($orders["id"] . $orders["uid"] . $timestamp . $pass);
			$transfer_id = $order_code;
			
			
			$sign = '';
			if($err == '') {
				$data = implode("|", [$timestamp, $transfer_id, $originator, $amount, $currency, $receiver]);		
				$private_key = Yii::app()->params['rsa_private_key'];
				$pk  = openssl_get_privatekey(Yii::app()->params['rsa_private_key']);
				openssl_sign($data, $sign_ssl, $pk);
				$sign = base64_encode($sign_ssl);
			}
			
			if($sign == '') {
				$err .= "<li>Сигнатура не совпадает</li>";
			}
			
 			
			if ($err == "") {
				
				$transaction = $connection->beginTransaction();
				try {
										
					$connection->createCommand()->insert('{{control_marketpay_start}}', array(
						'uid' => Yii::app()->user->id, 
						'oid' => $orders["id"],
						'timestamp' => $timestamp,
			            'amount' => $amount,
			            'currency' => $currency,
			            'transfer_id' => $transfer_id,
			            'remote' => $remote,
			            'originator' => $originator,
			            'receiver' => $receiver,
			            'note' => $note,
			            'sign' => $sign,
			            'status' => 0
					));
					$ms_start_id = $connection->getLastInsertID();
					
					$connection->createCommand("UPDATE {{control_marketpay}} SET status = 2 WHERE id = :id")
						->bindParam(":id", $id)
						->query();
						
						
						
					//Совершаем перевод на кошелек пользователя
					
					//Вставляем транзакцию мне
					$connection->createCommand()->insert('{{utransactions2}}', array('did' => 0, 'uid' => $orders_uid, 'ruid' => $user_to_uid, 'amount' => $amount, 'amount_now' => $wallet["cash_now"] - $amount, 'date' => time(), 'type' => 0, 'status' => 1, 'invoice' => $ms_start_id, 'action' => 42));
					$utransactions1 = $connection->getLastInsertID();

					//Вставляем транзакцию адрессату
					$connection->createCommand()->insert('{{utransactions2}}', array('did' => 0, 'uid' => $user_to_uid, 'ruid' => $orders_uid, 'amount' => $amount, 'amount_now' => $wallet_to["cash_now"] + $amount, 'date' => time(), 'type' => 1, 'status' => 1, 'invoice' => $ms_start_id, 'action' => 42));
					$utransactions2 = $connection->getLastInsertID();

					$connection->createCommand("UPDATE {{users_wallet}} SET cash_now = cash_now - :amount WHERE uid = :uid AND type = 1 AND status = 1; UPDATE {{users_wallet}} SET cash_now = cash_now + :amount WHERE uid = :touid AND type = 1 AND status = 1")
						->bindParam(":amount", $amount)
						->bindParam(":uid", $orders_uid)
						->bindParam(":touid", $user_to_uid)
						->query();
                    
					
					$transaction->commit();
					//Позитивный результат
					$res["status"] = 200;
					$res["message"] = "Оплата прошла успешно.";
				} catch (Exception $e) {
					$transaction->rollback();
					$res["status"] = 500;
					$res["message"] = $e . "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
				}
				
				
			} else {
				$res["status"] = 500;
				$res["message"] = "Возникла ошибка." . $err;
			}
			
			
			if($res["status"] = 200) {
				
				$money_receive = Api::money_receive($timestamp, $amount, $currency, $transfer_id, $remote, $originator, $receiver, $note, $sign);
				$money_receive_results = json_decode($money_receive, true);
				$connection->createCommand("UPDATE {{control_marketpay_start}} SET status_start = :status WHERE id = :id")->bindParam(":status", $money_receive_results)->bindParam(":id", $ms_start_id)->query();
				
			}
			
			

			echo CJSON::encode($res);
			Yii::app()->end();
			
		}
	}
	
	
	
	public function actionUserPay()
	{
		$this->render('userpay');
	}
	
	public function actionGetUserPay()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->bindValue(":action", 'userpay')
				->queryRow();
			if(empty($is_access))
                Yii::app()->end();
                
			$orders = $connection->createCommand("SELECT m.id, m.uid, m.amount, FROM_UNIXTIME(m.date, '%d.%m.%Y %H:%i') as date, m.wallet, m.status, m.confirm_status, m.confirm_amount, FROM_UNIXTIME(m.confirm_date, '%d.%m.%Y %H:%i') as confirm_date, CONCAT(u.name, ' ', u.fio) as fio, u.email, u.alias FROM {{control_userpay}} m INNER JOIN {{usersinfo}} u ON u.uid = m.uid WHERE m.status IN(-2,0,1,2,3,4) ORDER BY m.id DESC")
				->queryAll();
			
			if (!empty($orders)) {
				$res["orders"] = $orders;
				$res["status"] = 200;
			} else {
				$res["status"] = 500;
				$res["message"] = "Список заявок пуст.";
			}

			echo CJSON::encode($res);
			Yii::app()->end();
			
		}
	}
	
	
	public function actionSetUserPayCancel()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->bindValue(":action", 'userpay')
				->queryRow();
			if(empty($is_access))
                Yii::app()->end();
                
            $id = intval($_POST["id"]);
            	
			$orders = $connection->createCommand("SELECT * FROM {{control_userpay}} WHERE id = :id AND status IN (0,1)")
				->bindParam(":id", $id)
				->queryRow();
			
			$err = "";
			
			if(empty($orders)) {
				$err .= "Данная заявка не найдена.";
			}
 			
			if ($err == "") {
				
				$transaction = $connection->beginTransaction();
				try {
						
						$connection->createCommand("UPDATE {{control_userpay}} SET status = -2 WHERE id = :id")
						->bindParam(":id", $id)
						->query();

					$transaction->commit();
					$res["status"] = 200;
					$res["message"] = "Заявка отклонена.";
					
				} catch (Exception $e) {
					$transaction->rollback();
					$res["status"] = 500;
					$res["message"] = "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
				}
				
				
			} else {
				$res["status"] = 500;
				$res["message"] = "Возникла ошибка." . $err;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
			
		}
	}

	
	public function actionSetUserPayConfirm()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->bindValue(":action", 'userpay')
				->queryRow();
			if(empty($is_access))
                Yii::app()->end();
                
            $id = intval($_POST["id"]);
            	
			$orders = $connection->createCommand("SELECT * FROM {{control_userpay}} WHERE id = :id AND status IN (0)")
				->bindParam(":id", $id)
				->queryRow();
			
			$err = "";
			
			if(empty($orders)) {
				$err .= "<li>Данная заявка не найдена.</li>";
			}
 			
			if ($err == "") {
				
				$transaction = $connection->beginTransaction();
				try {
						
						$connection->createCommand("UPDATE {{control_userpay}} SET status = 1, confirm_amount = amount, confirm_status = 1, confirm_date = :confirm_date, confirm_uid = :confirm_uid  WHERE id = :id")
						->bindParam(":confirm_date", time())
						->bindParam(":confirm_uid", Yii::app()->user->id)
						->bindParam(":id", $id)
						->query();
						
						

					$transaction->commit();
					$res["status"] = 200;
					$res["message"] = "Заявка успешно подтверждена и передана на обработку.";
					
				} catch (Exception $e) {
					$transaction->rollback();
					$res["status"] = 500;
					$res["message"] = "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
				}
				
				
			} else {
				$res["status"] = 500;
				$res["message"] = "Возникла ошибка." . $err;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
			
		}
	}
	
	
	
	public function actionSetUserPayMs()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->bindValue(":action", 'userpay')
				->queryRow();
			if(empty($is_access))
                Yii::app()->end();
                
            $id = intval($_POST["id"]);
            	
			$orders = $connection->createCommand("SELECT * FROM {{control_userpay}} WHERE id = :id AND status IN (1)")
				->bindParam(":id", $id)
				->queryRow();
			$orders_uid = $orders["uid"];
			$orders_confirm_amount = $orders["confirm_amount"];
			
			$receiver = $connection->createCommand("SELECT email FROM {{usersinfo}} WHERE uid = :uid")
					->bindParam(":uid", $orders_uid)
					->queryScalar(); //кому перечислять деньги
			
			$err = "";
			
			if(empty($orders)) {
				$err .= "<li>Данная заявка не найдена.</li>";
			}
			
			if(empty($receiver)) {
				$err .= "<li>Пользователь не найден.</li>";
			}
			
			/*
			//Наш кошелек
			$wallet = $connection->createCommand("SELECT * FROM {{users_wallet}} WHERE uid = :uid AND type = 1 AND status = 1")->bindParam(":uid", $orders_uid)->queryRow();
			$my = $connection->createCommand("SELECT uid, CONCAT(name, ' ', fio) as 'fio' FROM {{usersinfo}} WHERE uid = :uid")->bindParam(":uid", $orders_uid)->queryRow();

			//Информация получателя
			$user_to_uid = 201378;
			
			$user_to = $connection->createCommand("SELECT uid, CONCAT(name, ' ', fio) as 'fio' FROM {{usersinfo}} WHERE uid = :uid AND status = 1")->bindParam(":uid", $user_to_uid)->queryRow();
			$wallet_to = $connection->createCommand("SELECT * FROM {{users_wallet}} WHERE uid = :uid AND type = 1 AND status = 1")->bindParam(":uid", $user_to_uid)->queryRow();

			if ((empty($user_to)) || (empty($wallet_to))) {
				$err .= "<li>Данного пользователя не существует.</li>";
			}
			if (($wallet['cash_now'] < $orders_confirm_amount) && ($orders_confirm_amount <= 0)) {
				$err .= "<li>У пользователя недостаточно средств на кошельке.</li>";
			}
			if ((empty($wallet)) || ($orders_uid == 0)) {
				$err .= "<li>Вы не можете провести оплату. Обновите страницу и повторите попытку снова.</li>";
			}
			*/
			
			//Данные платежа
			$timestamp = 1480520331;//time();
			$amount = $orders["confirm_amount"];
			$remote = 'bokobok';
			$note = 'Покупка USD за BP.';
			
			$currency = 'PM-USD';
			$originator = 'bokobok.ec@gmail.com';
			
			
			//Номер транзакции	
			$pass = "GccABqkHCfQ2x5zSE832ePrcpXFDle00";
			$order_code = $orders["id"] . "-" . md5($orders["id"] . $orders["uid"] . $timestamp . $pass);
			$transfer_id = $order_code;
			
			
			$sign = '';
			if($err == '') {
				$data = implode("|", [$timestamp, $transfer_id, $originator, $amount, $currency, $receiver]);		
				$private_key = Yii::app()->params['rsa_private_key'];
				$pk  = openssl_get_privatekey(Yii::app()->params['rsa_private_key']);
				openssl_sign($data, $sign_ssl, $pk);
				$sign = base64_encode($sign_ssl);
			}
			
			if($sign == '') {
				$err .= "<li>Сигнатура не совпадает</li>";
			}
			
 			
			if ($err == "") {
				
				$transaction = $connection->beginTransaction();
				try {
										
					$connection->createCommand()->insert('{{control_userpay_start}}', array(
						'uid' => Yii::app()->user->id, 
						'oid' => $orders["id"],
						'timestamp' => $timestamp,
			            'amount' => $amount,
			            'currency' => $currency,
			            'transfer_id' => $transfer_id,
			            'remote' => $remote,
			            'originator' => $originator,
			            'receiver' => $receiver,
			            'note' => $note,
			            'sign' => $sign,
			            'status' => 0
					));
					$ms_start_id = $connection->getLastInsertID();
					
					$connection->createCommand("UPDATE {{control_userpay}} SET status = 2 WHERE id = :id")
						->bindParam(":id", $id)
						->query();
						
					/*	
						
					//Совершаем перевод на кошелек пользователя
					
					//Вставляем транзакцию мне
					$connection->createCommand()->insert('{{utransactions2}}', array('did' => 0, 'uid' => $orders_uid, 'ruid' => $user_to_uid, 'amount' => $amount, 'amount_now' => $wallet["cash_now"] - $amount, 'date' => time(), 'type' => 0, 'status' => 1, 'invoice' => $ms_start_id, 'action' => 42));
					$utransactions1 = $connection->getLastInsertID();

					//Вставляем транзакцию адрессату
					$connection->createCommand()->insert('{{utransactions2}}', array('did' => 0, 'uid' => $user_to_uid, 'ruid' => $orders_uid, 'amount' => $amount, 'amount_now' => $wallet_to["cash_now"] + $amount, 'date' => time(), 'type' => 1, 'status' => 1, 'invoice' => $ms_start_id, 'action' => 42));
					$utransactions2 = $connection->getLastInsertID();

					$connection->createCommand("UPDATE {{users_wallet}} SET cash_now = cash_now - :amount WHERE uid = :uid AND type = 1 AND status = 1; UPDATE {{users_wallet}} SET cash_now = cash_now + :amount WHERE uid = :touid AND type = 1 AND status = 1")
						->bindParam(":amount", $amount)
						->bindParam(":uid", $orders_uid)
						->bindParam(":touid", $user_to_uid)
						->query();
                    
					*/
					
					
					$transaction->commit();
					//Позитивный результат
					$res["status"] = 200;
					$res["message"] = "Оплата прошла успешно.";
				} catch (Exception $e) {
					$transaction->rollback();
					$res["status"] = 500;
					$res["message"] = $e . "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
				}
				
				
			} else {
				$res["status"] = 500;
				$res["message"] = "Возникла ошибка." . $err;
			}
			
			
			if($res["status"] = 200) {
				
				$money_receive = Api::money_receive($timestamp, $amount, $currency, $transfer_id, $remote, $originator, $receiver, $note, $sign);
				$money_receive_results = json_decode($money_receive, true);
				$connection->createCommand("UPDATE {{control_userpay_start}} SET status_start = :status WHERE id = :id")->bindParam(":status", $money_receive_results)->bindParam(":id", $ms_start_id)->query();
				
			}
			
			

			echo CJSON::encode($res);
			Yii::app()->end();
			
		}
	}
	
	
	
	
	public function actionGoodClaim()
	{
		$this->render('goodclaim');
	}
	
	public function actionGetGoodClaim()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->bindValue(":action", 'goodclaim')
				->queryRow();

			if (Yii::app()->user->id > 0 && !empty($is_access)) {
				
				$date = time();
				
				$res["claim"]= $connection->createCommand("SELECT u.uid, u.alias, CONCAT(u.name, ' ', u.fio) as 'fio', FROM_UNIXTIME(c.date, '%d.%m.%Y') AS date, c.id, c.comment, g.gid, g.title FROM {{usersinfo}} u INNER JOIN {{control_good_claim}} c INNER JOIN {{goods}} g ON u.uid = c.uid AND c.gid = g.gid WHERE c.status = 1 ORDER BY c.id DESC")
					->queryAll();

				$res["status"] = 200;

			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	public function actionSetGoodClaimOk()
	{
		
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$id = intval($_POST["id"]);
			
			$err = "";
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->bindValue(":action", 'goodclaim')
				->queryRow();
			
			if(empty($is_access))
				Yii::app()->end();
				
			$good_claim = $connection->createCommand("SELECT * FROM {{control_good_claim}} WHERE id=:id AND status = 1")
			    ->bindParam(":id", $id)
			    ->queryRow();	
			    
			    			
			if(empty($good_claim))
				$err .= "<li>Данный вопрос уже решен ранее.</li>";
							
			if (Yii::app()->user->id > 0 && $err == "") {

				$connection->createCommand("UPDATE {{control_good_claim}} SET status = 0 WHERE id = :id AND status = 1")
					->bindParam(":id", $id)
					->query();
						
				$res["status"] = 200;
				$res["userinfo"] = $userinfo;
				$res["message"] = "Вопрос с жалобой успешно решен.";

			} else {
				$res["status"] = 500;
				$res["message"] = "Возникла ошибка. " . $err;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	
	public function actionUserVerifyPays()
	{
		$this->render('userverifypays');
	}
	
	public function actionGetUserVerifyPays()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->bindValue(":action", 'userverifypays')
				->queryRow();

			if (Yii::app()->user->id > 0 && !empty($is_access)) {
				
				$date = time();
				
				$res["claim"]= $connection->createCommand("SELECT u.uid, u.alias, CONCAT(u.name, ' ', u.fio) as 'fio', FROM_UNIXTIME(c.date, '%d.%m.%Y %H:%i:%s') AS date, c.id, c.paybp, c.payms, c.payms_wallet FROM {{usersinfo}} u INNER JOIN {{control_userverify_pays}} c ON u.uid = c.uid WHERE c.status = 0 ORDER BY c.id DESC")
					->queryAll();

				$res["status"] = 200;

			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	public function actionSetUserVerifyPaysOk()
	{
		
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$id = intval($_POST["id"]);
			
			$err = "";
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->bindValue(":action", 'userverifypays')
				->queryRow();
			
			if(empty($is_access))
				Yii::app()->end();
				
			$verify_pays = $connection->createCommand("SELECT * FROM {{control_userverify_pays}} WHERE id=:id AND status = 0")
			    ->bindParam(":id", $id)
			    ->queryRow();	
			    
			    			
			if(empty($verify_pays))
				$err .= "<li>Возникла ошибка при подтверждении. Данная заявка уже активирована или отклонена пользователем.</li>";
							
			if (Yii::app()->user->id > 0 && $err == "") {

				$connection->createCommand("UPDATE {{control_userverify_pays}} SET status = 1 WHERE id = :id AND status = 0")
					->bindParam(":id", $id)
					->query();
					
				$connection->createCommand("UPDATE {{users_verify}} SET paybp = :paybp, payms = :payms, payms_wallet = :payms_wallet WHERE uid = :uid")
					->bindParam(":paybp", $verify_pays["paybp"])
					->bindParam(":payms", $verify_pays["payms"])
					->bindParam(":payms_wallet", $verify_pays["payms_wallet"])
					->bindParam(":uid", $verify_pays["uid"])
					->query();
						
				$res["status"] = 200;
				$res["message"] = "Заявка успешно подтверждена.";

			} else {
				$res["status"] = 500;
				$res["message"] = "Возникла ошибка. " . $err;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	
	public function actionSetUserVerifyPaysCancel()
	{
		
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$id = intval($_POST["id"]);
			
			$err = "";
			
			$is_access = $connection->createCommand("SELECT r.id, r.uid FROM {{control_rules}} r INNER JOIN {{control_actions}} a ON a.id = r.action_id WHERE r.uid = :uid AND a.action = :action AND r.status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->bindValue(":action", 'userverifypays')
				->queryRow();
			
			if(empty($is_access))
				Yii::app()->end();
				
			$verify_pays = $connection->createCommand("SELECT * FROM {{control_userverify_pays}} WHERE id=:id AND status = 0")
			    ->bindParam(":id", $id)
			    ->queryRow();	
			    
			    			
			if(empty($verify_pays))
				$err .= "<li>Возникла ошибка при подтверждении. Данная заявка уже активирована или отклонена пользователем.</li>";
							
			if (Yii::app()->user->id > 0 && $err == "") {

				$connection->createCommand("UPDATE {{control_userverify_pays}} SET status = 2 WHERE id = :id AND status = 0")
					->bindParam(":id", $id)
					->query();
						
				$res["status"] = 200;
				$res["message"] = "Заявка успешно отклонена.";

			} else {
				$res["status"] = 500;
				$res["message"] = "Возникла ошибка. " . $err;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	
	

	/**
	 * This is the action to handle external exceptions.
	 */
	public function actionError()
	{
		if ($error = Yii::app()->errorHandler->error) {
			if (Yii::app()->request->isAjaxRequest)
				echo $error['message'];
			else
				$this->render('error', $error);
		}
	}
}