<?php

class EventsController extends Controller
{
	public $layout = 'main';

	/**
	 * @return array action filters
	 */
	public function filters()
	{
		return array(
			'accessControl', // perform access control for CRUD operations
		);
	}

	/**
	 * Specifies the access control rules.
	 * This method is used by the 'accessControl' filter.
	 * @return array access control rules
	 */
	public function accessRules()
	{
        return array(
            array('allow',
                'actions'=>array('index', 'esearch', 'event'),
                'users'=>array('?'),
            ),
            array('deny',
                'users'=>array('?'),
            ),
        );
	}

	public function actionIndex()
	{
		$this->render('events');
	}

	public function actionNew()
	{
		$this->render('new');
	}

	public function actionEvent()
	{
		$this->render('event');
	}

	public function actionSettings()
	{
		$this->render('settings');
	}

	public function actionMy()
	{
		$this->render('my');
	}

	public function actionEdit()
	{
		$this->render('edit');
	}

	public function actionCities()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;

			$country_id = intval($_POST['id']);

			if ($country_id > 0) {

				$res["cities"] = $connection->createCommand("SELECT DISTINCT city_id, city_name FROM {{users_events}} WHERE city_id > 0")->queryAll();
				$res["status"] = 200;
			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionEventEdit()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			
			Functions::access_control(1);
			
			$connection = Yii::app()->db;
			$res = array();
			$err = '';
            $site_name_pattern = '/^((http|https)?:\/\/)?[a-zA-Z0-9-\.]+\.[a-z]{2,}/i';

			$name = mysql_escape_string(htmlspecialchars(strip_tags($_POST["name"])));
			$alias = mysql_escape_string(htmlspecialchars(strip_tags($_POST["alias"])));
            $url = mysql_escape_string(htmlspecialchars(strip_tags($_POST["url"])));
			$about = mysql_escape_string(htmlspecialchars(strip_tags($_POST["about"])));
			$date = mysql_escape_string(htmlspecialchars(strip_tags($_POST["date"])));
			$create_date = strtotime($date);
			$address = mysql_escape_string(htmlspecialchars(strip_tags($_POST["address"])));
			$event = intval($_POST["event"]);

			$event_info = $connection->createCommand("SELECT * FROM {{usersinfo}} WHERE uid = :uid")->bindParam(":uid", $event)->queryRow();

			$country_id = intval($_POST["country"]);
			$country = Loc::getCountryById($country_id);

			$city_id = intval($_POST["city"]);
			$city = Loc::getCityById($city_id);

            if($url != '' && !preg_match($site_name_pattern, $url)){
                $err .= '<li>Укажите ссылку на страницу.</li>';
            }
			if(empty($country)){
				$err .= '<li>Укажите страну.</li>';
			}
			if(empty($city)){
				$err .= '<li>Укажите город.</li>';
			}
			if(empty($event_info)){
				$err .= '<li>При выполнении запроса произошла ошибка.</li>';
			}
			if(!empty($event_info) && $event_info['owner'] != Yii::app()->user->id){
				$err .= '<li>Доступ запрещен.</li>';
			}
			if(!empty($alias) && $alias != $event_info['alias'] &&  !f_alias_allowed($alias)){
				$err .= '<li>Вы ввели недопустимое название адреса страницы или указаный адрес уже занят.</li>';
			}
			if(empty($create_date)){
				$err .= '<li>Дата начала указано неверно.</li>';
			}
			if(empty($name)){
				$err .= '<li>Введите название.</li>';
			}
			if(empty($about)){
				$err .= '<li>Введите описание.</li>';
			}

			if (empty($err)) {
				$transaction = $connection->beginTransaction();
				try {

					$connection->createCommand("UPDATE {{usersinfo}} SET `name` = :name, birth = :birth, alias = :alias, about = :about WHERE uid = :uid")
						->bindParam(":uid", $event)
						->bindParam(":name", $name)
						->bindParam(":birth", $date)
						->bindParam(":alias", $alias)
						->bindParam(":about", $about)
						->query();

					$connection->createCommand("UPDATE {{alias}} SET `name` = :name WHERE uid = :uid")
						->bindParam(":uid", $event)
						->bindParam(":name", $alias)
						->query();

					$connection->createCommand("UPDATE {{users_events}} SET address = :address, date = :date, country_id = :country_id, country_name = :country_name, city_id = :city_id, city_name = :city_name, url = :url WHERE uid = :uid")
						->bindParam(":uid", $event)
						->bindParam(":address", $address)
						->bindParam(":date", $date)
						->bindParam(":country_id", $country['id'])
						->bindParam(":country_name", $country['title'])
						->bindParam(":city_id", $city['id'])
						->bindParam(":city_name", $city['title'])
                        ->bindParam(":url", $url)
						->query();

					$transaction->commit();
					$res["status"] = 200;
				} catch (Exception $e) {
					$transaction->rollback();
					$res["status"] = 500;
					$res["message"] = "Сервер временно недоступен.";
				}
			}else{
				$res["status"] = 500;
				$res["message"] = $err;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionEventNew()
	{

		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			
			Functions::access_control(1);
			
			$connection = Yii::app()->db;
			$res = array();
			$err = '';
            $site_name_pattern = '/^((http|https)?:\/\/)?[a-zA-Z0-9-\.]+\.[a-z]{2,}/i';

			$name = mysql_escape_string(htmlspecialchars(strip_tags($_POST["name"])));
			$alias = mysql_escape_string(htmlspecialchars(strip_tags($_POST["alias"])));
            $url = mysql_escape_string(htmlspecialchars(strip_tags($_POST["url"])));
			$about = mysql_escape_string(htmlspecialchars(strip_tags($_POST["about"])));
			$date = mysql_escape_string(htmlspecialchars(strip_tags($_POST["date"])));
			$create_date = strtotime($date);
			$address = mysql_escape_string(htmlspecialchars(strip_tags($_POST["address"])));

			$country_id = intval($_POST["country"]);
			$country = Loc::getCountryById($country_id);

			$city_id = intval($_POST["city"]);
			$city = Loc::getCityById($city_id);

            if($url != '' && !preg_match($site_name_pattern, $url)){
                $err .= '<li>Укажите ссылку на страницу.</li>';
            }
			if(empty($country)){
				$err .= '<li>Укажите страну.</li>';
			}
			if(empty($create_date)){
				$err .= '<li>Дата начала указано неверно.</li>';
			}
			if(empty($name)){
				$err .= '<li>Укажите название.</li>';
			}
			if(empty($name)){
				$err .= '<li>Укажите описание.</li>';
			}
            if(empty($address)){
                $err .= '<li>Укажите адрес.</li>';
            }
			if(!empty($alias) && !f_alias_allowed($alias)){
				$err .= '<li>Вы ввели недопустимое название адреса страницы или указаный адрес уже занят.</li>';
			}

			if (empty($err)) {
				$transaction = $connection->beginTransaction();
				try {
					$connection->createCommand()->insert('{{groups}}', array(
						'date' => time()
					));
					$event_id = Yii::app()->db->getLastInsertID();
					$alias = !empty($alias) ? $alias : 'event'.($event_id-1000000000);

					$connection->createCommand()->insert('{{usersinfo}}', array(
						'uid' => $event_id,
						'owner' => Yii::app()->user->id,
						'type' => 4,
						'name' => $name,
						'birth' => $date,
						'alias' => $alias,
						'about' => $about
					));

					$connection->createCommand()->insert('{{alias}}', array(
						'uid' => $event_id,
						'name' => $alias,
						'type' => 4
					));

					$connection->createCommand()->insert('{{users_events}}', array(
						'uid' => $event_id,
                        'url' => $url,
						'address' => $address,
						'count_user' => 0,
						'date' => time(),
						'country_id' => !empty($country) ? $country['id'] : 0,
						'country_name' => !empty($country) ? $country['title'] : '',
						'city_id' => !empty($city) ? $city['id'] : 0,
						'city_name' => !empty($city) ? $city['title'] : '',
					));

					$transaction->commit();
					$res["status"] = 200;
					$res["event"] = $alias;
				} catch (Exception $e) {
					$transaction->rollback();
					$res["status"] = 500;
					$res["message"] = "Сервер временно недоступен.";
				}
			} else {
				$res["status"] = 500;
				$res["message"] = $err;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionEsearch()
	{
		if (Yii::app()->request->isAjaxRequest) {
			$res = array();
			$connection = Yii::app()->db;
			$limit = Yii::app()->params['users-per-page'];

			$uid = isset($_POST['uid']) ? intval($_POST['uid']) : Yii::app()->user->id;
			$act = intval($_POST['act']);
			$page = intval($_POST['page']);
			$country = intval($_POST['country']);
			$city = intval($_POST['city']);
			$search_query = mysql_escape_string(htmlspecialchars(strip_tags($_POST["search_query"])));
			$date = mysql_escape_string(htmlspecialchars(strip_tags($_POST["date"])));

			$pieces = explode(" ", $search_query);

			$query = array();
			$order = 'ASC';
			try {
				$query['event'] = ' u.type = 4';

				if (!empty($country) && $country > 0) {
					$query['country'] = ' e.country_id = :country ';
				}
				if (!empty($city) && $city > 0) {
					$query['city'] = ' e.city_id = :city ';
				}
				if (!empty($date)) {
					$query['date'] = ' DATE(u.birth) = :date ';
				}
				if (!in_array($act, [1, 2])) {
                    $query['events_old'] = ' DATE(u.birth) > DATE(CURDATE()) ';
                    $order = 'DESC';
				} else{
//                    $query['events_old'] = ' DATE(u.birth) > DATE(CURDATE()) ';
                    $order = 'DESC';
				}

				if (!empty($search_query) && strlen($search_query) >= 3) {
					if (count($pieces) == 1) {
						$query['search_query'] = ' (u.name LIKE :text1) ';
					} elseif (count($pieces) == 2) {
						$query['search_query'] = ' (u.name LIKE :text1 || u.name LIKE :text2) ';
					}
				}

				$query = !empty($query) ? " WHERE " . implode(" AND ", $query) : '';

				if($act == 1){
					$sql = "SELECT e.count_user, u.birth, u.uid, u.name, u.fio, u.photo, u.alias, u.about, (f.uid IS NOT NULL) AS friend FROM {{usersinfo}} u INNER JOIN {{friends}} f ON f.uid = :uid AND f.fuid = u.uid INNER JOIN {{users_events}} e ON e.uid = u.uid  ".$query." ORDER BY (CASE WHEN DATE(u.birth) > DATE(CURDATE()) THEN 1 ELSE 0 END) DESC, u.birth ASC LIMIT :limit OFFSET :offset";
				}elseif($act == 2){
					$sql = "SELECT e.count_user, u.birth, u.uid, u.name, u.fio, u.photo, u.alias, u.about, (f.uid IS NOT NULL) AS friend FROM {{usersinfo}} u LEFT JOIN {{friends}} f ON f.uid = :uid AND f.fuid = u.uid INNER JOIN {{users_events}} e ON e.uid = u.uid  ".$query." AND u.owner = :uid ORDER BY (CASE WHEN DATE(u.birth) > DATE(CURDATE()) THEN 1 ELSE 0 END) ASC, u.birth DESC LIMIT :limit OFFSET :offset";
				}else{
					$sql = "SELECT e.count_user, u.birth, u.uid, u.name, u.fio, u.photo, u.alias, u.about, (f.uid IS NOT NULL) AS friend FROM {{usersinfo}} u LEFT JOIN {{friends}} f ON f.uid = :uid AND f.fuid = u.uid INNER JOIN {{users_events}} e ON e.uid = u.uid  ".$query." ORDER BY (CASE WHEN DATE(u.birth) > DATE(CURDATE()) THEN 1 ELSE 0 END) DESC, CASE WHEN DATE(u.birth) > DATE(CURDATE()) THEN u.birth END ASC, CASE WHEN DATE(u.birth) < DATE(CURDATE()) THEN u.birth END DESC LIMIT :limit OFFSET :offset";
				}

				$command = $connection->createCommand($sql);
				$command->bindParam(":uid", $uid, PDO::PARAM_INT);
				$command->bindValue(":limit", $limit, PDO::PARAM_INT);
				$command->bindValue(":offset", ($page - 1) * $limit, PDO::PARAM_INT);

				if (!empty($country) && $country > 0) {
					$command->bindParam(":country", $country);
				}
				if (!empty($city) && $city > 0) {
					$command->bindParam(":city", $city);
				}
				if (!empty($date)) {
					$time = strtotime($date);
					$date_format = date('Y-m-d', $time);
					$command->bindParam(":date", $date_format);
				}

				if (!empty($search_query) && strlen($search_query) >= 3) {
					if (count($pieces) == 1) {
						$command->bindValue(":text1", '%' . $pieces[0] . '%');
					} elseif (count($pieces) == 2) {
						$command->bindValue(":text1", '%' . $pieces[0] . '%');
						$command->bindValue(":text2", '%' . $pieces[2] . '%');
					}
				}

				$events = $command->queryAll();
				$totalRecords = $connection->createCommand('SELECT FOUND_ROWS()')->queryScalar();

				if (!empty($events)) {
					$res["status"] = 200;
					$res["events"] = $events;
					$res["total"] = $totalRecords;
				} else {
					$res["status"] = 500;
					$res["total"] = 0;
				}
			} catch (Exception $e) {
				$res["status"] = 500;
				$res["message"] = "Сервер временно недоступен.";
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	/**
	 * This is the action to handle external exceptions.
	 */
	public function actionError()
	{
		if ($error = Yii::app()->errorHandler->error) {
			if (Yii::app()->request->isAjaxRequest)
				echo $error['message'];
			else
				$this->render('error', $error);
		}
	}
}