<?php

class GoodsController extends Controller
{
    public function actionError()
    {
        if ($error = Yii::app()->errorHandler->error) {
            if (Yii::app()->request->isAjaxRequest)
                echo $error['message'];
            else
                $this->render('error', $error);
        }
    }

    public function filters()
    {
        return array(
            'accessControl', // perform access control for CRUD operations
        );
    }

    public function accessRules()
    {
        return array(
            array('allow',
                'users' => array('@'),
            ),
            array('deny',
                'users' => array('*'),
            )
        );
    }

    public function actionGetGoodInfo()
    {
        if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
            $connection = Yii::app()->db;

            //Входящие данные
            $id = intval($_POST["id"]);

            $res["good"] = $connection->createCommand("SELECT gid, LEFT(title , 255) as title, LEFT(text , 255) as `desc` FROM {{goods}} WHERE gid = :gid AND status = 1")->bindParam(":gid", $id)->queryRow();
            $res["status"] = 200;

            echo CJSON::encode($res);
            Yii::app()->end();
        }
    }

    public function actionPageGetRecommends()
    {
        if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
            $connection = Yii::app()->db;
            $res = array();

            $uid = intval($_POST["uid"]);
            $limit = 4;

            $user_info = $connection->createCommand("SELECT * FROM {{usersinfo}} WHERE uid = :uid")->bindParam(":uid", $uid)->queryRow();
            if (!empty($user_info)) {
                $recommends = $connection->createCommand("SELECT SQL_CALC_FOUND_ROWS r.img, r.title, r.url, r.desc FROM {{users_recommends}} r INNER JOIN {{goods}} g ON r.uid = :uid AND r.rid = g.gid AND g.status = 1 AND r.type = 1 AND r.status = 1 ORDER BY r.id DESC LIMIT :limit")
                    ->bindParam(":uid", $user_info['uid'])
                    ->bindValue(":limit", $limit)
                    ->queryAll();
                $totalRecords = $connection->createCommand('SELECT FOUND_ROWS()')->queryScalar();

                $res["recommends"] = $recommends;
                $res["total"] = $totalRecords;
                $res["status"] = 200;
            } else {
                $res["status"] = 500;
            }

            echo CJSON::encode($res);
            Yii::app()->end();
        }
    }

    public function actionSetRecommendUrl()
    {
        if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
            $connection = Yii::app()->db;
            $err = '';

            //Входящие данные
            $url = mysql_escape_string(htmlspecialchars(strip_tags($_POST["url"])));
            $title = mysql_escape_string(htmlspecialchars(strip_tags($_POST["title"])));
            $desc = mysql_escape_string(htmlspecialchars(strip_tags($_POST["desc"])));

            preg_match("/\d+$/", $url, $match);
            $id = !empty($match) && !empty($match[0]) ? intval($match[0]) : 0;

            $good = $connection->createCommand("SELECT gid, media_img FROM {{goods}} WHERE gid = :gid AND status = 1")->bindParam(":gid", $id)->queryRow();
            $recommend = $connection->createCommand("SELECT id FROM {{users_recommends}} WHERE uid = :uid AND rid = :id AND type = 1 AND status = 1")->bindParam(":uid", Yii::app()->user->id)->bindParam(":id", $id)->queryRow();

            if (empty($good)) {
                $err .= '<li>Товар не найден.</li>';
            }
            if ($title == '') {
                $err .= '<li>Укажите название.</li>';
            }
            if ($desc == '') {
                $err .= '<li>Укажите описание.</li>';
            }
            if ($title != '' && strlen($title) > 255) {
                $err .= '<li>Максимальная длина названия 255 символов.</li>';
            }
            if ($desc != '' && strlen($title) > 255) {
                $err .= '<li>Максимальная длина описания 255 символов.</li>';
            }
            if (!empty($recommend)) {
                $err .= '<li>Ссылка на товар уже находится в списке рекомендаций.</li>';
            }

            if ($err == '') {
                $transaction = $connection->beginTransaction();
                try {
                    $connection->createCommand()->insert('{{users_recommends}}', array('uid' => Yii::app()->user->id, 'rid' => $good['gid'], 'url' => '/market/' . $good['gid'], 'title' => $title, 'desc' => $desc, 'img' => $good['media_img'], 'type' => 1, 'status' => 1));

                    $transaction->commit();
                    $res["status"] = 200;
                } catch (Exception $e) {
                    $transaction->rollback();
                    $res["status"] = 500;
                    $res["message"] = "Сервер временно недоступен.";
                }
            } else {
                $res["status"] = 500;
                $res["message"] = $err;
            }

            echo CJSON::encode($res);
            Yii::app()->end();
        }
    }

    public function actionRecommendFilter()
    {
        if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
            $res = array();
            $connection = Yii::app()->db;
            $limit = Yii::app()->params['users-per-page'];

            $alias = mysql_escape_string(htmlspecialchars(strip_tags($_POST["alias"])));
            $user_info = !empty($alias) ? $connection->createCommand("SELECT uid, alias, CONCAT(name, ' ', fio) as fio FROM {{usersinfo}} WHERE alias = :alias")->bindParam(":alias", $alias)->queryRow() : $connection->createCommand("SELECT * FROM {{usersinfo}} WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->queryRow();

            $page = intval($_POST['page']);

            if(!empty($user_info)){
                try {
                    $sql = "SELECT SQL_CALC_FOUND_ROWS r.id, r.img, r.title, r.url, r.desc FROM {{users_recommends}} r INNER JOIN {{goods}} g ON r.uid = :uid AND r.rid = g.gid AND g.status = 1 AND r.type = 1 AND r.status = 1 ORDER BY r.id DESC LIMIT :limit OFFSET :offset";

                    $command = $connection->createCommand($sql);
                    $command->bindParam(":uid", $user_info['uid']);
                    $command->bindValue(":limit", $limit, PDO::PARAM_INT);
                    $command->bindValue(":offset", ($page - 1) * $limit, PDO::PARAM_INT);

                    $recommends = $command->queryAll();
                    $totalRecords = $connection->createCommand('SELECT FOUND_ROWS()')->queryScalar();

                    if (!empty($recommends)) {
                        $res["status"] = 200;
                        $res["recommends"] = $recommends;
                        $res["total"] = $totalRecords;
                    } else {
                        $res["status"] = 500;
                        $res["total"] = 0;
                    }
                } catch (Exception $e) {
                    $res["status"] = 500;
                    $res["message"] = $e."Сервер временно недоступен.";
                }
            }else{
                $res["status"] = 500;
                $res["total"] = 0;
            }

            echo CJSON::encode($res);
            Yii::app()->end();
        }
    }

    public function actionRecommendDelete()
    {
        if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
            $res = array();
            $connection = Yii::app()->db;
            $id = intval($_POST["id"]);

            $recommend = $connection->createCommand("SELECT id FROM {{users_recommends}} WHERE id = :id AND uid = :uid AND type = 1 AND status = 1")->bindParam(":uid", Yii::app()->user->id)->bindParam(":id", $id)->queryRow();

            if(!empty($recommend)){
                $transaction = $connection->beginTransaction();
                try {
                    $connection->createCommand("DELETE FROM {{users_recommends}} WHERE id = :id AND uid = :uid AND type = 1 AND status = 1")->bindParam(":uid", Yii::app()->user->id)->bindParam(":id", $id)->query();

                    $transaction->commit();
                    $res["status"] = 200;
                }catch (Exception $e) {
                    $transaction->rollback();
                    $res["status"] = 500;
                    $res["message"] = "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
                }
            }else{
                $res["status"] = 500;
                $res["message"] = "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
            }
            echo CJSON::encode($res);
            Yii::app()->end();
        }
    }
    
    
    
    public function actionPageGetFavorite()
    {
        if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
            $connection = Yii::app()->db;
            $res = array();

            $uid = intval($_POST["uid"]);
            $limit = 4;

            $user_info = $connection->createCommand("SELECT * FROM {{usersinfo}} WHERE uid = :uid")->bindParam(":uid", $uid)->queryRow();
            if (!empty($user_info)) {
                $favorite = $connection->createCommand("SELECT SQL_CALC_FOUND_ROWS g.media_img as img, g.title, g.gid, LEFT(g.text , 255) as `desc` FROM {{users_favorite_good}} f INNER JOIN {{goods}} g ON f.uid = :uid AND f.good_id = g.gid AND g.status = 1 ORDER BY f.id DESC LIMIT :limit")
                    ->bindParam(":uid", $user_info['uid'])
                    ->bindValue(":limit", $limit)
                    ->queryAll();
                $totalRecords = $connection->createCommand('SELECT FOUND_ROWS()')->queryScalar();

                $res["favorite"] = $favorite;
                $res["total"] = $totalRecords;
                $res["status"] = 200;
            } else {
                $res["status"] = 500;
            }

            echo CJSON::encode($res);
            Yii::app()->end();
        }
    }

    public function actionFavoriteFilter()
    {
        if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
            $res = array();
            $connection = Yii::app()->db;
            $limit = Yii::app()->params['users-per-page'];
            
            $user_info = $connection->createCommand("SELECT * FROM {{usersinfo}} WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->queryRow();

            $page = intval($_POST['page']);

            if(!empty($user_info) && !empty($page)){
                try {
                    $sql = "SELECT SQL_CALC_FOUND_ROWS f.id, g.media_img as img, g.title, g.gid, LEFT(g.text , 255) as `desc` FROM {{users_favorite_good}} f INNER JOIN {{goods}} g ON f.uid = :uid AND f.good_id = g.gid AND g.status = 1 ORDER BY f.id DESC LIMIT :limit OFFSET :offset";

                    $command = $connection->createCommand($sql);
                    $command->bindParam(":uid", $user_info['uid']);
                    $command->bindValue(":limit", $limit, PDO::PARAM_INT);
                    $command->bindValue(":offset", ($page - 1) * $limit, PDO::PARAM_INT);

                    $favorite = $command->queryAll();
                    $totalRecords = $connection->createCommand('SELECT FOUND_ROWS()')->queryScalar();

                    if (!empty($favorite)) {
                        $res["status"] = 200;
                        $res["favorite"] = $favorite;
                        $res["total"] = $totalRecords;
                    } else {
                        $res["status"] = 500;
                        $res["total"] = 0;
                    }
                } catch (Exception $e) {
                    $res["status"] = 500;
                    $res["message"] = $e."Сервер временно недоступен.";
                }
            }else{
                $res["status"] = 500;
                $res["total"] = 0;
            }

            echo CJSON::encode($res);
            Yii::app()->end();
        }
    }
    

    
    
    public function actionGoodAddFavorite()
    {
        if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
            Functions::access_control(1);
            $connection = Yii::app()->db;
            $err = '';

            //Входящие данные
            $id = intval($_POST["good_id"]);

            $good = $connection->createCommand("SELECT gid FROM {{goods}} WHERE (gid = :gid AND status = 1) OR :uid = uid")->bindParam(":gid", $id)->bindParam(":uid", Yii::app()->user->id)->queryRow();
            $favorite_good = $connection->createCommand("SELECT id FROM {{users_favorite_good}} WHERE uid = :uid AND good_id = :good_id")->bindParam(":uid", Yii::app()->user->id)->bindParam(":good_id", $id)->queryRow();

            if(empty($good)){
                $err .= '<li>Товар не найден.</li>';
            }
            if(!empty($favorite_good)){
                $err .= '<li>Товар уже находится в списке избранных.</li>';
            }

            if($err == ''){
                $transaction = $connection->beginTransaction();
                try {
                    $connection->createCommand()->insert('{{users_favorite_good}}', array('uid' => Yii::app()->user->id, 'good_id' => $id, 'date' => time()));

                    $transaction->commit();
                    $res["status"] = 200;
                } catch(Exception $e) {
                    $transaction->rollback();
                    $res["status"] = 500;
                    $res["message"] = "Сервер временно недоступен.";
                }
            }else{
                $res["status"] = 500;
                $res["message"] = $err;
            }

            echo CJSON::encode($res);
            Yii::app()->end();
        }
    }
    
    public function actionSetGoodClaim()
    {
        if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
            Functions::access_control(1);
            $connection = Yii::app()->db;
            $err = '';

            //Входящие данные
            $id = intval($_POST["id"]);
            $comment = mysql_escape_string(htmlspecialchars(strip_tags($_POST["comment"])));

            $good = $connection->createCommand("SELECT * FROM {{goods}} WHERE gid = :gid AND status = 1")
            ->bindParam(":gid", $id)
            ->queryRow();
            
            $claim_good = $connection->createCommand("SELECT * FROM {{control_good_claim}} WHERE uid = :uid AND gid = :gid")
            ->bindParam(":uid", Yii::app()->user->id)
            ->bindParam(":gid", $id)->queryRow();

            if(empty($good)){
                $err .= '<li>Товар не найден.</li>';
            }
            if(!empty($claim_good)){
                $err .= '<li>Вы уже отправляли жалобу на данный товар.</li>';
            }
            
            if(strlen($comment) < 10) {
	            $err .= '<li>Текст жалобы слишком маленький. Опишите ситуацию более детальнее.'.strlen($comment).'</li>';
            }
            
            if(strlen($comment) > 500) {
	            $err .= '<li>Текст жалобы слишком большой.</li>';
            }

            if($err == ''){
                $transaction = $connection->beginTransaction();
                try {
					
					$connection->createCommand()->insert('{{control_good_claim}}', array(
						'uid' => Yii::app()->user->id, 
						'gid' => $id, 
						'date' => time(),
						'comment' => $comment,
						'status' => 1
					));

                    $transaction->commit();
                    $res["status"] = 200;
                    $res["message"] = "Ваша жалоба отправлена на рассмотрение.";
                    
                } catch(Exception $e) {
                    $transaction->rollback();
                    $res["status"] = 500;
                    $res["message"] = "Сервер временно недоступен.";
                }
            }else{
                $res["status"] = 500;
                $res["message"] = "Возникла ошибка." . $err;
            }

            echo CJSON::encode($res);
            Yii::app()->end();
        }
    }
    
    

    
    
}