<?php

class GroupsController extends Controller
{
	public $layout = 'main';

	/**
	 * @return array action filters
	 */
	public function filters()
	{
		return array(
			'accessControl', // perform access control for CRUD operations
		);
	}

	/**
	 * Specifies the access control rules.
	 * This method is used by the 'accessControl' filter.
	 * @return array access control rules
	 */
	public function accessRules()
	{
		return array(
			array('allow',
				'users' => array('@'),
			),
			array('deny',
				'users' => array('*'),
			)
		);
	}

	public function actionGroupEdit()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			Functions::access_control(1);
			$connection = Yii::app()->db;
			$res = array();
			$err = '';

			$name = mysql_escape_string(htmlspecialchars(strip_tags($_POST["name"])));
			$alias = mysql_escape_string(htmlspecialchars(strip_tags($_POST["alias"])));
			$about = mysql_escape_string(htmlspecialchars(strip_tags($_POST["about"])));
			$c_day = intval($_POST["c_day"]);
			$c_month = intval($_POST["c_month"]);
			$c_year = intval($_POST["c_year"]);
			$create_date = strtotime($c_year . '-' . $c_month . '-' . $c_day);
			$settings_comments = intval($_POST["settings_comments"]);
			$group = intval($_POST["group"]);

			$group_info = $connection->createCommand("SELECT * FROM {{usersinfo}} WHERE uid = :uid AND status = 1")
				->bindParam(":uid", $group)
				->queryRow();

			if(empty($group_info)){
				$res["message"] = '<li>Доступ запрещен.</li>';
				$res["status"] = 500;
				echo CJSON::encode($res);
				Yii::app()->end();
			}

			if(!empty($group_info) && $group_info['owner'] != Yii::app()->user->id){
				$err .= '<li>Доступ запрещен.</li>';
			}
			if(empty($create_date)){
				$err .= '<li>Дата основания выбрана неверно.</li>';
			}
			if(empty($name)){
				$err .= '<li>Выберите название.</li>';
			}
			if(!in_array($settings_comments, array(0,1))){
				$err .= '<li>Обратная связь выбрана неверно.</li>';
			}
			if(!empty($alias) && !f_alias_allowed($alias)){
				$err .= '<li>Вы ввели недопустимое название адреса страницы или указаный адрес уже занят.</li>';
			}

			if ($err == '') {
				$transaction = $connection->beginTransaction();
				try {

					$connection->createCommand("UPDATE {{usersinfo}} SET `name` = :name, birth = :birth, alias = :alias, about = :about, settings_comments = :settings_comments WHERE uid = :uid")
						->bindParam(":uid", $group)
						->bindParam(":name", $name)
						->bindParam(":birth", date('Y-m-d', $create_date))
						->bindParam(":alias", $alias)
						->bindParam(":about", $about)
						->bindParam(":settings_comments", $settings_comments)
						->query();

					$connection->createCommand("UPDATE {{alias}} SET `name` = :name WHERE uid = :uid")
						->bindParam(":uid", $group)
						->bindParam(":name", $alias)
						->query();

					$transaction->commit();
					$res["status"] = 200;
				} catch (Exception $e) {
					$transaction->rollback();
					$res["status"] = 500;
					$res["message"] = "При запросе возникла ошибка.";
				}
			}else{
				$res["status"] = 500;
				$res["message"] = $err;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionGroupNew()
	{

		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			Functions::access_control(1);
			$connection = Yii::app()->db;
			$res = array();
			$err = '';

			$name = mysql_escape_string(htmlspecialchars(strip_tags($_POST["name"])));
			$alias = mysql_escape_string(htmlspecialchars(strip_tags($_POST["alias"])));
			$about = mysql_escape_string(htmlspecialchars(strip_tags($_POST["about"])));
			$c_day = intval($_POST["c_day"]);
			$c_month = intval($_POST["c_month"]);
			$c_year = intval($_POST["c_year"]);
			$create_date = strtotime($c_year . '-' . $c_month . '-' . $c_day);
			$settings_comments = intval($_POST["settings_comments"]);

			if(empty($create_date)){
				$err .= '<li>Дата основания выбрана неверно.</li>';
			}
			if(empty($name)){
				$err .= '<li>Выберите название.</li>';
			}
			if(!in_array($settings_comments, array(0,1))){
				$err .= '<li>Обратная связь выбрана неверно.</li>';
			}
			if(!empty($alias) && !f_alias_allowed($alias)){
				$err .= '<li>Вы ввели недопустимое название адреса страницы или указаный адрес уже занят.</li>';
			}

			if (empty($err)) {
				$transaction = $connection->beginTransaction();
				try {
					$connection->createCommand()->insert('{{groups}}', array(
							'date' => time()
					));
					$group_id = Yii::app()->db->getLastInsertID();
					$alias = !empty($alias) ? $alias : 'group'.($group_id-1000000000);

					$connection->createCommand()->insert('{{usersinfo}}', array(
							'uid' => $group_id,
							'owner' => Yii::app()->user->id,
							'type' => 2,
							'name' => $name,
							'birth' => date('Y-m-d', $create_date),
							'alias' => $alias,
							'about' => $about,
							'settings_comments' => $settings_comments
					));

					$connection->createCommand()->insert('{{alias}}', array(
							'uid' => $group_id,
							'name' => $alias,
							'type' => 2
					));

					$transaction->commit();
					$res["status"] = 200;
					$res["group"] = $alias;
				} catch (Exception $e) {
					$transaction->rollback();
					$res["status"] = 500;
					$res["message"] = "При создании канала возникла ошибка.";
				}
			} else {
				$res["status"] = 500;
				$res["message"] = $err;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionGroupsSettings()
	{

		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();

			$connection = Yii::app()->db;
			$limit = Yii::app()->params['users-per-page'];

			$friends = intval($_POST['friends']);
			$page = intval($_POST['page']);
			$search_query = mysql_escape_string(htmlspecialchars(strip_tags($_POST["search_query"])));
			$pieces = explode(" ", $search_query);

			$query = array();

			$query['not_me'] = ' u.uid <> :uid ';
			if (!empty($country) && $country > 0) {
				$query['country'] = ' u.country = :country ';
			}
			if (!empty($search_query) && strlen($search_query) >= 3) {
				if (count($pieces) == 1) {
					$query['search_query'] = ' (u.name LIKE :text1 || u.fio LIKE :text1) ';
				} elseif (count($pieces) == 2) {
					$query['search_query'] = ' (u.name LIKE :text1 || u.fio LIKE :text1 || u.name LIKE :text2 || u.fio LIKE :text2) ';
				}
			}

			$query = !empty($query) ? " WHERE " . implode(" AND ", $query) : '';
			$friends_query_1 = !empty($friends) ? "  INNER JOIN {{friends}} f ON f.uid = :uid AND f.fuid = u.uid  " : ' LEFT JOIN {{friends}} f ON f.uid = :uid AND f.fuid = u.uid ';
			$friends_query_2 = !empty($friends) ? "" : '  AND f.id IS NULL  ';

			$sql = "SELECT SQL_CALC_FOUND_ROWS u.uid, u.name, u.fio, u.tel, u.photo, u.country, a.name AS alias, (f.id IS NOT NULL) AS friend FROM {{usersinfo}} u ".$friends_query_1." LEFT JOIN {{alias}} a ON a.uid = u.uid " . $query . $friends_query_2 . " ORDER BY uid LIMIT :limit OFFSET :offset";
			$command = $connection->createCommand($sql);
			$command->bindParam(":uid", Yii::app()->user->id, PDO::PARAM_INT);
			$command->bindValue(":limit", $limit, PDO::PARAM_INT);
			$command->bindValue(":offset", ($page - 1) * $limit, PDO::PARAM_INT);

			if (!empty($search_query) && strlen($search_query) >= 3) {
				if (count($pieces) == 1) {
					$command->bindValue(":text1", '%' . $pieces[0] . '%');
				} elseif (count($pieces) == 2) {
					$command->bindValue(":text1", '%' . $pieces[0] . '%');
					$command->bindValue(":text2", '%' . $pieces[2] . '%');
				}
			}

			$users = $command->queryAll();
			$totalRecords = $connection->createCommand('SELECT FOUND_ROWS()')->queryScalar();

			if (!empty($users)) {
				$res["users"] = $users;
				$res["total"] = $totalRecords;
				$res["status"] = 200;
			} else {
				$res["status"] = 500;
				$res["total"] = 0;
			}
			$res["test"] = $friends;

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionIndex()
	{
		$this->render('groups');
	}

	public function actionEdit()
	{
		$this->render('edit');
	}
	
	public function actionContacts()
	{
		$this->render('contacts');
	}

	public function actionMy()
	{
		$this->render('my');
	}

	public function actionSettings()
	{
		$this->render('settings');
	}

	public function actionNew()
	{
		$this->render('new');
	}
	
	public function actionContactNew()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			Functions::access_control(1);
			$connection = Yii::app()->db;
			$res = array();
			$err = '';
			
			/*$res["status"] = 500;
			$a = serialize($_POST);
			$res["message"] = $a;

			echo CJSON::encode($res);
			Yii::app()->end();
			*/
			
			$link = mysql_escape_string(htmlspecialchars(strip_tags($_POST["link"])));
			$title = mysql_escape_string(htmlspecialchars(strip_tags($_POST["title"])));
			$uid = intval($_POST["uid"]);
			
			$alias = "";
			
			
			$replace_1 = array("http://", "https://", $_SERVER["SERVER_NAME"], "/");
			$replace_2   = array("", "", "", "");
			$alias = str_replace($replace_1, $replace_2, $link);
			
			$userinfo = $connection->createCommand("SELECT uid, name FROM {{alias}} WHERE name = :name")->bindParam(":name",$alias)->queryRow();
			$group = $connection->createCommand("SELECT uid FROM {{usersinfo}} WHERE uid = :uid AND owner = :owner AND type = 2")
			->bindParam(":uid",$uid)
			->bindParam(":owner",Yii::app()->user->id)
			->queryRow();
			
			$is_contact = $connection->createCommand("SELECT id FROM {{contact}} WHERE uid = :uid AND contact_uid = :contact_uid AND type = 2")
			->bindParam(":uid",$group["uid"])
			->bindParam(":contact_uid",$userinfo["uid"])
			->queryRow();
			
			if(empty($userinfo)){
				$err .= '<li>Информация о пользователе не найдена.</li>';
			}
			
			if(empty($group)){
				$err .= '<li>Данный пользователь уже находится в контактах данной группы.</li>';
			}
			
			if(!empty($is_contact)){
				$err .= '<li>Невозможно добавить контакты для данной группы.</li>';
			}

			if ($err == "") {
				$transaction = $connection->beginTransaction();
				try {
					
					$hash = $uid . "-" . $userinfo["uid"];
					$connection->createCommand()->insert('{{contact}}', array('uid' => $group["uid"], 'type' => 2, 'contact_uid' => $userinfo["uid"], 'contact_title' => $title, 'hash' => $hash, 'date' => time(), 'status' => 1 ));
					
					$transaction->commit();
					$res["status"] = 200;
					$res["user"] = $connection->createCommand("SELECT uid, name, fio, alias, photo FROM {{usersinfo}} WHERE uid = :uid")->bindParam(":uid",$userinfo["uid"])->queryRow();

					$res["message"] = "Пользователь успешно добавлен в список контактов.";
				} catch (Exception $e) {
					$transaction->rollback();
					$res["status"] = 500;
					$res["message"] = "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
				}
			} else {
				$res["status"] = 500;
				$res["message"] = $err;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	/**
	 * This is the action to handle external exceptions.
	 */
	public function actionError()
	{
		if ($error = Yii::app()->errorHandler->error) {
			if (Yii::app()->request->isAjaxRequest)
				echo $error['message'];
			else
				$this->render('error', $error);
		}
	}
}