<?php

class MarketController extends Controller
{
	public $layout = 'main';

	/**
	 * @return array action filters
	 */
	public function filters()
	{
		return array(
			'accessControl', // perform access control for CRUD operations
		);
	}

	/**
	 * Specifies the access control rules.
	 * This method is used by the 'accessControl' filter.
	 * @return array access control rules
	 */
	public function accessRules()
	{
		return array(
			array('allow',
				'users' => array('@'),
			),
			array('deny',
				'users' => array('*'),
			)
		);
	}

	public function actionEdit()
	{
		$this->render('edit');
	}

	public function actionAdd()
	{
		$this->render('add');
	}

	public function actionDetails()
	{
		$this->render('details');
	}

	public function actionIndex()
	{
		$this->render('index');
	}

	public function actionUser($uid)
	{
		$this->render('user');
	}

	public function actionGoodFilter()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			$limit = 9;

			$page = intval($_POST["page"]);
			$uid = isset($_POST['uid']) ? intval($_POST['uid']) : null;
			$type = intval($_POST["type"]);
			$search_query = mysql_escape_string(htmlspecialchars(strip_tags($_POST["query"])));
			$category = intval($_POST["category"]);
			$country = intval($_POST["country"]);
			$city = intval($_POST["city"]);
			$condition1 = intval($_POST["condition1"]);
			$condition2 = intval($_POST["condition2"]);
			$price_from = intval($_POST["price_from"]);
			$price_to = intval($_POST["price_to"]);
			$search_order = intval($_POST["order"]);

			try {
				if (!empty($page)){
					$query = array();
					$order = array();
					$join = array();

					$query['good_status'] = ' g.status = 1 ';
					if (!empty($uid)) {
						$query['uid'] = ' g.uid = :uid ';
					}
					if (!empty($country) && $country > 0 && $city == -1) {
						$query['country'] = ' g.country = :country ';
					}
					if (!empty($city) && $city > 0) {
						$query['city'] = ' g.city = :city ';
					}
					if (!empty($price_from)) {
						$query['price_from'] = ' g.price >= :price_from ';
					}
					if (!empty($price_to)) {
						$query['price_to'] = ' g.price <= :price_to ';
					}

					if (!empty($condition1) && !empty($condition2)) {
						$query['condition'] = ' (g.condition = 1 OR g.condition = 2)';
					}else{
						if (!empty($condition1)) {
							$query['condition'] = ' g.condition = 1 ';
						}
						if (!empty($condition2)) {
							$query['condition'] = ' g.condition = 2 ';
						}
					}
					if (!empty($price_to)) {
						$query['price_to'] = ' g.price <= :price_to ';
					}

					if (!empty($category) && $category > 0) {
						$join['category'] = ' INNER JOIN {{good_category}} gc ON gc.good_id = g.gid AND gc.category_id = :category ';
					}
					if (!empty($type) && in_array($type, [1,2])) {
						$query['type'] = ' g.type = :type ';
					}
					if (!empty($search_query) && strlen($search_query) >= 3) {
						$query['search_query'] = ' (g.title LIKE :text) ';
					}
					if (!empty($search_order)) {
						if($search_order == 1){
							$order['search_order'] = ' date DESC ';
							//$order['search_order'] = ' count_orders DESC ';
						}
						if($search_order == 2){
							$order['search_order'] = ' date ';
						}
						if($search_order == 3){
							$order['search_order'] = ' count_orders DESC ';
						}
					}

					$query = !empty($query) ? " WHERE " . implode(" AND ", $query) : '';
					$order = !empty($order) ? " ORDER BY " . implode(", ", $order) : '';
					$join = !empty($join) ? ' ' . implode(" ", $join) : '';

					$sql = "SELECT SQL_CALC_FOUND_ROWS g.verify, g.gid, g.uid, g.title, g.price, g.discount_price, g.discount, g.media_img as photo, c.name as category FROM {{goods}} g INNER JOIN {{categories}} c ON c.id = g.category_id ".$join." " . $query . " ".$order." LIMIT :limit OFFSET :offset";

					$command = $connection->createCommand($sql);
					$command->bindValue(":limit", $limit, PDO::PARAM_INT);
					$command->bindValue(":offset", ($page - 1) * $limit, PDO::PARAM_INT);

					if (!empty($uid)) {
						$command->bindParam(":uid", $uid);
					}
					if (!empty($country) && $country > 0 && $city == -1) {
						$command->bindParam(":country", $country);
					}
					if (!empty($city) && $city > 0) {
						$command->bindParam(":city", $city);
					}
					if (!empty($price_from)) {
						$command->bindParam(":price_from", $price_from);
					}
					if (!empty($price_to)) {
						$command->bindParam(":price_to", $price_to);
					}
					if (!empty($category) && $category > 0) {
						$command->bindParam(":category", $category);
					}
					if (!empty($type) && in_array($type, [1,2])) {
						$command->bindParam(":type", $type);
					}
					if (!empty($search_query) && strlen($search_query) >= 3) {
						$command->bindValue(":text", '%' . $search_query . '%');
					}
					if (!empty($search_order)) {
//						if($search_order == 2){
//							$command->bindParam(":popular_date", strtotime('-10 day', time()));
//						}
					}

					$goods = $command->queryAll();

					$res["goods"] = $goods;
					$res["status"] = 200;
				}else{
					$res["status"] = 500;
				}
			} catch (Exception $e) {
				$res["status"] = 500;
				$res["message"] = "Сервер временно недоступен.";
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionGoodEdit()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			Functions::access_control(3);
			$connection = Yii::app()->db;
			$fs_db = Yii::app()->fs_db;
			$res = array();
			$err = '';
			$regex_price = '/^[0-9]+(\.[0-9]{1,2})?$/';

			//Входящие данные
			$gid = intval($_POST["gid"]);
			$category_id = intval($_POST["category"]);
			$title = mysql_escape_string(htmlspecialchars(strip_tags($_POST["title"])));
			$text = mysql_escape_string(htmlspecialchars(strip_tags($_POST["text"])));
			$type = intval($_POST["type"]);
			$condition = intval($_POST["condition"]);
//			$price = doubleval($_POST["price"]);
//			$discount = intval($_POST["discount"]);
			$discount_price = doubleval($_POST["discount_price"]);
//			$cash = intval($_POST["cash"]);
//			$pay_for = mysql_escape_string(htmlspecialchars(strip_tags($_POST["pay_for"])));
			$delivery = mysql_escape_string(htmlspecialchars(strip_tags($_POST["delivery"])));
			$country_id = intval($_POST["country"]);
			$city_id = intval($_POST["city"]);
			$photo = mysql_escape_string(htmlspecialchars(strip_tags($_POST["photo"])));

			$user_info = $connection->createCommand("SELECT * FROM {{usersinfo}} WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->queryRow();
			$category = $connection->createCommand("SELECT * FROM {{categories}} WHERE id = :id")->bindParam(":id", $category_id)->queryRow();
			$country = Loc::getCountryById($category_id);
			$city = Loc::getCityById($city_id);
			$good = $connection->createCommand("SELECT * FROM {{goods}} WHERE gid = :gid AND uid = :uid")
				->bindParam(":gid", $gid)
				->bindParam(":uid", Yii::app()->user->id)
				->queryRow();

			if(empty($user_info) || empty($good)){
				$err .= '<p>Доступ запрещен.</p>';
			}
			if(empty($category)){
				$err .= '<p>Необходимо указать категорию.</p>';
			}
			if(empty($title)){
				$err .= '<p>Необходимо указать название товара/услуги.</p>';
			}
			if(strlen($title) > 250){
				$err .= '<p>Название товара/услуги не может превышать 250 символов.</p>';
			}
			if(empty($text)){
				$err .= '<p>Необходимо указать полное описание.</p>';
			}
			if(strlen($text) > 5000){
				$err .= '<p>Полное описание не может превышать 5000 символов.</p>';
			}
			if(!in_array($type, [1,2])){
				$err .= '<p>Необходимо указать тип вашего объявления.</p>';
			}
			if(!in_array($condition, [1,2])){
				$err .= '<p>Необходимо указать cостояние.</p>';
			}
//			if(empty($price) || !preg_match($regex_price, $price)){
//				$err .= '<p>Поле "Цена" указано неверно.</p>';
//			}
//			if($discount < 10){
//				$err .= '<p>Минимальная скидка 10%</p>';
//			}
//			if($discount > 100){
//				$err .= '<p>Максимальная скидка 100%</p>';
//			}
			if(empty($discount_price) || !preg_match($regex_price, $discount_price)){
				$err .= '<p>Поле "Полная стоимость" указано неверно.</p>';
			}
//			if($cash < 0){
//				$err .= '<p>Минимальный процент наличными 0%</p>';
//			}
//			if($cash > 50){
//				$err .= '<p>Максимальный процент наличными 50%</p>';
//			}
//			if(empty($pay_for)){
//				$err .= '<p>Необходимо указать оплату за.</p>';
//			}
			if(empty($delivery)){
				$err .= '<p>Необходимо указать оплату и доставку.</p>';
			}
			if(empty($country)){
				$err .= '<p>Необходимо указать страну.</p>';
			}
//			if(empty($city)){
//				$err .= '<p>Необходимо указать город.</p>';
//			}
			if(empty($photo)){
				$err .= '<p>Необходимо загрузить изображение.</p>';
			}

			if (empty($err)){
				$transaction = $connection->beginTransaction();
				try {
					$connection->createCommand("UPDATE {{goods}} SET category_id = :category_id, type = :type, title = :title, text = :text, `condition` = :condition, price = :price, discount_price = :discount_price, country = :country, city = :city, delivery = :delivery, media_img = :media_img, updated = :updated WHERE gid = :gid AND uid = :uid")
						->bindParam(":uid", Yii::app()->user->id)
						->bindParam(":gid", $gid)
						->bindParam(":category_id", $category_id)
						->bindParam(":type", $type)
						->bindParam(":title", $title)
						->bindParam(":text", $text)
						->bindParam(":condition", $condition)
						->bindValue(":price", $discount_price)
//						->bindParam(":cash", $cash)
//						->bindValue(":discount", $discount)
						->bindParam(":discount_price", $discount_price)
//						->bindParam(":pay_for", $pay_for)
						->bindParam(":country", $country_id)
						->bindParam(":city", $city_id)
						->bindParam(":delivery", $delivery)
						->bindParam(":media_img", $photo)
						->bindParam(":updated", time())
						->query();

					//Удаляем категории
					$connection->createCommand('DELETE FROM {{good_category}} WHERE good_id = :good_id')
						->bindParam('good_id', $gid)
						->query();

					// Вставляем категории
					$connection->createCommand()->insert('{{good_category}}', array(
						'good_id' => $gid,
						'category_id' => $category['id']
					));
					$parent_cat = $connection->createCommand("SELECT * FROM {{categories}} WHERE id = :id")->bindParam(":id", $category['parent'])->queryRow();
					if(!empty($parent_cat)){
						$connection->createCommand()->insert('{{good_category}}', array(
							'good_id' => $gid,
							'category_id' => $parent_cat['id']
						));
						$parent_cat2 = $connection->createCommand("SELECT * FROM {{categories}} WHERE id = :id")->bindParam(":id", $parent_cat['parent'])->queryRow();
						if(!empty($parent_cat2)){
							$connection->createCommand()->insert('{{good_category}}', array(
								'good_id' => $gid,
								'category_id' => $parent_cat2['id']
							));
						}
					}

					//Удаляем изображение
					$fs_db->createCommand("UPDATE {{images}} SET status = 2 WHERE path = :path")
						->bindParam(":path", $good['media_img'])
						->query();

					//Добавляем изображения
					$fs_db->createCommand("UPDATE {{images}} SET status = 1 WHERE path = :path")
						->bindParam(":path", $photo)
						->query();

					$transaction->commit();
					$res['good'] = $good;
					$res["status"] = 200;
				} catch (Exception $e) {
					$transaction->rollback();
					$res["status"] = 500;
					$res["message"] = "<p>Сервер временно недоступен.</p>";
				}
			} else {
				$res["status"] = 500;
				$res["message"] = $err;
			}
			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionMakeOrder()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			Functions::access_control(1);
			$connection = Yii::app()->db;
			$res = array();
			$err = '';

			//Входящие данные
			$gid = intval($_POST["gid"]);
			$order_name = mysql_escape_string(htmlspecialchars(strip_tags($_POST["order_name"])));
			$order_email = mysql_escape_string(htmlspecialchars(strip_tags($_POST["order_email"])));
			$order_tel = mysql_escape_string(htmlspecialchars(strip_tags($_POST["order_tel"])));
			$order_skype = mysql_escape_string(htmlspecialchars(strip_tags($_POST["order_skype"])));
			$order_quantity = intval($_POST["order_quantity"]);
			$order_details = mysql_escape_string(htmlspecialchars(strip_tags($_POST["order_details"])));
			$order_quick = intval($_POST["order_quick"]);

			$user_info = $connection->createCommand("SELECT * FROM {{usersinfo}} WHERE uid = :uid")
				->bindParam(":uid", Yii::app()->user->id)
				->queryRow();
			$good = $connection->createCommand("SELECT * FROM {{goods}} WHERE gid = :gid AND status = 1")
				->bindParam(":gid", $gid)
				->queryRow();
			$order = $connection->createCommand("SELECT id FROM {{orders}} WHERE gid = :gid AND uid = :uid AND status < 4")
				->bindParam(":gid", $gid)
				->bindParam(":uid", Yii::app()->user->id)
				->queryRow();
				
			//Вычисляем скидку от сети ********************************************************************************************
			$my = $connection->createCommand("SELECT package FROM {{usersinfo}} WHERE uid = :uid")
			->bindParam(":uid", Yii::app()->user->id)
			->queryRow();
			
			$amount_potential = $connection->createCommand("SELECT SUM(deposit) FROM {{users_potential}} WHERE uid = :uid AND status = 1 AND type = 1 AND dt < dte AND type = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->queryScalar();
			
			$sertification_discount = doubleval($connection->createCommand("SELECT discount FROM {{users_verify}} WHERE uid = :uid")
				->bindParam(":uid", $good["uid"])
				->queryScalar()) / 100; //Максимальная скидка
				
			$discount_now = $connection->createCommand("SELECT discount FROM {{settings_cashback}} WHERE :amount >= amount_from AND :amount < amount_to")
				->bindParam(":amount", $amount_potential)
				->queryScalar(); //Скидка для партнеров сети / по подписке в настройках	
			$discount_percent = $discount_now / 0.1; //Процент от максимальной скидки 10%)
			$discount_now = $sertification_discount * $discount_percent;
			
			//*************************************
			if($good["uid"] == 117485) {
				$discount_now = 0;
			}
			//*************************************
			
			$amount = $good['price'];
			$discount_amount = intval($amount * $discount_now * 100) / 100;
			
			
			$rx = 0;
			if(intval($_COOKIE[$good["gid"]]) > 0) {
				
				$rx = intval($_COOKIE[$good["gid"]]);
				
				$user_info_rx = $connection->createCommand("SELECT * FROM {{usersinfo}} WHERE uid = :uid AND uid > 0")
					->bindParam(":uid", $rx)
					->queryRow();
					
				if(empty($user_info_rx)) {
					$rx = 0;
				}
				
				if($rx == Yii::app()->user->id) {
					$rx = 0;
				}
				
				if($rx == $good["uid"]) {
					$rx = 0;
				}
				
			}
			
			
			//Начальные проверки ********************************************************************************************

			if(empty($user_info) || empty($good) || !in_array($order_quick, [0,1])){
				$err .= '<p>Доступ запрещен.</p>';
			}
//			if(!preg_match("/^[а-яА-Я]*$/", $order_name)){
//				$err .= '<p>Имя указано неверно.</p>';
//			}
			if(!filter_var($order_email, FILTER_VALIDATE_EMAIL)){
				$err .= '<p>Поле "E-mail" указано неверно.</p>';
			}
			if(!preg_match("/[0-9]+/", $order_tel)){
				$err .= '<p>Поле "Телефон" указано неверно.</p>';
			}
			if(Yii::app()->user->id == $good['uid']){
				$err .= '<p>Вы не можете заказать свой товар.</p>';
			}
			if($order_quantity < 1 || $order_quantity > 100){
				$err .= '<p>Максимальное "Количество" 100 единиц в одном заказе.</p>';
			}
			if(!empty($order)){
				$err .= '<p>У вас уже есть невыполненный заказ на данный товар.</p>';
			}
			
			
			if($good["uid"] == 201378) {
				
				$order_details = str_replace(" ", "", $order_details);
				$pattern = '/^\d{16}$/';
				
				if (!preg_match($pattern, $order_details) || !Functions::is_valid_credit_card($order_details)) {
				    $err = 'Неверный формат номера кошелька в Money Storage.';   
				}
				
			}
			

			if ($err == ""){
				$transaction = $connection->beginTransaction();
				try {
					$connection->createCommand()->insert('{{orders}}', array(
						'uid' => Yii::app()->user->id,
						'gid' => $gid,
						'name' => $order_name,
						'email' => $order_email,
						'tel' => $order_tel,
						'skype' => $order_skype,
						'quantity' => $order_quantity,
						'details' => $order_details,
						'amount' => $good['price'],
						'quick' => $order_quick,
						'date' => time(),
						'discount_amount' => $discount_amount,
						'discount_percent' => $discount_now,
						'uidx' => $rx
					));
					$order_id = Yii::app()->db->getLastInsertID();

					$text_msg = 'Заказ №'.$order_id.': новая заявка товара "'. $good['title'] .'".';
					$connection->createCommand()->insert('{{messages}}', array('date' => time(), 'fuid' => 2, 'tuid' => $good['uid'], 'message' => $text_msg));

					$transaction->commit();
					$res["status"] = 200;
					$res["message"] = '<p>Ваша заявка успешно подана. С Вами свяжутся, как только она будет обработана. Также отслеживать всю информацию о заказах можно на странице <a href="/buy">"Мои заказы"</a>.</p>';
				} catch (Exception $e) {
					$transaction->rollback();
					$res["status"] = 500;
					$res["message"] = "<p>Сервер временно недоступен.</p>";
				}
			} else {
				$res["status"] = 500;
				$res["message"] = $err;
			}
			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionGoodAdd()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			Functions::access_control(3);
			$connection = Yii::app()->db;
			$fs_db = Yii::app()->fs_db;
			$res = array();
			$err = '';
			$regex_price = '/^[0-9]+(\.[0-9]{1,2})?$/';

			//Входящие данные
			$category_id = intval($_POST["category"]);
			$title = mysql_escape_string(htmlspecialchars(strip_tags($_POST["title"])));
			$text = mysql_escape_string(htmlspecialchars(strip_tags($_POST["text"])));
			$type = intval($_POST["type"]);
			$condition = intval($_POST["condition"]);
//			$price = doubleval($_POST["price"]);
//			$discount = intval($_POST["discount"]);
			$discount_price = doubleval($_POST["discount_price"]);
//			$cash = intval($_POST["cash"]);
//			$pay_for = mysql_escape_string(htmlspecialchars(strip_tags($_POST["pay_for"])));
			$delivery = mysql_escape_string(htmlspecialchars(strip_tags($_POST["delivery"])));
			$country_id = intval($_POST["country"]);
			$city_id = intval($_POST["city"]);
			$photo = mysql_escape_string(htmlspecialchars(strip_tags($_POST["photo"])));

			$user_info = $connection->createCommand("SELECT * FROM {{usersinfo}} WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->queryRow();
			$category = $connection->createCommand("SELECT * FROM {{categories}} WHERE id = :id")->bindParam(":id", $category_id)->queryRow();
			$country = Loc::getCountryById($category_id);
			$city = Loc::getCityById($city_id);
			
			if($user_info["verify"] == 0)
				$err .= '<p>Создавать товары могут только верифицированные продавцы.</p>';
			
			if(empty($user_info)){
				$err .= '<p>Доступ запрещен.</p>';
			}
			if(empty($category)){
				$err .= '<p>Необходимо указать категорию.</p>';
			}
			if(empty($title)){
				$err .= '<p>Необходимо указать название товара/услуги.</p>';
			}
			if(strlen($title) > 250){
				$err .= '<p>Название товара/услуги не может превышать 250 символов.</p>';
			}
			if(empty($text)){
				$err .= '<p>Необходимо указать полное описание.</p>';
			}
			if(strlen($text) > 5000){
				$err .= '<p>Полное описание не может превышать 5000 символов.</p>';
			}
			if(!in_array($type, [1,2])){
				$err .= '<p>Необходимо указать тип вашего объявления.</p>';
			}
			if(!in_array($condition, [1,2])){
				$err .= '<p>Необходимо указать cостояние.</p>';
			}
//			if(empty($price) || !preg_match($regex_price, $price)){
//				$err .= '<p>Поле "Цена" указано неверно.</p>';
//			}
//			if($discount < 10){
//				$err .= '<p>Минимальная скидка 10%</p>';
//			}
//			if($discount > 100){
//				$err .= '<p>Максимальная скидка 100%</p>';
//			}
			if(empty($discount_price) || !preg_match($regex_price, $discount_price)){
				$err .= '<p>Поле "Полная стоимость" указано неверно.</p>';
			}
//			if($cash < 0){
//				$err .= '<p>Минимальный процент наличными 0%</p>';
//			}
//			if($cash > 50){
//				$err .= '<p>Максимальный процент наличными 50%</p>';
//			}
//			if(empty($pay_for)){
//				$err .= '<p>Необходимо указать оплату за.</p>';
//			}
			if(empty($delivery)){
				$err .= '<p>Необходимо указать оплату и доставку.</p>';
			}
			if(empty($country)){
				$err .= '<p>Необходимо указать страну.</p>';
			}
			if(empty($photo)){
				$err .= '<p>Необходимо загрузить изображение.</p>';
			}

			if (empty($err)){
				$transaction = $connection->beginTransaction();
				try {
					$connection->createCommand()->insert('{{goods}}', array(
						'uid' => Yii::app()->user->id,
						'category_id' => $category_id,
						'type' => $type,
						'title' => $title,
						'text' => $text,
						'approved' => 1,
						'condition' => $condition,
						'price' => $discount_price,
//						'cash' => $cash,
						'discount' => 0,
						'discount_price' => $discount_price,
//						'pay_for' => $pay_for,
						'country' => $country_id,
						'city' => $city_id,
						'delivery' => $delivery,
						'qty' => 1,
						'status' => 1,
						'secure' => 0,
						'views' => 0,
						'like_count' => 0,
						'media_img' => $photo,
						'media_vid' => '',
						'date' => time(),
						'updated' => time(),
						'verify' => $user_info['verify'],
					));
					$good_id = Yii::app()->db->getLastInsertID();

					// Вставляем категории
					$connection->createCommand()->insert('{{good_category}}', array(
						'good_id' => $good_id,
						'category_id' => $category['id']
					));
					$parent_cat = $connection->createCommand("SELECT * FROM {{categories}} WHERE id = :id")->bindParam(":id", $category['parent'])->queryRow();
					if(!empty($parent_cat)){
						$connection->createCommand()->insert('{{good_category}}', array(
							'good_id' => $good_id,
							'category_id' => $parent_cat['id']
						));
						$parent_cat2 = $connection->createCommand("SELECT * FROM {{categories}} WHERE id = :id")->bindParam(":id", $parent_cat['parent'])->queryRow();
						if(!empty($parent_cat2)){
							$connection->createCommand()->insert('{{good_category}}', array(
								'good_id' => $good_id,
								'category_id' => $parent_cat2['id']
							));
						}
					}

					//Добавляем изображения
					$fs_db->createCommand("UPDATE {{images}} SET status = 1 WHERE path = :path")
						->bindParam(":path", $photo)
						->query();

					$good = $connection->createCommand("SELECT * FROM {{goods}} WHERE gid = :gid")
						->bindParam(":gid", $good_id)
						->queryRow();

					$transaction->commit();
					$res['good'] = $good;
					$res["status"] = 200;
				} catch (Exception $e) {
					$transaction->rollback();
					$res["status"] = 500;
					$res["message"] = "<p>Сервер временно недоступен.</p>";
				}
			} else {
				$res["status"] = 500;
				$res["message"] = $err;
			}
			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionGoodUploadPhoto()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest && !empty($_FILES['good_photo'])) {
			Functions::access_control(3);
			$connection = Yii::app()->db;
			$res = array();
			$err = array();

			//Входящие данные
			$x1 = intval($_POST["x1"]);
			$y1 = intval($_POST["y1"]);
			$x2 = intval($_POST["x2"]);
			$y2 = intval($_POST["y2"]);

			//Получаем информацию о файле
			$type = mysql_escape_string(htmlspecialchars(strip_tags($_FILES['good_photo']["type"])));
			$tmp_name = mysql_escape_string(htmlspecialchars(strip_tags($_FILES['good_photo']["tmp_name"])));
			$name = mysql_escape_string(htmlspecialchars(strip_tags($_FILES['good_photo']["name"])));

			if (($type == "application/octet-stream") && (($type != "image/jpeg") || ($type != "image/png") || ($type != "image/gif"))) {
				$err .= "Тип файла не поддерживается.";
			}

			//Если файл поддерживается
			if (empty($err)) {
				$server = f_getUploadServer();
				$user_info = $connection->createCommand('SELECT * FROM {{usersinfo}} WHERE uid = :uid')
					->bindParam(":uid", Yii::app()->user->id)
					->queryRow();

				if(!empty($server) && !empty($user_info)){
					$data = array(
						'photo' => '@'.$tmp_name.';filename='.$name.';type='.$type,
						'x1' => $x1,
						'y1' => $y1,
						'x2' => $x2,
						'y2' => $y2,
						'uid' => Yii::app()->user->id,
						'server_id' => $server['id'],
						'signature' => sha1(md5($x1.$y1.$x2.$y2.Yii::app()->user->id.$server['id'].Yii::app()->params['api_pass']))
					);

					$ch = curl_init();
					curl_setopt($ch, CURLOPT_URL, "http://".$server['address']."/file/gooduploadphoto");
					curl_setopt($ch, CURLOPT_POST, 1);
					curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
					curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
					curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
					curl_setopt($ch, CURLOPT_REFERER, "http://".$server['address']."/file/gooduploadphoto");

					$result = curl_exec($ch);
					curl_close($ch);

					$results = json_decode($result, true);

					if ($results['status'] == 200 && !empty($results['photo'])) {
						$connection->createCommand("UPDATE {{servers}} set images = images + 1 WHERE id = :id")
							->bindParam(":id", $server['id'])
							->query();

						if(!empty($user_info['photo'])){
							$fs_db = Yii::app()->fs_db;
							$fs_db->createCommand("UPDATE {{images}} SET status = 2 WHERE path = :path")
								->bindParam(":path", $user_info['photo'])
								->query();
						}

						$res["status"] = 200;
						$res["file"] = $results['photo'];
					}else{
						$res["status"] = 500;
						$res["message"] = $results["message"];
					}
				}else{
					$res["status"] = 500;
					$res["message"] = 'Сервер временно недоступен.';
				}
			}else{
				$res["status"] = 500;
				$res["message"] = $err;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionComment()
	{
		if (!Yii::app()->user->isGuest && Yii::app()->request->isAjaxRequest) {
			Functions::access_control(1);
			$connection = Yii::app()->db;
			$res = array();

			$text = mysql_escape_string(htmlspecialchars(strip_tags($_POST["text"])));
			$gid = intval($_POST["gid"]);
			$answer_id = intval($_POST["answer_id"]);

			$good = $connection->createCommand("SELECT * FROM {{goods}} WHERE gid = :gid")
				->bindParam(":gid", $gid)
				->queryRow();

			$order = $connection->createCommand("SELECT id FROM {{orders}} WHERE gid = :gid AND uid = :uid AND order_pay = 1 AND order_delivery = 1")
				->bindParam(":gid", $gid)
				->bindParam(":uid", Yii::app()->user->id)
				->queryRow();

			if (!empty($text) && !empty($good) && !empty($order) && strlen($text) < 500) {
				$transaction = $connection->beginTransaction();
				try {
					$connection->createCommand()->insert('{{comments}}', array('date' => time(), 'uid' => Yii::app()->user->id, 'gid' => $good['gid'], 'text' => $text, 'type' => 2));
					$comment_id = Yii::app()->db->getLastInsertID();
					$comment = $connection->createCommand("SELECT c.*, CONCAT(u.name, ' ', u.fio) as 'fio', u.photo as photo, u.alias FROM {{comments}} c INNER JOIN {{usersinfo}} u ON c.id = :id AND c.uid = :uid AND u.uid = :uid AND c.type = 2")
						->bindParam(":id", $comment_id)
						->bindParam(":uid", Yii::app()->user->id)
						->queryRow();

					if (!empty($comment)) {

						//оставил комментарий к Вашей записи
						$good_owner = $connection->createCommand("SELECT * FROM {{usersinfo}} WHERE uid = :uid AND type = 1")
							->bindParam(":uid", $good['uid'])
							->queryRow();
						if (!empty($good_owner) && Yii::app()->user->id != $good['uid']) {
							$connection->createCommand()->insert('{{events}}', array(
								'uid' => $good['uid'],
								'fuid' => Yii::app()->user->id,
								'date' => time(),
								'type' => 6,
								'status' => 0,
								'data1' => $good['gid'],
								'data2' => $comment['id']
							));
						}

						//в ответ на Ваш комментарий
						$comment_event = $connection->createCommand("SELECT * FROM {{comments}} WHERE id = :id AND type = 2")
							->bindParam(":id", $answer_id)
							->queryRow();
						if (!empty($comment_event)) {
							$connection->createCommand()->insert('{{events}}', array(
								'uid' => $comment_event['uid'],
								'fuid' => Yii::app()->user->id,
								'date' => time(),
								'type' => 7,
								'status' => 0,
								'data1' => $good['gid'],
								'data2' => $comment_event['id'],
								'data3' => $comment['id']
							));
						}

						$transaction->commit();
						$res["comment"] = $comment;
						$res["status"] = 200;
					} else {
						$transaction->rollback();
						$res["status"] = 500;
						$res["message"] = "Сервер временно недоступен.";
					}
				} catch (Exception $e) {
					$transaction->rollback();
					$res["status"] = 500;
					$res["message"] = "Сервер временно недоступен.";
				}
			} else {
				$res["status"] = 500;
				$res["message"] = "Сервер временно недоступен.";
			}
			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionGoodDelete()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			Functions::access_control(3);
			$connection = Yii::app()->db;

			//Входящие данные
			$gid = intval($_POST["gid"]);

			$transaction = $connection->beginTransaction();
			try {
				$good = $connection->createCommand("SELECT * FROM {{goods}} WHERE gid = :gid AND uid = :uid AND status = 1")
					->bindParam(":gid", $gid)
					->bindParam(":uid", Yii::app()->user->id)
					->queryRow();
				if (!empty($good) && $good['uid'] == Yii::app()->user->id) {
					$connection->createCommand("UPDATE {{goods}} SET status = 2 WHERE gid = :gid AND uid = :uid AND status = 1")
						->bindParam(":gid", $gid)
						->bindParam(":uid", Yii::app()->user->id)
						->query();

//					Yii::app()->db->createCommand('DELETE FROM {{goods}} WHERE gid = :gid')
//						->bindParam(":gid", $gid)
//						->query();
//					Yii::app()->db->createCommand('DELETE FROM {{good_comments}} WHERE gid = :gid')
//						->bindParam(":gid", $gid)
//						->query();

					$transaction->commit();
					$res["status"] = 200;
				} else {
					$res["status"] = 500;
					$res["message"] = "Сервер временно недоступен.";
				}
			} catch(Exception $e) {
				$transaction->rollback();
				$res["status"] = 500;
				$res["message"] = "Сервер временно недоступен.";
			}
			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionGetComments()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$connection = Yii::app()->db;
			$res = array();

			$gid = intval($_POST["gid"]);
			$part = intval($_POST["part"]);

			$part_sql = $part == 1 ? 'ORDER BY date DESC LIMIT 3' : 'ORDER BY date ASC';
			$comments = $connection->createCommand("SELECT SQL_CALC_FOUND_ROWS c.*, CONCAT(u.name, ' ', u.fio) as 'fio', u.name, u.photo as photo, u.alias FROM {{comments}} c INNER JOIN {{usersinfo}} u ON c.gid = :gid AND c.uid = u.uid AND c.type = 2 ".$part_sql)->bindParam(":gid", $gid)->queryAll();
			$count = $connection->createCommand('SELECT FOUND_ROWS()')->queryScalar();

			$res["comments"] = $comments;
			$res["count"] = $count;
			$res["status"] = 200;

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionCommentDelete()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			Functions::access_control(1);
			$connection = Yii::app()->db;

			//Входящие данные
			$id = intval($_POST["id"]);

			$transaction = $connection->beginTransaction();
			try {
				$comment = $connection->createCommand("SELECT * FROM {{comments}} WHERE id = :id AND type = 2")
					->bindParam(":id", $id)
					->queryRow();
				if (!empty($comment) && $comment['uid'] == Yii::app()->user->id) {
					Yii::app()->db->createCommand('DELETE FROM {{comments}} WHERE id = :id AND type = 2')
						->bindParam(":id", $id)
						->query();

					$transaction->commit();
					$res["status"] = 200;
				} else {
					$res["status"] = 500;
					$res["message"] = "При удалении комментария возникла ошибка.";
				}
			} catch(Exception $e) {
				$transaction->rollback();
				$res["status"] = 500;
				$res["message"] = "При удалении комментария возникла ошибка.";
			}
			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionGetCategories()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$connection = Yii::app()->db;
			$res = array();

			$categories = $connection->createCommand("SELECT c.* FROM {{categories}} c INNER JOIN {{good_category}} gc LEFT JOIN {{goods}} g ON gc.category_id = c.id AND c.parent = 0 AND g.gid = gc.good_id AND g.status = 1 WHERE NOT ISNULL(g.gid) GROUP BY c.id")
				->queryAll();

			$res["categories"] = $categories;
			$res["status"] = 200;

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}


	/**
	 * This is the action to handle external exceptions.
	 */
	public function actionError()
	{
		if ($error = Yii::app()->errorHandler->error) {
			if (Yii::app()->request->isAjaxRequest)
				echo $error['message'];
			else
				$this->render('error', $error);
		}
	}
}