<?php

class MerchantController extends Controller
{

    /**
     * @return array action filters
     */
    public function filters()
    {
        return array(
            'accessControl', // perform access control for CRUD operations
        );
    }

    /**
     * Specifies the access control rules.
     * This method is used by the 'accessControl' filter.
     * @return array access control rules
     */
    public function accessRules()
    {
        return array(
            array('allow',
                'users' => array('*'),
            ),
//            array('deny',
//                'users' => array('*'),
//            )
        );
    }


    public function actionIndex($id)
    {
        $this->render('index');
    }


    public function actionSetMerchantStartPay()
    {
        if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
            Functions::access_control(1);
            $connection = Yii::app()->db;
            $res = array();
            $err = '';

            //Входящие данные
            $merchant_id = intval($_POST['merchant_id']);

            //Блокировка файлом ===================
            $lock = $connection->createCommand("SELECT uid, `lock` FROM {{users}} WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->queryRow();
            if ($lock['lock'] == 0) {
                $connection->createCommand("UPDATE {{users}} SET `lock` = 1 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
            } else {
                $res["status"] = 500;
                $res["message"] = "Идет обработка Вашего запроса. Обновите страницу через несколько минут и повторите попытку снова.";
                echo CJSON::encode($res);
                Yii::app()->end();
            }//Блокировка файлом ===================

            $merchant = $connection->createCommand("SELECT * FROM {{merchant}} WHERE id = :id AND status = 0")
                ->bindParam(":id", $merchant_id)
                ->queryRow();

            $merchant_system = $connection->createCommand("SELECT * FROM {{merchant_system}} WHERE id = :id AND status = 1")
                ->bindParam(":id", $merchant['merchant'])
                ->queryRow();

            if(!empty($merchant) && !empty($merchant_system)){

                //Информация отправителя
                $user_from = $connection->createCommand("SELECT uid, package, CONCAT(name, ' ', fio) as 'fio', verify FROM {{usersinfo}} WHERE email = :email AND package > 0")->bindParam(":email", $merchant['pay_email'])->queryRow();
                $wallet_from = $connection->createCommand("SELECT * FROM {{users_wallet}} WHERE uid = :uid AND type = 1 AND status = 1")->bindParam(":uid", $user_from['uid'])->queryRow();

                //Информация получателя
                $user_to = $connection->createCommand("SELECT uid, verify, CONCAT(name, ' ', fio) as 'fio' FROM {{usersinfo}} WHERE uid = :uid AND status = 1")->bindParam(":uid", $merchant_system['uid'])->queryRow();
                $wallet_to = $connection->createCommand("SELECT * FROM {{users_wallet}} WHERE uid = :uid AND type = 1 AND status = 1")->bindParam(":uid", $user_to["uid"])->queryRow();

                $start_date = strtotime(date('Y-m-01 00:00:00'));
                $month_amount = $connection->createCommand("SELECT COALESCE(SUM(amount),0) FROM {{utransactions2}} WHERE uid = :uid AND status = 1 AND type = 0 AND action = 41 AND date > :start_date AND date < :end_date")
                    ->bindParam(":uid", $user_from['uid'])
                    ->bindParam(":start_date", $start_date)
                    ->bindParam(":end_date", time())
                    ->queryScalar();
                $percent = Merchant::getTax($month_amount+$merchant['pay_amount']);
                if($user_from["verify"] == 1)
                	$percent = 0;

                $amount_tax = round(($percent*$merchant['pay_amount'])/100, 2);
                $amount = $merchant['pay_amount'];
                $amount_all = $amount + $amount_tax;
                $err = "";

                if ((empty($user_to)) || (empty($wallet_to))) {
                    $err .= "<p>Данного пользователя не существует.</p>";
                }
                if (($wallet_from['cash_now'] < $amount_all) && ($amount_all <= 0)) {
                    $err .= "<p>Неправильная сумма перевода.</p>";
                }
                if ((empty($wallet_from)) || (Yii::app()->user->id == 0)) {
                    $err .= "<p>Вы не можете провести оплату. Обновите стрницу и повторите попытку снова.</p>";
                }

                if ((!empty($wallet_from)) && (!empty($wallet_to)) && (!empty($user_to)) && ($user_to["uid"] == $wallet_to["uid"]) && (Yii::app()->user->id != $wallet_to["uid"]) && ($wallet_from["cash_now"] > 0) && ($wallet_from["cash_now"] >= $amount_all) && ($amount_all > 0) && (Yii::app()->user->id > 0) && ($err == "")) {

                    $transaction = $connection->beginTransaction();
                    try {
                        //БЛОКИРОВКА HASH
                        $connection->createCommand()->insert('{{users_hash_merchant}}', array('uid' => Yii::app()->user->id, 'hash' => Yii::app()->user->id.'.005'.$merchant['id'], 'date' => time()));

                        //Записываем комиссию пользователю
                        $connection->createCommand()->insert('{{merchant_tax}}', array(
                        'mid' => $merchant['id'],
                        'uid' => $user_from['uid'],
                        'tax_percent' => $percent,
                        'tax_amount' => $amount_tax,
                        'amount' => $merchant['pay_amount'],
                        'amount_month' => $month_amount
                        ));


                        //Обновляем мерчант
                        $connection->createCommand("UPDATE {{merchant}} SET status = 1 WHERE id = :id AND uid = :uid AND status = 0")
                            ->bindParam(":id", $merchant['id'])
                            ->bindParam(":uid", Yii::app()->user->id)
                            ->query();

                        //Вставляем транзакцию мне (сумма)
                        $connection->createCommand()->insert('{{utransactions2}}', array('did' => 0, 'uid' => Yii::app()->user->id, 'ruid' => $user_to["uid"], 'amount' => $merchant['pay_amount'], 'amount_now' => $wallet_from["cash_now"] - $merchant['pay_amount'], 'date' => time(), 'type' => 0, 'status' => 1, 'invoice' => $merchant['id'], 'action' => 41));
                        $utransactions1 = $connection->getLastInsertID();

                        //Вставляем транзакцию мне (комиссия)
                        $connection->createCommand()->insert('{{utransactions2}}', array('did' => 0, 'uid' => Yii::app()->user->id, 'ruid' => 40, 'amount' => $amount_tax, 'amount_now' => $wallet_from["cash_now"] - $merchant['pay_amount'] - $amount_tax, 'date' => time(), 'type' => 0, 'status' => 1, 'invoice' => $merchant['id'], 'action' => 40));
                        $utransactions1_tax = $connection->getLastInsertID();

                        //Вставляем транзакцию адрессату
                        $connection->createCommand()->insert('{{utransactions2}}', array('did' => 0, 'uid' => $user_to["uid"], 'ruid' => Yii::app()->user->id, 'amount' => $amount, 'amount_now' => $wallet_to["cash_now"] + $amount, 'date' => time(), 'type' => 1, 'status' => 1, 'invoice' => $merchant['id'], 'action' => 41));
                        $utransactions2 = $connection->getLastInsertID();

                        //Вставляем описание перевода мне
                        $connection->createCommand()->insert('{{utransactions2_desc}}', array('tid' => $utransactions1, 'uid' => Yii::app()->user->id, 'touid' => $user_to["uid"], 'text' => $merchant['pay_description']));

                        //Вставляем описание перевода адрессату
                        $connection->createCommand()->insert('{{utransactions2_desc}}', array('tid' => $utransactions2, 'uid' => Yii::app()->user->id, 'touid' => $user_to["uid"], 'text' => $merchant['pay_description']));

                        //Сообщение адрессату о том что получены деньги
                        $verify_class = $user_from["verify"] == 1 ? " style='color:green;' " : "";
                        $text_msg = "<span " . $verify_class . ">Оплата " . $amount . " BP от пользователя " . $user_from["fio"] . ". Детали: " . $merchant['pay_description'] . " Номер операции: " .  $merchant['pay_code'] . "</span>";
                        $connection->createCommand()->insert('{{messages}}', array('date' => time(), 'fuid' => 41, 'tuid' => $user_to['uid'], 'message' => $text_msg));

                        $connection->createCommand("UPDATE {{users_wallet}} SET cash_now = cash_now - :amount_from WHERE uid = :uid AND type = 1 AND status = 1; UPDATE {{users_wallet}} SET cash_now = cash_now + :amount_to WHERE uid = :touid AND type = 1 AND status = 1")
                        ->bindParam(":amount_from", $amount_all)
                        ->bindParam(":amount_to", $amount)
                        ->bindParam(":uid", Yii::app()->user->id)
                        ->bindParam(":touid", $user_to["uid"])
                        ->query();

                        $transaction->commit();

                        $res["status"] = 200;
                        $res['message'] = 'Оплата прошла успешно. Вы будете автоматически перенаправлены на сайт продавца.';
                        $res["redirect"] = $merchant_system['url_redirect'];
                    
                    } catch (Exception $e) {
                        $transaction->rollback();
                        $res["status"] = 500;
                        $res["message"] = "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
                    }
                } else {
                    //Хакерская атака - подмена данных
                    $res["status"] = 500;
                    $res["message"] = "<p>Вы не можете выполнить операцию. Убедитесь в правильности заполненных полей и повторите попытку снова.</p>" . $err;
                }
            }else{
                $res["status"] = 500;
                $res["test"] = $merchant;
                $res["message"] = "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
            }

            
            $connection->createCommand("UPDATE {{users}} SET `lock` = 0 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
            echo CJSON::encode($res);
            
            
            //Отправляем запрос назад
            if(Yii::app()->user->id > 0 && $err == "" && $res["status"] == 200) {
	            
	            $pass = Yii::app()->params['api_obmenbp'];
                //Отправляем запрос на сервер M5
                $transfer_data = array(
                    'merchant' => $merchant['merchant'],
                    'pay_email' => $merchant["pay_email"],
                    'pay_amount' => $merchant["pay_amount"],
                    'pay_code' => $merchant["pay_code"],
                    'pay_description' => $merchant["pay_description"],
                    'action' => 'success',
                    'dateserver' => time()
                );

                $transfer_post_data = array(
                    'merchant' => $transfer_data['merchant'],
                    'pay_email' => $transfer_data['pay_email'],
                    'pay_amount' => $transfer_data['pay_amount'],
                    'pay_code' => $transfer_data['pay_code'],
                    'pay_description' => $transfer_data['pay_description'],
                    'action' => $transfer_data['action'],
                    'dateserver' => $transfer_data['dateserver'],
                    'verify' => $user_from['verify'],
                    'signature' => sha1(md5(implode("", $transfer_data) . $pass))
                );

                //todo используем субдомен для сайтов pmvf.net
                $ch = curl_init();
                curl_setopt($ch, CURLOPT_URL, $merchant_system['url_success']);
                curl_setopt($ch, CURLOPT_POST, 1);
                curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($transfer_post_data));
                curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
                curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
                curl_setopt($ch, CURLOPT_USERAGENT, "Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.16 (KHTML, like Gecko) Chrome/10.0.648.204 Safari/534.16");
                curl_setopt($ch, CURLOPT_REFERER, $merchant_system['url_success']);

                $result = curl_exec($ch);
                curl_close($ch);
                $results = json_decode($result, true);
	            
            }
            
            
            Yii::app()->end();
        }
    }


    public function actionStart()
    {
		if (Yii::app()->request->isPostRequest && CHttpRequest::getUserHostAddress() == '192.81.220.64') {
           $connection = Yii::app()->db;
            $res = array();
            try {
                $pass = Yii::app()->params['api_obmenbp'];

                //Входящие данные
                $merchant_id = intval($_POST["merchant"]);
                $pay_email = mysql_escape_string(htmlspecialchars(strip_tags($_POST["pay_email"])));
                $pay_amount = intval($_POST["pay_amount"]);
                $pay_code = mysql_escape_string(htmlspecialchars(strip_tags($_POST["pay_code"])));
                $pay_description = mysql_escape_string(htmlspecialchars(strip_tags($_POST["pay_description"])));
                $post_signature = mysql_escape_string(htmlspecialchars(strip_tags($_POST["signature"])));

                $signature = sha1(md5($merchant_id.$pay_email.$pay_amount.$pay_code.$pay_description.$pass));


                if ($post_signature == $signature) {
                    $merchant_system = $connection->createCommand("SELECT * FROM {{merchant_system}} WHERE id = :id AND status = 1")
                        ->bindParam(":id", $merchant_id)
                        ->queryRow();

                    //Информация отправителя
                    $user_from = $connection->createCommand("SELECT uid, package FROM {{usersinfo}} WHERE email = :email AND package > 0")->bindParam(":email", $pay_email)->queryRow();
                    $wallet_from = $connection->createCommand("SELECT * FROM {{users_wallet}} WHERE uid = :uid AND type = 1 AND status = 1")->bindParam(":uid", $user_from['uid'])->queryRow();

                    //Информация получателя
                    $user_to = $connection->createCommand("SELECT uid, verify, CONCAT(name, ' ', fio) as 'fio' FROM {{usersinfo}} WHERE uid = :uid AND status = 1")->bindParam(":uid", $merchant_system['uid'])->queryRow();
                    $wallet_to = $connection->createCommand("SELECT * FROM {{users_wallet}} WHERE uid = :uid AND type = 1 AND status = 1")->bindParam(":uid", $user_to["uid"])->queryRow();

                    if(!empty($merchant_system) && !empty($user_from) && !empty($user_to) && !empty($wallet_to)){
                        $transaction = $connection->beginTransaction();
                        try{
                            $connection->createCommand()->insert('{{merchant}}', array(
                                'uid' => $user_from['uid'],
                                'tuid' => $merchant_system['uid'],
                                'cuid' => $merchant_system['uid'],
                                'merchant' => $merchant_system['id'],
                                'pay_email' => $pay_email,
                                'pay_amount' => $pay_amount,
                                'pay_code' => $pay_code,
                                'pay_description' => $pay_description,
                                'type' => 3,
                                'action' => 31,
                                'status' => 0,
                                'date' => time(),
                                'hash' => $merchant_system['uid'].'.'.time()
                            ));
                            $merchant = $connection->getLastInsertID();

                            $transaction->commit();
                            $res['status'] = 200;
                            $res['merchant'] = $merchant;
                        }catch(Exception $e){
                            $transaction->rollback();
                            $res["status"] = 500;
                            $res["message"] = "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
                        }
                    }else{
                        $res['status'] = 500;
                        $res['message'] = 'Сервер временно недоступен. Обновите страницу и повторите попытку снова.';
                    }
                } else {
                    //Попытка взлома
                    $user_signature_post_data = implode('.', $_POST);
                    $actual_link = "http://$_SERVER[HTTP_HOST]$_SERVER[REQUEST_URI]";
                    $connection->createCommand()->insert('{{users_signature}}', array('date' => time(), 'signature' => $post_signature, 'data' => $user_signature_post_data, 'request_url' => $actual_link));
                    //Попытка взлома signature
                    $res["status"] = 500;
                    $res["message"] = 'Доступ запрещен.';
                }
            } catch (Exception $e) {
                $res['status'] = 500;
                $res['message'] = 'Сервер временно недоступен. Обновите страницу и повторите попытку снова.';
            }

            echo CJSON::encode($res);
            Yii::app()->end();
        }
    }


    /**
     * This is the action to handle external exceptions.
     */
    public function actionError()
    {
        if ($error = Yii::app()->errorHandler->error) {
            if (Yii::app()->request->isAjaxRequest)
                echo $error['message'];
            else
                $this->render('error', $error);
        }
    }


}