<?php

class MessagesController extends Controller
{
	public function filters()
	{
		return array(
			'accessControl', // perform access control for CRUD operations
		);
	}

	public function accessRules()
	{
		return array(
			array('allow',
				'users' => array('@'),
			),
			array('deny',
				'users' => array('*'),
			)
		);
	}

	public function actionDialogHistory(){
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
//			$msg_db = Yii::app()->msg_db;
			$connection = Yii::app()->db;
			$res = array();

			$page = intval($_POST["page"]);

			if (!empty($page)) {
				$dialogs = $connection->createCommand("SELECT fuid, tuid, date, message, is_readed, u.uid, CONCAT(u.name, ' ', u.fio) as 'fio', u.photo, u.alias FROM(SELECT id , fuid, tuid, message, date, is_readed FROM ((SELECT * FROM {{messages}} WHERE fuid = :uid OR tuid = :uid ORDER BY id DESC) as m) GROUP BY (CASE WHEN tuid = :uid THEN fuid ELSE tuid END)) as d INNER JOIN {{usersinfo}} u ON (CASE WHEN tuid = :uid THEN fuid ELSE tuid END) = u.uid ORDER BY date DESC LIMIT :limit OFFSET :offset")
						->bindValue(":uid", Yii::app()->user->id)
						->bindValue(":limit", 10, PDO::PARAM_INT)
						->bindValue(":offset", ($page - 1) * 10, PDO::PARAM_INT)
						->queryAll();

				$res["dialogs"] = $dialogs;
				$res["status"] = 200;
			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionDialogDelete()
	{
		$res["status"] = 500;
		$res["message"] = "Опция вскоре будет доступна.";
		echo CJSON::encode($res);
		Yii::app()->end();

		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$connection = Yii::app()->db;
//			$msg_db = Yii::app()->msg_db;

			//Входящие данные
			$uid = intval($_POST["id"]);
			$user_ban = intval($_POST["user_ban"]);

			$transaction = $connection->beginTransaction();
			try {
				$user_info = $connection->createCommand("SELECT * FROM {{usersinfo}} WHERE uid = :uid")
						->bindParam(":uid", $uid)
						->queryRow();

				if (!empty($user_info) && in_array($user_ban, [0,1])) {
					//удаляем сообщения
					$connection->createCommand('DELETE FROM {{messages}} WHERE (fuid = :uid1 AND tuid = :uid2) OR (fuid = :uid2 AND tuid = :uid1)')
							->bindParam('uid1', $uid)
							->bindParam('uid2', Yii::app()->user->id)
							->query();

					if($user_ban == 1 && $user_info['type'] == 1){
						$banned = $connection->createCommand("SELECT * FROM {{users_ban}} WHERE uid = :uid AND fuid = :fuid")
								->bindParam(":uid", Yii::app()->user->id)
								->bindParam(":fuid", $user_info['uid'])
								->queryRow();
						if(empty($banned)){
							$connection->createCommand()->insert('{{users_ban}}', array(
									'uid' => Yii::app()->user->id,
									'fuid' => $user_info['uid'],
									'date' => time()
							));

							$connection->createCommand("DELETE FROM {{friends}} WHERE (uid = :uid AND fuid = :fuid) OR (uid = :fuid AND fuid = :uid)")
									->bindParam(":uid", Yii::app()->user->id)
									->bindParam(":fuid", $uid)
									->query();

							$res["status"] = 200;
						}
					}

					$transaction->commit();
					$res["status"] = 200;
				} else {
					$transaction->rollback();
					$res["status"] = 500;
					$res["message"] = "При удалении диалога возникла ошибка.";
				}
			} catch(Exception $e) {
				$transaction->rollback();
				$res["status"] = 500;
				$res["message"] = "При удалении диалога возникла ошибка.";
			}
			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionMessageReceived()
	{
		if (Yii::app()->request->isAjaxRequest) {
			$connection = Yii::app()->db;
//			$msg_db = Yii::app()->msg_db;
			$res = array();

			$fuid = intval($_POST["id"]);

			$user_to = $connection->createCommand("SELECT uid FROM {{usersinfo}} WHERE uid = :uid")->bindParam(":uid", $fuid)->queryRow();
			if (!Yii::app()->user->isGuest && !empty($user_to)) {
				$banned = $connection->createCommand("SELECT * FROM {{users_ban}} WHERE uid = :uid AND fuid = :fuid")
						->bindParam(":uid", $user_to['uid'])
						->bindParam(":fuid", Yii::app()->user->id)
						->queryRow();
				if(empty($banned)){
					$connection->createCommand("UPDATE {{messages}} SET is_readed = 1 WHERE fuid = :sel AND tuid = :uid AND is_readed = 0")
							->bindValue(":uid", Yii::app()->user->id)
							->bindParam(":sel", $fuid)
							->query();
				}else{
					$res["status"] = 500;
				}
			}
			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionCheckIm()
	{
		if (Yii::app()->request->isAjaxRequest) {
			$connection = Yii::app()->db;
//			$msg_db = Yii::app()->msg_db;
			$res = array();

			$friend_uid = intval($_POST["uid"]);
			$date = intval($_POST["m_time"]);

			if (!Yii::app()->user->isGuest) {
				$messages = $connection->createCommand('SELECT id , fuid, tuid, message, date, is_readed FROM {{messages}} WHERE ((fuid = :friend_uid AND tuid = :uid)) AND date > :date')
						->bindValue(":uid", Yii::app()->user->id)
						->bindValue(":friend_uid", $friend_uid)
						->bindValue(":date", $date)
						->queryAll();
				$count = $connection->createCommand('SELECT COUNT(*) FROM {{messages}} WHERE ((fuid = :uid AND tuid = :friend_uid)) AND is_readed = 0 AND date > :date')
						->bindValue(":uid", Yii::app()->user->id)
						->bindValue(":friend_uid", $friend_uid)
						->bindValue(":date", time() - 3600)
						->queryScalar();
				if (!empty($messages)) {
					$res["messages"] = $messages;
					$res["status"] = 200;
				} else {
					$res["status"] = 500;
				}

				$res["readed"] = empty($count);

			}
			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}


	public function actionSendMessage()
	{
		Functions::access_control(1);
		if (Yii::app()->request->isAjaxRequest) {
			$connection = Yii::app()->db;
//			$msg_db = Yii::app()->msg_db;
			$res = array();

			$fuid = intval($_POST["id"]);
			$text = mysql_escape_string(strip_tags($_POST["text"]));

			$user_to = $connection->createCommand("SELECT uid FROM {{usersinfo}} WHERE uid = :uid AND :uid NOT IN (2,161143)")->bindParam(":uid", $fuid)->queryRow();
			if (!Yii::app()->user->isGuest && !empty($user_to) && !empty($text) && strlen($text) <= 1000) {
				$banned = $connection->createCommand("SELECT * FROM {{users_ban}} WHERE uid = :uid AND fuid = :fuid")
						->bindParam(":uid", $user_to['uid'])
						->bindParam(":fuid", Yii::app()->user->id)
						->queryRow();
				if(empty($banned)){
					$connection->createCommand()->insert('{{messages}}', array('date' => time(), 'fuid' => Yii::app()->user->id, 'tuid' => $fuid, 'message' => $text));
					$message_id = $connection->getLastInsertID();
					$message = $connection->createCommand("SELECT * FROM {{messages}} WHERE id = :id AND fuid = :fuid")
							->bindParam(":id", $message_id)
							->bindParam(":fuid", Yii::app()->user->id)
							->queryRow();
					if (!empty($message)) {
						$res["message"] = $message;
						$res["status"] = 200;
						$res["test"] = $text;
					} else {
						$res["status"] = 500;
					}
				}else{
					$res["status"] = 500;
				}
			} else {
				
				$res["status"] = 500;
				$res["message"] = "Вы не можете отправлять сообщения данному пользователю.";
				
			}
			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
}