<?php

class OrderController extends Controller
{
	/**
	 * @return array action filters
	 */
	public function filters()
	{
		return array(
			'accessControl', // perform access control for CRUD operations
		);
	}


	/**
	 * Specifies the access control rules.
	 * This method is used by the 'accessControl' filter.
	 * @return array access control rules
	 */
	public function accessRules()
	{
		return array(
			array('allow',
				'users' => array('@'),
			),
			array('deny',
				'users' => array('*'),
			)
		);
	}

	/**
	 * Declares class-based actions.
	 */
	public function actions()
	{
		return array(
			// captcha action renders the CAPTCHA image displayed on the contact page
			'captcha'=>array(
				'class'=>'CCaptchaAction',
				'backColor'=>0xFFFFFF,
			),
		);
	}

	
	//=============================================================================================================
	//Продажа
	//=============================================================================================================

	public function actionSellMyOrderCancel(){
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			Functions::access_control(1);
			$res = array();
			$connection = Yii::app()->db;
			$id = intval($_POST['id']); // id заказа
			
			
			//Блокировка файлом ===================
			 $lock = $connection->createCommand("SELECT uid, `lock` FROM {{users}} WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->queryRow();
			 if ($lock['lock'] == 0) {
			 $connection->createCommand("UPDATE {{users}} SET `lock` = 1 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
			 } else { 
			 $res["status"] = 500;
			 $res["message"] = "Идет обработка Вашего запроса. Обновите страницу через несколько минут и повторите попытку снова.";
			 echo CJSON::encode($res);
			 Yii::app()->end();
			 }//Блокировка файлом ===================
			
			
			$order = $connection->createCommand("SELECT * FROM {{orders}} WHERE id = :id AND status IN (0,1,2,3)")
				->bindParam(":id", $id)
				->queryRow();

			$good = $connection->createCommand("SELECT * FROM {{goods}} WHERE gid = :gid AND uid = :uid")
				->bindParam(":gid", $order['gid'])
				->bindParam(":uid", Yii::app()->user->id)
				->queryRow();

			if (!empty($order) && !empty($good)) {
				if($order['status'] < 2){
					// Если нет оплаты тогда удалаем заявку
					$connection->createCommand("DELETE FROM {{orders}} WHERE id = :id AND gid = :gid")
						->bindParam(":id", $order['id'])
						->bindParam(":gid", $good['gid'])
						->query();
					$res["status"] = 200;
				}else{ //Возвращаем деньги покупателю
					
					//Инвойс покупки
					$invoice = $connection->createCommand("SELECT * FROM {{users_invoice}} WHERE `data` = :order_id AND uid = :uid AND type = 2")
						->bindParam(":uid", $order['uid'])
						->bindParam(":order_id", $order['id'])
						->queryRow();
					if(!empty($order) && !empty($good) && !empty($invoice)){
						$amount = $invoice['amount'];
						$err = "";

						// Моя информация
						$my = $connection->createCommand("SELECT uid, CONCAT(name, ' ', fio) as 'fio' FROM {{usersinfo}} WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->queryRow();

						//Информация получателя
						$user_to = $connection->createCommand("SELECT uid, CONCAT(name, ' ', fio) as 'fio' FROM {{usersinfo}} WHERE uid = :uid AND status = 1")->bindParam(":uid", $order['uid'])->queryRow();
						$wallet_to = $connection->createCommand("SELECT * FROM {{users_wallet}} WHERE uid = :uid AND type = 1 AND status = 1")->bindParam(":uid", $user_to["uid"])->queryRow();

						if ((empty($user_to)) || (empty($wallet_to))) {
							$err .= "<p>Данного пользователя не существует.</p>";
						}

						if ((!empty($wallet_to)) && (!empty($user_to)) && ($user_to["uid"] == $wallet_to["uid"]) && (Yii::app()->user->id != $wallet_to["uid"]) && ($amount > 0) && (Yii::app()->user->id > 0) && ($err == "")) {

							$transaction = $connection->beginTransaction();
							try {
								
								$connection->createCommand()->insert('{{users_hash_order}}', array('uid' => Yii::app()->user->id, 'hash' => Yii::app()->user->id.'.000'.$order['id'], 'date' => time()));
								
								//Ставим инвойсу статус 2 (отменен)
								$connection->createCommand("UPDATE {{users_invoice}} SET status = 2 WHERE id = :id AND uid = :uid AND status = 1")
									->bindParam(":id", $invoice['id'])
									->bindParam(":uid", $order['uid'])
									->query();

								//Ставим транзакции покупателю статус 1
								$connection->createCommand("UPDATE {{utransactions2}} SET status = 1, ruid = 21 WHERE invoice = :invoice AND uid = :uid AND status = 0 AND `action` = 21;")
									->bindParam(":invoice", $invoice['id'])
									->bindParam(":uid", $order['uid'])
									->query();

								//Возвращаем деньги покупателю

								//Вставляем транзакцию адрессату
								$connection->createCommand()->insert('{{utransactions2}}', array('did' => $good['gid'], 'uid' => $user_to["uid"], 'ruid' => 21, 'amount' => $amount, 'amount_now' => $wallet_to["cash_now"] + $amount, 'date' => time(), 'type' => 1, 'status' => 1, 'invoice' => $invoice, 'action' => 20));
								$utransactions2 = $connection->getLastInsertID();


								//Сообщение адрессату о том что получены деньги
								$text_msg = "Ваш заказ №".$order['id']." отменен продавцом. " . $amount . " BP возвращено на Ваш кошелек. Назначение платежа: Возврат денег за покупку товара.";
								$connection->createCommand()->insert('{{messages}}', array('date' => time(), 'fuid' => 2, 'tuid' => $user_to['uid'], 'message' => $text_msg));

								$connection->createCommand("UPDATE {{users_wallet}} SET cash_now = cash_now + :amount WHERE uid = :touid AND type = 1 AND status = 1")
									->bindParam(":amount", $amount)
									->bindParam(":touid", $user_to["uid"])
									->query();
									
									
								// Если нет оплаты тогда удалаем заявку
								$connection->createCommand("UPDATE {{orders}} SET status = 6 WHERE id = :id AND gid = :gid")
									->bindParam(":id", $order['id'])
									->bindParam(":gid", $good['gid'])
									->query();

								$transaction->commit();
								//Позитивный результат
								$res["status"] = 200;
							} catch (Exception $e) {
								$transaction->rollback();
								$res["status"] = 500;
								$res["message"] = "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
							}
						} else {
							//Хакерская атака - подмена данных
							$res["status"] = 500;
							$res["message"] = "<p>Вы не можете оплатить товар на сумму в размере " . $amount . " BP. Убедитесь в правильности заполненных полей и повторите попытку снова.</p>" . $err;
						}
					}else{
						$res["status"] = 500;
						$res["message"] = "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
					}

					$connection->createCommand("UPDATE {{users}} SET `lock` = 0 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
					echo CJSON::encode($res);
					Yii::app()->end();


				}
			} else {
				$res["status"] = 500;
				$res["message"] = "Сервер временно недоступен.";
			}
			
			$connection->createCommand("UPDATE {{users}} SET `lock` = 0 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	public function actionSellGetMyGoods()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$orders = $connection->createCommand("SELECT gid, title, media_img, price, status, FROM_UNIXTIME(date, '%d-%m-%Y') AS date FROM {{goods}} WHERE uid = :uid ORDER BY date DESC")
				->bindParam(":uid", Yii::app()->user->id)
				->queryAll();
			if (!empty($orders)) {
				$res["orders"] = $orders;
				$res["status"] = 200;
			} else {
				$res["status"] = 500;
				$res["message"] = "Список заказов пуст.";
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionSellMyOrderSend()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			Functions::access_control(1);
			$res = array();
			$connection = Yii::app()->db;
			$id = intval($_POST['id']);

			$order = $connection->createCommand("SELECT o.* FROM {{orders}} o INNER JOIN {{goods}} g ON g.gid = o.gid AND g.uid = :uid WHERE o.id = :id AND o.status = 2")
				->bindParam(":uid", Yii::app()->user->id)
				->bindParam(":id", $id)
				->queryRow();
			$good = $connection->createCommand("SELECT * FROM {{goods}} WHERE gid = :gid")
				->bindParam(":gid", $order['gid'])
				->queryRow();

			if (!empty($order) && !empty($good)) {
				$connection->createCommand("UPDATE {{orders}} SET status = 3, order_delivery = 1 WHERE id = :id AND gid = :gid")
					->bindParam(":id", $id)
					->bindParam(":gid", $order['gid'])
					->query();

				$text_msg = 'Заказ №'.$order['id'].': Продавец отправил товар "'. $good['title'] .'". Как только Вы получите товар - обязательно подтвердите это на странице "Мои заказы".';
				$connection->createCommand()->insert('{{messages}}', array('date' => time(), 'fuid' => 2, 'tuid' => $order['uid'], 'message' => $text_msg));

				$res["status"] = 200;
			} else {
				$res["status"] = 500;
				$res["message"] = "Сервер временно недоступен.";
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionSellMyOrderOk()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			Functions::access_control(1);
			$res = array();
			$connection = Yii::app()->db;
			$id = intval($_POST['id']);

			$order = $connection->createCommand("SELECT o.* FROM {{orders}} o INNER JOIN {{goods}} g ON g.gid = o.gid AND g.uid = :uid WHERE o.id = :id AND o.status = 0")
				->bindParam(":uid", Yii::app()->user->id)
				->bindParam(":id", $id)
				->queryRow();
			$good = $connection->createCommand("SELECT * FROM {{goods}} WHERE gid = :gid")
				->bindParam(":gid", $order['gid'])
				->queryRow();

			if (!empty($order) && !empty($good)) {
				$connection->createCommand("UPDATE {{orders}} SET status = 1 WHERE id = :id AND gid = :gid")
					->bindParam(":id", $id)
					->bindParam(":gid", $order['gid'])
					->query();

				$text_msg = 'Заказ №'.$order['id'].': Продавец подтвердил наличие товара "'. $good['title'] .'". Перейдите к оплате на странице "Мои заказы".';
				$connection->createCommand()->insert('{{messages}}', array('date' => time(), 'fuid' => 2, 'tuid' => $order['uid'], 'message' => $text_msg));

				$res["status"] = 200;
			} else {
				$res["status"] = 500;
				$res["message"] = "Сервер временно недоступен.";
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionSellGetMyOrders()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;

			$orders = $connection->createCommand("SELECT u.alias, o.id, o.name, o.email, o.tel, o.skype, o.details, o.quick, o.gid, o.uid, o.quantity, FROM_UNIXTIME(o.date, '%d.%m.%Y') AS date, o.status, g.title, g.media_img, g.price FROM {{orders}} o INNER JOIN {{goods}} g ON o.gid = g.gid INNER JOIN {{usersinfo}} u ON u.uid = o.uid WHERE g.uid = :uid AND o.status < 4")
				->bindParam(":uid", Yii::app()->user->id)
				->queryAll();
				
			$superverify = $connection->createCommand("SELECT * FROM {{users_verify_super}} WHERE uid = :uid")
				->bindParam(":uid", Yii::app()->user->id)
				->queryRow();
				
			$res["superverify"] = empty($superverify) ? 0 : 1;
			
			
			if (!empty($orders)) {
				$res["orders"] = $orders;
				$res["status"] = 200;
			} else {
				$res["status"] = 500;
				$res["message"] = "Список заказов пуст.";
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	public function actionSellGetMyOrdersToPay()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;

			$orders = $connection->createCommand("SELECT id, uid, amount, FROM_UNIXTIME(date, '%d.%m.%Y %H:%i') as date, wallet, status FROM {{control_marketpay}} WHERE uid = :uid ORDER BY id DESC")
				->bindParam(":uid", Yii::app()->user->id)
				->queryAll();
			
			if (!empty($orders)) {
				$res["orders"] = $orders;
				$res["status"] = 200;
			} else {
				$res["status"] = 500;
				$res["message"] = "Список заявок пуст.";
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	public function actionSetSellGetMyOrdersToPayNew()
	{	
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$amount = intval($_POST['amount']);
			$wallet = mysql_escape_string(htmlspecialchars(strip_tags($_POST['wallet'])));

			$orders = $connection->createCommand("SELECT * FROM {{control_marketpay}} WHERE uid = :uid AND status IN (0,1)")
				->bindParam(":uid", Yii::app()->user->id)
				->queryRow();
				
			$wallet_info = $connection->createCommand("SELECT * FROM {{users_wallet}} WHERE uid = :uid AND type = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->queryRow();

			$err = '';
			
			if(!empty($orders)) {
				$err .= "<li>У вас есть необработанные заявки.</li>";
			}
			
			if($amount > $wallet_info["cash_now"]) {
				$err .= "<li>У вас недостаточно средств для подачи $amount BP.</li>";
			}
			
			if($amount <= 0) {
				$err .= "<li>Недопустима сумма для подачи заявки.</li>";
			}
			
			$wallet = str_replace(" ", "", $wallet);
			$pattern = '/^\d{16}$/';
			
			if (!preg_match($pattern, $wallet) || !Functions::is_valid_credit_card($wallet)) {
			    $err .= '<li>Неверный формат номера кошелька в Money Storage.</li>';   
			}

			
			if ($err == "") {
				
				$transaction = $connection->beginTransaction();
					try {
							
							$connection->createCommand()->insert('{{control_marketpay}}', array(
								'uid' => Yii::app()->user->id,
								'amount' => $amount,
								'date' => time(),
								'status' => 0,
								'currency' => 'PM-USD',
								'wallet' => $wallet
							));
							
						
						$transaction->commit();
						$res["status"] = 200;
						$res["message"] = "Заявка успешно подана на рассмотрение.";
						
					} catch (Exception $e) {
						$transaction->rollback();
						$res["status"] = 500;
						$res["message"] = $e . "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
					}
			
			} else {
			
				$res["status"] = 500;
				$res["message"] = "Возникла ошибка." . $err;
			
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	
	public function actionSetSellGetMyOrdersToPayCancel()
	{	
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$id = intval($_POST['id']);

			$orders = $connection->createCommand("SELECT * FROM {{control_marketpay}} WHERE id = :id AND uid = :uid AND status = 0")
				->bindParam(":id", $id)
				->bindParam(":uid", Yii::app()->user->id)
				->queryRow();

			$err = '';
			
			if(empty($orders)) {
				$err .= "<li>Невозможно отменить данную заявку.</li>";
			}
			
			if ($err == "") {
				
				$transaction = $connection->beginTransaction();
					try {
							
							$connection->createCommand("UPDATE {{control_marketpay}} SET status = -1 WHERE id = :id AND uid = :uid")
							->bindParam(":id", $id)
							->bindParam(":uid", Yii::app()->user->id)
							->query();
							
						
						$transaction->commit();
						$res["status"] = 200;
						$res["message"] = "Заявка отменена.";
						
					} catch (Exception $e) {
						$transaction->rollback();
						$res["status"] = 500;
						$res["message"] = $e . "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
					}
			
			} else {
			
				$res["status"] = 500;
				$res["message"] = "Возникла ошибка." . $err;
			
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	
	public function actionSellGetMyOrdersOk()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;

			$orders = $connection->createCommand("SELECT u.alias, o.id, o.name, o.email, o.tel, o.skype, o.details, o.quick, o.gid, o.uid, o.quantity, FROM_UNIXTIME(o.date, '%d.%m.%Y') AS date, o.date as date2, o.status, g.title, g.media_img, g.price FROM {{orders}} o INNER JOIN {{goods}} g ON o.gid = g.gid INNER JOIN {{usersinfo}} u ON u.uid = o.uid WHERE g.uid = :uid AND o.status = 4 ORDER BY date2 DESC")
				->bindParam(":uid", Yii::app()->user->id)
				->queryAll();

			if (!empty($orders)) {
				$res["orders"] = $orders;
				$res["status"] = 200;
			} else {
				$res["status"] = 500;
				$res["message"] = "Список продвнных товаров пуст.";
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	//Активация для показа в каталоге или нет
	public function actionSellSetGoodActivate()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$gid = intval($_POST["gid"]);
			$status = intval($_POST["status"]);
			
			$good = $connection->createCommand("SELECT gid, status FROM {{goods}} WHERE uid = :uid AND gid = :gid")
				->bindParam(":uid", Yii::app()->user->id)
				->bindParam(":gid", $gid)
				->queryRow();
				
				$status = $good["status"] == 1 ? 0 : 1;

			if (!empty($good)) {
				
				$connection->createCommand("UPDATE {{goods}} SET status = :status WHERE uid = :uid AND gid = :gid")
				->bindParam(":status", $status)
				->bindParam(":uid", Yii::app()->user->id)
				->bindParam(":gid", $gid)
				->query();
								
				$res["status"] = 200;
			} else {
				$res["status"] = 500;
				$res["message"] = "Возникла непредвиденная ошибка. Обновите страницу и повторите попытку снова.";
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	//=============================================================================================================
	//Покупка
	//=============================================================================================================


	public function actionBuyGetMyGoods()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;

			$orders = $connection->createCommand("SELECT u.alias, o.id, o.gid, o.uid, o.quantity, FROM_UNIXTIME(o.date, '%d.%m.%Y') AS date, o.status, g.title, g.media_img, o.amount as 'price' FROM {{orders}} o INNER JOIN {{goods}} g ON o.gid = g.gid INNER JOIN {{usersinfo}} u ON u.uid = o.uid WHERE o.status = 4 AND o.uid = :uid ORDER BY o.date DESC")
				->bindParam(":uid", Yii::app()->user->id)
				->queryAll();

			if (!empty($orders)) {
				$res["orders"] = $orders;
				$res["status"] = 200;
			} else {
				$res["status"] = 500;
				$res["message"] = "Список заказов пуст.";
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionSetInvoiceOrderPayOk()
	{
		try {
		
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			Functions::access_control(1);
			$connection = Yii::app()->db;
			$res = array();
			$err = '';
			
			//Входящие данные
			$id = intval($_POST['id']);

			//Блокировка файлом ===================
			$lock = $connection->createCommand("SELECT uid, `lock` FROM {{users}} WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->queryRow();
			if ($lock['lock'] == 0) {
				$connection->createCommand("UPDATE {{users}} SET `lock` = 1 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
			} else {
				$res["status"] = 500;
				$res["message"] = "Идет обработка Вашего запроса. Обновите страницу через несколько минут и повторите попытку снова.";
				echo CJSON::encode($res);
				Yii::app()->end();
			}//Блокировка файлом ===================

			//Заказ
			$order = $connection->createCommand("SELECT * FROM {{orders}} WHERE id = :id AND uid = :uid AND status = 3")
				->bindParam(":uid", Yii::app()->user->id)
				->bindParam(":id", $id)
				->queryRow();
			$good = $connection->createCommand("SELECT * FROM {{goods}} WHERE gid = :gid")
				->bindParam(":gid", $order['gid'])
				->queryRow();
			
			$invoice = $connection->createCommand("SELECT * FROM {{users_invoice}} WHERE `data` = :order_id AND uid = :uid AND type = 2")
				->bindParam(":uid", Yii::app()->user->id)
				->bindParam(":order_id", $id)
				->queryRow();
			if(!empty($order) && !empty($good) && !empty($invoice)){
				$amount = $order['amount']*$order['quantity']; //Цена без скидки
				$amount_pay = ($order['amount'] - $order['discount_amount']) * $order['quantity']; //Цена со скидкой
				$err = "";
			
			//Начисление потенциала в день
			$amount_potential = $connection->createCommand("SELECT SUM(deposit*percent) FROM {{users_potential}} WHERE uid = :uid AND status = 1 AND dt < dte")
				->bindParam(":uid", Yii::app()->user->id)
				->queryScalar();
			
			if($amount_pay > 0) {
			$amount_month = $amount_potential * 30;
			
			$potential_percent = intval(($amount_pay / $amount_month) * 100 ) / 100;
			if($potential_percent > 1) $potential_percent = 1;
			if($potential_percent < 0.2) $potential_percent = 0.2;
			} else {
				$potential_percent = 0;
			}	
			$msg_potential = "";

				// Моя информация
				$my = $connection->createCommand("SELECT uid, package, CONCAT(name, ' ', fio) as 'fio' FROM {{usersinfo}} WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->queryRow();

				//Информация получателя
				$user_to = $connection->createCommand("SELECT uid, verify, CONCAT(name, ' ', fio) as 'fio' FROM {{usersinfo}} WHERE uid = :uid AND status = 1")->bindParam(":uid", $good['uid'])->queryRow();
				$wallet_to = $connection->createCommand("SELECT * FROM {{users_wallet}} WHERE uid = :uid AND type = 1 AND status = 1")->bindParam(":uid", $user_to["uid"])->queryRow();
				
				//Комиссия продавца			
				$percent_bokobok = intval($connection->createCommand("SELECT percent FROM {{users_verify}} WHERE uid = :uid")->bindParam(":uid", $user_to['uid'])->queryScalar()) / 100;
				$amount_bokobok = intval($amount * $percent_bokobok * 100) / 100;
				
				
				//Рефера за продажу товара
				$rx = 0;
				if($order["uidx"] > 0 && $order["uidx"] != $order["uid"] && $order["uidx"] != $good["uid"]) {
					
					$rx = $order["uidx"];
					
					$user_info_rx = $connection->createCommand("SELECT uid FROM {{usersinfo}} WHERE uid = :uid AND uid > 0")
					->bindParam(":uid", $rx)
					->queryRow();
					
					$user_info_rx = $connection->createCommand("SELECT uid FROM {{usersinfo}} WHERE uid = :uid AND uid > 0")
					->bindParam(":uid", $rx)
					->queryRow();
					
					if(empty($user_info_rx)) {
						$rx = 0; //Если не нашло пользователя - аннулируем его
					} else {
						
						//Находим кошелек реферала
						$wallet_rx = $connection->createCommand("SELECT * FROM {{users_wallet}} WHERE uid = :uid AND type = 1 AND status = 1")->bindParam(":uid", $rx)->queryRow();
						if(empty($wallet_rx)) {
							$rx = 0; //Если не нашло кошелек - аннулируем его
						}
						
					}
					
				}
				

				if ((empty($user_to)) || (empty($wallet_to))) {
					$err .= "<p>Подтверждение получения данного товара временно недоступно.</p>";
				}
				
				if(!Functions::access_level(1, Yii::app()->user->id))
					$err = "<p>Возникла непредвиденная ошибка.</p>";
				
					
				if ((!empty($wallet_to)) && (!empty($user_to)) && ($user_to["uid"] == $wallet_to["uid"]) && (Yii::app()->user->id != $wallet_to["uid"]) && ($amount > 0) && (Yii::app()->user->id > 0) && ($err == "")) {

					$transaction = $connection->beginTransaction();
					try {
						$connection->createCommand()->insert('{{users_hash_order}}', array('uid' => Yii::app()->user->id, 'hash' => Yii::app()->user->id.'.004'.$order['id'], 'date' => time()));

						
						//Записываем комиссию пользователю
                        $connection->createCommand()->insert('{{orders_tax}}', array(
                        'oid' => $order['id'],
                        'uid' => $user_to["uid"],
                        'tax_percent' => $percent_bokobok,
                        'tax_amount' => $amount_bokobok,
                        'amount' => $amount,
                        'date' =>time()
                        ));
                        
						
						//Обновляем транзакцию мне
						$connection->createCommand("UPDATE {{utransactions2}} SET status = 1 WHERE invoice = :invoice AND uid = :uid AND status = 0 AND `action` = 21;")
							->bindParam(":invoice", $invoice['id'])
							->bindParam(":uid", Yii::app()->user->id)
							->query();

						//Вставляем транзакцию адрессату
						$connection->createCommand()->insert('{{utransactions2}}', array('did' => $good['gid'], 'uid' => $user_to["uid"], 'ruid' => Yii::app()->user->id, 'amount' => $amount, 'amount_now' => $wallet_to["cash_now"] + $amount, 'date' => time(), 'type' => 1, 'status' => 1, 'invoice' => $invoice['id'], 'action' => 21));
						$utransactions2 = $connection->getLastInsertID();
						
						$connection->createCommand()->insert('{{utransactions2}}', array('did' => $good['gid'], 'uid' => $user_to["uid"], 'ruid' => 22, 'amount' => $amount_bokobok, 'amount_now' => doubleval($wallet_to["cash_now"] + $amount - $amount_bokobok), 'date' => time(), 'type' => 0, 'status' => 1, 'invoice' => $invoice['id'], 'action' => 22));
						
						$utransactions2 = $connection->getLastInsertID();

						$connection->createCommand("UPDATE {{users_wallet}} SET cash_now = cash_now + :amount WHERE uid = :touid AND type = 1 AND status = 1")
							->bindParam(":amount", doubleval($amount - $amount_bokobok))
							->bindParam(":touid", $user_to['uid'])
							->query();
							
							
						//Добавляем реферальные тому кто продал товар по рекомендации
						if($rx > 0) {
							
							$amount_rx = intval($amount * 0.01 * 100) / 100;
							
							$connection->createCommand()->insert('{{utransactions2}}', array('did' => $order['id'], 'uid' => $rx, 'ruid' => 23, 'amount' => $amount_rx, 'amount_now' => doubleval($wallet_rx["cash_now"] + $amount_rx), 'date' => time(), 'type' => 1, 'status' => 1, 'invoice' => $invoice['id'], 'action' => 23));
							$connection->createCommand("UPDATE {{users_wallet}} SET cash_now = cash_now + :amount WHERE uid = :touid AND type = 1 AND status = 1")
								->bindParam(":amount", doubleval($amount_rx))
								->bindParam(":touid", $rx)
								->query();
						}


						if($user_to['verify'] == 1 && $my['package'] > 0){
							
								
								$amount_potential = $connection->createCommand("SELECT SUM(deposit) FROM {{users_potential}} WHERE uid = :uid AND status = 1 AND type = 1 AND dt < dte")
								->bindParam(":uid", Yii::app()->user->id)
								->queryScalar();
								
								//Базовый кешбек
								$cashback = 0.3; //Стартовый
								$cashback = $connection->createCommand("SELECT cashback FROM {{settings_cashback}} WHERE :amount >= amount_from AND :amount < amount_to")
									->bindParam(":amount", $amount_potential)
									->queryScalar();
								
								//Множитель продавца
								$sertification_multi = doubleval($connection->createCommand("SELECT multi FROM {{users_verify}} WHERE uid = :uid")
									->bindParam(":uid", $good["uid"])
									->queryScalar()) / 100; //Максимальная скидка
									
								//Расчет реального кешбека с учетом множителя
								$cashback = $cashback * $sertification_multi;
								
								//*************************************
								if($good["uid"] == 117485) {
									$cashback = 0;
								}
								//*************************************
									
								$percent = 0.002;
								$days = 500;
								$amount_back = intval($amount_pay*$cashback*100) / 100;
								
							/*
							
								$cashback = $connection->createCommand("SELECT cashback FROM {{settings_package}} WHERE package = :package")
									->bindParam(":package", $my['package'])
									->queryScalar();
								
								if($cashback*$potential_percent < 0.1) {
									$potential_percent = doubleval(0.1 / $cashback);
								}
								
								$percent = 0.003;
								$days = 333;
								$amount_back = intval($amount_pay*$cashback*$potential_percent*100) / 100;
							
							}*/
							
							$connection->createCommand()->insert('{{users_potential}}', array(
								'uid' => Yii::app()->user->id,
								'cuid' => Yii::app()->user->id,
								'puid' => 0,
								'fuid' => 0,
								'date' => time(),
								'dt' => 0,
								'dte' => $days,
								'deposit' => $amount_back,
								'percent' => $percent,
								'cash_now' => 0,
								'cash_out' => 0,
								'cash_all' => 0,
								'type' => 4,
								'status' => 1,
								'newsystem' => 1
							));
							
							$connection->createCommand()->insert('{{goods_cashback}}', array(
								'uid' => Yii::app()->user->id,
								'gid' => $order['gid'],
								'oid' => $order["id"],
								'amount' => $amount_pay,
								'date' => time(),
								'package' => $my['package'],
								'cb_package' => $cashback,
								'cb_percent' => $cashback,
								'cb_amount' => $amount_back,
								'status' => 1
							));
							
							
							
							$msg_potential = "Ваш потенциал увеличен на $amount_back BP.";
							
						}

						$connection->createCommand("UPDATE {{orders}} SET order_delivery = 1, status = 4 WHERE id = :id AND uid = :uid AND status = 3 AND order_pay = 1;")
							->bindParam(":id", $order['id'])
							->bindParam(":uid", Yii::app()->user->id)
							->query();

						$text_msg = 'Заказ №'.$order['id'].': пользователь подтвердил получение товара "'.$good['title'].'". На Ваш баланс зачислено '.doubleval($amount - $amount_bokobok).' BP.';
						$connection->createCommand()->insert('{{messages}}', array('date' => time(), 'fuid' => 2, 'tuid' => $good['uid'], 'message' => $text_msg));
						
						
						//Обновляем транзакцию мне
						$connection->createCommand("UPDATE {{goods}} SET count_orders = count_orders + :count_orders, count_amount = count_amount + :count_amount WHERE gid = :id")
							->bindParam(":id", $order['gid'])
							->bindParam(":count_amount", $amount_pay)
							->bindParam(":count_orders", $order['quantity'])
							->query();
						
						
						$transaction->commit();
						//Позитивный результат
						$res["status"] = 200;
						$res["message"] = "Спасибо за покупку! " . $msg_potential;
					} catch (Exception $e) {
						$transaction->rollback();
						$res["status"] = 500;
						$res["message"] = "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
					}
					
				} else {
					//Хакерская атака - подмена данных
					$res["status"] = 500;
					$res["message"] = "<p>Вы не можете оплатить товар на сумму в размере " . $amount . " BP. Убедитесь в правильности заполненных полей и повторите попытку снова.</p>" . $err;
				}
			}else{
				$res["status"] = 500;
				$res["message"] = "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
			}

			$connection->createCommand("UPDATE {{users}} SET `lock` = 0 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
			echo CJSON::encode($res);
			Yii::app()->end();
		}
		
		
		} catch (Exception $e) {
			
			$connection->createCommand("UPDATE {{users}} SET `lock` = 0 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
			$res["status"] = 500;
			$res["message"] = "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
			echo CJSON::encode($res);
			Yii::app()->end();
		}
		
	}

	public function actionBuyMyOrderCancel(){
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			Functions::access_control(1);
			$res = array();
			$connection = Yii::app()->db;
			$id = intval($_POST['id']);

			$order = $connection->createCommand("SELECT * FROM {{orders}} WHERE id = :id AND uid = :uid AND (status = 0 OR status = 1)")
				->bindParam(":uid", Yii::app()->user->id)
				->bindParam(":id", $id)
				->queryRow();

			if (!empty($order)) {
				$connection->createCommand("DELETE FROM {{orders}} WHERE id = :id AND uid = :uid AND (status = 0 OR status = 1)")
					->bindParam(":uid", Yii::app()->user->id)
					->bindParam(":id", $id)
					->query();

				$res["status"] = 200;
			} else {
				$res["status"] = 500;
				$res["message"] = "Сервер временно недоступен.";
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionBuyGetMyOrders()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$orders = $connection->createCommand("SELECT o.id, o.uid, o.gid, o.quantity, FROM_UNIXTIME(o.date, '%d.%m.%Y') AS date, o.status, g.title, g.media_img, o.amount as 'price' FROM {{orders}} o INNER JOIN {{goods}} g ON o.gid = g.gid WHERE o.uid = :uid AND o.status < 4 ORDER BY o.status DESC")
				->bindParam(":uid", Yii::app()->user->id)
				->queryAll();
			if (!empty($orders)) {
				$res["orders"] = $orders;
				$res["status"] = 200;
			} else {
				$res["status"] = 500;
				$res["message"] = "Список заказов пуст.";
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	
	public function actionSetInvoiceOrderPayOkSuperVerifyConfirm()
	{
		
		/*$res["status"] = 500;
		$a = serialize($_POST);
		$res["message"] = $a;
		echo CJSON::encode($res);
		Yii::app()->end();*/
		
		try {
		
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			Functions::access_control(1);
			$connection = Yii::app()->db;
			$res = array();
			$err = '';
			
			//Входящие данные
			$id = intval($_POST['id']);

			//Блокировка файлом ===================
			$lock = $connection->createCommand("SELECT uid, `lock` FROM {{users}} WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->queryRow();
			if ($lock['lock'] == 0) {
				$connection->createCommand("UPDATE {{users}} SET `lock` = 1 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
			} else {
				$res["status"] = 500;
				$res["message"] = "Идет обработка Вашего запроса. Обновите страницу через несколько минут и повторите попытку снова.";
				echo CJSON::encode($res);
				Yii::app()->end();
			}//Блокировка файлом ===================
			
			$is_super = $connection->createCommand("SELECT * FROM {{users_verify_super}} WHERE uid = :uid AND status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->queryRow();
				
			if(empty($is_super)) {
				$res["status"] = 500;
				$res["message"] = "Недостаточно прав для выполнения данного действия.";
				echo CJSON::encode($res);
				Yii::app()->end();
			}
			
			//Заказ
			$order = $connection->createCommand("SELECT * FROM {{orders}} WHERE id = :id AND status = 3")
				->bindParam(":id", $id)
				->queryRow();
			$order_uid = $order["uid"];	
			$order_gid = $order["gid"];	
			
			$good = $connection->createCommand("SELECT * FROM {{goods}} WHERE gid = :gid AND uid = :uid")
				->bindParam(":gid", $order_gid)
				->bindParam(":uid", Yii::app()->user->id)
				->queryRow();
			$good_uid = Yii::app()->user->id;
			
			$invoice = $connection->createCommand("SELECT * FROM {{users_invoice}} WHERE `data` = :order_id AND uid = :uid AND type = 2")
				->bindParam(":uid", $order_uid)
				->bindParam(":order_id", $id)
				->queryRow();
			if(!empty($order) && !empty($good) && !empty($invoice)){
				$amount = $order['amount']*$order['quantity']; //Цена без скидки
				$amount_pay = ($order['amount'] - $order['discount_amount']) * $order['quantity']; //Цена со скидкой
				$err = "";
			
			//Начисление потенциала в день
			$amount_potential = $connection->createCommand("SELECT SUM(deposit*percent) FROM {{users_potential}} WHERE uid = :uid AND status = 1 AND dt < dte")
				->bindParam(":uid", $order_uid)
				->queryScalar();
			
			if($amount_pay > 0) {
			$amount_month = $amount_potential * 30;
			
			$potential_percent = intval(($amount_pay / $amount_month) * 100 ) / 100;
			if($potential_percent > 1) $potential_percent = 1;
			if($potential_percent < 0.2) $potential_percent = 0.2;
			} else {
				$potential_percent = 0;
			}	
			$msg_potential = "";

				// Моя информация
				$my = $connection->createCommand("SELECT uid, package, CONCAT(name, ' ', fio) as 'fio' FROM {{usersinfo}} WHERE uid = :uid")->bindParam(":uid", $order_uid)->queryRow();

				//Информация получателя
				$user_to = $connection->createCommand("SELECT uid, verify, CONCAT(name, ' ', fio) as 'fio' FROM {{usersinfo}} WHERE uid = :uid AND status = 1")->bindParam(":uid", $good['uid'])->queryRow();
				$wallet_to = $connection->createCommand("SELECT * FROM {{users_wallet}} WHERE uid = :uid AND type = 1 AND status = 1")->bindParam(":uid", $user_to["uid"])->queryRow();
				
				//Комиссия продавца			
				$percent_bokobok = intval($connection->createCommand("SELECT percent FROM {{users_verify}} WHERE uid = :uid")->bindParam(":uid", $user_to['uid'])->queryScalar()) / 100;
				$amount_bokobok = intval($amount * $percent_bokobok * 100) / 100;
				
				
				//Рефера за продажу товара
				$rx = 0;
				if($order["uidx"] > 0 && $order["uidx"] != $order["uid"] && $order["uidx"] != $good["uid"]) {
					
					$rx = $order["uidx"];
					
					$user_info_rx = $connection->createCommand("SELECT uid FROM {{usersinfo}} WHERE uid = :uid AND uid > 0")
					->bindParam(":uid", $rx)
					->queryRow();
					
					$user_info_rx = $connection->createCommand("SELECT uid FROM {{usersinfo}} WHERE uid = :uid AND uid > 0")
					->bindParam(":uid", $rx)
					->queryRow();
					
					if(empty($user_info_rx)) {
						$rx = 0; //Если не нашло пользователя - аннулируем его
					} else {
						
						//Находим кошелек реферала
						$wallet_rx = $connection->createCommand("SELECT * FROM {{users_wallet}} WHERE uid = :uid AND type = 1 AND status = 1")->bindParam(":uid", $rx)->queryRow();
						if(empty($wallet_rx)) {
							$rx = 0; //Если не нашло кошелек - аннулируем его
						}
						
					}
					
				}
				

				if ((empty($user_to)) || (empty($wallet_to))) {
					$err .= "<p>Подтверждение получения данного товара временно недоступно.</p>";
				}
				
				if(!Functions::access_level(1, $order_uid))
					$err = "<p>Возникла непредвиденная ошибка.</p>";
				
					
				if ((!empty($wallet_to)) && (!empty($user_to)) && ($user_to["uid"] == $wallet_to["uid"]) && ($order_uid != $wallet_to["uid"]) && ($amount > 0) && (Yii::app()->user->id > 0) && ($err == "")) {

					$transaction = $connection->beginTransaction();
					try {
						$connection->createCommand()->insert('{{users_hash_order}}', array('uid' => $order_uid, 'hash' => $order_uid.'.004'.$order['id'], 'date' => time()));

						
						//Записываем комиссию пользователю
                        $connection->createCommand()->insert('{{orders_tax}}', array(
                        'oid' => $order['id'],
                        'uid' => $user_to["uid"],
                        'tax_percent' => $percent_bokobok,
                        'tax_amount' => $amount_bokobok,
                        'amount' => $amount,
                        'date' =>time()
                        ));
                        
						
						//Обновляем транзакцию мне
						$connection->createCommand("UPDATE {{utransactions2}} SET status = 1 WHERE invoice = :invoice AND uid = :uid AND status = 0 AND `action` = 21;")
							->bindParam(":invoice", $invoice['id'])
							->bindParam(":uid", $order_uid)
							->query();

						//Вставляем транзакцию адрессату
						$connection->createCommand()->insert('{{utransactions2}}', array('did' => $good['gid'], 'uid' => $user_to["uid"], 'ruid' => $order_uid, 'amount' => $amount, 'amount_now' => $wallet_to["cash_now"] + $amount, 'date' => time(), 'type' => 1, 'status' => 1, 'invoice' => $invoice['id'], 'action' => 21));
						$utransactions2 = $connection->getLastInsertID();
						
						$connection->createCommand()->insert('{{utransactions2}}', array('did' => $good['gid'], 'uid' => $user_to["uid"], 'ruid' => 22, 'amount' => $amount_bokobok, 'amount_now' => doubleval($wallet_to["cash_now"] + $amount - $amount_bokobok), 'date' => time(), 'type' => 0, 'status' => 1, 'invoice' => $invoice['id'], 'action' => 22));
						
						$utransactions2 = $connection->getLastInsertID();

						$connection->createCommand("UPDATE {{users_wallet}} SET cash_now = cash_now + :amount WHERE uid = :touid AND type = 1 AND status = 1")
							->bindParam(":amount", doubleval($amount - $amount_bokobok))
							->bindParam(":touid", $user_to['uid'])
							->query();
							
							
						//Добавляем реферальные тому кто продал товар по рекомендации
						if($rx > 0) {
							
							$amount_rx = intval($amount * 0.01 * 100) / 100;
							
							$connection->createCommand()->insert('{{utransactions2}}', array('did' => $order['id'], 'uid' => $rx, 'ruid' => 23, 'amount' => $amount_rx, 'amount_now' => doubleval($wallet_rx["cash_now"] + $amount_rx), 'date' => time(), 'type' => 1, 'status' => 1, 'invoice' => $invoice['id'], 'action' => 23));
							$connection->createCommand("UPDATE {{users_wallet}} SET cash_now = cash_now + :amount WHERE uid = :touid AND type = 1 AND status = 1")
								->bindParam(":amount", doubleval($amount_rx))
								->bindParam(":touid", $rx)
								->query();
						}


						if($user_to['verify'] == 1 && $my['package'] > 0){
							
								
								$amount_potential = $connection->createCommand("SELECT SUM(deposit) FROM {{users_potential}} WHERE uid = :uid AND status = 1 AND type = 1 AND dt < dte")
								->bindParam(":uid", $order_uid)
								->queryScalar();
								
								//Базовый кешбек
								$cashback = 0.3; //Стартовый
								$cashback = $connection->createCommand("SELECT cashback FROM {{settings_cashback}} WHERE :amount >= amount_from AND :amount < amount_to")
									->bindParam(":amount", $amount_potential)
									->queryScalar();
								
								//Множитель продавца
								$sertification_multi = doubleval($connection->createCommand("SELECT multi FROM {{users_verify}} WHERE uid = :uid")
									->bindParam(":uid", $good["uid"])
									->queryScalar()) / 100; //Максимальная скидка
									
								//Расчет реального кешбека с учетом множителя
								$cashback = $cashback * $sertification_multi;
								
								//*************************************
								if($good["uid"] == 117485) {
									$cashback = 0;
								}
								//*************************************
									
								$percent = 0.002;
								$days = 500;
								$amount_back = intval($amount_pay*$cashback*100) / 100;
								
							/*
							
								$cashback = $connection->createCommand("SELECT cashback FROM {{settings_package}} WHERE package = :package")
									->bindParam(":package", $my['package'])
									->queryScalar();
								
								if($cashback*$potential_percent < 0.1) {
									$potential_percent = doubleval(0.1 / $cashback);
								}
								
								$percent = 0.003;
								$days = 333;
								$amount_back = intval($amount_pay*$cashback*$potential_percent*100) / 100;
							
							}*/
							
							$connection->createCommand()->insert('{{users_potential}}', array(
								'uid' => $order_uid,
								'cuid' => $order_uid,
								'puid' => 0,
								'fuid' => 0,
								'date' => time(),
								'dt' => 0,
								'dte' => $days,
								'deposit' => $amount_back,
								'percent' => $percent,
								'cash_now' => 0,
								'cash_out' => 0,
								'cash_all' => 0,
								'type' => 4,
								'status' => 1,
								'newsystem' => 1
							));
							
							$connection->createCommand()->insert('{{goods_cashback}}', array(
								'uid' => $order_uid,
								'gid' => $order['gid'],
								'oid' => $order["id"],
								'amount' => $amount_pay,
								'date' => time(),
								'package' => $my['package'],
								'cb_package' => $cashback,
								'cb_percent' => $cashback,
								'cb_amount' => $amount_back,
								'status' => 1
							));
							
							
							
							$msg_potential = "Ваш потенциал увеличен на $amount_back BP.";
							
						}

						$connection->createCommand("UPDATE {{orders}} SET order_delivery = 1, status = 4 WHERE id = :id AND uid = :uid AND status = 3 AND order_pay = 1;")
							->bindParam(":id", $order['id'])
							->bindParam(":uid", $order_uid)
							->query();

						$text_msg = 'Заказ №'.$order['id'].': пользователь подтвердил получение товара "'.$good['title'].'". На Ваш баланс зачислено '.doubleval($amount - $amount_bokobok).' BP.';
						$connection->createCommand()->insert('{{messages}}', array('date' => time(), 'fuid' => 2, 'tuid' => $good['uid'], 'message' => $text_msg));

						$transaction->commit();
						//Позитивный результат
						$res["status"] = 200;
						$res["message"] = "Спасибо за покупку! " . $msg_potential;
					} catch (Exception $e) {
						$transaction->rollback();
						$res["status"] = 500;
						$res["message"] = $e . "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
					}
					
				} else {
					//Хакерская атака - подмена данных
					$res["status"] = 500;
					$res["message"] = "<p>Вы не можете оплатить товар на сумму в размере " . $amount . " BP. Убедитесь в правильности заполненных полей и повторите попытку снова.</p>" . $err;
				}
			}else{
				$res["status"] = 500;
				$res["message"] = "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
			}

			$connection->createCommand("UPDATE {{users}} SET `lock` = 0 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
			echo CJSON::encode($res);
			Yii::app()->end();
		}
		
		
		} catch (Exception $e) {
			
			$connection->createCommand("UPDATE {{users}} SET `lock` = 0 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
			$res["status"] = 500;
			$res["message"] = $e. "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
			echo CJSON::encode($res);
			Yii::app()->end();
		}
		
	}
	
	
	
	
	
	public function actionSetInvoiceOrderPayOkSuperMsConfirm()
	{
		
		/*$res["status"] = 500;
		$a = serialize($_POST);
		$res["message"] = $a;
		echo CJSON::encode($res);
		Yii::app()->end();*/
		
		try {
		
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			Functions::access_control(1);
			$connection = Yii::app()->db;
			$res = array();
			$err = '';
			
			//Входящие данные
			$id = intval($_POST['id']);
			
			return;

			//Блокировка файлом ===================
			/*$lock = $connection->createCommand("SELECT uid, `lock` FROM {{users}} WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->queryRow();
			if ($lock['lock'] == 0) {
				$connection->createCommand("UPDATE {{users}} SET `lock` = 1 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
			} else {
				$res["status"] = 500;
				$res["message"] = "Идет обработка Вашего запроса. Обновите страницу через несколько минут и повторите попытку снова.";
				echo CJSON::encode($res);
				Yii::app()->end();
			}//Блокировка файлом ===================
			*/
			
			$err = "";
			
			if(!in_array(Yii::app()->user->id, array(201378))) {
				$res["status"] = 500;
				$res["message"] = "Недостаточно прав для выполнения данного действия.";
				echo CJSON::encode($res);
				Yii::app()->end();
			}
			
			//Заказ
			$order = $connection->createCommand("SELECT * FROM {{orders}} WHERE id = :id AND status = 2")
				->bindParam(":id", $id)
				->queryRow();
			$order_uid = $order["uid"];	
			$order_gid = $order["gid"];	
			
			$good = $connection->createCommand("SELECT * FROM {{goods}} WHERE gid = :gid AND uid = :uid")
				->bindParam(":gid", $order_gid)
				->bindParam(":uid", Yii::app()->user->id)
				->queryRow();
			$good_uid = Yii::app()->user->id;
			
			//Данные платежа
			
			$timestamp = 1480520331;//time();
			$amount = $order["quantity"];
			$remote = 'bokobok';
			$note = 'Покупка в магазине электронных валют.';
			
			$currency = 'PM-USD';
			switch(intval($good["gid"])) {
				case 40194:
					$currency = 'PM-USD';
					break;
				case 40197:
					$currency = 'XBT';
					break;
				case 40200:
					$currency = 'CRT';
					break;	

			}
			
			if($currency == '') {
				$err .= "<li>Валюта перевода не совпадает</li>";
			}
			
			
			$originator = 'bokobok.ec@gmail.com';
			$receiver = $connection->createCommand("SELECT email FROM {{usersinfo}} WHERE uid = :uid")
				->bindParam(":uid", $order_uid)
				->queryScalar(); //кому перечислять деньги
			
			//Номер транзакции	
			$pass = "GccABqkHCfQ2x5zSE832ePrcpXFDle00";
			$order_code = $order["id"] . "-" . md5($order["id"] . $order["uid"] . $timestamp . $pass);
			$transfer_id = $order_code;
			
			
			$sign = '';
			if($err == '') {
				$data = implode("|", [$timestamp, $transfer_id, $originator, $amount, $currency, $receiver]);		
				$private_key = Yii::app()->params['rsa_private_key'];
				$pk  = openssl_get_privatekey(Yii::app()->params['rsa_private_key']);
				openssl_sign($data, $sign_ssl, $pk);
				$sign = base64_encode($sign_ssl);
			}
			
			if($sign == '') {
				$err .= "<li>Сигнатура не совпадает</li>";
			}
			
			
			
			if(!empty($order) && !empty($good) && $err == ""){
				
				$transaction = $connection->beginTransaction();
				try {
					
										
					$connection->createCommand()->insert('{{orders_mec_start}}', array(
						'uid' => Yii::app()->user->id, 
						'oid' => $order["id"],
						'timestamp' => $timestamp,
			            'amount' => $amount,
			            'currency' => $currency,
			            'transfer_id' => $transfer_id,
			            'remote' => $remote,
			            'originator' => $originator,
			            'receiver' => $receiver,
			            'note' => $note,
			            'sign' => $sign,
			            'status' => 0
					));
					$ms_start_id = $connection->getLastInsertID();
					
					$connection->createCommand("UPDATE {{orders}} SET status = 3, order_delivery = 1 WHERE id = :id AND gid = :gid")
					->bindParam(":id", $order["id"])
					->bindParam(":gid", $order['gid'])
					->query();
                    
					
					$transaction->commit();
					//Позитивный результат
					$res["status"] = 200;
					$res["message"] = "Спасибо за покупку! " . $msg_potential;
				} catch (Exception $e) {
					$transaction->rollback();
					$res["status"] = 500;
					$res["message"] = $e . "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
				}
				
				
			}else{
				$res["status"] = 500;
				$res["message"] = "Возникла ошибка." . $err;
			}
			
			if($res["status"] = 200) {
				
				$money_receive = Api::money_receive($timestamp, $amount, $currency, $transfer_id, $remote, $originator, $receiver, $note, $sign);
				$money_receive_results = json_decode($money_receive, true);
				$connection->createCommand("UPDATE {{orders_mec_start}} SET status_start = :status WHERE id = :id")->bindParam(":status", $money_receive_results)->bindParam(":id", $ms_start_id)->query();
				
			}
			

			$connection->createCommand("UPDATE {{users}} SET `lock` = 0 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
			echo CJSON::encode($res);
			Yii::app()->end();
		}
		
		
		} catch (Exception $e) {
			
			$connection->createCommand("UPDATE {{users}} SET `lock` = 0 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
			$res["status"] = 500;
			$res["message"] = $e. "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
			echo CJSON::encode($res);
			Yii::app()->end();
		}
		
	}
	
	
	
	public function actionSetSellOrdersSettingsNew()
	{	
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			$paybp = intval($_POST['paybp']);
			$payms = intval($_POST['payms']);
			$wallet = mysql_escape_string(htmlspecialchars(strip_tags($_POST['wallet'])));

			$verify = $connection->createCommand("SELECT * FROM {{users_verify_super}} WHERE uid = :uid")
				->bindParam(":uid", Yii::app()->user->id)
				->queryRow();
				
			$verify_pays = $connection->createCommand("SELECT * FROM {{control_userverify_pays}} WHERE uid = :uid AND status = 0")
				->bindParam(":uid", Yii::app()->user->id)
				->queryRow();

			$err = '';
			
			if(($paybp + $payms) > 100) {
				$err .= "<li>Параметры указаны неверно.</li>";
			}
			
			if($payms > 80) {
				$err .= "<li>Максимальный процент приема платежей через MS - 80%.</li>";
			}
			
			$wallet = str_replace(" ", "", $wallet);
			$pattern = '/^\d{16}$/';
			
			if (!preg_match($pattern, $wallet) || !Functions::is_valid_credit_card($wallet)) {
			    $err .= '<li>Неверный формат номера кошелька в Money Storage.</li>';   
			}
			
			if(empty($verify)) {
				$err .= '<li>Функция временно недоступна.</li>';
			}
			
			if(!empty($verify_pays)) {
				$err .= '<li>Ваша заявка на изменение настроек уже находится в обработке.</li>';
			}
			
			if ($err == "") {
				
				$transaction = $connection->beginTransaction();
					try {
							
							$connection->createCommand()->insert('{{control_userverify_pays}}', array(
								'uid' => Yii::app()->user->id,
								'date' => time(),
								'paybp' => $paybp,
								'payms' => $payms,
								'payms_wallet' => $wallet,
								'status' => 0
							));
							
						
						$transaction->commit();
						$res["status"] = 200;
						$res["message"] = "Заявка на изменение настроек оплаты успешно подана на рассмотрение. Как только она будет обработана новые настройки будут автоматически применены.";
						
					} catch (Exception $e) {
						$transaction->rollback();
						$res["status"] = 500;
						$res["message"] = $e . "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
					}
			
			} else {
			
				$res["status"] = 500;
				$res["message"] = "Возникла ошибка." . $err;
			
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	
	public function actionSetSellOrdersSettingsCancel()
	{	
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
							
			$verify_pays = $connection->createCommand("SELECT * FROM {{control_userverify_pays}} WHERE uid = :uid AND status = 0")
				->bindParam(":uid", Yii::app()->user->id)
				->queryRow();

			$err = '';

			if(empty($verify_pays)) {
				$err .= '<li>Обновите страницу и повторите попытку снова.</li>';
			}
			
			if ($err == "") {
				
				$transaction = $connection->beginTransaction();
					try {
							
						$connection->createCommand("UPDATE {{control_userverify_pays}} SET status=3 WHERE uid = :uid AND status = 0")
							->bindParam(":uid", Yii::app()->user->id)
							->query();
							
						$res["verify"] = $connection->createCommand("SELECT paybp, payms, payms_wallet FROM {{users_verify}} WHERE uid = :uid")
							->bindParam(":uid", Yii::app()->user->id)
							->queryRow();

						$transaction->commit();
						$res["status"] = 200;
						$res["message"] = "Заявка на установку настроек оплаты успешно отклонена.";
						
					} catch (Exception $e) {
						$transaction->rollback();
						$res["status"] = 500;
						$res["message"] = $e . "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
					}
			
			} else {
			
				$res["status"] = 500;
				$res["message"] = "Возникла ошибка." . $err;
			
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	

	/**
	 * This is the action to handle external exceptions.
	 */
	public function actionError()
	{
		if ($error = Yii::app()->errorHandler->error) {
			if (Yii::app()->request->isAjaxRequest)
				echo $error['message'];
			else
				$this->render('error', $error);
		}
	}


}