<?php

class PostController extends Controller
{
	public function filters()
	{
		return array(
			'accessControl', // perform access control for CRUD operations
		);
	}

	public function accessRules()
	{
		return array(
			array('allow',
				'actions'=>array('getpost', 'postgetnext'),
				'users'=>array('?'),
			),
			array('deny',
				'users'=>array('?'),
			),
		);
	}

	public function actionDislike()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			Functions::access_control(1);
			$res = array();
			$connection = Yii::app()->db;
			$post_id = intval($_POST["post"]);
			$post = $connection->createCommand("SELECT * FROM {{posts}} WHERE id = :post_id AND status = 1")->bindParam(":post_id", $post_id)->queryRow();

			if (!empty($post)) {
				$dislike = $connection->createCommand("SELECT * FROM {{posts_dislike}} WHERE uid = :uid AND pid = :pid")
					->bindParam(":pid", $post_id)
					->bindParam(":uid", Yii::app()->user->id)
					->queryRow();

				if(empty($dislike)){
					$connection->createCommand("UPDATE {{posts}} SET dislike_count = dislike_count + 1  WHERE id = :id")
						->bindParam(":id", $post["id"])
						->query();
					$connection->createCommand()->insert('{{posts_dislike}}', array(
						'uid' => Yii::app()->user->id,
						'pid' => $post["id"]
					));

					$res["status"] = 200;
					$res["message"] = "<p>Жалоба успешно отправлена!</p>";
				}else{
					$res["status"] = 500;
					$res["message"] = "<p>Вы уже отправили жалобу на данную публикацию.</p>";
				}
			} else {
				$res["status"] = 500;
				$res["message"] = "<p>Сервер временно недоступен.</p>";
			}
			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionPopular()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$connection = Yii::app()->db;
			$res = array();
			$page = intval($_POST["page"]);

			if (!empty($page)) {
				$posts = $connection->createCommand("SELECT p.id, p.uid, p.text, p.desc, p.title, p.repost, p.date, p.like_count, p.repost_count, p.media_img, p.media_vid, u.photo, CONCAT(u.name, ' ', u.fio) as 'fio', u.alias, u2.photo as repost_photo, CONCAT(u2.name, ' ', u2.fio) as 'repost_fio', u2.alias as repost_alias FROM {{posts}} p INNER JOIN {{usersinfo}} u ON u.uid = p.uid LEFT JOIN {{usersinfo}} u2 ON u2.uid = p.puid WHERE p.like_count >= 10 ORDER BY date DESC LIMIT :limit OFFSET :offset")
					->bindValue(":limit", 10, PDO::PARAM_INT)
					->bindValue(":offset", ($page - 1) * 10, PDO::PARAM_INT)
					->queryAll();

				$res["posts"] = $posts;
				$res["status"] = 200;
			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionDelete()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			Functions::access_control(1);
			$connection = Yii::app()->db;
			$fs_db = Yii::app()->fs_db;
			$res = array();

			//Входящие данные
			$id = intval($_POST["id"]);

			$transaction = $connection->beginTransaction();
			try {
				$post = $connection->createCommand("SELECT * FROM {{posts}} WHERE id = :id AND status = 1")
					->bindParam(":id", $id)
					->queryRow();
				$user_info = $connection->createCommand("SELECT * FROM {{usersinfo}} WHERE uid = :uid")
					->bindParam(":uid", $post['puid'])
					->queryRow();
				if (
					(!empty($post) && !empty($user_info)) &&
					($post['uid'] == Yii::app()->user->id && $post['repost'] == 0) || //мои записи на моей и чужой стене не репост
					($post['puid'] == Yii::app()->user->id && $post['repost'] == 0) || //Мои и чужие записи на моей стене
					($post['puid'] == Yii::app()->user->id && $post['repost'] > 0) || //Мои репосты на моей стене
					($post['puid'] == $post['uid'] && $user_info['owner'] == Yii::app()->user->id) //записи на стене моей групы
				) {
					$connection->createCommand("UPDATE {{posts}} SET status = 0 WHERE id = :id AND status = 1")
						->bindParam(":id", $id)
						->query();

					if(!empty($post['media_img'])){
						$photos_count = $connection->createCommand("SELECT COUNT(*) FROM {{posts}} WHERE media_img = :photo AND status = 1")
							->bindParam(":photo", $post['media_img'])
							->queryScalar();
						if($photos_count == 0){
							//Удаляем изображение
							$fs_db->createCommand("UPDATE {{images}} SET status = 2 WHERE path = :path")
								->bindParam(":path", $post['media_img'])
								->query();
						}
					}


					$transaction->commit();
					$res["status"] = 200;
				} else {
					$transaction->rollback();
					$res["status"] = 500;
					$res["message"] = "<p>Сервер временно недоступен.</p>";
				}

//				if (
//					(!empty($post) && !empty($user_info)) &&
//					($post['uid'] == Yii::app()->user->id && $post['repost'] == 0) ||
//					($post['puid'] == Yii::app()->user->id && $post['repost'] == 0) ||
//					($post['puid'] == $user_info['uid'])
//				) {
//					//удаляем комменарии
//					Yii::app()->db->createCommand('DELETE FROM {{comments}} WHERE pid = :pid')
//						->bindParam('pid', $post['id'])
//						->query();
//
//					//удаляем запись
//					Yii::app()->db->createCommand('DELETE FROM {{posts}} WHERE id = :id')
//						->bindParam(":id", $id)
//						->query();
//
//					//удаляем лайки
//					Yii::app()->db->createCommand('DELETE FROM {{posts_like}} WHERE pid = :pid')
//						->bindParam(":pid", $id)
//						->query();
//
//					//удаляем репост
//					if($post['repost'] > 0){
//						$reposted = $connection->createCommand("SELECT id FROM {{posts}} WHERE puid = :uid AND repost <> 0 AND repost = :pid")
//							->bindParam(":uid", Yii::app()->user->id)
//							->bindParam(":pid", $post['repost'])
//							->queryRow();
//
//						$connection->createCommand("UPDATE {{posts}} SET repost_count = repost_count - :repost_count WHERE id = :id")
//							->bindParam(":id", $post["repost"])
//							->bindValue(":repost_count", empty($reposted) ? 1 : 0)
//							->query();
//					}
//
//					$transaction->commit();
//					$res["status"] = 200;
//				} else {
//					$transaction->rollback();
//					$res["status"] = 500;
//					$res["message"] = "При удалении записи возникла ошибка.";
//				}
			} catch (Exception $e) {
				$transaction->rollback();
				$res["status"] = 500;
				$res["message"] = "При удалении записи возникла ошибка.";
			}
			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionRepost()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;

			$post_id = intval($_POST["post"]);
			$post = $connection->createCommand("SELECT * FROM {{posts}} WHERE id = :post_id")->bindParam(":post_id", $post_id)->queryRow();
			$re_post = $connection->createCommand("SELECT * FROM {{posts}} WHERE repost = :post_id AND puid = :puid AND uid = :uid")
					->bindParam(":post_id", $post_id)
					->bindParam(":puid", Yii::app()->user->id)
					->bindParam(":uid", $post['uid'])
					->queryRow();

			if (!empty($post) && $post['puid'] != Yii::app()->user->id AND empty($re_post)) {
				$transaction = $connection->beginTransaction();
				try {
					$reposted = $connection->createCommand("SELECT * FROM {{posts}} WHERE puid = :uid AND repost <> 0 AND repost = :pid")
						->bindParam(":uid", Yii::app()->user->id)
						->bindParam(":pid", $post['id'])
						->queryRow();
					if (empty($reposted)) {
						$rep_add = !empty($reposted) ? 0 : 1;

						$time = time();
						$connection->createCommand()->insert('{{posts}}', array(
							'uid' => $post['uid'],
							'puid' => Yii::app()->user->id,
							'title' => $post['title'],
							'desc' => $post['desc'],
							'text' => $post['text'],
							'type' => $post['type'],
							'category_name' => $post['category_name'],
							'media_img' => $post['media_img'],
							'media_vid' => $post['media_vid'],
							'date' => $time,
							'status' => 1,
							'repost' => $post['id'],
							'hash' => Yii::app()->user->id.'.'.$post['id']
						));

						$post_owner = $connection->createCommand("SELECT * FROM {{usersinfo}} WHERE uid = :uid")
							->bindParam(":uid", $post['puid'])
							->queryRow();

						// уведомления
						$answer_repost = $connection->createCommand("SELECT * FROM {{events}} WHERE uid = :uid AND fuid = :fuid AND type = 2 AND data1 = :post_id")
							->bindParam(":uid", $post['uid'])
							->bindParam(":fuid", Yii::app()->user->id)
							->bindParam(":post_id", $post['id'])
							->queryRow();
						if (empty($answer_repost) && !empty($post_owner) && $post_owner['type'] == 1) {
							$connection->createCommand()->insert('{{events}}', array(
								'uid' => $post['puid'],
								'fuid' => Yii::app()->user->id,
								'date' => time(),
								'type' => 2,
								'status' => 0,
								'data1' => $post['id']
							));
						}

						// лайк
						$like = $connection->createCommand("SELECT * FROM {{posts_like}} WHERE uid = :uid AND pid = :pid")
							->bindParam(":pid", $post_id)
							->bindParam(":uid", Yii::app()->user->id)
							->queryRow();
						if (empty($like)) {
							$connection->createCommand("UPDATE {{posts}} SET repost_count = repost_count + :rep_count, like_count = like_count + 1  WHERE id = :id")
								->bindParam(":id", $post["id"])
								->bindParam(":rep_count", $rep_add)
								->query();
							$connection->createCommand()->insert('{{posts_like}}', array(
								'uid' => Yii::app()->user->id,
								'pid' => $post["id"],
								'hash' => Yii::app()->user->id.'.'.$post["id"]
							));
							$likes = $post["like_count"] + 1;
						} else {
							$connection->createCommand("UPDATE {{posts}} SET repost_count = repost_count + :rep_count WHERE id = :id")
								->bindParam(":id", $post["id"])
								->bindParam(":rep_count", $rep_add)
								->query();
							$likes = $post["like_count"];
						}

						$reposts = $post["repost_count"] + $rep_add;

					} else {
						$likes = $post['like_count'];
						$reposts = $post['repost_count'];
					}

					$transaction->commit();
					$res['post'] = $post;
					$res['post']['like_count'] = $likes;
					$res['post']['repost_count'] = $reposts;
					$res["message"] = 'Запись успешно отправлена на вашу страницу.';
					$res["status"] = 200;

				} catch (Exception $e) {
					$transaction->rollback();
					$res["status"] = 500;
					$res["message"] = "<p>Запись уже находится на Вашей странице.</p>";
				}
			} else {
				$res["status"] = 500;
				$res["message"] = "<p>Сервер временно недоступен.</p>";
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionGetPost()
	{
		if (Yii::app()->request->isAjaxRequest) {
			$connection = Yii::app()->db;
			$res = array();

			$post_id = intval($_POST["post_id"]);

			$post = $connection->createCommand("SELECT p.id, p.uid, p.puid, p.category_name, p.text, p.desc, p.title, p.date, p.like_count, p.repost_count, p.repost, p.media_img, p.media_vid, p.comment, u.photo, CONCAT(u.name, ' ', u.fio) as 'fio', u.alias, u.owner FROM {{posts}} p INNER JOIN {{usersinfo}} u ON u.uid = p.uid WHERE p.id = :post_id")->bindParam(":post_id", $post_id)->queryRow();

			if(!empty($post)){
				$res["post"] = $post;
				$res["status"] = 200;
			}else{
				$res["status"] = 500;
			}
			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionPostAdd()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			Functions::access_control(1);
			$connection = Yii::app()->db;
			$fs_db = Yii::app()->fs_db;
			$res = array();
			$err = '';

			$text = mysql_escape_string(htmlspecialchars(strip_tags($_POST["text"])));
			$type = intval($_POST["type"]);
			$category_id = intval($_POST["category"]);
			$puid = intval($_POST["fuid"]);
			$photo = mysql_escape_string(htmlspecialchars(strip_tags($_POST["media"])));
			$media_vid = mysql_escape_string(htmlspecialchars(strip_tags($_POST["media_vid"])));
			$media_vid = urldecode($media_vid);
			if($type == 3){
				$res["status"] = 500;
				$res["message"] = "Возможность предлагать вскоре будет доступна.";
				echo CJSON::encode($res);
				Yii::app()->end();
			}

			$media_vid = explode(',', $media_vid);

			$page_userinfo = $connection->createCommand("SELECT * FROM {{usersinfo}} WHERE uid = :uid")->bindParam(":uid", $puid)->queryRow();
			$category = $connection->createCommand("SELECT * FROM {{categories}} WHERE id = :id")->bindParam(":id", $category_id)->queryRow();

			if(empty($page_userinfo)){
				$err .= '<p>Доступ запрещен.</p>';
			}
			if($page_userinfo['type'] == 2 && $page_userinfo['owner'] != Yii::app()->user->id){
				$err .= '<p>Доступ запрещен.</p>';
			}
			if(!in_array($type, [1,2,3])){
				$err .= '<p>Необходимо указать тип поста.</p>';
			}
			if(($type == 2 || $type == 3) && empty($category) ){
				$err .= '<p>Необходимо указать категорию.</p>';
			}
			if(!((!empty($text) && strlen($text) <= 5000) || !empty($photo) || !empty($media_vid))){
				$err .= '<p>Необходимо указать текст сообщения</p>';
			}


			//Запретить писать в группе
//			if($page_userinfo['type'] == 2 && $page_userinfo['owner'] == Yii::app()->user->id){
//				$res["status"] = 500;
//				$res["message"] = "Возможность вскоре будет доступна.";
//				echo CJSON::encode($res);
//				Yii::app()->end();
//			}
			//Запретить писать на чужой стене
			if($page_userinfo['type'] == 1 && $page_userinfo['uid'] != Yii::app()->user->id){
				$res["status"] = 500;
				$res["message"] = "Возможность вскоре будет доступна.";
				echo CJSON::encode($res);
				Yii::app()->end();
			}

			if (empty($err)){
				$transaction = $connection->beginTransaction();
				try {
                    $uid = in_array($page_userinfo['type'], [2,3,4]) ? $puid : Yii::app()->user->id;

					$videos = $media_vid;
					$time = time();
					$connection->createCommand()->insert('{{posts}}', array(
						'status' => 1,
						'date' => $time,
						'uid' => $uid,
						'puid' => $page_userinfo['uid'],
						'text' => $text,
						'type' => $type,
						'category_name' => !empty($category) ? $category['name'] : '',
						'media_img' => $photo,
						'media_vid' => !empty($videos) ? implode('&', $videos) : '',
						'hash' => $uid . "." . (round($time/10) * 10) // 1 пост в 10 секунд
					));

					$post_id = Yii::app()->db->getLastInsertID();

					// Вставляем категории
					if($type == 2 || $type == 3){
						$connection->createCommand()->insert('{{post_category}}', array(
							'post_id' => $post_id,
							'category_id' => $category['id']
						));
						$parent_cat = $connection->createCommand("SELECT * FROM {{categories}} WHERE id = :id")->bindParam(":id", $category['parent'])->queryRow();
						if(!empty($parent_cat)){
							$connection->createCommand()->insert('{{post_category}}', array(
								'post_id' => $post_id,
								'category_id' => $parent_cat['id']
							));
							$parent_cat2 = $connection->createCommand("SELECT * FROM {{categories}} WHERE id = :id")->bindParam(":id", $parent_cat['parent'])->queryRow();
							if(!empty($parent_cat2)){
								$connection->createCommand()->insert('{{post_category}}', array(
									'post_id' => $post_id,
									'category_id' => $parent_cat2['id']
								));
							}
						}
					}

					$post = $connection->createCommand("SELECT p.*, CONCAT(u.name, ' ', u.fio) as 'fio', u.photo, u.alias, u.owner FROM {{posts}} p INNER JOIN {{usersinfo}} u ON p.id = :id AND p.uid = :uid AND u.uid = :uid")
						->bindParam(":id", $post_id)
						->bindParam(":uid", $uid)
						->queryRow();

					//Добавляем изображения
					$fs_db->createCommand("UPDATE {{images}} SET status = 1 WHERE path = :path")
						->bindParam(":path", $photo)
						->query();

					$transaction->commit();
					$res['post'] = $post;
					$res["status"] = 200;
				} catch (Exception $e) {
					$transaction->rollback();
					$res["status"] = 500;
					$res["message"] = "<p>Сервер временно недоступен. Повторите попытку через несколько минут.</p>";
				}
			} else {
				$res["status"] = 500;
				$res["message"] = $err;
			}
			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionPostGetNext()
	{
		if (Yii::app()->request->isAjaxRequest) {
			$connection = Yii::app()->db;
			$res = array();

			$page = intval($_POST["page"]);
			$uid = intval($_POST["uid"]);

			if (!empty($page) && !empty($uid)) {
				if(Yii::app()->user->id == $uid){
					$posts = $connection->createCommand("SELECT p.id, p.uid, p.puid, p.type, p.category_name, p.text, p.desc, p.title, p.date, p.like_count, p.repost_count, p.repost, p.media_img, p.media_vid, p.comment, u.photo, CONCAT(u.name, ' ', u.fio) as 'fio', u.alias, u.owner FROM {{posts}} p INNER JOIN {{usersinfo}} u ON u.uid = p.uid WHERE ((p.repost = 0 AND p.puid = :uid AND p.uid = :uid) OR p.puid = :uid) AND p.status = 1 ORDER BY date DESC LIMIT :limit OFFSET :offset")
						->bindValue(":uid", $uid)
						->bindValue(":limit", 10, PDO::PARAM_INT)
						->bindValue(":offset", ($page - 1) * 10, PDO::PARAM_INT)
						->queryAll();
				}else{
					$posts = $connection->createCommand("SELECT p.id, p.uid, p.puid, p.type, p.category_name, p.text, p.desc, p.title, p.date, p.like_count, p.repost_count, p.repost, p.media_img, p.media_vid, p.comment, u.photo, CONCAT(u.name, ' ', u.fio) as 'fio', u.alias, u.owner FROM {{posts}} p INNER JOIN {{usersinfo}} u ON u.uid = p.uid WHERE ((p.uid = :uid AND p.repost = 0) OR p.puid = :uid) AND p.status = 1 ORDER BY date DESC LIMIT :limit OFFSET :offset")
						->bindValue(":uid", $uid)
						->bindValue(":limit", 10, PDO::PARAM_INT)
						->bindValue(":offset", ($page - 1) * 10, PDO::PARAM_INT)
						->queryAll();
				}


				$res["posts"] = $posts;
				$res["status"] = 200;
			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	public function actionFeedFilter()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			$limit = Yii::app()->params['users-per-page'];

			$page = intval($_POST["page"]);
			$uid = Yii::app()->user->id;
			$type = intval($_POST["type"]);
			$search_query = mysql_escape_string(htmlspecialchars(strip_tags($_POST["query"])));
			$category = intval($_POST["category"]);
			$country = intval($_POST["country"]);
			$city = intval($_POST["city"]);
			$search = intval($_POST["search"]);
			$search_order = intval($_POST["order"]);

			$page_info = $connection->createCommand("SELECT * FROM {{usersinfo}} WHERE uid = :uid")->bindParam(":uid", $uid)->queryRow();

			if (!empty($page) && !empty($page_info)) {
				$query = array();
				$order = array();
				$join = array();

				$query['deleted'] = ' p.status = 1 ';
				if($search == 1){
					$join['friend'] = ' LEFT JOIN {{friends}} f ON f.uid = :uid';
					$query["feed"] = '((f.id IS NOT NULL AND ((f.fuid = p.uid AND f.fuid = p.puid) OR (f.fuid = p.puid AND p.repost > 0))) AND ((p.puid <> :uid) OR (p.uid = :uid AND p.puid = :uid)))';
				}else{
					$query["feed"] = '((p.puid <> :uid) OR (p.uid = :uid AND p.puid = :uid))';
				}

                $users_settings = $connection->createCommand("SELECT uid, find_place FROM {{users_settings}} WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->queryRow();
                if(!empty($users_settings)){
                    $connection->createCommand("UPDATE {{users_settings}} SET find_place = :find_place WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->bindValue(":find_place", $search == 1 ? 1 : 2)->query();
                }else{
                    $connection->createCommand()->insert('{{users_settings}}', array('uid' => Yii::app()->user->id, 'find_place' => $search == 1 ? 1 : 2, 'mail_send' => 1 ));
                }

				if (!empty($country) && $country > 0 && $city == -1) {
					$query['country'] = ' u.country = :country ';
				}
				if (!empty($city) && $city > 0) {
					$query['city'] = ' u.city = :city ';
				}
				if (!empty($category) && $category > 0 && ($type == 2 || $type == 3) ) {
					$join['category'] = ' INNER JOIN {{post_category}} pc ON pc.post_id = p.id AND pc.category_id = :category ';
				}
				if (!empty($type) && in_array($type, [1,2,3])) {
					$query['type'] = ' p.type = :type ';
				}
				if (!empty($search_query) && strlen($search_query) >= 3) {
					$query['search_query'] = ' (p.text LIKE :text) ';
				}
				if (!empty($search_order)) {
					if($search_order == 1){
						$order['search_order'] = ' date DESC ';
					}
					if($search_order == 2){
						$query['search_order'] = ' p.date > :popular_date AND p.repost = 0 ';
						$order['search_order'] = ' like_count DESC ';
					}
				}

				$query = !empty($query) ? " WHERE " . implode(" AND ", $query) : '';
				$order = !empty($order) ? " ORDER BY " . implode(", ", $order) : '';
				$join = !empty($join) ? ' ' . implode(" ", $join) : '';

				$sql = "SELECT SQL_CALC_FOUND_ROWS p.id, p.uid, p.puid, p.type, p.category_name, p.text, p.desc, p.title, p.repost, p.date, p.like_count, p.repost_count, p.media_img, p.media_vid, u.photo, CONCAT(u.name, ' ', u.fio) as 'fio', u.alias, u2.photo as repost_photo, CONCAT(u2.name, ' ', u2.fio) as 'repost_fio', u2.alias as repost_alias FROM {{posts}} p INNER JOIN {{usersinfo}} u ON u.uid = p.uid LEFT JOIN {{usersinfo}} u2 ON u2.uid = p.puid  ".$join." " . $query . " ".$order." LIMIT :limit OFFSET :offset";

				$command = $connection->createCommand($sql);
				$command->bindParam(":uid", $uid, PDO::PARAM_INT);
				$command->bindValue(":limit", $limit, PDO::PARAM_INT);
				$command->bindValue(":offset", ($page - 1) * $limit, PDO::PARAM_INT);

				if (!empty($country) && $country > 0 && $city == -1) {
					$command->bindParam(":country", $country);
				}
				if (!empty($city) && $city > 0) {
					$command->bindParam(":city", $city);
				}
				if (!empty($category) && $category > 0 && ($type == 2 || $type == 3) ) {
					$command->bindParam(":category", $category);
				}
				if (!empty($type) && in_array($type, [1,2,3])) {
					$command->bindParam(":type", $type);
				}
				if (!empty($search_query) && strlen($search_query) >= 3) {
					$command->bindValue(":text", '%' . $search_query . '%');
				}
				if (!empty($search_order)) {
					if($search_order == 2){
						$command->bindParam(":popular_date", strtotime('-10 day', time()));
					}
				}

				$posts = $command->queryAll();

				$res["posts"] = $posts;
				$res["status"] = 200;
			} else {
				$res["status"] = 500;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	public function actionPostEdit()
    {
        if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
            Functions::access_control(1);
            $connection = Yii::app()->db;
            $res = array();
            $err = '';

            //Входящие данные
            $id = intval($_POST["id"]);
            $text = mysql_escape_string(htmlspecialchars(strip_tags($_POST["text"])));

            $post = $connection->createCommand("SELECT p.* FROM {{posts}} p INNER JOIN {{usersinfo}} u ON p.id = :id AND p.status = 1 AND p.repost = 0 AND p.uid = p.puid AND p.uid = u.uid AND p.puid = u.uid AND u.owner = :uid")->bindParam(":id", $id)->bindParam(":uid", Yii::app()->user->id)->queryRow();

            if(empty($post)){
                $err .= '<li>У Вас недостаточно прав для выполнения данного действия.</li>';
            }
            if(!empty($post) && (($post['date'] - time()) > 86400 )){
                $err .= '<li>У Вас недостаточно прав для выполнения данного действия.</li>';
            }
            if($text == ''){
                $err .= '<li>Укажите текст сообщения.</li>';
            }
            if(!empty($text) && strlen($text) > 5000){
                $err .= '<li>Длина текста не должна превышать 5000 символов.</li>';
            }

            if($err == ''){
                $transaction = $connection->beginTransaction();
                try {
                    $connection->createCommand("UPDATE {{posts}} SET text = :text WHERE id = :id AND status = 1 AND repost = 0")->bindParam(":id", $id)->bindParam(":text", $text)->query();

                    $transaction->commit();
                    $res["status"] = 200;
                } catch (Exception $e) {
                    $transaction->rollback();
                    $res["status"] = 500;
                    $res["message"] = "<li>Сервер временно недоступен.</li>";
                }
            }else{
                $res["status"] = 500;
                $res["message"] = $err;
            }

            echo CJSON::encode($res);
            Yii::app()->end();
        }
    }
	
}