<?php

class SiteController extends Controller
{
	public $layout = 'main';

	public $loginModel;
	public $registerModel;

	/**
	 * @return array action filters
	 */
	public function filters()
	{
		return array(
			'accessControl', // perform access control for CRUD operations
		);
	}

	/**
	 * Specifies the access control rules.
	 * This method is used by the 'accessControl' filter.
	 * @return array access control rules
	 */
	public function accessRules()
	{
		return array(
			array('allow',
				'users' => array('*')
			)
		);
	}

	/**
	 * This is the default 'index' action that is invoked
	 * when an action is not explicitly requested by users.
	 */
	public function actionIndex()
	{
        $redirect = Yii::app()->request->cookies['redirect_page']->value;
        if(!empty($redirect)){
            unset(Yii::app()->request->cookies['redirect_page']);
            $this->redirect(array($redirect));
        }

        if(Yii::app()->user->isGuest){
            $blocked = mysql_escape_string(htmlspecialchars(strip_tags($_COOKIE['blocked'])));
            if(!empty($blocked) && $blocked == 'true'){
                $this->layout = 'block';
                $this->render('block');
            }else{
                $this->layout = 'login';
                $this->render('index');
            }
		}else{
			$this->redirect('/feed');
		}
	}

	/**
	 * This is the action to handle external exceptions.
	 */
	public function actionError()
	{
		if ($error = Yii::app()->errorHandler->error) {
			if (Yii::app()->request->isAjaxRequest)
				echo $error['message'];
			else
				$this->render('error', $error);
		}
	}

	/**
	 * Displays the login page
	 */
	public function actionLogin()
	{
        $this->layout = 'login';
		$serviceName = mysql_escape_string(htmlspecialchars(strip_tags($_GET["service"])));
		
		if (!empty($serviceName)) {
			//var_dump($serviceName); exit;
			/** @var $eauth EAuthServiceBase */
			$eauth = Yii::app()->eauth->getIdentity($serviceName);
			$eauth->redirectUrl = Yii::app()->user->returnUrl;
			$eauth->cancelUrl = $this->createAbsoluteUrl('/');

			try {
				if ($eauth->authenticate()) {
					$identity = new BUserIdentity($eauth);

					// successful authentication
					if ($identity->authenticate() && Yii::app()->user->login($identity)) {
						// redirect and close the popup window if needed
						$eauth->redirect();
						$this->redirect(array('/'.Yii::app()->user->alias));
					}
					else {
                        if($identity->isBlocked()){
                            setcookie('blocked', 'true', time()+60, '/');
                            setcookie('date_end', $identity->getBlockDate(), time()+60, '/');
                            $eauth->redirect('/');
                        }else{
                            // close popup window and redirect to cancelUrl
                            $eauth->cancel();
                        }
					}
				}

				// Something went wrong, redirect back to login page
				$this->redirect(array('/'));
			}
			catch (EAuthException $e) {
				// save authentication error to session
				Yii::app()->user->setFlash('error', 'EAuthException: '.$e->getMessage());

				// close popup window and redirect to cancelUrl
				$eauth->redirect($eauth->getCancelUrl());
			}
		}
		$this->render('index');
	}

	/**
	 * Logs out the current user and redirect to homepage.
	 */
	public function actionLogout()
	{
//		$this->layout = 'login';
		$connection = Yii::app()->db;
		$connection->createCommand("DELETE FROM {{sessions}} WHERE uid = :uid")
			->bindParam(":uid", Yii::app()->user->id)
			->query();
		Yii::app()->user->logout();
		$this->redirect('/');
	}
}