<?php

class WalletController extends Controller
{
	/**
	 * @return array action filters
	 */
	public function filters()
	{
		return array(
			'accessControl', // perform access control for CRUD operations
		);
	}

	public function redirectHome(){ // send to homesite
		$this->redirect('/');
	}


	/**
	 * Specifies the access control rules.
	 * This method is used by the 'accessControl' filter.
	 * @return array access control rules
	 */
	public function accessRules()
	{
		return array(
			array('allow', 
				'actions'=>array('getwallets'),
				'users'=>array('?'),
			),
			array('deny', 
				'users'=>array('?'),
			)
		);
	}

	/**
	 * Declares class-based actions.
	 */
	public function actions()
	{
		return array(
			// captcha action renders the CAPTCHA image displayed on the contact page
			'captcha'=>array(
				'class'=>'CCaptchaAction',
				'backColor'=>0xFFFFFF,
			),
			// page action renders "static" pages stored under 'protected/views/site/pages'
			// They can be accessed via: index.php?r=site/page&view=FileName
//			'page'=>array(
//				'class'=>'CViewAction',
//			),
		);
	}

	
	public function actionIndex()
	{
		$this->render('index');
	}

	public function actionSetInvoiceOrderPay()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			Functions::access_control(1);
			$connection = Yii::app()->db;
			$res = array();
			$err = '';

			//Входящие данные
			$order_id = intval($_POST['order_id']);

			//Блокировка файлом ===================
			$lock = $connection->createCommand("SELECT uid, `lock` FROM {{users}} WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->queryRow();
			if ($lock['lock'] == 0) {
				$connection->createCommand("UPDATE {{users}} SET `lock` = 1 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
			} else {
				$res["status"] = 500;
				$res["message"] = "Идет обработка Вашего запроса. Обновите страницу через несколько минут и повторите попытку снова.";
				echo CJSON::encode($res);
				Yii::app()->end();
			}//Блокировка файлом ===================

			//Заказ
			$order = $connection->createCommand("SELECT * FROM {{orders}} WHERE id = :order_id AND uid = :uid AND status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->bindParam(":order_id", $order_id)
				->queryRow();
			$good = $connection->createCommand("SELECT * FROM {{goods}} WHERE gid = :gid")
				->bindParam(":gid", $order['gid'])
				->queryRow();
			if(!empty($order) && !empty($good)){
				$amount = $order['amount']*$order['quantity'] - $order['discount_amount']*$order['quantity'];
				$err = "";

				//Наш кошелек
				$wallet = $connection->createCommand("SELECT * FROM {{users_wallet}} WHERE uid = :uid AND type = 1 AND status = 1")->bindParam(":uid", Yii::app()->user->id)->queryRow();
				$my = $connection->createCommand("SELECT uid, CONCAT(name, ' ', fio) as 'fio' FROM {{usersinfo}} WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->queryRow();

				//Информация получателя
				$user_to = $connection->createCommand("SELECT uid, CONCAT(name, ' ', fio) as 'fio' FROM {{usersinfo}} WHERE uid = :uid AND status = 1")->bindParam(":uid", $good['uid'])->queryRow();
				$wallet_to = $connection->createCommand("SELECT * FROM {{users_wallet}} WHERE uid = :uid AND type = 1 AND status = 1")->bindParam(":uid", $user_to["uid"])->queryRow();

				if ((empty($user_to)) || (empty($wallet_to))) {
					$err .= "<p>Данного пользователя не существует.</p>";
				}
				if (($wallet['cash_now'] < $amount) && ($amount <= 0)) {
					$err .= "<p>Неправильная сумма перевода.</p>";
				}
				if ((empty($wallet)) || (Yii::app()->user->id == 0)) {
					$err .= "<p>Вы не можете провести оплату. Обновите стрницу и повторите попытку снова.</p>";
				}

				if ((!empty($wallet)) && (!empty($wallet_to)) && (!empty($user_to)) && ($user_to["uid"] == $wallet_to["uid"]) && (Yii::app()->user->id != $wallet_to["uid"]) && ($wallet["cash_now"] > 0) && ($wallet["cash_now"] >= $amount) && ($amount > 0) && (Yii::app()->user->id > 0) && ($err == "")) {

					$transaction = $connection->beginTransaction();
					try {
						//БЛОКИРОВКА HASH
							$connection->createCommand()->insert('{{users_hash_order}}', array('uid' => Yii::app()->user->id, 'hash' => Yii::app()->user->id.'.003'.$order['id'], 'date' => time()));

						//Вставляем инвойс
						$connection->createCommand()->insert('{{users_invoice}}', array('uid' => Yii::app()->user->id, 'tuid' => $good['uid'], 'cuid' => $good['uid'], 'amount' => $amount, 'description' => 'Оплата за покупку товара.', 'date' => time(), 'data' => $order['id'], 'type' => 2, 'status' => 1, 'action' => 21, 'hash' => Yii::app()->user->id.'.'.time()));
						$invoice = $connection->getLastInsertID();

						//Вставляем транзакцию мне
						$connection->createCommand()->insert('{{utransactions2}}', array('did' => $good['gid'], 'uid' => Yii::app()->user->id, 'ruid' => $user_to["uid"], 'amount' => $amount, 'amount_now' => $wallet["cash_now"] - $amount, 'date' => time(), 'type' => 0, 'status' => 0, 'invoice' => $invoice, 'action' => 21));
						$utransactions1 = $connection->getLastInsertID();

						//Вставляем описание перевода мне
						$connection->createCommand()->insert('{{utransactions2_desc}}', array('tid' => $utransactions1, 'uid' => Yii::app()->user->id, 'touid' => $user_to["uid"], 'text' => 'Оплата за покупку товара.'));
						$connection->createCommand("UPDATE {{users_wallet}} SET cash_now = cash_now - :amount WHERE uid = :uid AND type = 1 AND status = 1;")
							->bindParam(":amount", $amount)
							->bindParam(":uid", Yii::app()->user->id)
							->query();

						$connection->createCommand("UPDATE {{orders}} SET order_pay = 1, status = 2 WHERE id = :id AND uid = :uid AND status = 1 AND order_pay = 0;")
							->bindParam(":id", $order['id'])
							->bindParam(":uid", Yii::app()->user->id)
							->query();

						$text_msg = 'Заказ №'.$order['id'].': пользователь оплатил товар "'. $good['title'] .'". Сумма оплаты '.$amount.' BP.';
						$connection->createCommand()->insert('{{messages}}', array('date' => time(), 'fuid' => 2, 'tuid' => $good['uid'], 'message' => $text_msg));

						$transaction->commit();
						//Позитивный результат
						$res["status"] = 200;
						$res["message"] = "Оплата товара на сумму в размере " . $amount . " BP прошла успешно";


					} catch (Exception $e) {
						$transaction->rollback();
						$res["status"] = 500;
						$res["message"] = "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
					}
				} else {
					//Хакерская атака - подмена данных
					$res["status"] = 500;
					$res["message"] = "<p>Вы не можете оплатить товар на сумму в размере " . $amount . " BP. Убедитесь в правильности заполненных полей и повторите попытку снова.</p>" . $err;
				}
			}else{
				$res["status"] = 500;
				$res["message"] = "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
			}

			$connection->createCommand("UPDATE {{users}} SET `lock` = 0 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	

	//get-wallet-my
	public function actionGetWalletsMy()
	{
		if (Yii::app()->request->isAjaxRequest) {
			$connection = Yii::app()->db;
			$res = array();

			if(!Yii::app()->user->isGuest) {
				$res["status"] = 200;

				//Кошельки
				$res["wallet"] = $connection->createCommand("SELECT id, uid, cash_now FROM {{users_wallet}} WHERE uid = :uid AND status = 1 AND type = 1")
					->bindParam(":uid", Yii::app()->user->id)
					->queryRow();
			} else {
				$res["status"] = 500;
				$res["message"] = "Просмотр данных временно запрещен.";
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	public function actionGetWallets()
	{
		if (Yii::app()->request->isAjaxRequest) {
			$connection = Yii::app()->db;
			$res = array();

			if(Yii::app()->user->id > 0) {
				$res["status"] = 200;
				
				//Потенциал
				$res["potential"] = doubleval($connection->createCommand("SELECT SUM(deposit) FROM {{users_potential}} WHERE uid = :uid AND status = 1 AND dt < dte AND type NOT IN (5)")
					->bindParam(":uid", Yii::app()->user->id)
					->queryScalar());
					
				$res["potential_archive"] = intval($connection->createCommand("SELECT SUM(deposit) FROM {{users_potential}} WHERE uid = :uid AND status = 1 AND dt < dte AND type=5")
					->bindParam(":uid", Yii::app()->user->id)
					->queryScalar());
					
				$res["potential_bonus"] = intval( ($res["potential"] * 0.003 + $res["potential_archive"] * 0.002) * 100) / 100;
				
				$res["potential_date_next"] = intval($connection->createCommand("SELECT date_next FROM {{users_potential_bonus}} WHERE uid = :uid ORDER BY id DESC LIMIT 1")
			    ->bindParam(":uid", Yii::app()->user->id)
				->queryScalar());
				
				//Кошельки
				$res["wallet"] = $connection->createCommand("SELECT * FROM {{users_wallet}} WHERE uid = :uid AND status = 1")
					->bindParam(":uid", Yii::app()->user->id)
					->queryAll();

				$res["date"] = time();
				
			} else {
				$res["status"] = 500;
				$res["message"] = "Просмотр данных временно запрещен.";
			}
			
			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	public function actionSetwalletpay()
	{
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			Functions::access_control(1);
			$connection = Yii::app()->db;
			$res = array();
			$err = '';

			//Входящие данные
			$amount = intval($_POST["amount"]);
			$email = mysql_escape_string(htmlspecialchars(strip_tags($_POST["email"])));
			$text = mysql_escape_string(htmlspecialchars(strip_tags($_POST["comment"])));

			//Блокировка файлом ===================
			$lock = $connection->createCommand("SELECT uid, `lock` FROM {{users}} WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->queryRow();
			if ($lock['lock'] == 0) {
				$connection->createCommand("UPDATE {{users}} SET `lock` = 1 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
			} else {
				$res["status"] = 500;
				$res["message"] = "Идет обработка Вашего запроса. Обновите страницу через несколько минут и повторите попытку снова.";
				echo CJSON::encode($res);
				Yii::app()->end();
			}//Блокировка файлом ===================

			$err = "";

			//Наш кошелек
			$wallet = $connection->createCommand("SELECT * FROM {{users_wallet}} WHERE uid = :uid AND type = 1 AND status = 1")->bindParam(":uid", Yii::app()->user->id)->queryRow();
			$my = $connection->createCommand("SELECT uid, CONCAT(name, ' ', fio) as 'fio' FROM {{usersinfo}} WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->queryRow();

			//Информация получателя
			$user_to = $connection->createCommand("SELECT uid, CONCAT(name, ' ', fio) as 'fio' FROM {{usersinfo}} WHERE email = :email AND status = 1")->bindParam(":email", $email)->queryRow();
			$wallet_to = $connection->createCommand("SELECT * FROM {{users_wallet}} WHERE uid = :uid AND type = 1 AND status = 1")->bindParam(":uid", $user_to["uid"])->queryRow();

			if ((empty($user_to)) || (empty($wallet_to))) {
				$err .= "<p>Данного пользователя не существует.</p>";
			}
			if (($wallet['cash_now'] < $amount) && ($amount <= 0)) {
				$err .= "<p>Неправильная сумма перевода.</p>";
			}
			if ((empty($wallet)) || (Yii::app()->user->id == 0)) {
				$err .= "<p>Вы не можете отправить перевод. Обновите стрницу и повторите попытку снова.</p>";
			}
			
			$err = "<p>Возможность доступна только для сертифицированных продавцов.</p>";

			if ((!empty($wallet)) && (!empty($wallet_to)) && (!empty($user_to)) && ($user_to["uid"] == $wallet_to["uid"]) && (Yii::app()->user->id != $wallet_to["uid"]) && ($wallet["cash_now"] > 0) && ($wallet["cash_now"] >= $amount) && ($amount > 0) && (Yii::app()->user->id > 0) && ($err == "")) {

				$transaction = $connection->beginTransaction();
				try {
					//Вставляем инвойс
					$connection->createCommand()->insert('{{users_invoice}}', array('uid' => Yii::app()->user->id, 'tuid' => $user_to['uid'], 'cuid' => Yii::app()->user->id, 'amount' => $amount, 'description' => $text, 'date' => time(), 'data' => 0, 'type' => 1, 'status' => 1, 'action' => 11, 'hash' => Yii::app()->user->id.'.'.time()));
					$invoice = $connection->getLastInsertID();

					//Вставляем транзакцию мне
					$connection->createCommand()->insert('{{utransactions2}}', array('did' => 0, 'uid' => Yii::app()->user->id, 'ruid' => $user_to["uid"], 'amount' => $amount, 'amount_now' => $wallet["cash_now"] - $amount, 'date' => time(), 'type' => 0, 'status' => 1, 'invoice' => $invoice, 'action' => 11));
					$utransactions1 = $connection->getLastInsertID();

					//Вставляем транзакцию адрессату
					$connection->createCommand()->insert('{{utransactions2}}', array('did' => 0, 'uid' => $user_to["uid"], 'ruid' => Yii::app()->user->id, 'amount' => $amount, 'amount_now' => $wallet_to["cash_now"] + $amount, 'date' => time(), 'type' => 1, 'status' => 1, 'invoice' => $invoice, 'action' => 11));
					$utransactions2 = $connection->getLastInsertID();

					//Вставляем описание перевода мне
					$connection->createCommand()->insert('{{utransactions2_desc}}', array('tid' => $utransactions1, 'uid' => Yii::app()->user->id, 'touid' => $user_to["uid"], 'text' => $text));

					//Вставляем описание перевода адрессату
					$connection->createCommand()->insert('{{utransactions2_desc}}', array('tid' => $utransactions2, 'uid' => Yii::app()->user->id, 'touid' => $user_to["uid"], 'text' => $text));

					//Сообщение адрессату о том что получены деньги
					$text_msg = "Ваш активный бонус пополнен на сумму " . $amount . " BP от пользователя " . $my["fio"] . ".Назначение перевода: " . $text . ".";
					$connection->createCommand()->insert('{{messages}}', array('date' => time(), 'fuid' => 2, 'tuid' => $user_to['uid'], 'message' => $text_msg));

					$connection->createCommand("UPDATE {{users_wallet}} SET cash_now = cash_now - :amount WHERE uid = :uid AND type = 1 AND status = 1; UPDATE {{users_wallet}} SET cash_now = cash_now + :amount WHERE uid = :touid AND type = 1 AND status = 1")
						->bindParam(":amount", $amount)
						->bindParam(":uid", Yii::app()->user->id)
						->bindParam(":touid", $user_to["uid"])
						->query();

					$transaction->commit();
					//Позитивный результат
					$res["status"] = 200;
					$res["message"] = "Сумма в размере " . $amount . " BP успешно переведена пользователю " . $user_to["fio"] . ".";
				} catch (Exception $e) {
					$transaction->rollback();
					$res["status"] = 500;
					$res["message"] = "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
				}

			} else {
				//Хакерская атака - подмена данных
				$res["status"] = 500;
				$res["message"] = "<p>Вы не можете отправить сумму в размере " . $amount . " BP пользователю " . $email . ". Убедитесь в правильности заполненных полей и повторите попытку снова.</p>" . $err;
			}

			$connection->createCommand("UPDATE {{users}} SET `lock` = 0 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
			echo CJSON::encode($res);
			Yii::app()->end();

		}
	}
	
	
public function actionSetWalletBonusActivate()
	{
			
	if (Yii::app()->request->isAjaxRequest) {
		Functions::access_control(1);
	        $connection=Yii::app()->db;
	
		    /*$res["status"] = 500;
		    $a = serialize($_POST);
		    $res["message"] = $a;
			echo CJSON::encode($res);
			Yii::app()->end();*/
			
	        //Блокировка файлом ===================
	         $lock = $connection->createCommand("SELECT uid, `lock` FROM {{users}} WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->queryRow();
	         if ($lock['lock'] == 0) {
	         $connection->createCommand("UPDATE {{users}} SET `lock` = 1 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
	         } else { 
	         $res["status"] = 500;
	         $res["message"] = "Идет обработка Вашего запроса. Обновите страницу через несколько минут и повторите попытку снова.";
	         echo CJSON::encode($res);
	         Yii::app()->end();
	         }//Блокировка файлом ===================
	        
	        
	        $err = "";
	
	        $today =  mktime(00, 00, 00, date("m"), date("d"), date("Y"));
			
			$is_today = $connection->createCommand("SELECT id FROM {{users_potential_bonus}} WHERE uid = :uid AND date = :date")
	            ->bindParam(":uid", Yii::app()->user->id)
	            ->bindParam(":date", $today)
	            ->queryRow();
	            
	        if(!empty($is_today)) {
			    $res["status"] = 500;
				$res["message"] = "Вы уже активировали сегодня бонусы.";
				$connection->createCommand("UPDATE {{users}} SET `lock` = 0 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
		        echo CJSON::encode($res);
		        Yii::app()->end();    
	        }
			
			$is_potential = $connection->createCommand("SELECT deposit FROM {{users_potential}} WHERE uid = :uid")
	            ->bindParam(":uid", Yii::app()->user->id)
	            ->queryRow();
						
			$last = $connection->createCommand("SELECT * FROM {{users_potential_bonus}} WHERE uid = :uid ORDER BY id DESC LIMIT 1")
			    ->bindParam(":uid", Yii::app()->user->id)
				->queryRow();
				
			$amount = $connection->createCommand("SELECT SUM(deposit*percent) FROM {{users_potential}} WHERE uid = :uid AND status = 1 AND dt < dte")
					->bindParam(":uid", Yii::app()->user->id)
					->queryScalar();
					
			$wallet = $connection->createCommand("SELECT id, cash_now  FROM {{users_wallet}} WHERE uid = :uid AND type = 1 AND status = 1")
	            ->bindParam(":uid", Yii::app()->user->id)
	            ->queryRow();
						
			if($last["date"] == $today)
			 	$err = "<li>Вы уже активировали сегодня бонусы.</li>";
			
			if(time() < $last["date_next"])
				$err = "<li>Активируйте Ваш бонус по окончанию таймера.</li>";

							
			if($is_potential["deposit"] == 0) 
				$err = "<li>У Вас нулевой потенциал. Активация бонусов недоступна.</li>";
			
			if($last["date"] > $today)
			 	$err = "<li>Сервер временно недоступен. Обновите страницу и повторите попытку снова.</li>";
			
			if($amount <= 0)
				$err .= "<li>Недостаточная сумма для начисления бонуса.</li>";
			
			if(empty($wallet)) 
				$err .= "<li>Активные бонусы временно недоступны.</li>";
			
		    if ((Yii::app()->user->id > 0) && ($err == "")) {

			    $transaction = $connection->beginTransaction();
			    try {
				   
				   $code = Yii::app()->user->id . "." . $today;

				   $amount_bouns = intval($amount * 100) / 100;
				   $date_next = time() + 86400; //Время заморозки активации 1 день
				   
				   $connection->createCommand()->insert('{{users_potential_bonus}}', array('uid' => Yii::app()->user->id, 'date' => $today, 'date_now' => time(), 'date_next' => $date_next, 'amount' => $amount_bouns, 'code' => $code));
				   
				   $connection->createCommand("UPDATE {{users_wallet}} SET cash_now = cash_now + :money WHERE type = 1 AND status = 1 AND uid = :uid AND id = :id")
				   		->bindParam(":id", $wallet["id"])
				   		->bindParam(":uid", Yii::app()->user->id)
				   		->bindParam(":money", $amount_bouns)
						->query();
						
					$connection->createCommand("UPDATE {{users_potential}} SET cash_now = cash_now + :money, dt = dt + 1 WHERE status = 1 AND uid = :uid AND dt < dte")
				   		->bindParam(":uid", Yii::app()->user->id)
				   		->bindParam(":money", $amount_bouns)
						->query();
						
					//Вставляем транзакцию
					$connection->createCommand()->insert('{{utransactions2}}', array('did' => 0, 'uid' => Yii::app()->user->id, 'ruid' => Yii::app()->user->id, 'amount' => $amount_bouns, 'amount_now' => $wallet["cash_now"] + $amount_bouns, 'date' => time(), 'type' => 1, 'status' => 1, 'action' => 31));
				   
				    $transaction->commit();
				    //Позитивный результат
				    $res["status"] = 200;
				    $res["message"] = "Активация $amount_bouns BP прошла успешно.";
			    } catch (Exception $e) {
				    $transaction->rollback();
				    $res["status"] = 500;
				    $res["message"] = "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
				    $connection->createCommand("UPDATE {{users}} SET `lock` = 0 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
			    }

		    } else {
			    //Хакерская атака - подмена данных
			    $res["status"] = 500;
			    $res["message"] = "Возникла ошибка при начислении средств." . $err;
		    }
	
	        $connection->createCommand("UPDATE {{users}} SET `lock` = 0 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
	        echo CJSON::encode($res);
	        Yii::app()->end();
	   }
	
	}
	
	
	
	//get-wallet-money
	public function actionGetWalletMoney()
	{
		$connection=Yii::app()->db;
		$users = $connection->createCommand("SELECT uid FROM {{users}}")
			->queryAll();
		if(Yii::app()->user->id == 1) {
		foreach($users as $val) {
			
			echo $val["uid"] . "<br>";
			
			/*$hash1 = $val["uid"] . "-" . 1;
			$connection->createCommand()->insert('{{users_wallet}}', array('uid' => $val["uid"], 'puid' => 0, 'fuid' => 0, 'date' => time(), 'cash_now' => 0, 'cash_out' => 0, 'cash_all' => 0, 'cash_percent' => 0, 'quotas' => 0, 'quotas_once' => 0, 'type' => 1, 'status' => 1, 'cerrency' => 'BP', 'hash' => $hash1));
			
			$hash2 = $val["uid"] . "-" . 2;
			$connection->createCommand()->insert('{{users_wallet}}', array('uid' => $val["uid"], 'puid' => 0, 'fuid' => 0, 'date' => time(), 'cash_now' => 0, 'cash_out' => 0, 'cash_all' => 0, 'cash_percent' => 0, 'quotas' => 0, 'quotas_once' => 0, 'type' => 2, 'status' => 1, 'cerrency' => 'BP', 'hash' => $hash2));
			
			$hash3 = $val["uid"] . "-" . 3;
			$connection->createCommand()->insert('{{users_wallet}}', array('uid' => $val["uid"], 'puid' => 0, 'fuid' => 0, 'date' => time(), 'cash_now' => 0, 'cash_out' => 0, 'cash_all' => 0, 'cash_percent' => 0, 'quotas' => 0, 'quotas_once' => 0, 'type' => 3, 'status' => 1, 'cerrency' => 'BP', 'hash' => $hash3));
			
			$hash4 = $val["uid"] . "-" . 4;
			$connection->createCommand()->insert('{{users_wallet}}', array('uid' => $val["uid"], 'puid' => 0, 'fuid' => 0, 'date' => time(), 'cash_now' => 0, 'cash_out' => 0, 'cash_all' => 0, 'cash_percent' => 0, 'quotas' => 0, 'quotas_once' => 0, 'type' => 4, 'status' => 0, 'cerrency' => 'BP', 'hash' => $hash4));
			
			$hash5 = $val["uid"] . "-" . 5;
			$connection->createCommand()->insert('{{users_wallet}}', array('uid' => $val["uid"], 'puid' => 0, 'fuid' => 0, 'date' => time(), 'cash_now' => 0, 'cash_out' => 0, 'cash_all' => 0, 'cash_percent' => 0, 'quotas' => 0, 'quotas_once' => 0, 'type' => 5, 'status' => 0, 'cerrency' => 'BP', 'hash' => $hash5));
			
			
			$connection->createCommand()->insert('{{users_potential}}', array('uid' => $val["uid"], 'cuid' => 0, 'puid' => 0, 'date' => time(), 'dt' => 0, 'dte' => 333, 'deposit' => 0, 'percent' => 0.003, 'cash_now' => 0, 'cash_out' => 0, 'cash_all' => 0, 'type' => 1, 'status' => '1'));
			*/
			
		}
		
		} //if

		
	}
	
	
	
	
	public function actionSetbonussendactive()
	{

		if (Yii::app()->request->isAjaxRequest) {
			Functions::access_control(1);
			$connection=Yii::app()->db;

			//Блокировка файлом ===================
			$lock = $connection->createCommand("SELECT uid, `lock` FROM {{users}} WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->queryRow();
			if ($lock['lock'] == 0) {
				$connection->createCommand("UPDATE {{users}} SET `lock` = 1 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
			} else {
				$res["status"] = 500;
				$res["message"] = "Идет обработка Вашего запроса. Обновите страницу через несколько минут и повторите попытку снова.";
				echo CJSON::encode($res);
				Yii::app()->end();
			}//Блокировка файлом ===================

			
			$err = "";

			$today =  mktime(00, 00, 00, date("m"), date("d"), date("Y"));

			$is_today = $connection->createCommand("SELECT id FROM {{users_wallet_bonus}} WHERE uid = :uid AND date = :today")
				->bindParam(":uid", Yii::app()->user->id)
				->bindParam(":today", $today)
				->queryRow();

			if(!empty($is_today)) {
				$res["status"] = 500;
				$res["message"] = "Перевод призовых бонусов доступен один раз в день.";
				$connection->createCommand("UPDATE {{users}} SET `lock` = 0 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
				echo CJSON::encode($res);
				Yii::app()->end();
			}

			$wallet_prise = $connection->createCommand("SELECT id, cash_now  FROM {{users_wallet}} WHERE uid = :uid AND type = 3 AND status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->queryRow();

			$wallet_active = $connection->createCommand("SELECT id, cash_now  FROM {{users_wallet}} WHERE uid = :uid AND type = 1 AND status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->queryRow();

			
			$wallet_prise['cash_now'] = intval($wallet_prise['cash_now'] * 100) / 100;
			$amount = $wallet_prise['cash_now'];

			if(empty($wallet_prise) || empty($wallet_active))
				$err .= "<li>Призовые бонусы временно недоступны.</li>";

			if($amount <= 0)
				$err .= "<li>Недостаточная сумма для перевода.</li>";

			if ((Yii::app()->user->id > 0) && ($err == "")) {

				$transaction = $connection->beginTransaction();
				try {

					$connection->createCommand()->insert('{{users_wallet_bonus}}', array(
						'uid' => Yii::app()->user->id,
						'wid' => $wallet_prise['id'],
						'date' => $today,
						'amount' => $wallet_prise['cash_now'],
						'hash' => Yii::app()->user->id . "." . $today
					));

					$connection->createCommand("UPDATE {{users_wallet}} SET cash_now = cash_now + :money WHERE type = 1 AND status = 1 AND uid = :uid AND id = :id")
						->bindParam(":id", $wallet_active["id"])
						->bindParam(":uid", Yii::app()->user->id)
						->bindParam(":money", $wallet_prise['cash_now'])
						->query();

					$connection->createCommand("UPDATE {{users_wallet}} SET cash_all = cash_all + cash_now, cash_now = cash_now - :money WHERE type = 3 AND status = 1 AND uid = :uid AND id = :id")
						->bindParam(":id", $wallet_prise["id"])
						->bindParam(":uid", Yii::app()->user->id)
						->bindParam(":money", $wallet_prise['cash_now'])
						->query();

					//Вставляем транзакцию
					$connection->createCommand()->insert('{{utransactions2}}', array('did' => 0, 'uid' => Yii::app()->user->id, 'ruid' => Yii::app()->user->id, 'amount' => $wallet_prise["cash_now"], 'amount_now' => $wallet_active["cash_now"] + $wallet_prise["cash_now"], 'date' => time(), 'type' => 1, 'status' => 1, 'action' => 32));

					$transaction->commit();
					//Позитивный результат
					$res["status"] = 200;
					$res["message"] = "Перевод " .$wallet_prise['cash_now']. " BP  призовых бонусов в активные прошел успешно.";
				} catch (Exception $e) {
					$transaction->rollback();
					$res["status"] = 500;
					$res["message"] = "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
					$connection->createCommand("UPDATE {{users}} SET `lock` = 0 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
				}

			} else {
				//Хакерская атака - подмена данных
				$res["status"] = 500;
				$res["message"] = "Возникла ошибка при переводе." . $err;
			}

			$connection->createCommand("UPDATE {{users}} SET `lock` = 0 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
			echo CJSON::encode($res);
			Yii::app()->end();
		}

	}
	
	
	
	// Получить архивные бонусы
	public function actionGetArchiveBonus()
	{
		if (Yii::app()->request->isAjaxRequest) {
			$connection = Yii::app()->db;
			$res = array();

			if(Yii::app()->user->id > 0) {
				$res["status"] = 200;

				$res["bonuses"] = $connection->createCommand("SELECT id, FROM_UNIXTIME(date, '%d/%m/%Y') AS date, uid, amount FROM {{users_potential_archive}} WHERE uid = :uid AND status = 0 ORDER BY date DESC")
					->bindParam(":uid", Yii::app()->user->id)
					->queryAll();

			} else {
				$res["status"] = 500;
				$res["message"] = "Просмотр данных временно запрещен.";
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	
	
	// Получить архивные бонусы
	public function actionGetArchiveBonusNew()
	{
		if (Yii::app()->request->isAjaxRequest) {
			$connection = Yii::app()->db;
			$res = array();

			if(Yii::app()->user->id > 0) {
				$res["status"] = 200;

				$res["bonuses"] = $connection->createCommand("SELECT id, FROM_UNIXTIME(date, '%d/%m/%Y') AS date, uid, amount FROM {{users_potential_archive}} WHERE uid = :uid AND status = 0 ORDER BY date DESC")
					->bindParam(":uid", Yii::app()->user->id)
					->queryAll();
					
				$res["bonuses_sum"] = doubleval($connection->createCommand("SELECT SUM(amount) FROM {{users_potential_archive}} WHERE uid = :uid AND status = 0 AND date >= 1477958400")
					->bindParam(":uid", Yii::app()->user->id)
					->queryScalar());
					
				$res["bonuses_sum2"] = doubleval($connection->createCommand("SELECT SUM(amount) FROM {{users_potential_archive}} WHERE uid = :uid AND status = 0 AND date < 1477958400")
					->bindParam(":uid", Yii::app()->user->id)
					->queryScalar());
					
				$bonus_amount = 0;
				$promo = 0;
				$amount = $res["bonuses_sum"];
				$tr = 0;
				
				if($amount >= 0 && $amount < 250) {
					$promo = 0;
					$tr = 1;
				} else if ($amount >= 250 && $amount < 500) {
					$promo = 0.1;
					$tr = 2;
				} else if ($amount >= 500 && $amount < 1000) {
					$promo = 0.2;
					$tr = 3;
				} else if ($amount >= 1000 && $amount < 2500) {
					$promo = 0.3;
					$tr = 4;
				} else if ($amount >= 2500 && $amount < 5000) {
					$promo = 0.4;
					$tr = 5;
				} else if ($amount >= 5000 && $amount < 10000) {
					$promo = 0.5;
					$tr = 6;
				} else if ($amount >= 10000 && $amount < 25000) {
					$promo = 0.6;
					$tr = 7;
				} else if ($amount >= 25000 && $amount < 50000) {
					$promo = 0.7;
					$tr = 8;
				} else if ($amount >= 50000 && $amount < 100000) {
					$promo = 0.8;
					$tr = 9;
				} else if ($amount >= 100000 && $amount < 250000) {
					$promo = 0.9;
					$tr = 10;
				} else if ($amount >= 250000) {
					$promo = 1;
					$tr = 11;
				}
				
				$res["bonuses_percent"] = $promo * 100;
				$res["bonuses_sum_bonus"] = intval($amount * $promo * 100) / 100;
				$res["bonuses_sum_all"] = $res["bonuses_sum"] + $res["bonuses_sum_bonus"] + $res["bonuses_sum2"];
				$res["bonuses_row"] = $tr;

			} else {
				$res["status"] = 500;
				$res["message"] = "Просмотр данных временно запрещен.";
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	
	// Отказ от архивного бонуса
	public function actionSetArchiveBonusCancel(){

		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			Functions::access_control(1);
			$res = array();
			$connection = Yii::app()->db;
			$err = '';

			$id = intval($_POST["id"]);

			$bonus = $connection->createCommand("SELECT * FROM {{users_potential_archive}} WHERE uid = :uid AND id = :id AND status = 0")
				->bindParam(":uid", Yii::app()->user->id)
				->bindParam(":id", $id)
				->queryRow();

			if(empty($bonus)){
				$err .= '<li>Сервер временно недоступен.</li>';
			}

			if (Yii::app()->user->id > 0 && $err == '') {

				$connection->createCommand("UPDATE {{users_potential_archive}} SET status = 2 WHERE uid = :uid AND id = :id AND status = 0")
					->bindParam(":uid", Yii::app()->user->id)
					->bindParam(":id", $id)
					->query();

				$res["status"] = 200;
				$res["message"] = 'Бонус успешно отменен.';
			} else {
				$res["status"] = 500;
				$res["message"] = $err;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}

	
	public function actionGetWalletsPotential()
	{
		if (Yii::app()->request->isAjaxRequest) {
			$connection = Yii::app()->db;
			$res = array();

			if(Yii::app()->user->id > 0) {
				$res["status"] = 200;
				
				//Потенциал
				$res["potential"] = doubleval($connection->createCommand("SELECT SUM(deposit) FROM {{users_potential}} WHERE uid = :uid AND status = 1 AND dt < dte")
					->bindParam(":uid", Yii::app()->user->id)
					->queryScalar());
	
				$res["potential_podarok"] = doubleval($connection->createCommand("SELECT SUM(deposit) FROM {{users_potential}} WHERE uid = :uid AND status = 1 AND dt < dte AND type=3")
					->bindParam(":uid", Yii::app()->user->id)
					->queryScalar());
					
					
				$res["potential_archive"] = doubleval($connection->createCommand("SELECT SUM(deposit) FROM {{users_potential}} WHERE uid = :uid AND status = 1 AND dt < dte AND type=5")
					->bindParam(":uid", Yii::app()->user->id)
					->queryScalar());
				
				$res["potential_cashback_real"] = doubleval($connection->createCommand("SELECT SUM(cb_amount) FROM {{goods_cashback}} WHERE uid = :uid AND status = 1")
					->bindParam(":uid", Yii::app()->user->id)
					->queryScalar());
					
				
				$res["potential_cashback"] = $res["potential_cashback_real"];/*doubleval($connection->createCommand("SELECT SUM(deposit) FROM {{users_potential}} WHERE uid = :uid AND status = 1 AND dt < dte AND type=4")
					->bindParam(":uid", Yii::app()->user->id)
					->queryScalar());	*/
					
					
				$res["potential_in"] = doubleval($connection->createCommand("SELECT SUM(deposit) FROM {{users_potential}} WHERE uid = :uid AND status = 1 AND dt < dte AND type = 1")
					->bindParam(":uid", Yii::app()->user->id)
					->queryScalar() +
					
					$connection->createCommand("SELECT SUM(deposit) FROM {{users_potential}} WHERE uid = :uid AND status = 1 AND dt < dte AND type=4")
					->bindParam(":uid", Yii::app()->user->id)
					->queryScalar() -
					
					$res["potential_cashback"]
					
					);
					
				$res["potential_bonus"] = intval( $connection->createCommand("SELECT SUM(deposit*percent) FROM {{users_potential}} WHERE uid = :uid AND status = 1 AND dt < dte")
					->bindParam(":uid", Yii::app()->user->id)
					->queryScalar() * 100) / 100;
				
				$res["potential_date_next"] = intval($connection->createCommand("SELECT date_next FROM {{users_potential_bonus}} WHERE uid = :uid ORDER BY id DESC LIMIT 1")
			    ->bindParam(":uid", Yii::app()->user->id)
				->queryScalar());
				
				//Кошельки
				$res["wallet_active"] = doubleval($connection->createCommand("SELECT cash_now FROM {{users_wallet}} WHERE uid = :uid AND type = 1 AND status = 1")
					->bindParam(":uid", Yii::app()->user->id)
					->queryScalar());
					
				$res["wallet_structure"] = doubleval($connection->createCommand("SELECT cash_now FROM {{users_wallet}} WHERE uid = :uid AND type = 3 AND status = 1")
					->bindParam(":uid", Yii::app()->user->id)
					->queryScalar());
					
					
				$res["wallet_instant"] = doubleval($connection->createCommand("SELECT cash_now FROM {{users_wallet}} WHERE uid = :uid AND type = 5")
					->bindParam(":uid", Yii::app()->user->id)
					->queryScalar());
				
				
					
				$res["wallet"] = $res["wallet_active"] + $res["wallet_structure"];
				

				$res["date"] = time();
				
			} else {
				$res["status"] = 500;
				$res["message"] = "Просмотр данных временно запрещен.";
			}
			
			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	
	
	// Активация архивный бонус
	public function actionSetArchiveBonusActivate(){
		
		//if(Yii::app()->user->id !=) {
		
			$res["status"] = 500;
			$res["message"] = "Возможность активации вскоре будет доступна.";
			echo CJSON::encode($res);
			Yii::app()->end();
		
		//}
		
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			Functions::access_control(1);
			$res = array();
			$connection = Yii::app()->db;
			$err = '';

			$courses = [
				'uah' => 25.3000,
				'rub' => 68.3703,
				'eur' => 0.9000,
				'crt' => 0.1262,
				'mdl' => 25.3000,
				'kzt' => 329.9241,
				'pln' => 3.8661
			];

			$id = intval($_POST["id"]);
			$code = mysql_escape_string(htmlspecialchars(strip_tags($_POST['code'])));

			$bonus = $connection->createCommand("SELECT * FROM {{users_potential_archive}} WHERE uid = :uid AND id = :id AND status = 0")
				->bindParam(":uid", Yii::app()->user->id)
				->bindParam(":id", $id)
				->queryRow();

			$my = $connection->createCommand("SELECT uid, email FROM {{usersinfo}} WHERE uid = :uid")
				->bindParam(":uid", Yii::app()->user->id)
				->queryRow();


			if(empty($bonus)){
				$err .= '<li>Сервер временно недоступен.</li>';
			}
			if(empty($my)){
				$err .= '<li>Пользователь не найден.</li>';
			}
			if(!in_array($code, ['CRT', 'EUR', 'USD', 'UAH', 'RUB', 'KZT', 'MDL', 'PLN'])){
				$err .= '<li>Выберите кошелек с которого произойдет списание ЕК.</li>';
			}

			if (Yii::app()->user->id > 0 && $err == '') {

				// Рассчитаем курс
				$bonus_amount = $bonus['amount'];
				$course = 1;

				switch ($code) {
					case 'USD': {
						$course = 1;
						break;
					}
					case 'UAH':
					case 'KZT':
					case 'MDL':
					case 'PLN':
					case 'RUB':
					case 'EUR':
					case 'CRT':{
						$course = intval($courses[strtolower($code)] * 100) / 100;
						$bonus_amount = intval($course * $bonus['amount'] * 100) / 100;
						break;
					}
				}

				// Отправляем запрос на сервер Архива Меркурия
				$pass = Yii::app()->params['bonus_pass'];
				$encrypt = new Encryption();
				$host = 'http://f01-ams.arch.yttm.work/crt/activatebonusbokobok';
				$datetime = time();
				
				$from_amount = $encrypt->encode($bonus['amount']);
				$to_amount = $encrypt->encode($bonus_amount);
				$from_currency = $encrypt->encode('USD');
				$to_currency = $encrypt->encode($code);
				$email = $encrypt->encode($my['email']);
				$course = $encrypt->encode($course);
				$date = $encrypt->encode($datetime);

				$data = array(
					'from_amount' => $from_amount,
					'to_amount' => $to_amount,
					'from_currency' => $from_currency,
					'to_currency' => $to_currency,
					'email' => $email,
					'course' => $course,
					'date' => $date,
					'signature' => sha1(md5($from_amount . $to_amount . $from_currency . $to_currency . $email . $course . $date . $pass))
				);

				$ch = curl_init();
				curl_setopt($ch, CURLOPT_URL, $host);
				curl_setopt($ch, CURLOPT_POST, 1);
				curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($data));
				curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
				curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
				curl_setopt($ch, CURLOPT_USERAGENT, "Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.16 (KHTML, like Gecko) Chrome/10.0.648.204 Safari/534.16");
				curl_setopt($ch, CURLOPT_REFERER, $host);

				$result = curl_exec($ch);
				curl_close($ch);

				$results = json_decode($result, true);

				if (!empty($results['status']) && $results['status'] == 200) {

					$transaction = $connection->beginTransaction();
					try {

						$connection->createCommand()->insert('{{users_potential_archive_ok}}', array(
							'uid' => Yii::app()->user->id,
							'aid' => $bonus['id'],
							'gid' => $bonus["gid"],
							'pid' => $bonus["pid"],
							'date' => time(),
							'status' => 1
						));
						$archive_ok_id = Yii::app()->db->getLastInsertID();

						$connection->createCommand()->insert('{{users_potential}}', array(
							'gid' => 0,
							'uid' => Yii::app()->user->id,
							'cuid' => Yii::app()->user->id,
							'puid' => 0,
							'fuid' => 0,
							'date' => time(),
							'dt' => 0,
							'dte' => 500,
							'deposit' => $bonus["amount"],
							'percent' => 0.002,
							'cash_now' => 0,
							'cash_out' => 0,
							'cash_all' => 0,
							'type' => 5,
							'status' => 1
						));
						$pid_id = Yii::app()->db->getLastInsertID();

						$connection->createCommand("UPDATE {{users_potential_archive}} SET status = 1 WHERE uid = :uid AND id = :id AND status = 0")
							->bindParam(":uid", Yii::app()->user->id)
							->bindParam(":id", $id)
							->query();

//						$connection->createCommand("UPDATE {{users_potential_group}} SET percent = 0.002 WHERE id = :gid")
//							->bindParam(":gid", $bonus["gid"])
//							->query();

						

						$res["status"] = 200;
						$res["message"] = $results['message'];

						$transaction->commit();

					} catch (Exception $e) {
						$transaction->rollback();
						$res["message"] = $e . "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
					}

				} else {
					$res["status"] = 500;
					$res["message"] = $results['message'];
				}
			} else {
				$res["status"] = 500;
				$res["message"] = $err;
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	
	// Активация архивный бонус
	public function actionSetArchiveBonusActivateAllNew(){
		
		/*if(Yii::app()->user->id != 3) {
		
		$res["status"] = 500;
		$res["message"] = "Возможность активации вскоре будет доступна.";
		echo CJSON::encode($res);
		Yii::app()->end();
		
		}*/
		
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			Functions::access_control(1);
			$res = array();
			$connection = Yii::app()->db;
			$err = '';
			
			
			//##################################################################
			$db_transaction = $connection->beginTransaction();
			try {
				$connection->createCommand()->insert('{{block}}', array(
					'uid' => Yii::app()->user->id,
					'date' => time()
				));
						
				$db_transaction->commit();
	
			} catch (Exception $e) {
				$db_transaction->rollback();
				$res["message"] = "Идет обработка предыдущего запроса. Обновите страницу и повторите попытку снова.";
				echo CJSON::encode($res);
				Yii::app()->end();

			}
			//##################################################################
			
			

			$courses = [
				'uah' => 25.3000,
				'rub' => 68.3703,
				'eur' => 0.9000,
				'crt' => 0.1262,
				'mdl' => 25.3000,
				'kzt' => 329.9241,
				'pln' => 3.8661
			];

			$id = intval($_POST["id"]);
			$code = mysql_escape_string(htmlspecialchars(strip_tags($_POST['code'])));

			$bonus = $connection->createCommand("SELECT * FROM {{users_potential_archive}} WHERE uid = :uid AND id = :id AND status = 0")
				->bindParam(":uid", Yii::app()->user->id)
				->bindParam(":id", $id)
				->queryRow();

			$my = $connection->createCommand("SELECT uid, email FROM {{usersinfo}} WHERE uid = :uid")
				->bindParam(":uid", Yii::app()->user->id)
				->queryRow();
			
			$bonus_sum = doubleval($connection->createCommand("SELECT SUM(amount) FROM {{users_potential_archive}} WHERE uid = :uid AND status = 0 AND date >= 1477958400")
				->bindParam(":uid", Yii::app()->user->id)
				->queryScalar());
				
			$bonus_sum_last = doubleval($connection->createCommand("SELECT SUM(amount) FROM {{users_potential_archive}} WHERE uid = :uid AND status = 0 AND date < 1477958400")
				->bindParam(":uid", Yii::app()->user->id)
				->queryScalar());
				
			
			$bonuses =  $connection->createCommand("SELECT id FROM {{users_potential_archive}} WHERE uid = :uid AND status = 0")
				->bindParam(":uid", Yii::app()->user->id)
				->queryAll();
				
			//Вычисляем новые надбавки
				
			$amount = $bonus_sum;
						
			$promo = 0;
			if($amount >= 0 && $amount < 250) {
				$promo = 0;
				$tr = 1;
			} else if ($amount >= 250 && $amount < 500) {
				$promo = 0.1;
				$tr = 2;
			} else if ($amount >= 500 && $amount < 1000) {
				$promo = 0.2;
				$tr = 3;
			} else if ($amount >= 1000 && $amount < 2500) {
				$promo = 0.3;
				$tr = 4;
			} else if ($amount >= 2500 && $amount < 5000) {
				$promo = 0.4;
				$tr = 5;
			} else if ($amount >= 5000 && $amount < 10000) {
				$promo = 0.5;
				$tr = 6;
			} else if ($amount >= 10000 && $amount < 25000) {
				$promo = 0.6;
				$tr = 7;
			} else if ($amount >= 25000 && $amount < 50000) {
				$promo = 0.7;
				$tr = 8;
			} else if ($amount >= 50000 && $amount < 100000) {
				$promo = 0.8;
				$tr = 9;
			} else if ($amount >= 100000 && $amount < 250000) {
				$promo = 0.9;
				$tr = 10;
			} else if ($amount >= 250000) {
				$promo = 1;
				$tr = 11;
			}
			
			$amount_bonus = $amount * $promo;
			$amount_percent = $promo;
			
			$amount_all = $bonus_sum + $bonus_sum_last + $amount_bonus;	
			
			if($amount_all <= 0) {
				$err .= '<li>Недостаточная сумма для проведения активации.</li>';
			}
			
			
			if(empty($my)){
				$err .= '<li>Пользователь не найден.</li>';
			}
			if(!in_array($code, ['CRT', 'EUR', 'USD', 'UAH', 'RUB', 'KZT', 'MDL', 'PLN'])){
				$err .= '<li>Выберите кошелек с которого произойдет списание ЕК.</li>';
			}

			if (Yii::app()->user->id > 0 && $err == '') {

				// Рассчитаем курс
				$bonus_amount = $bonus_sum;
				$course = 1;

				switch ($code) {
					case 'USD': {
						$course = 1;
						break;
					}
					case 'UAH':
					case 'KZT':
					case 'MDL':
					case 'PLN':
					case 'RUB':
					case 'EUR':
					case 'CRT':{
						$course = intval($courses[strtolower($code)] * 100) / 100;
						$bonus_amount = intval($course * $amount_all * 100) / 100;
						break;
					}
				}

				// Отправляем запрос на сервер Архива Меркурия
				$pass = Yii::app()->params['bonus_pass'];
				$encrypt = new Encryption();
				$host = 'http://f01-ams.arch.yttm.work/crt/activatebonusbokobok';
				$datetime = time();
				
				$from_amount = $encrypt->encode($bonus_amount);
				$to_amount = $encrypt->encode($bonus_amount);
				$from_currency = $encrypt->encode('USD');
				$to_currency = $encrypt->encode($code);
				$email = $encrypt->encode($my['email']);
				$course = $encrypt->encode($course);
				$date = $encrypt->encode($datetime);

				$data = array(
					'from_amount' => $from_amount,
					'to_amount' => $to_amount,
					'from_currency' => $from_currency,
					'to_currency' => $to_currency,
					'email' => $email,
					'course' => $course,
					'date' => $date,
					'signature' => sha1(md5($from_amount . $to_amount . $from_currency . $to_currency . $email . $course . $date . $pass))
				);

				$ch = curl_init();
				curl_setopt($ch, CURLOPT_URL, $host);
				curl_setopt($ch, CURLOPT_POST, 1);
				curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($data));
				curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
				curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
				curl_setopt($ch, CURLOPT_USERAGENT, "Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/534.16 (KHTML, like Gecko) Chrome/10.0.648.204 Safari/534.16");
				curl_setopt($ch, CURLOPT_REFERER, $host);

				$result = curl_exec($ch);
				curl_close($ch);

				$results = json_decode($result, true);

				if (!empty($results['status']) && $results['status'] == 200) {

					$transaction = $connection->beginTransaction();
					try {

						$connection->createCommand()->insert('{{users_potential_archive_group}}', array(
							'uid' => Yii::app()->user->id,
							'amount' => $bonus_sum,
							'amount_last' => $bonus_sum_last,
							'amount_all' => $amount_all,
							'amount_bonus' => $amount_bonus,
							'amount_percent' => $amount_percent,
							'date' => time(),
							'data' => serialize($bonuses),
							'status' => 1
						));
						$archive_group_id= Yii::app()->db->getLastInsertID();
						
						$connection->createCommand("UPDATE {{users_potential_archive}} SET status = 1, group_id = :group_id WHERE uid = :uid AND status = 0")
							->bindParam(":uid", Yii::app()->user->id)
							->bindParam(":group_id", $archive_group_id)
							->query();
							
							
						$connection->createCommand()->insert('{{users_potential}}', array(
							'gid' => 0,
							'uid' => Yii::app()->user->id,
							'cuid' => Yii::app()->user->id,
							'puid' => 0,
							'fuid' => 0,
							'date' => time(),
							'dt' => 0,
							'dte' => 500,
							'deposit' => $amount_all,
							'percent' => 0.002,
							'cash_now' => 0,
							'cash_out' => 0,
							'cash_all' => 0,
							'type' => 5,
							'status' => 1,
							'newsystem' => 1,
							'archive_group' => $archive_group_id
						));
						$pid_id = Yii::app()->db->getLastInsertID();
						
						
						/*$connection->createCommand()->insert('{{users_potential_archive_ok}}', array(
							'uid' => Yii::app()->user->id,
							'aid' => $bonus['id'],
							'gid' => $bonus["gid"],
							'pid' => $bonus["pid"],
							'date' => time(),
							'status' => 1
						));
						$archive_ok_id = Yii::app()->db->getLastInsertID();

						$connection->createCommand()->insert('{{users_potential}}', array(
							'gid' => 0,
							'uid' => Yii::app()->user->id,
							'cuid' => Yii::app()->user->id,
							'puid' => 0,
							'fuid' => 0,
							'date' => time(),
							'dt' => 0,
							'dte' => 500,
							'deposit' => $amount,
							'percent' => 0.002,
							'cash_now' => 0,
							'cash_out' => 0,
							'cash_all' => 0,
							'type' => 5,
							'status' => 1
						));
						$pid_id = Yii::app()->db->getLastInsertID();*/

						$connection->createCommand("UPDATE {{users_potential_archive}} SET status = 1 WHERE uid = :uid AND status = 0")
							->bindParam(":uid", Yii::app()->user->id)
							->query();

//						$connection->createCommand("UPDATE {{users_potential_group}} SET percent = 0.002 WHERE id = :gid")
//							->bindParam(":gid", $bonus["gid"])
//							->query();

						

						$res["status"] = 200;
						$res["message"] = $results['message'];

						$transaction->commit();

					} catch (Exception $e) {
						$transaction->rollback();
						$res["message"] = $e . "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
					}

				} else {
					$res["status"] = 500;
					$res["message"] = $results['message'];
				}
			} else {
				$res["status"] = 500;
				$res["message"] = $err;
			}
			

			//##################################################################
			$connection->createCommand("DELETE FROM {{block}} WHERE uid = :uid")
				->bindParam(":uid",Yii::app()->user->id)
				->query();
			//##################################################################
				
			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	
	
	
	public function actionSetbonusInstantSendActive()
	{

		if (Yii::app()->request->isAjaxRequest) {
			Functions::access_control(1);
			$connection=Yii::app()->db;

			//Блокировка файлом ===================
			$lock = $connection->createCommand("SELECT uid, `lock` FROM {{users}} WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->queryRow();
			if ($lock['lock'] == 0) {
				$connection->createCommand("UPDATE {{users}} SET `lock` = 1 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
			} else {
				$res["status"] = 500;
				$res["message"] = "Идет обработка Вашего запроса. Обновите страницу через несколько минут и повторите попытку снова.";
				echo CJSON::encode($res);
				Yii::app()->end();
			}//Блокировка файлом ===================

			
			$err = "";

			$today =  mktime(00, 00, 00, date("m"), date("d"), date("Y"));

			$is_today = $connection->createCommand("SELECT id FROM {{users_wallet_bonus_instant}} WHERE uid = :uid AND date = :today")
				->bindParam(":uid", Yii::app()->user->id)
				->bindParam(":today", $today)
				->queryRow();

			if(!empty($is_today)) {
				$res["status"] = 500;
				$res["message"] = "Перевод мгновенных бонусов доступен один раз в день.";
				$connection->createCommand("UPDATE {{users}} SET `lock` = 0 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
				echo CJSON::encode($res);
				Yii::app()->end();
			}

			$wallet_prise = $connection->createCommand("SELECT id, cash_now  FROM {{users_wallet}} WHERE uid = :uid AND type = 5 AND status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->queryRow();

			$wallet_active = $connection->createCommand("SELECT id, cash_now  FROM {{users_wallet}} WHERE uid = :uid AND type = 1 AND status = 1")
				->bindParam(":uid", Yii::app()->user->id)
				->queryRow();

			
			$wallet_prise['cash_now'] = intval($wallet_prise['cash_now'] * 100) / 100;
			$amount = $wallet_prise['cash_now'];

			if(empty($wallet_prise) || empty($wallet_active))
				$err .= "<li>Призовые бонусы временно недоступны.</li>";

			if($amount <= 0)
				$err .= "<li>Недостаточная сумма для перевода.</li>";

			if ((Yii::app()->user->id > 0) && ($err == "")) {

				$transaction = $connection->beginTransaction();
				try {

					$connection->createCommand()->insert('{{users_wallet_bonus_instant}}', array(
						'uid' => Yii::app()->user->id,
						'wid' => $wallet_prise['id'],
						'date' => $today,
						'amount' => $wallet_prise['cash_now'],
						'hash' => Yii::app()->user->id . "." . $today
					));

					$connection->createCommand("UPDATE {{users_wallet}} SET cash_now = cash_now + :money WHERE type = 1 AND status = 1 AND uid = :uid AND id = :id")
						->bindParam(":id", $wallet_active["id"])
						->bindParam(":uid", Yii::app()->user->id)
						->bindParam(":money", $wallet_prise['cash_now'])
						->query();

					$connection->createCommand("UPDATE {{users_wallet}} SET cash_all = cash_all + cash_now, cash_now = cash_now - :money WHERE type = 5 AND status = 1 AND uid = :uid AND id = :id")
						->bindParam(":id", $wallet_prise["id"])
						->bindParam(":uid", Yii::app()->user->id)
						->bindParam(":money", $wallet_prise['cash_now'])
						->query();

					//Вставляем транзакцию
					$connection->createCommand()->insert('{{utransactions2}}', array('did' => 0, 'uid' => Yii::app()->user->id, 'ruid' => Yii::app()->user->id, 'amount' => $wallet_prise["cash_now"], 'amount_now' => $wallet_active["cash_now"] + $wallet_prise["cash_now"], 'date' => time(), 'type' => 1, 'status' => 1, 'action' => 32));

					$transaction->commit();
					//Позитивный результат
					$res["status"] = 200;
					$res["message"] = "Перевод " .$wallet_prise['cash_now']. " BP  мгновенных бонусов в активные прошел успешно.";
				} catch (Exception $e) {
					$transaction->rollback();
					$res["status"] = 500;
					$res["message"] = "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
					$connection->createCommand("UPDATE {{users}} SET `lock` = 0 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
				}

			} else {
				//Хакерская атака - подмена данных
				$res["status"] = 500;
				$res["message"] = "Возникла ошибка при переводе." . $err;
			}

			$connection->createCommand("UPDATE {{users}} SET `lock` = 0 WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->query();
			echo CJSON::encode($res);
			Yii::app()->end();
		}

	}
	
	
	
	public function actionGetWalletInstantExchange()
	{

		if (Yii::app()->request->isAjaxRequest) {
			$connection = Yii::app()->db;
			$res = array();

			if(Yii::app()->user->id > 0) {

				$res["transactions"] = $connection->createCommand("SELECT id, uid, amount, FROM_UNIXTIME(date, '%d.%m.%Y %H:%i') as date, wallet, status, confirm_status FROM {{control_userpay}} WHERE uid = :uid")
					->bindParam(":uid", Yii::app()->user->id)
					->queryAll();

				$res["status"] = 200;
				
			} else {
				
				$res["status"] = 500;
				
			}

			echo CJSON::encode($res);
			Yii::app()->end();
		}

	}
	
	
	
	public function actionSetWalletInstantExchangeNew()
	{	
		if (Yii::app()->request->isAjaxRequest && !Yii::app()->user->isGuest) {
			$res = array();
			$connection = Yii::app()->db;
			
			
			//##################################################################
			$db_transaction = $connection->beginTransaction();
			try {
				$connection->createCommand()->insert('{{block}}', array(
					'uid' => Yii::app()->user->id,
					'date' => time()
				));
						
				$db_transaction->commit();
	
			} catch (Exception $e) {
				$db_transaction->rollback();
				$res["message"] = "Идет обработка предыдущего запроса. Обновите страницу и повторите попытку снова.";
				echo CJSON::encode($res);
				Yii::app()->end();

			}
			//##################################################################
			
			$amount = doubleval($_POST['amount']);
			$walletms = mysql_escape_string(htmlspecialchars(strip_tags($_POST['wallet'])));
			
			$amount = intval($amount * 100) / 100;

			$orders = $connection->createCommand("SELECT * FROM {{control_userpay}} WHERE uid = :uid AND status IN (0,1)")
				->bindParam(":uid", Yii::app()->user->id)
				->queryRow();
				
			$wallet_info = $connection->createCommand("SELECT * FROM {{users_wallet}} WHERE uid = :uid AND type = 3")
				->bindParam(":uid", Yii::app()->user->id)
				->queryRow();

			$err = '';
			
			if(!empty($orders)) {
				$err .= "<li>У вас есть необработанные заявки.</li>";
			}
			
			if($amount > $wallet_info["cash_now"]) {
				$err .= "<li>У вас недостаточно средств для подачи $amount BP.</li>";
			}
			
			if($amount <= 0) {
				$err .= "<li>Недопустима сумма для подачи заявки.</li>";
			}
			
			$walletms = str_replace(" ", "", $walletms);
			$pattern = '/^\d{16}$/';
			
			if (!preg_match($pattern, $walletms) || !Functions::is_valid_credit_card($walletms)) {
			    $err .= '<li>Неверный формат номера кошелька в Money Storage.</li>';   
			}
			
			
			//Наш кошелек
			$wallet = $connection->createCommand("SELECT * FROM {{users_wallet}} WHERE uid = :uid AND type = 3 AND status = 1")->bindParam(":uid", Yii::app()->user->id)->queryRow();
			$my = $connection->createCommand("SELECT uid, CONCAT(name, ' ', fio) as 'fio' FROM {{usersinfo}} WHERE uid = :uid")->bindParam(":uid", Yii::app()->user->id)->queryRow();

			//Информация получателя
			$user_to_uid = 201378;
			
			$user_to = $connection->createCommand("SELECT uid, CONCAT(name, ' ', fio) as 'fio' FROM {{usersinfo}} WHERE uid = :uid AND status = 1")->bindParam(":uid", $user_to_uid)->queryRow();
			$wallet_to = $connection->createCommand("SELECT * FROM {{users_wallet}} WHERE uid = :uid AND type = 3 AND status = 1")->bindParam(":uid", $user_to_uid)->queryRow();

			
			if ($err == "") {
				
				$transaction = $connection->beginTransaction();
					try {
							
							$connection->createCommand()->insert('{{control_userpay}}', array(
								'uid' => Yii::app()->user->id,
								'amount' => $amount,
								'date' => time(),
								'status' => 0,
								'currency' => 'PM-USD',
								'wallet' => $walletms
							));
							
						$connection->createCommand("UPDATE {{users_wallet}} SET cash_now = cash_now - :amount WHERE uid = :uid AND type = 3 AND status = 1; UPDATE {{users_wallet}} SET cash_now = cash_now + :amount WHERE uid = :touid AND type = 3 AND status = 1")
						->bindParam(":amount", $amount)
						->bindParam(":uid", Yii::app()->user->id)
						->bindParam(":touid", $user_to_uid)
						->query();
							
						
						$transaction->commit();
						$res["date"] = date("d.m.Y H:i:s",time());
						$res["status"] = 200;
						$res["message"] = "Заявка успешно подана на рассмотрение.";
						
					} catch (Exception $e) {
						$transaction->rollback();
						$res["status"] = 500;
						$res["message"] = $e . "Сервер временно недоступен. Обновите страницу и повторите попытку снова.";
					}
			
			} else {
			
				$res["status"] = 500;
				$res["message"] = "Возникла ошибка." . $err;
			
			}
			
			//##################################################################
			$connection->createCommand("DELETE FROM {{block}} WHERE uid = :uid")
				->bindParam(":uid",Yii::app()->user->id)
				->query();
			//##################################################################

			echo CJSON::encode($res);
			Yii::app()->end();
		}
	}
	
	
	
	
	
	

	

	/**
	 * This is the action to handle external exceptions.
	 */
	public function actionError()
	{
		if ($error = Yii::app()->errorHandler->error) {
			if (Yii::app()->request->isAjaxRequest)
				echo $error['message'];
			else
				$this->render('error', $error);
		}
	}


}